(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42248,       1191]*)
(*NotebookOutlinePosition[     46401,       1310]*)
(*  CellTagsIndexPosition[     46288,       1303]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["3.   The Cross Product", "Title"],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  InitializationCell->True],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(\(\(Needs["\<TContinuumMechanics1`TContinuumMechanics`\>"]\)\(\n\)
    \)\), "\n", 
    \(\(numequ = 1;\)\), "\[IndentingNewLine]", 
    \(ResultFrame[i_] := 
      StyleForm[
        SequenceForm["\<      \>", 
          i, "\<      (3.\>", \(numequ++\), "\<)\>"], 
        Background -> RGBColor[0, 1, 0], Magnification -> 1.2]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}, {green, ForestGreen}, {star, 
        SuperStar}, {blue, Blue}, {hat, OverHat}, {tilde, Overtilde}, {bar, 
        OverBar}]\), "\[IndentingNewLine]", 
    \(\(black = Identity;\)\), "\[IndentingNewLine]", 
    \(\(DeclareBaseIndices[{1, 2, 3}];\)\), "\n", 
    \(\({NDim, BaseIndices};\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DefineTensorShortcuts[{{\[DoubleStruckE], u, v, w, dr, ds, 
            dt, \[Gamma]}, 1}, {{g, \[Beta], a}, 2}, {{\[Epsilon], e}, 
          3}];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
The following values are taken as an example of a (red) basis frame :\
\>", "Text"],

Cell[BoxData[{\(SetMetricValues[g, 
      IdentityMatrix[3]]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"RedBasisVectors", "=", 
        RowBox[{"(", GridBox[{
              {"1", "1", "0"},
              {"0", "1", "2"},
              {"1", "0", "1"}
              }], ")"}]}], ";", 
      RowBox[{"RedMetric", "=", 
        StyleBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "1", "1"},
                {"1", "5", "2"},
                {"1", "2", "2"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
          FontFamily->"Courier",
          FontSize->12]}], 
      StyleBox[";",
        FontFamily->"Courier",
        FontSize->
          12]}], "\[IndentingNewLine]", \
\(SetTensorValueRules[\[DoubleStruckE]d[red@i], 
      RedBasisVectors]\), "\[IndentingNewLine]", \(SetTensorValueRules[\
\[DoubleStruckE]u[red@i], 
      Inverse[RedBasisVectors // 
          Transpose]]\), "\[IndentingNewLine]", \(SetMetricValueRules[g, 
      RedMetric, red]\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Generalities", "Section",
  CellTags->"Generalities"],

Cell[CellGroupData[{

Cell["Completely antisymmetric tensor ", "Subsection"],

Cell[BoxData[
    \(MapThread[{#, "\<\[DoubleLongRightArrow]\>", # /. 
            PermutationSymbolRule[\[Epsilon]]} &, {{\[Epsilon]ddd[a, c, 
            b], \[Epsilon]uuu[a, b, c] // ToFlavor[red], \[Epsilon]ddd[2, 3, 
            1], \[Epsilon]ddd[2, 3, 1] // ToFlavor[red], \[Epsilon]ddd[red@2, 
            3, 1], \[Epsilon]ddd[1, 3, 2], \[Epsilon]ddd[1, 2, 
            2], \[Epsilon]dud[1, 3, 2]}}]\)], "Input"],

Cell[BoxData[{
    \(Tensor[T, {i, j, k}, {Void, Void, Void}] \[Epsilon]ddd[i, j, 
        k]\), "\[IndentingNewLine]", 
    \(\((% // EinsteinSum[])\) /. 
      PermutationSymbolRule[\[Epsilon]]\)}], "Input"],

Cell[TextData[{
  "Remark : ",
  StyleBox["AntiSymmetric",
    FontWeight->"Bold"],
  " includes the factor 1/ n!"
}], "Text"],

Cell[BoxData[{
    \(Tensor[T, {i, j, k}, {Void, Void, Void}]\), "\[IndentingNewLine]", 
    \(\((% // AntiSymmetric[{i, j, k}])\) /. {i -> 1, j -> 2, 
        k -> 3}\)}], "Input"],

Cell[TextData[{
  "Definition of the operator",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["CrossProductExpansion",
    FontWeight->"Bold"],
  " which calculate the ",
  StyleBox["ScalarTripleProduct",
    FontWeight->"Bold"],
  " of the basis set, and the ",
  StyleBox["Cross Product",
    FontWeight->"Bold"],
  " of two basis vectors.:\nCrossProductExpansion[\[DoubleStruckE]_,e_][expr] \
expand the triple scalar products and the cross products expressed in a given \
basis \[DoubleStruckE] into ",
  StyleBox["LeviCivita symbols",
    FontWeight->"Bold"],
  " e. The considered space is three-dimensional."
}], "Text"],

Cell[TextData[{
  StyleBox["In an ",
    FontSlant->"Plain"],
  StyleBox["orthonormal",
    FontSlant->"Plain",
    FontVariations->{"Underline"->True}],
  StyleBox[" (blue-)basis, ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["e", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 0.0, 0.0, 1.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 0.0, 0.0, 1.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["k",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 0.0, 0.0, 1.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                blue[ i], ShowContents -> False], 
              StyleForm[ 
                blue[ j], ShowContents -> False], 
              StyleForm[ 
                blue[ k], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0.0, 0.0, 1.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0.0, 0.0, 1.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["k",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0.0, 0.0, 1.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              blue[ i], 
              blue[ j], 
              blue[ k]],
            Editable->False]], TraditionalForm]]],
  StyleBox[" is simply a ",
    FontSlant->"Plain"],
  StyleBox["PermutationSymbol [e]",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  StyleBox[" and the cross product of two basis vectors is given by ",
    FontSlant->"Plain"]
}], "Text",
  FontSlant->"Italic"],

Cell[BoxData[{
    \(\(\[DoubleStruckE]u[blue@i]\[Cross]\[DoubleStruckE]u[blue@j] // 
        CrossProductExpansion[\[DoubleStruckE], e, k]\) // 
      EinsteinSum[]\), "\[IndentingNewLine]", 
    \(\((% // ArrayExpansion[blue@i, blue@j])\) /. 
      PermutationSymbolRule[e]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determinants", "Subsection"],

Cell[TextData[{
  "The two kinds of ",
  "PermutationSymbolRule",
  "[\[Epsilon]] ",
  StyleBox[" \[Epsilon]ddd[i,j,k]",
    FontWeight->"Bold"],
  " or ",
  StyleBox["\[Epsilon]uuu[i,j,k]",
    FontWeight->"Bold"],
  " also allow to calculate determinants (in the base system) :"
}], "Text"],

Cell[BoxData[{
    \(\(detA = \((\((A = 
                  adu[1, i] adu[2, j] adu[3, k] \[Epsilon]ddd[i, j, k])\) // 
              EinsteinSum[])\) /. 
          PermutationSymbolRule[\[Epsilon]];\)\), "\[IndentingNewLine]", 
    \(\(detA1 = \((\((A1 = 
                  adu[i, 1] adu[j, 2] adu[k, 3] \[Epsilon]uuu[i, j, k])\) // 
              EinsteinSum[])\) /. 
          PermutationSymbolRule[\[Epsilon]];\)\), "\[IndentingNewLine]", 
    \(A\), "\[IndentingNewLine]", 
    \(A1\), "\[IndentingNewLine]", 
    \(detA\), "\[IndentingNewLine]", 
    \(detA == detA1\), "\[IndentingNewLine]", 
    \(A =. ; A1 =. \)}], "Input"],

Cell["\<\
and of course we can verify the equivalence of the above detA with the build \
in Det function :\
\>", "Text"],

Cell[BoxData[{
    \(adu[i, j] // ArrayExpansion[{i, j}]\), "\[IndentingNewLine]", 
    \(Det[%] == detA\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determinants of the metric tensors g", "Subsection"],

Cell[BoxData[
    \(Map[{# // 
            Det, "\<\[DoubleLongRightArrow]\>", \((\(# // 
                    ArrayExpansion[red@i, red@j]\) // Det)\) /. 
              TensorValueRules[g] // MetricSimplify[g]} &, {guu[red@i, 
          red@j], gdd[red@i, red@j], gud[red@i, red@j]}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transformation tensors \[Beta] ", "Subsection"],

Cell["\<\
Example : Basis change from the black to the red basis (see Chapter 1)\
\>", "Text"],

Cell[BoxData[{
    \(\[DoubleStruckE]u[j] . \[DoubleStruckE]d[red@i] // 
      EvaluateDotProducts[\ \[DoubleStruckE], \[Beta]]\), \
"\[IndentingNewLine]", 
    \(\[DoubleStruckE]d[
        red@i] == \[DoubleStruckE]d[j] %\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Beta]]\)}], "Input"],

Cell[BoxData[
    \(SetTensorValueRules[\[Beta]ud[j, 
        red@i], \((\[DoubleStruckE]d[red@i] // ArrayExpansion[red@i])\) /. 
        TensorValueRules[\[DoubleStruckE], g]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Determinants of the transformation tensors \[Beta] \
\>", "Subsection"],

Cell[TextData[{
  "Introduction of a determinant \[CapitalDelta] of a transformation matrix \
\[Beta] between the initial flavor, flavor1, to the final flavor, flavor2.\n\
",
  StyleBox["Note",
    FontColor->RGBColor[1, 0, 0]],
  " : I shall have to ",
  StyleBox["check the homogeneity of the notations",
    FontVariations->{"Underline"->True}],
  " between initial and final situations (see ToFlavor for instance, for \
which it is the reverse)."
}], "Text"],

Cell[BoxData[
    \(\(\[CapitalDelta][\[Beta]_]\)[flavor1_, flavor2_] := 
      Det[\(Tensor[\[Beta], {flavor1@i, Void}, {Void, flavor2@j}] // 
            ArrayExpansion[flavor1@i]\) // 
          ArrayExpansion[flavor2@j]]\)], "Input"],

Cell[BoxData[
    \(\(\[CapitalDelta][\[Beta]]\)[red, blue]\)], "Input"],

Cell[BoxData[
    \(\(\(\(\[CapitalDelta][\[Beta]]\)[black, 
        red]\)\(/.\)\(TensorValueRules[\[Beta]]\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Introduction of the elementary volume formed by the basis set ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubsuperscriptBox[
            StyleBox["\[DoubleStruckE]",
              FontWeight->"Plain"], 
            InterpretationBox[
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"],
              SequenceForm[ 
                red[ i]],
              Editable->False], 
            InterpretationBox[
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]],
              Editable->False]],
          FontSize->18], TraditionalForm]]],
  " (for the red flavor) associated to g"
}], "Text"],

Cell[BoxData[{
    \(g[flavor_] := 
      Det[gdd[flavor@i, flavor@j] // ArrayExpansion[flavor@i, flavor@j]] /. 
        TensorValueRules[g]\), "\[IndentingNewLine]", 
    \(g[black] := 
      Det[gdd[i, j] // ArrayExpansion[i, j]] /. 
        TensorValueRules[g]\)}], "Input"],

Cell[BoxData[
    \(g[red]\)], "Input"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          RowBox[{
          "From", " ", "the", " ", "relation", " ", "between", " ", "the", 
            " ", "two", " ", "basis", "    ", 
            TagBox[
              StyleBox[
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["h",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                          h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          StyleForm[ 
                          k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              TagBox[
                                StyleBox["h",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            StyleForm[ 
                            h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False], 
                          StyleForm[ 
                            StyleForm[ 
                            k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        StyleForm[ h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        
                        StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                       
                      SequenceForm[ 
                        StyleForm[ 
                          StyleForm[ 
                          h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False], 
                        StyleForm[ 
                          StyleForm[ 
                          k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"],
                FontFamily->"Courier",
                FontSize->16],
              (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)]}],
          "Text",
          FontWeight->"Plain",
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox["=",
          "Text",
          FontWeight->"Plain",
          FontVariations->{"CompatibilityType"->0}], 
        StyleBox[" ",
          "Text",
          FontWeight->"Plain",
          FontVariations->{"CompatibilityType"->0}], 
        RowBox[{
          StyleBox[
            FormBox[
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["g", 
                        InterpretationBox[\(i\[InvisibleSpace]j\),
                          SequenceForm[ i, j],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["i",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["j",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ i, ShowContents -> False], 
                            StyleForm[ j, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ g, 
                        SequenceForm[ i, j], 
                        SequenceForm[ 
                          StyleForm[ i, ShowContents -> False], 
                          StyleForm[ j, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"],
                  FontFamily->"Courier",
                  FontSize->16],
                (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)],
              "TraditionalForm"],
            "Text",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox[" ",
            "Text",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox[
            FormBox[
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Beta]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["i",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["h",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)]}],
                          SequenceForm[ 
                            StyleForm[ i, ShowContents -> False], 
                            StyleForm[ 
                            h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{"i", "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                TagBox[
                                  StyleBox["h",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ i, 
                            StyleForm[ 
                              StyleForm[ 
                              h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                              ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Beta], 
                        SequenceForm[ 
                          StyleForm[ i, ShowContents -> False], 
                          StyleForm[ 
                          h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]], 
                        SequenceForm[ i, 
                          StyleForm[ 
                            StyleForm[ 
                            h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"],
                  FontFamily->"Courier",
                  FontSize->16],
                (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)],
              "TraditionalForm"],
            "Text",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox["  ",
            "Text",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox[
            TagBox[
              StyleBox[
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Beta]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["i",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)]}],
                        SequenceForm[ 
                          StyleForm[ i, ShowContents -> False], 
                          StyleForm[ 
                          k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{"i", "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ i, 
                          StyleForm[ 
                            StyleForm[ 
                            k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Beta], 
                      SequenceForm[ 
                        StyleForm[ i, ShowContents -> False], 
                        StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                       
                      SequenceForm[ i, 
                        StyleForm[ 
                          StyleForm[ 
                          k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"],
                FontFamily->"Courier",
                FontSize->16],
              (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)],
            "Text",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], " "}]}]],
    FontFamily->"Times"]
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\(we\ deduce\ that\ \ \ g[red]\),
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["=",
        FontFamily->"Times"], 
      RowBox[{
        RowBox[{
          StyleBox["det",
            FontFamily->"Times"], 
          StyleBox["[",
            FontFamily->"Times"], 
          FormBox[
            SubsuperscriptBox["g", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox["h",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox["k",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
                
                SequenceForm[ 
                  StyleForm[ h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                Editable->False], 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["h",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ 
                    StyleForm[ h, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False]],
                Editable->False]],
            "TraditionalForm"], 
          StyleBox["]",
            FontFamily->"Times"]}], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["=",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        RowBox[{
          StyleBox[
            RowBox[{
              RowBox[{"det", "[", 
                FormBox[
                  SubscriptBox["g", 
                    InterpretationBox[\(i\[InvisibleSpace]j\),
                      SequenceForm[ i, j],
                      Editable->False]],
                  "TraditionalForm"], "]"}], " ", 
              "/", \(\[CapitalDelta]\^2\)}],
            FontFamily->"Times"], 
          StyleBox["  ",
            FontFamily->"Times"], 
          StyleBox["=",
            FontFamily->"Times"], 
          RowBox[{
            RowBox[{
              StyleBox["1",
                FontFamily->"Times"], "/", \(\[CapitalDelta]\^2\)}], 
            StyleBox["         ",
              FontFamily->"Times"], 
            RowBox[{
              StyleBox["(",
                FontFamily->"Times"], 
              StyleBox["  ",
                FontFamily->"Times"], 
              RowBox[{
                StyleBox[\(with\ \ \ \[CapitalDelta]\),
                  FontFamily->"Times"], 
                StyleBox["=",
                  FontFamily->"Times"], 
                RowBox[{
                  RowBox[{
                    StyleBox["\[CapitalDelta]",
                      FontFamily->"Times"], \((red, black)\)}], " ", "=", " ",
                   
                  RowBox[{
                    RowBox[{"1", "/", 
                      StyleBox["\[CapitalDelta]",
                        FontFamily->"Times"]}], \((black, red)\)}]}]}], "  ", 
              ")"}]}]}]}]}]], "Text",
  FontFamily->"Times"],

Cell[BoxData[
    \(ResultFrame[\ \ \ 1\/\[CapitalDelta] == \@\[ScriptG][flavor]\ \ \ ]\)], \
"Input",
  CellOpen->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basis Change of any tensor", "Subsection"],

Cell["Examples :", "Text"],

Cell[BoxData[
    \(MapThread[{# // 
            ToFlavor[red, 
              blue], "\<\[DoubleLongLeftArrow]\>", # // \
\((BasisChange[\[Beta], red])\)} &, {{Tensor[
            T, {blue@i, blue@j}, {Void, Void}], 
          Tensor[T, {blue@i, Void}, {Void, blue@j}], 
          Tensor[T, {Void, Void, Void}, {blue@i, blue@j, blue@k}], 
          Tensor[T, {blue@i, blue@j, blue@k}, {Void, Void, Void}], 
          Tensor[T, {blue@i, Void, blue@j}, {Void, blue@k, 
              Void}]}}]\)], "Input"],

Cell[TextData[{
  "We can now extend the antisymmetric tensor   \[Epsilon] ddd [ i , j , k ] \
to general coordinate systems and define a tensor eddd [ i , j , k ] and \
equivalently a tensor  euuu [ i , j , k ] .",
  Cell[BoxData[""]],
  " These tensors are called ",
  StyleBox["permutation tensors",
    FontColor->RGBColor[0, 0, 1]],
  " or ",
  StyleBox["Levi-Civita tensors",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Levi-Civita tensors", "Subsection"],

Cell[BoxData[{
    \(eddd[red@i, red@j, red@k]\), "\[IndentingNewLine]", 
    \(% /. \(LeviCivitaRule[e, \[Epsilon]]\)[g$, 
        red]\), "\[IndentingNewLine]", 
    \(% /. g$ -> g\), "\[IndentingNewLine]", 
    \(\(Tensor[T, red /@ {i, j, k}, {Void, Void, Void}] % // 
        EinsteinSum[];\)\), "\[IndentingNewLine]", 
    \(% /. PermutationSymbolRule[\[Epsilon]] // Factor\)}], "Input"],

Cell[BoxData[{
    \(euuu[red@i, red@j, red@k] /. \(LeviCivitaRule[e, \[Epsilon]]\)[g$, 
        red]\), "\[IndentingNewLine]", 
    \(% /. g$ -> g\), "\[IndentingNewLine]", 
    \(\(Tensor[T, {Void, Void, Void}, red /@ {i, j, k}] % // 
        EinsteinSum[];\)\), "\[IndentingNewLine]", 
    \(% /. PermutationSymbolRule[\[Epsilon]] // Factor\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cross Product", "Section",
  CellTags->"Cross Product"],

Cell[TextData[{
  "We also introduce here, to be complete, the standard notation used in the \
",
  StyleBox["Standard Packages",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(<< Calculus`VectorAnalysis`\)], "Input"],

Cell[BoxData[
    \(CrossProduct[{a1, a2, a3}, {b1, b2, b3}]\)], "Input"],

Cell["We can define for convenience :", "Text"],

Cell[BoxData[
    \(\(coord[flavor_]\)[a_] := 
      a[flavor@k] // ArrayExpansion[flavor@k]\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(CrossProduct[\(coord[red]\)[uu], \(coord[red]\)[vu]]\)], "Input"],

Cell[BoxData[
    \(\(coord[black]\)[uu]\)], "Input"],

Cell[BoxData[
    \(CrossProduct[\(coord[black]\)[uu], \(coord[black]\)[vu]]\)], "Input"],

Cell[BoxData[{
    \(eddd[i, j, k] uu[i] vu[j]\), "\[IndentingNewLine]", 
    \(\(\((\(% // EinsteinSum[]\) // ArrayExpansion[k])\) /. \(LeviCivitaRule[
              e, \[Epsilon]]\)[g, black]\) /. 
        PermutationSymbolRule[\[Epsilon]] // Factor\)}], "Input"],

Cell[BoxData[{
    \(eddd[red@i, red@j, red@k] uu[red@i] 
      vu[red@j]\), "\[IndentingNewLine]", 
    \(\(\((\(% // EinsteinSum[]\) // 
              ArrayExpansion[red@k])\) /. \(LeviCivitaRule[e, \[Epsilon]]\)[
            g, red]\) /. PermutationSymbolRule[\[Epsilon]] // 
      Factor\)}], "Input"],

Cell["The \"black\" basis is orthonormal. But not the red's one  :", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cross", "[", 
          StyleBox[\(\[DoubleStruckE]u[red@1], \[DoubleStruckE]u[red@2]\),
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}], 
        StyleBox["  ",
          FontSize->12], "-", 
        StyleBox[\(\[DoubleStruckE]u[red@3]\),
          FontSize->12]}], 
      StyleBox["   ",
        FontSize->12], 
      "/.", \(TensorValueRules[\[DoubleStruckE]]\)}]], "Input"],

Cell["Consider the three following vectors :", "Text"],

Cell[BoxData[{
    \(\(\[DoubleStruckU] = 
        uu[i] \[DoubleStruckE]d[i];\)\), "\[IndentingNewLine]", 
    \(\(\[DoubleStruckV] = 
        vu[j] \[DoubleStruckE]d[j];\)\), "\[IndentingNewLine]", 
    \(\(\[DoubleStruckW] = wd[k] \[DoubleStruckE]u[k];\)\)}], "Input"],

Cell[BoxData[{
    \(\((\((\(\((\[DoubleStruckU]\[Cross]\[DoubleStruckV])\) . \
\[DoubleStruckW] // 
              ToFlavor[red]\) // \(LinearBreakout[
                Cross]\)[\[DoubleStruckE]d[_], \[DoubleStruckE]u[_]])\) // 
        CrossProductExpansion[\[DoubleStruckE], e, 
          h])\)\), "\[IndentingNewLine]", 
    \(\((% // 
        EvaluateDotProducts[\[DoubleStruckE], g, 
          False])\)\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input"],

Cell[TextData[{
  StyleBox["ScalarTripleProduct ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " is defined in the package  ",
  ButtonBox["Calculus`VectorAnalysis`",
    ButtonData:>{"Calculus`VectorAnalysis`", "1.15"},
    ButtonStyle->"AddOnsLink"],
  " . We define here the operation ",
  StyleBox["MetricTripleProduct",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " which groups all the operation performed above"
}], "Text"],

Cell[BoxData[
    \(\((\(\((\[DoubleStruckU]\[Cross]\[DoubleStruckV])\) . \[DoubleStruckW] // 
          ToFlavor[red]\) // 
        MetricTripleProduct[\[DoubleStruckE], g, e, h])\)\)], "Input"],

Cell[BoxData[
    \(\((% // MetricSimplify[g])\)\)], "Input"],

Cell[TextData[{
  "Note about raising and lowering indices : MetricSimplify acts on the first \
index in the alphabetic order ( ",
  StyleBox["i$",
    FontWeight->"Bold"],
  " < ",
  StyleBox["k",
    FontWeight->"Bold"],
  " <",
  StyleBox[" l ",
    FontWeight->"Bold"],
  ") and it is necessary to change the indices to have the convenient \
lowering or raising :"
}], "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(\(\((\[DoubleStruckU]\[Cross]\[DoubleStruckV])\) . \[DoubleStruckW] // 
        MetricTripleProduct[\[DoubleStruckE], g, e, i$]\) // 
      MetricSimplify[g]\), "\[IndentingNewLine]", 
    \(\(\((\[DoubleStruckU]\[Cross]\[DoubleStruckV])\) . \[DoubleStruckW] // 
        MetricTripleProduct[\[DoubleStruckE], g, e, l]\) // 
      MetricSimplify[g]\)}], "Input",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\@g[red]\ is\ the\ volume\ of\ parallelepipedon\ which\ has\ the\ \
convariant\ \((red)\)\ base\ vectors\ for\ its\ edges . \ 
        Hence\ we\ \(\(have\)\(:\)\)\)], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Cross", "[", 
          StyleBox[\(\[DoubleStruckE]d[red@1], \[DoubleStruckE]d[red@2]\),
            FontSize->12], 
          StyleBox["]",
            FontSize->12]}], 
        StyleBox["  ",
          FontSize->12], 
        StyleBox["-",
          FontSize->12], 
        StyleBox[" ",
          FontSize->12], 
        RowBox[{\(\@g[red]\), 
          StyleBox[\(\[DoubleStruckE]u[red@3]\),
            FontSize->12]}]}], 
      StyleBox["   ",
        FontSize->12], 
      "/.", \(TensorValueRules[\[DoubleStruckE]]\)}]], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Definition of an element of surface and of volume",
  FontVariations->{"Underline"->True}]], "Subsubsection"],

Cell[BoxData[{
    \(d\[DoubleStruckR] = dru[red@i] \[DoubleStruckE]d[red@i]\), "\n", 
    \(d\[DoubleStruckS] = dsu[red@j] \[DoubleStruckE]d[red@j]\), "\n", 
    \(d\[DoubleStruckT] = dtu[red@k] \[DoubleStruckE]d[red@k]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["The volume element defined by the three vectors \
{d\[DoubleStruckR], d\[DoubleStruckS], d\[DoubleStruckT]}  is", 
    "Subsubsection"],
  StyleBox[" :", "Subsubsection"]
}], "Subsubsection"],

Cell[BoxData[
    \(dV = \(d\[DoubleStruckR]\[Cross]d\[DoubleStruckS] . d\[DoubleStruckT] // 
          MetricTripleProduct[\[DoubleStruckE], g, e, h]\) // 
        MetricSimplify[g]\)], "Input"],

Cell[TextData[StyleBox["Its explicit value is :",
  FontSlant->"Plain"]], "Text",
  FontSlant->"Italic"],

Cell[BoxData[
    \(dVval = dV /. \(LeviCivitaRule[e, \[Epsilon]]\)[g, red]\)], "Input"],

Cell[TextData[{
  "In another reference frame this volume will remain unchanged. So we must \
be very careful that only the LeviCivita (",
  StyleBox["e",
    FontWeight->"Bold"],
  " here) symbol is a tensor.",
  "\n",
  "So, the correct transformation is :"
}], "Text"],

Cell[BoxData[
    \(\((dV // ToFlavor[black, red])\) == dV\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Definition of an area element by the vector  d\[DoubleStruckCapitalA]  normal \
to it :\
\>", "Subsubsection"],

Cell[BoxData[{
    \(d\[DoubleStruckCapitalA] = \(d\[DoubleStruckR]\[Cross]
            d\[DoubleStruckS] // \(LinearBreakout[
              Cross]\)[\[DoubleStruckE]d[_], \[DoubleStruckE]u[_]]\) // 
        CrossProductExpansion[\[DoubleStruckE], e, 
          h]\), "\[IndentingNewLine]", 
    \(d\[ScriptCapitalA]d[l_] := 
      d\[DoubleStruckCapitalA] . \[DoubleStruckE]d[l] // 
        EvaluateDotProducts[\[DoubleStruckE], g]\), "\[IndentingNewLine]", 
    \(\((d\[ScriptCapitalA]\[Section][red_@k_] = 
          Tensor[d\[ScriptCapitalA], {Void}, {red@k}])\) == 
      d\[ScriptCapitalA]d[red@k]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pressure p of a fluid or a gas", "Subsection"],

Cell[TextData[{
  "Its product with an area ",
  StyleBox["dA",
    FontWeight->"Bold"],
  ",on which it acts,is a force ",
  StyleBox["d\[DoubleStruckCapitalF]",
    FontWeight->"Bold"],
  " normal to the area,i.e.it has the direction of ",
  StyleBox["d\[DoubleStruckCapitalA]",
    FontWeight->"Bold"],
  ",with components:"
}], "Text"],

Cell[BoxData[{
    \(\(d\[DoubleStruckCapitalF] = \(-p\)\ d\[DoubleStruckCapitalA];\)\), "\n\
", 
    \(dFd[red@l_] = \(-p\)\ d\[ScriptCapitalA]d[red@l]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Weight of a volume element dV", "Subsection"],

Cell[TextData[{
  "The weight ",
  StyleBox["d\[DoubleStruckCapitalW]",
    FontWeight->"Bold"],
  " of a volume element ",
  StyleBox["dV",
    FontWeight->"Bold"],
  " is a vector (",
  StyleBox["direction of the gravity field",
    FontColor->RGBColor[0, 0, 1]],
  "), the product of the volume and the specific weight ",
  StyleBox["\[CurlyCapitalUpsilon]",
    FontWeight->"Bold"],
  " :"
}], "Text"],

Cell[BoxData[
    \(\(\(\t\t\t\t\t\t\)\(\[CurlyCapitalUpsilon] := \ \[Gamma]u[
          red@l] \[DoubleStruckE]d[red@l]\[IndentingNewLine]
    \[CurlyCapitalUpsilon]\[IndentingNewLine]
    Print["\<and    dV = \>", dV]\)\)\)], "Input"],

Cell["hence", "Text"],

Cell[BoxData[
    \(\(\(\t\t\t\t\t\t\)\(d\[DoubleStruckCapitalW] = \[CurlyCapitalUpsilon]\ \
dV\)\)\)], "Input"],

Cell[TextData[{
  StyleBox["d\[DoubleStruckCapitalW]",
    FontWeight->"Bold"],
  " also remains invariant by any change of frame. Explicitly we have,"
}], "Text"],

Cell[BoxData[
    \(\((d\[DoubleStruckCapitalW] /. \(LeviCivitaRule[e, \[Epsilon]]\)[g, 
                red] // EinsteinSum[])\) /. 
        PermutationSymbolRule[\[Epsilon]] // Simplify\)], "Input"],

Cell[BoxData[
    \(\(ClearTensorShortcuts[{{\[DoubleStruckE], u, v, w, dr, ds, 
            dt, \[Gamma]}, 1}, {{g, \[Beta], a}, 2}, {{\[Epsilon], e}, 
          3}];\)\)], "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{987, 650},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"], None, Cell[ 
      "J.-F. Gouyet", "Header"]}, {
    Cell[ "Continuum Mechanics", "Header"], None, Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{True, True},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->True,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
ShowCellLabel->False,
CellLabelAutoDelete->True,
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Generalities"->{
    Cell[4275, 127, 59, 1, 41, "Section",
      CellTags->"Generalities"]},
  "Cross Product"->{
    Cell[32905, 890, 61, 1, 41, "Section",
      CellTags->"Cross Product"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Generalities", 46088, 1293},
  {"Cross Product", 46185, 1296}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 39, 0, 76, "Title"],

Cell[CellGroupData[{
Cell[1840, 57, 64, 1, 49, "Subsection",
  InitializationCell->True],
Cell[1907, 60, 448, 10, 146, "Input",
  InitializationCell->True],
Cell[2358, 72, 498, 9, 166, "Input",
  InitializationCell->True],
Cell[2859, 83, 211, 4, 46, "Input",
  InitializationCell->True],
Cell[3073, 89, 93, 2, 34, "Text"],
Cell[3169, 93, 1069, 29, 159, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4275, 127, 59, 1, 41, "Section",
  CellTags->"Generalities"],

Cell[CellGroupData[{
Cell[4359, 132, 54, 0, 49, "Subsection"],
Cell[4416, 134, 419, 6, 86, "Input"],
Cell[4838, 142, 209, 4, 66, "Input"],
Cell[5050, 148, 126, 5, 35, "Text"],
Cell[5179, 155, 181, 3, 66, "Input"],
Cell[5363, 160, 633, 18, 76, "Text"],
Cell[5999, 180, 3297, 92, 36, "Text"],
Cell[9299, 274, 289, 5, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9625, 284, 34, 0, 49, "Subsection"],
Cell[9662, 286, 292, 10, 35, "Text"],
Cell[9957, 298, 632, 13, 186, "Input"],
Cell[10592, 313, 120, 3, 34, "Text"],
Cell[10715, 318, 118, 2, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10870, 325, 58, 0, 49, "Subsection"],
Cell[10931, 327, 296, 5, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11264, 337, 53, 0, 49, "Subsection"],
Cell[11320, 339, 94, 2, 34, "Text"],
Cell[11417, 343, 299, 6, 86, "Input"],
Cell[11719, 351, 189, 3, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11945, 359, 81, 2, 49, "Subsection"],
Cell[12029, 363, 462, 11, 54, "Text"],
Cell[12494, 376, 237, 4, 66, "Input"],
Cell[12734, 382, 72, 1, 46, "Input"],
Cell[12809, 385, 131, 2, 46, "Input"],
Cell[12943, 389, 1328, 37, 35, "Text"],
Cell[14274, 428, 277, 6, 66, "Input"],
Cell[14554, 436, 39, 1, 46, "Input"],
Cell[14596, 439, 11964, 268, 35, "Text"],
Cell[26563, 709, 4279, 115, 34, "Text"],
Cell[30845, 826, 121, 3, 19, "Input",
  CellOpen->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[31003, 834, 48, 0, 49, "Subsection"],
Cell[31054, 836, 26, 0, 34, "Text"],
Cell[31083, 838, 503, 10, 126, "Input"],
Cell[31589, 850, 434, 12, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32060, 867, 41, 0, 49, "Subsection"],
Cell[32104, 869, 392, 7, 126, "Input"],
Cell[32499, 878, 357, 6, 106, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[32905, 890, 61, 1, 41, "Section",
  CellTags->"Cross Product"],
Cell[32969, 893, 172, 6, 35, "Text"],
Cell[33144, 901, 60, 1, 46, "Input"],
Cell[33207, 904, 73, 1, 46, "Input"],
Cell[33283, 907, 47, 0, 34, "Text"],
Cell[33333, 909, 138, 3, 46, "Input"],
Cell[33474, 914, 85, 1, 46, "Input"],
Cell[33562, 917, 53, 1, 46, "Input"],
Cell[33618, 920, 89, 1, 46, "Input"],
Cell[33710, 923, 265, 4, 86, "Input"],
Cell[33978, 929, 305, 6, 86, "Input"],
Cell[34286, 937, 76, 0, 34, "Text"],
Cell[34365, 939, 468, 14, 46, "Input"],
Cell[34836, 955, 54, 0, 34, "Text"],
Cell[34893, 957, 271, 5, 86, "Input"],
Cell[35167, 964, 477, 10, 86, "Input"],
Cell[35647, 976, 464, 13, 56, "Text"],
Cell[36114, 991, 195, 3, 46, "Input"],
Cell[36312, 996, 61, 1, 46, "Input"],
Cell[36376, 999, 415, 14, 71, "Text"],
Cell[36794, 1015, 417, 7, 66, "Input"],
Cell[37214, 1024, 195, 3, 34, "Text"],
Cell[37412, 1029, 596, 19, 48, "Input"],

Cell[CellGroupData[{
Cell[38033, 1052, 133, 1, 43, "Subsubsection"],
Cell[38169, 1055, 234, 3, 86, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38440, 1063, 219, 5, 43, "Subsubsection"],
Cell[38662, 1070, 195, 3, 46, "Input"],
Cell[38860, 1075, 104, 2, 34, "Text"],
Cell[38967, 1079, 88, 1, 46, "Input"],
Cell[39058, 1082, 271, 8, 55, "Text"],
Cell[39332, 1092, 71, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39440, 1098, 120, 3, 43, "Subsubsection"],
Cell[39563, 1103, 617, 11, 86, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40217, 1119, 52, 0, 49, "Subsection"],
Cell[40272, 1121, 339, 11, 35, "Text"],
Cell[40614, 1134, 166, 3, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40817, 1142, 51, 0, 49, "Subsection"],
Cell[40871, 1144, 405, 14, 35, "Text"],
Cell[41279, 1160, 236, 4, 86, "Input"],
Cell[41518, 1166, 21, 0, 34, "Text"],
Cell[41542, 1168, 112, 2, 46, "Input"],
Cell[41657, 1172, 163, 4, 35, "Text"],
Cell[41823, 1178, 200, 3, 46, "Input"],
Cell[42026, 1183, 182, 3, 46, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

