(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1792718,      35992]*)
(*NotebookOutlinePosition[   1797041,      36115]*)
(*  CellTagsIndexPosition[   1796878,      36107]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4.   Stress", "Title"],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  InitializationCell->True],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(\(\(Needs["\<TContinuumMechanics1`TContinuumMechanics`\>"]\)\(\n\)
    \)\), "\n", 
    \(\(numequ = 1;\)\), "\[IndentingNewLine]", 
    \(ResultFrame[i_] := 
      StyleForm[
        SequenceForm["\<      \>", 
          i, "\<      (4.\>", \(numequ++\), "\<)\>"], 
        Background -> RGBColor[0, 1, 0], Magnification -> 1.2]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}, {green, ForestGreen}, {star, 
        SuperStar}, {blue, Blue}, {hat, OverHat}, {tilde, Overtilde}, {bar, 
        OverBar}]\), "\[IndentingNewLine]", 
    \(\(black = Identity;\)\), "\[IndentingNewLine]", 
    \(\(DeclareBaseIndices[{1, 2, 3}];\)\), "\n", 
    \(\({NDim, BaseIndices};\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DefineTensorShortcuts[{{\[DoubleStruckE], da, db, dc, 
            u, \[ScriptCapitalE], \[Sigma], d\[ScriptCapitalA]}, 
          1}, {{g, \[Sigma], \[ScriptCapitalE], \[ScriptCapitalE]\[Section], 
            d\[ScriptCapitalE], \[Gamma], \[Tau], F}, 2}, {{e}, 
          3}, {{\[DoubleStruckCapitalE]}, 4}];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
The following values are taken as an example of a (red) basis frame :\
\>", "Text"],

Cell[BoxData[{\(SetMetricValues[g, 
      IdentityMatrix[3]]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"RedBasisVectors", "=", 
        RowBox[{"(", GridBox[{
              {"1", "1", "0"},
              {"0", "1", "2"},
              {"1", "0", "1"}
              }], ")"}]}], ";", 
      RowBox[{"RedMetric", "=", 
        StyleBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "1", "1"},
                {"1", "5", "2"},
                {"1", "2", "2"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
          FontFamily->"Courier",
          FontSize->12]}], 
      StyleBox[";",
        FontFamily->"Courier",
        FontSize->
          12]}], "\[IndentingNewLine]", \
\(SetTensorValueRules[\[DoubleStruckE]d[red@i], 
      RedBasisVectors]\), "\[IndentingNewLine]", \(SetTensorValueRules[\
\[DoubleStruckE]u[red@i], 
      Inverse[RedBasisVectors // 
          Transpose]]\), "\[IndentingNewLine]", \(SetMetricValueRules[g, 
      RedMetric, red]\)}], "Input",
  InitializationCell->True],

Cell["and from equation (2.5) :", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(Tensor[\[ScriptCapitalE]\[Section], {Void, Void}, {i_, 
          j_}] := \((PartialD[ud[red@i], red@j] + 
            PartialD[ud[red@j], red@i])\)/2\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Stress tensor (\[Sigma])", "Section",
  CellTags->"Stress tensor"],

Cell["The upper figure works for Mac, the lower for PC.", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[GraphicsData["PICT", "\<\
On@1802@0RH1c@0A0_l<0?ooool0T0000B00007=00029P000000000N00402P4P
09029P7=09X0003oQ?@1802@0RH1c@0000@0000004P000180000400P00<02000
0005o9j@1ObN[04P09029P7=0B00T08V0Ld0000JPOoSoo`0POn1olWoo021oh7o
bOol087oiol0487oPOn1oh7oPOn1oh7ob_l0487oPOn1oh7oPOn1oh7ob_l0487o
POn1oh7oPOn1oh7ob_l0487oPOn1oh7oPOn1oh7ob_l0487oPOn1oh7oPOn1oh7o
b_l0487oPOn1oh7oPOn1oh7ob_l0487oPOn1oh7oPOn1oh7ob_l0487oPOn1oh7o
POn1oh7ob_l0487oPOn1oh7oPOn1oh7ob_l0487oPOn1oh7oPOn1oh7ob_l0487o
POn1oh7oPOn1oh7ob_l0487oPOn1oh7oPOn1oh7ob_l0487oPOn1oh7oPOn1oh7o
b_l0487oPOn1oh7oPOn1oh7ob_l0487oPOn1oh7oPOn1oh7ob_l0687oT_l0P87o
POo5o`20POn1olGo082do`0KPOnDo`60087oPOo6o`60087oPOo6o`600;?o02B1
oiOo1<100010POn1olWo1<100010POn1olWo1<100010/ol09h7oVOl1`43m0030
POn1ol_o0L10o@00`87oPOo;o`70@?d00<2co`0iPOnio`CgUHSVP>Wo0L20nP21
oh7oj_l4miF8iX3Yo`70P?X0POn1on[o1?NER>J0jOl1`83j0;;o04:1ok[o1OLc
CGP[0>_o0L10n@00P87oPOo[o`Gg<deh:`3[o`70@?T00821oh7ojol5mc==N2/0
jol1`43i0020/_l0Bh7o^_l5QaWooj80oOl2C01<lOoh0020POn1on_o1HLIoonR
0?go0T`0C?7on000P87oPOo[o`F76OooXP3mo`9<04caooP0082bo`1APOnjo`DI
I_ookP3no`BVS?n<Y_;o0<3i087oPOoZo`DII_ookP3no`BVS?n<Y_;o0<3i087o
POoZo`DII_ookP3no`BVS?n<Y_;o0<3i0;7o05N1ok[o1@20oook0?ko1<3ookNR
lOl0`?/00821oh7oj_l5083ooo/0o_l4`?oo]j;ao`30n`00P87oPOoZo`D0P?oo
n`3no`C0oongX_7o0<3k0020/Ol0DH7o^_l5<dWook80o?l2P3?8lOl0@?/00<21
oh7oj_l5<dWook80o?l2P3?8lOl0@?/00<21oh7oj_l5<dWook80o?l2P3?8lOl0
@?/00<2ao`1PPOnjo`GM7UYc9P3no`C0ooogR?;o043n00=00010POn1onWo1MdN
FW<V0?ko1<3oooN8l_l0@?h00d000421oh7ojOl5gAiJLbH0o_l4`?oomhSbo`10
oP03@000@;3o0621okWo1>jAR=D4o_l4YXcoS:Kco`Q00010oom00821oh7oj?l4
kY68e@Cno`BVS?n<Y_?o2400043ood00P87oPOoXo`C^THSE1?ko1:J<ohbVlol8
@000@?oo@020/?l0FX7o^_l5:d3^mgM4oOl2YX2Vlol3@000@?go0421oh7oj?l5
:d3^mgM4oOl2YX2Vlol3@000@?go0421oh7oj?l5:d3^mgM4oOl2YX2Vlol3@000
@?go042_o`0lPOnjo`GgGPT4@>K]o`=00010POn1on;o1OMN2@A0i^go0d000421
oh7oh_l5meh9143VkOl3@000@:Wo01j1oj7o083n087oPOo8o`20oP21oh7ob?l0
P?h0Z?l0987oX_l0P?h00<21oh7obOl0P?h00<21oh7obOl0P?h00<2Xo`0TPOnS
o`20oP00`87oPOo9o`20oP00`87oPOo9o`20oP00`:Oo02B1ojCo0<3n0030POn1
olWo0<3n0030POn1olWo0<3n0030Y_l0987oYOl0`?h00421oh7obOl0`?h00421
oh7obOl0`?h0042Uo`0/POnVo`30oP00P;So0821oi?o0<3n0020^?l0P87oTol0
`?h0082ho`20k_l0>87oYol0`?h00<2ko`B0P000`87oU?l0`?h00<2ko`B0P000
`87oU?l0`?h00<2ko`B0P000`>ko02b1ojOooP00P;co083l087oToon0020_?l0
P?`0POnCooh0082lo`20o03]o`0kPOnXo`=00010_ol2P810n`00P87oU?l3@000
@;oo0X20@?/00821oiCo0d00042oo`:0P43k0020kOl0>87oZOl3@000@<7o0H10
n000P87oU?l3@000@<7o0H10n000P87oU?l3@000@<7o0H10n000P>co03:1oj[o
oP00@<3o0<3h0010POnDooh00430o`30n000@87oU?on0010`?l0`?P0043[o`0e
POn[o`=00010__l0`?T00<21oiGo0d00042no`30n@00`87oUOl3@000@;ko0<3i
0030jol0>87o[?l0@?h00<2mo`20n`00P87oUOl0@?h00<2mo`20n`00P87oUOl0
@?h00<2mo`20n`00P>[o03R1ojgo043n0030_Ol0`?/00421oiGo043n0030_Ol0
`?/00421oiGo043n0030_Ol0`?/0043Yo`11POn^o`=00010_?l0@?h0043n0030
POnFo`=00010_?l0@?h0043n0030POnFo`=00010_?l0@?h0043n0030jOl0>h7o
[ol0P?h0_?l0P?d00on00021oiKo083n0;co083m00?oP000POnFo`20oP2lo`20
o@03oh000>So04N1ok3o0<3n0030_Ol0@?h0083no`50`87oUol0`?h00<2mo`10
oP00P?ko0D30POnGo`30oP00`;go043n0020o_l1@<3Xo`17POnao`30oP00`;ko
0L10oP00`?go0<21oiOo0<3n0030__l1`43n0030oOl0`87oUol0`?h00<2no`70
@?h00<3mo`30iol0=H7o/Ol3@000`;ko083n0010POn@o`=00030__l0P?h00421
oi3o0d000<2no`20oP00@>3o03R1ok?o0<3n0020_ol0`?d00821oi7o0<3n0020
_ol0`?d00821oi7o0<3n0020_ol0`?d0083Oo`0hPOndo`30oP00@;oo083m0030
POnAo`30oP00@;oo083m0030POnAo`30oP00@;oo083m0030g_l0>87o]Ol0`?h0
042oo`10oP00P87oT?l0`?h0042oo`10oP00P87oT?l0`?h0042oo`10oP00P=co
03^1okKo0<3n0020`?l0`?h00D30POn@o`30oP00P<3o0<3n0050`87oT?l0`?h0
0830o`30oP01@<3Ko`0VPOnfooh0082oood0POn>ooh0082oood0POn>ooh0082o
ood0fOl0>87o]ol3@000@<3o083n0050`87oSol3@000@<3o083n0050`87oSol3
@000@<3o083n0050`=Wo05>1okSo0d000431o`70@?h0043do`GcC@0_FX21oj7o
0d000431o`70@?h0043do`GcC@0_FX21oj7o0d000431o`70@?h0043do`GcC@0_
FX3Zo`1LPOnio`?00010`Ol0`?d00<3co`ENH_O84H3lo`34POnXo`?00010`Ol0
`?d00<3co`ENH_O84H3lo`34POnXo`?00010`Ol0`?d00<3co`ENH_O84H3lo`34
l?l0Gh7o^_l0P?h0`Ol0@?h00H30l_l53NKoofn0oOl1Ka61ojWo083n0<7o043n
0060`?;o1@gVoom_P?go0FlAPOnYo`20oP31o`10oP01P<3bo`D=i_ooKh3mo`5_
4O3o06:1ok_o043n0030`ol1`43n0030l?l00?ko0Gb0o?l0P87oZ_l0@?h00<33
o`70@?h00<3`o`00o_l1O83lo`20POnZo`10oP00`<?o0L10oP00`?3o003no`5l
P?co083`o`1OPOnlo`10oP00`<?o0<3n0010k_l56/Sooc>0o?l0P87oZol0@?h0
0<33o`30oP00@>ko1A[8oolcP?co0821oj_o043n0030`ol0`?h0043^o`DJb?oo
<h3lo`20l?l0Dh7o_Ol0P?h00833oo`0kOl5GCcgO`20o?l0P87o[?l0P?h00833
oo`0kOl5GCcgO`20o?l0P87o[?l0P?h00833oo`0kOl5GCcgO`20o?l0P?3o05n1
okko0<3n0020`ol0@?h0043/o`GM@00[FX3lo`20POn]o`30oP00P<?o043n0010
k?l5gD00:eZ0o?l0P87o[Ol0`?h00833o`10oP00@>co1Me002]JP?co083`o`1O
POnoo`30oP00`<Co0<3m0020jol5P?OoodfIo?l0P87o[_l0`?h00<34o`30o@00
P>_o1H3goom=VOco0821ojko0<3n0030a?l0`?d0083[o`F0moooCIWlo`20l?l0
Dh7o`?l0`?h00<34o`20o@00`>[o1EDgP5HVkX7oZOl0`?h00<34o`20o@00`>[o
1EDgP5HVkX7oZOl0`?h00<34o`20o@00`>[o1EDgP5HVk^[o04f1ol3o0d000<34
o`10oP00`>So1?^VP9G^POnXo`=00030a?l0@?h00<3Xo`CkYX2EkX7oZ?l3@000
`<Co043n0030j?l4njJ0UNkYo`0hPOo1o`=00020aOl0`?h00D30POn:o`=00020
aOl0`?h00D30POn:o`=00020aOl0`?h00D30b_l0>h7o`ol0`?h00436o`70P?h0
0421oh[o0<3n0010a_l1`83n0010POn:o`30oP00@<Ko0L20oP00@<So03R1olCo
0<3n0010a_l0`?d00<21oh[o0<3n0010a_l0`?d00<21oh[o0<3n0010a_l0`?d0
0<37o`0/POo4ood0a_l0P?d00821ohWoo@36o`20o@00P87oROom0<Ko083m0020
a_l0>87oaOl0@?h00<37o`30o@00`87oROl0@?h00<37o`30o@00`87oROl0@?h0
0<37o`30o@00`<Go03F1olKo0d000436o`10oP00P87oR?l3@000@<Ko043n0020
POn8o`=00010a_l0@?h00833o`0hPOo7o`=00010aol1`43n0030POn8o`=00010
aol1`43n0030POn8o`=00010aol1`43n0030`_l0=H7ob?l3`000@<Oo083n0010
POn7o`?00010aol0P?h00421ohOo0l000437o`20oP00@<3o03:1olWo0<3n0<So
0<3m0020POn7o`30oP38o`30o@00P87oQol0`?h0b?l0`?d0082oo`0hPOo:o`20
oP00`<Wo043m0030POn7o`20oP00`<Wo043m0030POn7o`20oP00`<Wo043m0030
__l0EX7oh?l5mfhE01Z4l_l0@?h00<3:o`70@?h00821oi_o1OM^5@0JQ?;o043n
0030b_l1`43n0020POnKo`GgKQD06XCbo`10oP00`<[o0L10oP00P;co04Z1on3o
1WL0/_nR06Kdo`20oP00P<Woo@21oiWo1WL0/_nR06Kdo`20oP00P<Woo@21oiWo
1WL0/_nR06Kdo`20oP00P<Woo@2jo`1OPOoQo`;^3L3no`:A0;ofo`30oP00@<[o
0L10oP00`87oV_l2kPg0o_l2T@2om_l0`?h0043:o`70@?h00<21oi[o0^h=`?ko
0Y40_oKo0<3n0010b_l1`43n0030^_l0FH7ohOl1WDSmo`;gP<3go`30oP00P<[o
083n0010POnHo`6MB?go0_N0`?Oo0<3n0020b_l0P?h00421oiSo0Ie8oOl2mh30
mol0`?h0083:o`20oP00@;So0461on7o0H20l?on0030bol0`?d00821oiOo0H20
l?on0030bol0`?d00821oiOo0H20l?on0030bol0`?d0082go`14POoQo`68Lo7o
0d000<3;o`20o@00`87oU_l1R7?ao`=00030bol0P?d00<21oiKo0HQclOl3@000
`<_o083m0030]_l0FH7ohOl2_bKko_l2c02EnOl3@000@<_o043n0020POnDo`:o
9__no`;<09Gio`=00010bol0@?h00821oiCo0[lVnoko0/`0UOWo0d00043;o`10
oP00P;Co05V1on3o1caJgOo89Sc^n_l3@000@<co0<3n0050`87oT_l7?5[MolPV
?>kjo`=00010c?l0`?h00D30POnBo`LlF]gob2Hlk_[o0d00043<o`30oP01@<2c
o`0kPOoPo`7V2?h004Ciood0boom087oT?l1iPSn0014nOom0<_oo@21oi3o0NH8
oP00A?Woo@3;ood0/Ol0Dh7ogol4gHf0X_Ojo`10oP00`<go083n0050`87oSol4
gHf0X_Ojo`10oP00`<go083n0050`87oSol4gHf0X_Ojo`10oP00`<go083n0050
`;7o03^1omCo043n0030c_l1`43n0010POn2o`10oP00`<ko0L10oP00@87oP_l0
@?h00<3>o`70@?h0042_o`0hPOoEo`10oP00`<ko0<3m0030POn2o`10oP00`<ko
0<3m0030POn2o`10oP00`<ko0<3m0030[_l0>87oe_l3P000@<go043n0060`87o
P_l3P000@<go043n0060`87oP_l3P000@<go043n0060`:go03R1omOo0l00043>
o`70@?h00<21oh7o0l00043>o`70@?h00<21oh7o0l00043>o`70@?h00<2[o`0j
POoHo`30oP00`<oo0<3n0010POn1o`7o`?h00<3?o`30oP00@87oPOl1ol3n0030
col0`?h0042Yo`0jPOoIo`30oP00`=3o0<3m0020POn1o`7o`?h00<3@o`30o@00
P87oPOl1ol3n0030d?l0`?d0082Xo`0bPOoIooh0083?ood00821oh7o0OoooP00
P<ooo@00P87oPOl1ooon0020coom0020Yol0>X7ofol0`?h0043@o`30o@00P87o
POl1ol3n0010d?l0`?d00821oh7o0Oo0oP00@=3o0<3m0020Y_l0>X7og?l0`?h0
043@o`20o@00`87oPOl1ol3n0010d?l0P?d00<21oh7o0Oo0oP00@=3o083m0030
YOl0=X7ogOl0`?d0d?l0@?h00<21oh7o0_oo`?d0d?l0@?h00<21oh7o0_oo`?d0
d?l0@?h00<2So`0lPOoMooh00H10d_l0`?h00D30POn1ookooP01P43Bo`30oP01
@<21oh7oo_on0060@=;o0<3n0050`:;o04:1omko043n0060P=Co0L20oP00@87o
POomo`10oP01P83Do`70P?h00421oh7ooOl0@?h00H20e?l1`83n0010X?l0?h7o
gol0@?d00On0eOl0`?d00<21oh7ooOl0@?d00On0eOl0`?d00<21oh7ooOl0@?d0
0On0eOl0`?d00<2Oo`0lPOoPo`20n`00P=Ko083m0020POn1oogo083k0020e_l0
P?d00821oh7ooOl0P?/0083Fo`20o@00P9ko03n1on7o0<3k007o@=Oo0<3m0030
POn1oogo0<3k007o@=Oo0<3m0030POn1oogo0<3k007o@=Oo0<3m0030WOl0?h7o
h_l0P?X00H10f?l0@?h00821oh7oo?l0P?X00H10f?l0@?h00821oh7oo?l0P?X0
0H10f?l0@?h0082Ko`12POoSo`10n@01oh3Jo`70@?h00<21oh7oo?l0@?T00On0
f_l1`43n0030POn1ooco043i007oP=[o0L10oP00`9[o04:1onCo043i0090P83K
o`20oP00@87oPOoko`10n@02@820fol0P?h00421oh7onol0@?T00T20P=_o083n
0010V?l0@X7oiOl0P?P00X3o@=go0<3m0020POn1oo_o083h00:0od3Mo`30o@00
P87oPOoko`20n002P?m0gOl0`?d0082Go`1>POoVo`C00010P?/00X20@=ko083m
0030POn1oo_o1<000420n`02P810g_l0P?d00<21oh7onol4`000@83k00:0P43N
o`20o@00`9Ko05B1onOo0<3n00;0ol3l0090oh3Oo`10oP00P87oPOojo`30oP02
`?o0o002@?n0gol0@?h00821oh7on_l0`?h00/3o`?`00T3oP=oo043n0020U?l0
B87oioon00>0P?oon`01oh3Pood00821oh7onOon00>0P?oon`01oh3Pood00821
oh7onOon00>0P?oon`01oh3Pood0082Co`1MPOoXo`=00010o_l8P020P410P810
hOl0@?h00<21oh7onOl3@000@?ko2800P810@820@>7o043n0030POn1ooWo0d00
043no`R00820@420P43Qo`10oP00`9;o06>1onWo14000430o_l4003o`83no`10
hol0P?h00D30POn1ooWo14000430o_l4003o`83no`10hol0P?h00D30POn1ooWo
14000430o_l4003o`83no`10hol0P?h00D30TOl0IX7ojol0`?h0043mo`T00430
`?n0`820iOl1`43n0010POn1ooWo0<3n0010oOl90010`<3oP<20P>Go0L10oP00
@87oPOoio`30oP00@?go2@00@<30oh30P83Uo`70@?h0042?o`2:`Ol1mj[no`C^
UH24a;Ko0<3n0050`?ko2T000<20ooo0P?n0i_l0`?d00<21olko0ONZo_l4kYF0
Q<Bfo`30oP01@<3no`Y00030P?oo`83oP>Ko0<3m0030POo>o`7gZ_ko1>jEP8C4
]_l0`?h00D30o_l:@000`83ool20oh3Vo`30o@00`8ko08g1o`^k0?oo`2;4onYR
DO^ho`=00010o?l:@010`?n0`<3oP43Wo`10oP01P<21olgo2k/0ooo08/CojV9A
nkSo0d00043lo`Y00430oh30`?n0@>Oo043n0060`87ocOl;^`3ool0Ra?oZHU7k
^?l3@000@?co2T00@<3oP<30oh10iol0@?h00H30SOl0Tl3o103ola6Eo_l2naZ0
^Ol0@?h00<3no`S0`000P?oo`83no`10jOl1`43n0030POo:o`@0oo<AUOko0_/J
P;Wo043n0030o_l8`<00083ool20o_l0@>Wo0L10oP00`87ob_l40?oc4IGno`;k
6X2io`10oP00`?ko2<300020ooo0P?ko043Yo`70@?h00<2;o`2Ca?l8eDB0N`3o
W@3IoOl1FAZjo`=00010nol;@020oh30`?n0`820j_l0`?h00421olco2=E4P7/0
oid0fOgo0ETJ^_l3@000@?_o2d00P?n0`<3oP<20P>[o0<3n0010POo<o`SEA81k
0?nM0=Wmo`5I6[[o0d00043ko`]0083oP<30oh30P83Zo`30oP00@8Wo08C4o`QM
Z_o^0?n00=gmo`5M0;_o083n0?[o0@00o_l0P?ko0X3oP>_oo021ol_o25fZonh0
oh00gOgo0Ed0^ol0P?h0n_l1003no`20o_l2P?n0jool087obol8GJ[okP3oP03M
oOl1G@2ko`20oP3jo`400?ko083no`:0oh3[oo`0R?l0WlCo21[^ool0oh00gOgo
0Ed0_?l0`?h0083mo`k0oh00@?ooP<30oh30P83/o`10oP00@87ob_l86^koo`3o
P03MoOl1G@2lo`30oP00P?go3/3oP010oon0`<3oP<20P>co043n0010POo:o`PJ
k_oo0?n00=gmo`5M0;co0<3n0020oOl>`?n0043ooh30`?n0`820k?l0@?h00427
o`2Ia?l80?_oo`3o[P34oOl1A3Nmo`30oP00`?[o2000oh20ooo0P?ko043^o`30
o@00P87obOl80?_oo`3o[P34oOl1A3Nmo`30oP00`?[o2000oh20ooo0P?ko043^
o`30o@00P87obOl80?_oo`3o[P34oOl1A3Nmo`30oP00`?[o2000oh20ooo0P?ko
043^o`30o@00P8Ko0:S4o`PZ/_oo0?_k9U7no`;A0;^no`20oP00P?go4<3ooh00
P<20`<3oP<30oh10kol0P?d00<21olSo22Zbool0no/VDOko0]40^kko083n0020
oOl@`?ooP020`830`?n0`<3oP43_o`20o@00`87ob?l8:[;oo`3knbIAo_l2d@2k
__l0P?h0083moa30oon00830P<30oh30`?n0@>oo083m0030QOl0W<Co3L@[MiTV
]ooV>dB0LcNg__l0@?h00<3io`d00830ooo0P?oo`83oP?3o043n0030POo6o`g4
:gNI9[OoiS]4P7<g]kko043n0030nOl=0020`?oo`83ool20oh3`o`10oP00`87o
a_l=a2]gVBJgonHkA81c=kNno`10oP00`?Wo3@00P<3ool20ooo0P?n0l?l0@?h0
0<23o`2C^ol4K`00MnZoo`30oP00P?ko0<3mo`i00430P?ooP<30oh30P83bo`30
oP01@<21okco16l007OZ_ol0`?h0083no`30oOl>@010`83ooh30`?n0`820l_l0
`?h00D30POnlo`A_001gj[oo0<3n0020o_l0`?go3T00@<20oon0`<3oP<20P?;o
0<3n0050`8;o08Jjo`7^Z_j0`Ol0`?h0083ho`X00<3ooh20ooo0P?ko043do`70
P?h00421okWo0NjZoX31o`30oP00P?So2P00`?ooP83ool20o_l0@?Co0L20oP00
@87o^Ol1kZ[nP<7o0<3n0020n?l:0030oon0P?oo`83no`10m?l1`83n0010POl0
o`1ePOoeood0o_l0P?go383o0820ool0P?ooP83no`00m?om0020POn1oo?oo@3n
o`20oOl<P?l0P83oo`20oon0P?ko003dood00821oh7oloom0?ko083mo`b0o`20
P?oo083ooh20o_l00?Coo@00P87o0Ooo07N1ooKo0d00043go`n00830`83ooh30
`?n0`820m_l1`43n0010POn1oo?o0d00043go`n00830`83ooh30`?n0`820m_l1
`43n0010POn1oo?o0d00043go`n00830`83ooh30`?n0`820m_l1`43n0010POon
o`1aPOogo`=00010m_l4P83ool3mo`J0ooo0P?n0mol0`?d00<21oh7olol3@000
@?Ko1820ooo0oOl6P?oo`83oP?Oo0<3m0030POn1oo?o0d00043fo`B0P?oo`?go
1X3ool20oh3go`30o@00`87ooOl0Q;ko0<2lo`=00010n_l1P83do`F0`<3oP43h
o`10oP00P>?o0mW8ol3kP87oh?l0`;co0d00043jo`60P?Co1H30`?n0@?So043n
0020hol3fLSo`?^0POoPo`30_?l3@000@?[o0H20m?l5P<30oh10n?l0@?h0083S
o`?Ib?o0nh2So`2U_Ol20430`?l3@000@?ko083mo`60P?Co0L20o_l0@?[o0L10
oP00`>;o2Cb0oomR0??k^aj1omoo0P10`<3o0d00043no`20oOl1P83do`70P?ko
043jo`70@?h00<3Ro`TlP?ooHP3cnk/NPOoOo`80@<30o`=00010o_l0P?go0H20
m?l1`83no`10n_l1`43n0030h_l9?83oof80lo^k7Z?o0<Jmo`10oP01@<35o`30
oP00@?co3?=4029EP?ogKPd06XSlo`K0`?n0`820nol0P?h0043Po`V0P?ooP03o
om6APOoOo`10oP01@<35o`30oP00@?co3?=4029EP?ogKPd06XSlo`K0`?n0`820
nol0P?h0043Po`V0P?ooP03oom6APOoOo`10oP01@<35o`30oP00@?co3?=4029E
P?ogKPd06XSlo`K0`?n0`820nol0P?h0043Po`V0P?ooP03oom6AXol0d[go0<3k
0020aol3@000@?ko4<3oof9Nml`AP?l[05Z0=`2koOl6`?oo`83oP?go0<3m0020
h_l;eDAl@83ooh00nj60POoNo`30n`00P<Oo0d00043noa30oomRG_O<4H3o:`1J
P3L0^ogo1/3ool20oh3mo`30o@00P>;o2mE4O420oon00?^QP87og_l0`?/00837
o`=00010o_l@`?ooHUkgc160ob/0FX0g0;_mo`K0ooo0P?n0oOl0`?d0083Ro`_E
A7a0P?ooP03kXH2Ro`30_?oi0050`<_o043n0?[o3@gZoom_P?l[08BkfH30o?l5
P<30oh10o_l0P?d00<3Qo`]4a?mgP?ooP01l<h21omgon@01@<3;o`10oP3jo`d=
j_ooKh3o:`24^mV0`?co1H30`?n0@?ko083m0030hOl;A<CoMh3ooh00O3>0POoM
ooT00D30bol0@?h0n_l=3N[oofn0ob/0Q;_IP<3lo`F0`<3oP43no`20o@00`>7o
2dC4ogN0oon007`cP:;o0;Nlo`20nP3:o`20oP00P?[o003no`B0P?o^:oh00B_g
nol0P?ko0h3ooh3m0=oo2`Sooh20oon00?o^P87ogOl0P?X0b_l0P?h0083jo`00
o_l4P83okR_n004[mo_o083no`>0oon0o@3Oo`/8oon0P?ooP03okX21omgo083j
0<[o083n0020n_l00?ko1820onh[oP01:oOko`20o_l3P?ooP?d0gol;2?ooP83o
oh00onj0X_l0g[co0<3m0010fol0P?3o0<3n0020o_l0`?ko3X09j_ooJX3oP83I
]hP0UOco1h30`?n0@?n0oP00@=ko2`3koh20oon00?ooeH7ogOl0`?d0043Ko`20
l?l0`?h0083no`30o_l>P0WZoomZP?n0P=VgR02Eo?l7P<30oh10oh3n0010g_l;
0?_oP83ooh00oooEPOoMo`30o@00@=_o083`o`30oP00P?ko0<3no`j02N[oofZ0
oh20fKN809Glo`N0`<3oP43oP?h0043No`/0non0P?ooP03oomFRo`3H^oon0090
043Lo`00lOl0`?h00<3ho`eAG_O83H3oG@0gP5h0TOgo1l3ool20oh10oP00`>?o
0/20P?ko22Zboh1loon0087ofOon0090043Lo`00lOl0`?h00<3ho`eAG_O83H3o
G@0gP5h0TOgo1l3ool20oh10oP00`>?o0/20P?ko22Zboh1loon0087ofOon0090
043Lo`00lOl0`?h00<3ho`eAG_O83H3oG@0gP5h0TOgo1l3ool20oh10oP00`>?o
0/20P?ko22Zboh1loon009oo0B>ko`J0043o@010hOl;a828g@3ooo^VP830nOl0
`?h00<3no`30o_l@`?oojT@0<fJ0oon45@0=H_Omo`G0`?n0`83n0050`>_o0l20
P43j0030o_l9a2^8DE[o`280Jh7of_l6P010od00@>7o2lB0R=d0oookYX20`?Wo
0<3n0030o_l0`?ko4<3oonY403=VP?ooQ1D03F;goOl5`<3oP<20oP01@<3[o`?0
P810nP00`?ko2L@[R55Jol0R06^1om[o1X00@?m0043Qo`_4P8SM0?oonjJ0P<3i
o`30oP00`?ko0<3noa30oooZA00cIX3ooh@E00eRmogo1L30oh30P?h00D30jol3
`820@?X00<3no`W4:hQAF_o08P1[X?l0YK[o1P20oom0043So`Rc4GQ_:`3oodgm
0020nol0`?h00<3So`?0P<10oP00@>So083i0030POo;o`H0P?oo@010hol8/a5h
Kb/0oom=o@00P?_o0<3n0030hol3`830@?h0043Xo`20n@00`87obol6083ood00
@>?o2;<AN6l[0?ooCOd0083ko`30oP00`>?o0l20`43n0010j?l0P?T00<2Bo`39
^_l1P83no`90043To`d_]ooo_`3o]`20nnI04Oco083n00?0ooo0oOl0`?ko083^
o`60@?d00<3Vo`70@?`00<21ol[o0H20o_l2@010i?l=;kOookl0okL0P?_V@17l
o`20oP03`?oo`?go0<3no`20k_l1P43m0030i_l1`43l0030POo:o`60P?ko0T00
@>Co3Bngoono0?ng083kiT0Ao?l0P?h00l3ool3mo`30o_l0P>ko0H10o@00`>Ko
0L10o000`97o09Vio`30oOl3@000`>Ko003mo`@0oh00moWo0<3n0030h_l1`43n
0060@>Oo083j0030POo8o`30oOl3@000`>Ko003mo`@0oh00moWo0<3n0030h_l1
`43n0060@>Oo083j0030POo8o`30oOl3@000`>Ko003mo`@0oh00moWo0<3n0030
h_l1`43n0060@>Oo083j0030T?l0nK?o0d000<3Wo`d9j_oojP3oS03QoongP?ko
0<3n00>0ooo0oOl0`?ko0<3mo`n0P<3o`?o0ol3o`?o0oon0oP00@?j0jOl0P?h0
1H30o`00`87o`Ol3@000`>Oo3@WZoooZ0?n<0>7ookN0o_l0`?h00h3ool3mo`30
o_l0`?go3h20`?o0ol3o`?o0ol3ooh3n0010oX3Yo`20oP05P<3o0030POo1o`=0
0030iol=2N[oonX0oh`0hOoo]h3no`30oP03P?oo`?go0<3no`30oOl?P830ol3o
`?o0ol3o`?ooP?h0043nP>Wo083n00F0`?l00<2?o`2g/_on0>Oo3C>IoonI0?o3
04cogA4[o_om0?3o3P00oon0oh3ooh20ool0P?d0o_l00>[oo@3no`800821okoo
oP3Wo`dcVOooV@3o``1<omdA:okoo@3`o`h00?ooP?n0oon0P?oo083m0?ko003Z
ood0o_l20020POnoooh0iol=<iWooiT0ol<0C?oM4B_nood0l?l>003ooh3oP?oo
P83oo`20o@3no`00j_om0?ko0P00P8ko0?Vao`90043Xo`RR4GQ_=`3onc?m00>M
oom0oP02`?o0o_l0`?go0<3noa20oh000?oo`830oon0`?ooP?d0083no`10kOl1
P43n0020oOl10421okgo0T00@>So2:8AN6lg0?ok<od00igood3n00;0ol3no`30
oOl0`?ko483oP000ooo0P<3ooh30oon0o@00P?ko043]o`60@?h0083mo`40@87o
_Ol2@010j?l8XQ5hKcL0oo/co@03WOoo@?h00/3o`?ko0<3mo`30o_l@P?n0003o
ol20`?ooP<3ooh3m0020o_l0@>go0H10oP00P?go0@10SOl0c;3o0T00@>So4LB0
T>Z0ooogWX28c?oo@000@>oo3@00`830`?o0`83o`810o@05`?n0`820kol0P?d0
083lo`60P87o^ol2@010j?lAa82@jX3oooNNP8S<oom00010kol=0030P<30ol30
P?o0P43m00G0oh30P83_o`20o@00P?co0H20POnko`90043Xoa74P93ZP?oomij0
R<cood00043_o`d00<20`<3o`<20ol20@?d01L3oP<20P>oo083m0020o?l1P82<
o`3<[ol2@010g?l6@000@?oo`?ko0<3mo`30o_l8`?oo`010ol20o_l3P<3o`?d0
1h20ooo0P?n0lOl0P?h0083io`30POnio`90043Lo`I00010ooo0o_l0`?go0<3n
o`S0ooo0043o`83no`>0`?o0o@07P83ool20oh3ao`20oP00P?Wo0<21okWo0T00
@=co1T00043ool3no`30oOl0`?ko2<3ool00@?o0P?ko0h30ol3m00N0P?oo`83o
P?7o083n0020nOl0`8_o09^^o`90043No`=00010k_l;@020`<3oP?n0ol10o@08
P<3oP<30oh10m?l1P83n0020POn]o`90043No`=00010k_l;@020`<3oP?n0ol10
o@08P<3oP<30oh10m?l1P83n0020POn]o`90043No`=00010k_l;@020`<3oP?n0
ol10o@08P<3oP<30oh10m?l1P83n0020POl0o`3;[Ol2@010h?l6P000@?oo`?ko
0<3no`30oOl0`?ko2h000<20ooo0P<30@?h01/20P?oo`83no`10m_l0P?d00821
oj[o0T00@>3o1X00043ool3no`30o_l0`?go0<3no`^00030P?oo`830`43n00K0
P83ool20o_l0@?Ko083m0020POnZo`90043Po`J00010ooo0o_l0`?ko0<3mo`30
o_l;P000`83ool20`<10oP06`820ooo0P?ko043fo`20o@00P87oo_l0Y:co0d00
0<3So`>00010k_l:`000@<3oP<30oh3n00a0`83ooh30`?n0`820n?l0P?h00821
ojKo0d000<3So`>00010k_l:`000@<3oP<30oh3n00a0`83ooh30`?n0`820n?l0
P?h00821ojKo0d000<3So`>00010k_l:`000@<3oP<30oh3n00a0`83ooh30`?n0
`820n?l0P?h00821oo_o08V[ooh0i?l0P?h0083^o`>00020o_l1P?ol007oP?go
083no`:0oh3iood0POnSooh0i?l0P?h0083^o`>00020o_l1P?ol007oP?go083n
o`:0oh3iood0POnSooh0i?l0P?h0083^o`>00020o_l1P?ol007oP?go083no`:0
oh3iood0POoio`3DZol3`000@>Ko0<3n00=0ooo0o_l0`?ko0<3mo`30o_l9`000
@<30oh30@?d03Oo0`83ooh30`?n0`820o?l0P?d00821oj;o0l00043Vo`30oP03
@?oo`?ko0<3no`30oOl0`?ko2L000430`?n0`43m00go`<20oon0`<3oP<20P?co
083m0020POnRo`?00010i_l0`?h00d3ool3no`30o_l0`?go0<3no`W00010`<3o
P<10o@0=ol30P?ooP<30oh30P83lo`20o@00P87on?l0]ZWo0T00@>So0<3n0010
nOl1TM7go`N00030ol20`?d02h3oP<3ooh20ooo0P?ko043no`20oP01@821oiko
0T00@>So0<3n0010nOl1TM7go`N00030ol20`?d02h3oP<3ooh20ooo0P?ko043n
o`20oP01@821oiko0T00@>So0<3n0010nOl1TM7go`N00030ol20`?d02h3oP<3o
oh20ooo0P?ko043no`20oP01@821ooKo0;nXo`90043Zo`30oP03P?oo`?co0^40
H_Wo2<3o0020`?n0@?d04X3o`<20ol20`<3oP<30oh10oh3n0020POnJo`90043Z
o`30oP03P?oo`?co0^40H_Wo2<3o0020`?n0@?d04X3o`<20ol20`<3oP<30oh10
oh3n0020POnJo`90043Zo`30oP03P?oo`?co0^40H_Wo2<3o0020`?n0@?d04X3o
`<20ol20`<3oP<30oh10oh3n0020POoco`3<Yol2@010k?l0`?h00<3ho`>=JQGk
nOl6P010ol20@?h04/3ooh30oon0`?oo`83ool20P43n0020[Ol5ldd0;eZ0POoa
o`90043/o`30oP00`?So0heZ5O_io`J0043o`810oP0B`?ooP<3ooh30ooo0P?oo
`820@?h0082]o`GcC@0_FX21oo7o0T00@>co0<3n0030n?l3SFXEnoWo1X00@?o0
P43n01;0oon0`?ooP<3ool20ooo0P810oP00P:go1O==02mJP<_o0?VVo`90043^
o`30oP03`?oo`?ko0<3no`<_c4fgo?l7`?oo0030od3n0150P<3o`<20ol30P?oo
P<30od3n0050P:_o1EiRmlPAP?ko0nJ0P>J1ooOo0T00@>ko0<3n00?0ooo0o_l0
`?ko0bo<CKOlo`O0ool00<3o@?h04D20`?o0`83o`<20oon0`<3o@?h00D20Zol5
GV;gb160o_l3iX20iX7omol2@010k_l0`?h00l3ool3no`30o_l3;la=]oco1l3o
o`00`?m0oP0A@830ol30P?o0`83ooh30`?m0oP01@82[o`ENH_O84H3no`?VP83V
d_l0dZGo0T00@>oooP00`?Oo1;8NoieRn_l3P010P?d0443ool20`?ooP<3ooh20
oom0oP01P42Yo`D=i_ooKh3no`=<i^I<POofo`90043_ooh00<3go`Bb7_nMH_[o
0h00@83m0110ooo0P<3ooh30oon0P?oo@?h00H10ZOl53NKoofn0o_l3C>KVC87o
m_l2@010koon0030mol4/QkoWF;jo`>00420o@0@@?oo`830oon0`?ooP83ood3n
0060@:Wo1@gVoom_P?ko0dcViTcBo`3ZY?l3@000`?;o1D000<3o`?go0<3no`Kg
4C>0Ja7knol20020o@09@<30oh3oP?o0`?b0043n00=0oh10ZOl00?ko0Gb0o_l3
`?ooLh7omOl3@000`?;o1D000<3o`?go0<3no`Kg4C>0Ja7knol20020o@09@<30
oh3oP?o0`?b0043n00=0oh10ZOl00?ko0Gb0o_l3`?ooLh7omOl3@000`?;o1D00
0<3o`?go0<3no`Kg4C>0Ja7knol20020o@09@<30oh3oP?o0`?b0043n00=0oh10
ZOl00?ko0Gb0o_l3`?ooLm;o0:jSooh0loom0?Ko0;_l003<o?l0P?X00oooP83n
o`>0P?oonP04oh20oh2Yo`D8i_ooEH3lo`73EH7om?on0??oo@3fo`2ko000c?co
083j00?ooh20o_l3P83oooX01?n0P?n0ZOl52>KooeF0o?l1`eF1ooCooP3cood0
m_l0^o`00<clo`20nP03oon0P?ko0h20oooj00CoP83oP:Wo1@SVoomEP?co0L=E
d_l0l:?o0l00043eo`10oP01`<3mo`30o_l8`?mg2??oofZ=oOl1`43l00F0P?oo
`83no`>0`?oon`05ooo0P?n0ZOl5A7?k`0V0o_l3mhQokX7om?l3`000@?Go043n
0070`?go0<3no`S0ogL8loooJXgmo`70@?`01H20ooo0P?ko0h30oook00Gool20
oh2Yo`E4Lo_02H3no`?gR7o^POodo`?00010mOl0@?h00L30oOl0`?ko2<3oM`Sc
oomZSOgo0L10o005P83ool20o_l3P<3ooo/01Ooo`83oP:Wo1DAcnl09P?ko0oN8
OnkBo`3NXOl2@010mol0@?h00<3eo`4NVOko0KlgoOl0`?d06T20`?n0`<3oP?n0
ol30P?m00010oh30`?n0@:Wo1Me002]JP?ko0F;QPOo`o`90043go`10oP00`?Go
0AjIo_l1_cOmo`30o@0J@830oh30`?n0oh3o`<20od00043oP<30oh10ZOl5gD00
:eZ0o_l1H^61oo3o0T00@?Oo043n0030mOl17YWno`6o=ogo0<3m01Y0P<3oP<30
oh3oP?o0`83o@000@?n0`<3oP42Yo`GM@00[FX3no`5RhM3o0@FPo`90043io`10
oP01`<3no`30oOl4`?oolhClo`F0nooo`43n0130P83ool20ooo0P<3ooh30P?d0
0X30P?ko042Yo`F0moooCIWno`0loH3n0?Z0POolo`90043io`10oP01`<3no`30
oOl4`?oolhClo`F0nooo`43n0130P83ool20ooo0P<3ooh30P?d00X30P?ko042Y
o`F0moooCIWno`0loH3n0?Z0POolo`90043io`10oP01`<3no`30oOl4`?oolhCl
o`F0nooo`43n0130P83ool20ooo0P<3ooh30P?d00X30P?ko042Yo`F0moooCIWn
o`0loH3n0?Z0gOl0bIoo0T00@?_o0d00043Yo`20oP0M@<20oon0`<3oP<30ol30
P?o00020`000`?n0`820ZOl5ECN0ERK^nOod0030POl4oom0043ko`=00010jOl0
P?h07D30P?ooP<30oh30`?o0`83o`000P<000<3oP<20P:Wo1EDgP5HVk_Wom000
`87o1?oo@010nol3@000@>Wo083n01e0`83ooh30`?n0`<3o`<20ol0008300030
oh30P82Yo`EE=h1F9^kioo@00<3Qo`3fW_l2@010oOl5@000@?n0o_l0`?go0<3n
o`30nOl0`?`02_n0`?oo`83ool20o_l?P<3ooh30ooo0P?oo`83oP:Wo1?^VP9G^
n?l0P?H00<21oogo0T00@?go1D00043oP?ko0<3mo`30o_l0`?Wo0<3l00[oP<3o
ol20ooo0P?ko3h30oon0`?oo`83ool20oh2Yo`CkYX2Ek_So083f0030POomo`90
043mo`E00010oh3no`30oOl0`?ko0<3io`30o00:oh30ooo0P?oo`83no`n0`?oo
P<3ool20ooo0P?n0ZOl4njJ0UNkho`20mP00`>3o0;6Mo`Q0043ooh00043Zo`20
o@0O@000ol30P<3oP<30oh3oP?o0`83o`830`?n0`<3oP42JooL00<21oo_o2400
@?ooP000@>[o083m01m0003o`<20`?n0`<3oP?n0ol30P?o0P<30oh30`?n0@9[o
m`00`87onol8@010oon00010j_l0P?d07d000?o0`830oh30`?n0oh3o`<20ol20
`<3oP<30oh10V_og0030gol0lico24000800043o`?ko0<3no`30oOl0`?ko0<3n
o`70@?h07H30od00@?n0P?oo`83ool20`?ooP<3ooh20ooo0P?ko042Mo`70P?P0
0421ooSo24000800043o`?ko0<3no`30oOl0`?ko0<3no`70@?h07H30od00@?n0
P?oo`83ool20`?ooP<3ooh20ooo0P?ko042Mo`70P?P00421ooSo24000800043o
`?ko0<3no`30oOl0`?ko0<3no`70@?h07H30od00@?n0P?oo`83ool20`?ooP<3o
oh20ooo0P?ko042Mo`70P?P0043Mo`2RVool0020joom00B0oon0ooh06_ooP?n0
oh3oP?n0oh3oP?n0oon0oh3oP?l0P9oo083e087om_ol0020joom00B0oon0ooh0
6_ooP?n0oh3oP?n0oh3oP?n0oon0oh3oP?l0P9oo083e087om_ol0020joom00B0
oon0ooh06_ooP?n0oh3oP?n0oh3oP?n0oon0oh3oP?l0P9oo083e0=co0;ZKo`20
oP00@>_o043n0130`?o0oon00030ol20ooo0P?ko3h30oon0`?oo`83ool20oh2R
o`60P?D00421ooGo083n0010jol0@?h04<30ol3ooh000<3o`83ool20o_l?P<3o
oh30ooo0P?oo`83oP:;o0H20m@00@87omOl0P?h0043[o`10oP0@`<3o`?ooP000
`?o0P?oo`83no`n0`?ooP<3ool20ooo0P?n0X_l1P83e0010fol129co0<3m0050
`?ko083no`30oOl0`?ko0l3ooh3n00I0`<3oP?ooo/0K0020P<30oh30`?o0`83o
`<20oon0`<3oP<20P:Ko0H20nP04P83ood3n0020POoeo`30o@01@<3no`20o_l0
`?go0<3no`?0oon0oP06@<30oh3oook06`00P830`?n0`<3o`<20ol30P?ooP<30
oh30P82Vo`60P?X01820oom0oP00P87omOl0`?d00D30o_l0P?ko0<3mo`30o_l3
`?ooP?h01T30`?n0ooon`1/00820`<3oP<30ol30P?o0`83ooh30`?n0`820Y_l1
P83j00B0P?oo@?h0083Jo`3]WOl0`?h00d10043`o`70@?h08T30ol3ool30ooo0
`000@?o0P?oo`830oon0`?ooP83ool20o_l0@:[o0/20@?/00T20`?co0h000<21
ooGo0<3n00=0@010l?l1`43n0290`?o0ooo0`?oo`<00043o`83ool20`?ooP<3o
oh20ooo0P?ko042Zo`;0P43k0090P<3lo`>00030POoeo`30oP03@400@?3o0L10
oP0R@<3o`?oo`<3ool300010ol20ooo0P<3ooh30oon0P?oo`83no`10Z_l2`810
n`02@830o?l3P000`=Wo0@jNo`30oP0:P?o0@010`400P<3no`30oOl2`?o0o@0W
`<3o`?o0ooo0`?oo`<000420`<3oP?n0ol30P?o0P<30oh30`?n0@:ko0/20@?/0
0T20P?Oo0@30POoeo`30oP0:P?o0@010`400P<3no`30oOl2`?o0o@0W`<3o`?o0
ooo0`?oo`<000420`<3oP?n0ol30P?o0P<30oh30`?n0@:ko0/20@?/00T20P?Oo
0@30POoeo`30oP0:P?o0@010`400P<3no`30oOl2`?o0o@0W`<3o`?o0ooo0`?oo
`<000420`<3oP?n0ol30P?o0P<30oh30`?n0@:ko0/20@?/00T20P?Oo0@30f?l0
`ioo0<3n0030oOl0@?d00<3go`10oP0BP83o`?o0ol3o`?oo`<3ooh100?;o1l20
ooo0P?n0/Ol1P83j0060P87oi_l0`?h00<3mo`10o@00`?Oo043n01:0P?o0ol3o
`?o0ooo0`?ooP400l_l7`83ool20oh2ao`60P?X00H20POoVo`30oP00`?go043m
0030mol0@?h04X20ol3o`?o0ol3ool30oon0@03bo`O0P?oo`83oP;7o0H20nP01
P838o`3WWoon0070`?go0<3n0020o_l0`?go0/30@?h04h3ool3o`?o0oh3ool30
ooo0ol10oOl1P03ho`N0`<3oP<20P;Go0H20nP02P830POoSooh00L30oOl0`?h0
083no`30oOl2`<10oP0CP?oo`?o0ol3oP?oo`<3ool3o`43mo`600?So1h30`?n0
`820]Ol1P83j00:0P<21on?ooP01`<3mo`30oP00P?ko0<3mo`;0`43n01>0ooo0
ol3o`?n0ooo0`?oo`?o0@?go0H00n?l7P<30oh30P82eo`60P?X00X20`<Go0;BP
o`>00020nool0020nOom0?go083no`20o_l0P?ko083io`600?Wo183ooh20o_l0
0;Oo083i0020POoPo`>00020nool0020nOom0?go083no`20o_l0P?ko083io`60
0?Wo183ooh20o_l00;Oo083i0020POoPo`>00020nool0020nOom0?go083no`20
o_l0P?ko083io`600?Wo183ooh20o_l00;Oo083i0020`Ol11J7o0<3n0030oOl8
`?l004000830o_l3`?n0@?h08<30oh3ool30ooo0ol3o`?o0ol3o`?ooa82RP03o
`83MQ?ko1<3ool20o_l0@;[o0H10nP01P<21omoo0<3n0030oOl8`?l004000830
o_l3`?n0@?h08<30oh3ool30ooo0ol3o`?o0ol3o`?ooa82RP03o`83MQ?ko1<3o
ol20o_l0@;[o0H10nP01P<21omoo0<3n0030oOl8`?l004000830o_l3`?n0@?h0
8<30oh3ool30ooo0ol3o`?o0ol3o`?ooa82RP03o`83MQ?ko1<3ool20o_l0@;[o
0H10nP01P<2oo`3KX_l0P?h00<3_o`10oP0R@?o0ol3o`?o0ol20P?ooP830ol3o
P?o0/a5hCAH0oh007P3mo`N0`<3oP<20P;ko0H10nP01P<21omco083n0030kol0
@?h08T3o`?o0ol3o`?o0P83ooh20`?o0oh3o`;<AN4dF0?n001h0oOl7P<30oh30
P82no`60@?X00H30POoLo`20oP00`>oo043n0290ol3o`?o0ol3o`820oon0P<3o
`?n0ol2c4GQ=5P3oP00N0?go1h30`?n0`820__l1P43j0060`;_o0@:So`10oP00
P?ko0<3mo`30o_l0P?ko0L30o@0R@?o0ol3ool30ooo00020P000ol3o`?oo`2ng
oom00?n009Glo`O0P?oo`83oP<;o0L20nP01@821omWo043n0020o_l0`?go0<3n
o`20o_l1`<3m0290ol3o`?oo`<3ool000820003o`?o0ooo0;kOood00oh00UOco
1l20ooo0P?n0`_l1`83j0050P87ofOl0@?h0083no`30oOl0`?ko083no`70`?d0
8T3o`?o0ooo0`?oo`000P8000?o0ol3ool0_]ooo@03oP02Eo?l7`83ool20oh32
o`70P?X00D20]ol0cjCo043n0030l?l0P?d01<3ool30nOl0`?d02<30ol3ool3o
0?ko1H00oh00nogo2<30oh30`?n0@<Ko0L20nP01@821omKo043n0030l?l0P?d0
1<3ool30nOl0`?d02<30ol3ool3o0?ko1H00oh00nogo2<30oh30`?n0@<Ko0L20
nP01@821omKo043n0030l?l0P?d01<3ool30nOl0`?d02<30ol3ool3o0?ko1H00
oh00nogo2<30oh30`?n0@<Ko0L20nP01@82co`3fYOl0@?h0083no`30oOl0`?ko
0<3no`70@?h00<3mo`60P?So043n0120ol3o`?o0o`WZoomZ0?n00?co1<3ool20
o_l0@<Wo0H10nP01P<21omCo043n0020o_l0`?go0<3no`30o_l1`43n0030oOl1
P83ho`10oP0@P?o0ol3o`?l9j_ooJP3oP03lo`C0ooo0P?ko0439o`60@?X00H30
POoDo`10oP00P?ko0<3mo`30o_l0`?ko0L10oP00`?go0H20n?l0@?h0483o`?o0
ol3o2N[oofX0oh00o?l4`?oo`83no`10bOl1P43j0060`;3o0>BVo`=00010l?l0
`?h04430ooo4P::0P?ooc8f0[__ooP0B@000`?o0oh3o`55NmlP=0?n00?_o1h30
`?n0`820cOl1P43j0060P87odOl3@000@?3o0<3n0110`?ooa82RP83oolb=P:kk
ooh04T000<3o`?n0ol1AG_O83@3oP03ko`N0`<3oP<20P<go0H10nP01P821om7o
0d00043`o`30oP0@@<3oolB0XX20ooo<SH2^noon01900030ol3oP?o0DEkgb0d0
oh00nol7P<30oh30P83=o`60@?X00H20[?l12jOo1<000430o_l0`?ko0<3mo`C0
ooo0P?h02d3ooo]^4GQ=5X3oO?d05dCoP83o`8000<3o`?oo`>Y403=V0?n00?_o
1l20ooo0P?n0dOl1`83j0050P87oc_l4`000@<3no`30o_l0`?go1<3ool20oP0;
@?oonfhAN4dFP?mlo@0GA?n0P?o0P000`?o0ooo0jT@0<fH0oh00nol7`83ool20
oh3Ao`70P?X00D20POo>o`C00010`?ko0<3no`30oOl4`?oo`83n00]0oookKQ5h
CAJ0ogcm01M4oh20ol200030ol3ool3ZA00cIP3oP03ko`O0P?oo`83oP=7o0L20
nP01@82Xo`2UYoon0?3oo@00P?ko3L<0VOoo8X3o6@28od@0nol1P03mo`20lOl7
P?n0oh3o083CooP00821ol_ooP3`ood0083no`g309Woob:0oaT0R?m40?_o0H00
oOl0P?7o1h3oP?n0o`20dooh0020POo;ooh0l?om0020o_l=``2IoolRP?lI08So
A03ko`600?go083ao`N0oh3oP?l0P=?on000P:Go0=:Xo`=00010l_l1`43n0050
`?ko3H`0j_ooKh3oP838/c`0o?l1`?on`0;ool3bo`C0ooo0P?ko043Go`70P?X0
0T20`87ob_l3@000@?;o0L10oP01@<3no`f<0>[oofn0oh20b;<l0?co0L3oo/02
ooo0l_l4`?oo`83no`10eol1`83j0090P<21ol[o0d00043bo`70@?h00D30o_l=
S03Zoom_P?n0P<Rc?03lo`70ook00_oo`?;o1<3ool20o_l0@=Oo0L20nP02@830
Xol0l:Wo14000430o_l0`?ko0<3mo`;0ol3m0070`?go0H00o_l8P83oO00RFD00
o?l8`<3ool30ooo0lol8`<3oP<30oh10f_l1P43j0060P87oaol4@000@<3no`30
o_l0`?go0/3o`?d00L30oOl1P03no`R0P?ml029I@03lo`S0`?oo`<3ool3co`S0
`?n0`<3oP43Jo`60@?X00H20POo7o`A00010`?ko0<3no`30oOl2`?o0o@01`<3m
o`600?ko2820og`08UU00?co2<30ooo0`?oo`??o2<30oh30`?n0@=[o0H10nP01
P82Oo`3lZol0`?h0043bo`10oP03@?oo`?go3J80]ooo=h3o103MjT00oOlP`?oo
`<3ooh3o`?o0ol3ool30oom0043ool10ooo0P?n0g_l1P43j0060`87oaOl0`?h0
043bo`10oP03@?oo`?go3J80]ooo=h3o103MjT00oOlP`?oo`<3ooh3o`?o0ol3o
ol30oom0043ool10ooo0P?n0g_l1P43j0060`87oaOl0`?h0043bo`10oP03@?oo
`?go3J80]ooo=h3o103MjT00oOlP`?oo`<3ooh3o`?o0ol3ool30oom0043ool10
ooo0P?n0g_l1P43j0060`9_o0B>/o`30oP01@<3no`30o_l0`?ko0l3o`43n00F0
ooo0ol3no`SgEA5hBBJ0ob[n008V0>kloak0`?oo`?m0`<3o`?o0ol3ool30@000
`400P?n0`820h_l1`83j0050P87o`_l0`?h00D30o_l0`?ko0<3no`?0ol10oP05
P?oo`?o0o_l8meDAN4TVP?lZoP029P3^o?lN`<3ool3o@<30ol3o`?o0ooo0`400
0<10083oP<20P>;o0L20nP01@821ol;o0<3n0050`?ko0<3no`30o_l3`?o0@?h0
1H3ool3o`?ko2?ME4GQ99X3o:_h00RH0k_co7/30ooo0od30`?o0ol3o`?oo`<10
0030@020oh30P83Ro`70P?X00D20Uol0o:go0<3n0010lol0P?h01d3ool3o`?o0
o?l<a82b`<3ojY20a<R0`?go5L3ool30oh00083o`?o0ooo0`?oo`43l0020o_l0
@>Ko0L20nP01@821okoo0<3n0010lol0P?h01d3ool3o`?o0o?l<a82b`<3ojY20
a<R0`?go5L3ool30oh00083o`?o0ooo0`?oo`43l0020o_l0@>Ko0L20nP01@821
okoo0<3n0010lol0P?h01d3ool3o`?o0o?l<a82b`<3ojY20a<R0`?go5L3ool30
oh00083o`?o0ooo0`?oo`43l0020o_l0@>Ko0L20nP01@82Co`3Z[_l0`?h00H30
o_l0`?ko0<3no`70`?d01h30`?ooP?o0j_lE`<3ool30ol00083o`?n0ooo0`?oo
`?`01830oh10jOl1P43j0060`87o_Ol0`?h00H30o_l0`?ko0<3no`70`?d01h30
`?ooP?o0j_lE`<3ool30ol00083o`?n0ooo0`?oo`?`01830oh10jOl1P43j0060
`87o_Ol0`?h00H30o_l0`?ko0<3no`70`?d01h30`?ooP?o0j_lE`<3ool30ol00
083o`?n0ooo0`?oo`?`01830oh10jOl1P43j0060`93o0:j^o`>00020loom0020
o_l0P?ko083Xo`20o_l40?n0003mo`20o_l2P?n0o03nP07oP>co083h087o^Ol3
P000P??oo@00P?ko083no`20j?l0P?ko103oP000oOl0P?ko0X3oP?`0oX01oh3/
o`20n021okWo0h00083cood0083no`20o_l0P>So083no`@0oh000?go083no`:0
oh3l0?j00On0k?l0P?P0S?l0i:oo0<3n0?go0<3no`30o_l1`<3m00Q0ol3o`?o0
ol3ZoaG0ol3o`?o0ooo0@020`<3ool3o`?n0n`04@<20oh3_o`60P?X00H20POnh
o`30oP3mo`30o_l0`?ko0L30o@08@?o0ol3o`?o0j_lE`?o0ol3o`?oo`400P<30
ooo0ol3oP?/01430P?n0kol1P83j0060P87o^?l0`?h0oOl0`?ko0<3no`70`?d0
243o`?o0ol3o`>[o5L3o`?o0ol3ool100830`?oo`?o0oh3k00A0`83oP>oo0H20
nP01P82:o`4>/?l0`?h00<3eo`20oP0>@83o`?o0ol3ool3o`?o0o_l0`?ko0<3m
o`30o_l0`?ko4l3o`?o0ooo0ol20`?o0ol3o`?n0n@03P?n0@??o0X20@?/00T20
`87o]_l0`?h00<3eo`20oP0>@83o`?o0ol3ool3o`?o0o_l0`?ko0<3mo`30o_l0
`?ko4l3o`?o0ooo0ol20`?o0ol3o`?n0n@03P?n0@??o0X20@?/00T20`87o]_l0
`?h00<3eo`20oP0>@83o`?o0ol3ool3o`?o0o_l0`?ko0<3mo`30o_l0`?ko4l3o
`?o0ooo0ol20`?o0ol3o`?n0n@03P?n0@??o0X20@?/00T20`8Oo0C:ao`30oP00
`?ko0<3no`30o_l1`43n03R0ooo0ol3o`?o0ooo0`?oo`<3ool3o`?o0oh3ool30
ooo0ol3o`?o0ol3o`?oo`<3ooh3o`?o0oh3j00>0oom0mol2`810n`02@830POnc
o`30oP00`?ko0<3no`30o_l1`43n03R0ooo0ol3o`?o0ooo0`?oo`<3ool3o`?o0
oh3ool30ooo0ol3o`?o0ol3o`?oo`<3ooh3o`?o0oh3j00>0oom0mol2`810n`02
@830POnco`30oP00`?ko0<3no`30o_l1`43n03R0ooo0ol3o`?o0ooo0`?oo`<3o
ol3o`?o0oh3ool30ooo0ol3o`?o0ol3o`?oo`<3ooh3o`?o0oh3j00>0oom0mol2
`810n`02@830Pol18;;o083n0030m_l0P?h0?D20ol3ool3o`?o0oh3o`?o0ol3o
ol3o`?o0ol3o`?o0ol3o`?oo`?o0ol3oP?o0ol3o`?oo`?o0ol3o`810o002`820
n_l1P83j0060P87o/?l0P?h00<3fo`20oP0m@83o`?oo`?o0ol3oP?o0ol3o`?oo
`?o0ol3o`?o0ol3o`?o0ooo0ol3o`?n0ol3o`?o0ooo0ol3o`?o0P43l00;0P83j
o`60P?X00H20POn`o`20oP00`?Ko083n03e0P?o0ooo0ol3o`?n0ol3o`?o0ooo0
ol3o`?o0ol3o`?o0ol3ool3o`?o0oh3o`?o0ol3ool3o`?o0ol20@?`00/20P?[o
0H20nP01P821o`7oo`4m/ol0@?h00l3ool3mo`C0ooo0@?h0@430ooo0ol3o`?o0
ol3o`?oo`<3ooh3o`?o0ol3ool30ooo0`?oo`?o0ol3o`?oo`<3ool30ooo0ol3o
`?n0ol20oP02@?n0o_l1P83j0060P87o[Ol0@?h00l3ool3mo`C0ooo0@?h0@430
ooo0ol3o`?o0ol3o`?oo`<3ooh3o`?o0ol3ool30ooo0`?oo`?o0ol3o`?oo`<3o
ol30ooo0ol3o`?n0ol20oP02@?n0o_l1P83j0060P87o[Ol0@?h00l3ool3mo`C0
ooo0@?h0@430ooo0ol3o`?o0ol3o`?oo`<3ooh3o`?o0ol3ool30ooo0`?oo`?o0
ol3o`?oo`<3ool30ooo0ol3o`?n0ol20oP02@?n0o_l1P83j0060P87onol19KCo
043n0030mol0`?d0BL3o`?o0oh3o`?o0ol3ool3o`010oh000?o0ol3o`?oo`?o0
ol3oP?o0ol3o`?oo`?o0ol3o`?o0@83o`?o0ooo0ol200420@810n`02@830POn[
o`10oP00`?Oo0<3m04W0ol3o`?n0ol3o`?o0ooo0ol00@?n0003o`?o0ol3ool3o
`?o0oh3o`?o0ol3ool3o`?o0ol3o`420ol3o`?oo`?o0P010P420@?/00T20`87o
Zol0@?h00<3go`30o@19`?o0ol3oP?o0ol3o`?oo`?o0043oP000ol3o`?o0ooo0
ol3o`?n0ol3o`?o0ooo0ol3o`?o0ol10P?o0ol3ool3o`800@810P43k0090P<21
ooSo0Bjeo`10oP03`?oo`?go0l3ood3n04J0P<3ool30ooo0ol3o`?o0ooo0`400
@000@<3o`?o0oh3ool30ooo0ol3o`?o0ol3o`?oo`<3ooh300020ol3ool30oon0
@?X00T20P87oZ?l0@?h00l3ool3mo`?0oom0oP16P830ooo0`?oo`?o0ol3o`?oo
`<1004000430ol3o`?n0ooo0`?oo`?o0ol3o`?o0ol3ool30oon0`000P?o0ooo0
`?ooP43j0090P821ojSo043n00?0ooo0oOl3`?oo@?h0AX20`?oo`<3ool3o`?o0
ol3ool30@0100010`?o0ol3oP?oo`<3ool3o`?o0ol3o`?o0ooo0`?ooP<00083o
`?oo`<3ooh10nP02@820POodo`3e]Oon0?Ko083n0020o_l0P?ko083mo`20o_l0
0?ko083m0020o_l0P?ko083no`20oOl0P?ko083no`20o_l0P?ko1H000?ooP?ko
083h087oY?on0?Ko083n0020o_l0P?ko083mo`20o_l00?ko083m0020o_l0P?ko
083no`20oOl0P?ko083no`20o_l0P?ko1H000?ooP?ko083h087oY?on0?Ko083n
0020o_l0P?ko083mo`20o_l00?ko083m0020o_l0P?ko083no`20oOl0P?ko083n
o`20o_l0P?ko1H000?ooP?ko083h087ol?l12[Ko0d000<3go`10oP13@?oo`?o0
ol3o`?oo`<3ool30ooo0ol100020ooo0`?oo`?o0ol3o`?o0ol3ool30oon0ol3o
`?o0ooo0`400@<3oP43i0020POnSo`=00030mol0@?h0@d3ool3o`?o0ol3ool30
ooo0`?oo`?o0@000P?oo`<3ool3o`?o0ol3o`?o0ooo0`?ooP?o0ol3o`?oo`<10
0430oh10n@00P87oXol3@000`?Oo043n04=0ooo0ol3o`?o0ooo0`?oo`<3ool3o
`400083ool30ooo0ol3o`?o0ol3o`?oo`<3ooh3o`?o0ol3ool30@010`?n0@?T0
0821onko0A>go`=00010o_l0`?ko0l3oP43n01N0oon0ol3o`?o0ooo0`?oo`<3o
ol3o`43m02=0`<3ool30ooo0ol3o`?n0ooo0`?oo`?o0ol3o`?o0ol3ood3g0060
P87oX_l3@000@?ko0<3no`?0oh10oP0GP?ooP?o0ol3o`?oo`<3ool30ooo0ol10
o@0S@<30ooo0`?oo`?o0ol3oP?oo`<3ool3o`?o0ol3o`?o0oom0m`01P821oj;o
0d00043no`30o_l3`?n0@?h05h3ooh3o`?o0ol3ool30ooo0`?oo`?o0@?d08d30
`?oo`<3ool3o`?o0oh3ool30ooo0ol3o`?o0ol3o`?oo@?L00H20POo/o`41^?l3
@000@?So043n01Q0ooo0`?oo`?o0ol3oP?oo`<3ool3o`?o0oP0SP000ooo0`?oo
P?o0ol3o`?oo`<3ool30ooo0ol3o`?o0oh10n@01P821oioo0d00043ho`10oP0H
@?oo`<3ool3o`?o0oh3ool30ooo0ol3o`?h08h000?oo`<3ooh3o`?o0ol3ool30
ooo0`?oo`?o0ol3o`?n0@?T00H20POnOo`=00010n?l0@?h0643ool30ooo0ol3o
`?n0ooo0`?oo`?o0ol3n02>0003ool30oon0ol3o`?o0ooo0`?oo`<3ool3o`?o0
ol3oP43i0060P87oj?l11;Wo0d00043no`20o_l1`<3m03b0`<3ool3o`?o0ol3o
`?o0ooo0`?ooP?o0ol00@?oo`<3ool30ooo0ol3o`?o0ooo0`?oo`<3ool3o`810
m`00P87oWOl3@000@?ko083no`70`?d0?830`?oo`?o0ol3o`?o0ol3ool30oon0
ol3o`010ooo0`?oo`<3ool3o`?o0ol3ool30ooo0`?oo`?o0P43g0020POnMo`=0
0010o_l0P?ko0L30o@0lP<30ooo0ol3o`?o0ol3o`?oo`<3ooh3o`?o0043ool30
ooo0`?oo`?o0ol3o`?oo`<3ool30ooo0ol20@?L00821onGo0AVko`30oP00@?Wo
043m03W0`?oo`<3ool3o`?o0ol3ool30ooo0`?oo`?n0043oP?oo`<3ool3o`?o0
ol3o`?o0ooo0`?ooP<20n@07@830od000<3foof00HC<POnao`30oP00@?Wo043m
03W0`?oo`<3ool3o`?o0ol3ool30ooo0`?oo`?n0043oP?oo`<3ool3o`?o0ol3o
`?o0ooo0`?ooP<20n@07@830od000<3foof00HC<POnao`30oP00@?Wo043m03W0
`?oo`<3ool3o`?o0ol3ool30ooo0`?oo`?n0043oP?oo`<3ool3o`?o0ol3o`?o0
ooo0`?ooP<20n@07@830od000<3foof00HC<POogo`4a_?l0`?h0043no`30o_l1
P43n03>0ol3ool30oon0ol3o`?o0ooo0`?oo`<3ool3o`800`<3ool30ooo0`?oo
`?o0ol3oP?ooo/00P?T00T20`?_o0h000<3go`00oX02J`W8POnco`30oP00@?ko
0<3no`60@?h0<h3o`?oo`<3ooh3o`?o0ol3ool30ooo0`?oo`?o0P030`?oo`<3o
ol30ooo0ol3o`?n0ooon`020n@02@830nol3P000`?Oo003nP09[2LR1ok?o0<3n
0010o_l0`?ko0H10oP0cP?o0ooo0`?ooP?o0ol3o`?oo`<3ool30ooo0ol200<30
ooo0`?oo`<3ool3o`?o0oh3oook0083i0090P<3ko`>00030mol00?j00V/9b87o
n?l15[go0<3n0010n_l0`?d0=Oo0ooo0`?oo`<3ool3o`?o0oh3ool30ooo0ol3o
`800ol3o`?oo`<3ooh3o`?o0ol3ool10@?T00H30m_l3`000`?So003mo`5gP87o
]?l0`?h0043jo`30o@0eol3ool30ooo0`?oo`?o0ol3oP?oo`<3ool3o`?o0P03o
`?o0ooo0`?ooP?o0ol3o`?oo`410n@01P<3fo`?00030n?l00?go0GN0POndo`30
oP00@?[o0<3m03Go`?oo`<3ool30ooo0ol3o`?n0ooo0`?oo`?o0ol200?o0ol3o
ol30oon0ol3o`?o0ooo0@43i0060`?Ko0l000<3ho`00oOl1Mh21ooSo0>nmo`20
oP3no`20o_ol0?ko003no`20oOl0P?ko083no`20o_l0P?go183o0020o_l0P?ko
083mo`20o_of0?7o0X000?So003mo`5MT87o]?l0P?h0o_l0P?koo03no`00o_l0
P?go083no`20o_l0P?ko083mo`B0o`00P?ko083no`20oOl0P?komP3ao`:0003h
o`00oOl1GI21okCo083n0?ko083noo`0o_l00?ko083mo`20o_l0P?ko083no`20
oOl4P?l0083no`20o_l0P?go083nooH0lOl2P000n?l00?go0Ef@POoho`47__l3
`000@?[o043n0390`?o0ooo0ol3o`?o0ol3o`?o0ol3ool3o`?o0oh3o`?l0@<3o
ol3o`?o0ol3o`?o0P43i0020kOl2@010nOl00?j00VHRjX7o]Ol3`000@?[o043n
0390`?o0ooo0ol3o`?o0ol3o`?o0ol3ool3o`?o0oh3o`?l0@<3ool3o`?o0ol3o
`?o0P43i0020kOl2@010nOl00?j00VHRjX7o]Ol3`000@?[o043n0390`?o0ooo0
ol3o`?o0ol3o`?o0ol3ool3o`?o0oh3o`?l0@<3ool3o`?o0ol3o`?o0P43i0020
kOl2@010nOl00?j00VHRjX7on?l19Koo0<3n00K0ooo0ooo0o@0`P<3ool30ooo0
ol3o`?n0ooo0`?oo`?o0ol3o`?o0ol3o`010oon0ol3o`?o0oh10@?X00D20n_l4
P83o083eo`90043jo`00oX02Laj4POnfo`30oP06`?oo`?oo`?d0<830ooo0`?oo
`?o0ol3oP?oo`<3ool3o`?o0ol3o`?o0ol00@?ooP?o0ol3o`?n0@43j0050P?[o
1820o`20mOl2@010n_l00?j00W<NQ87o]_l0`?h01/3ool3ool3m0320`?oo`<3o
ol3o`?o0oh3ool30ooo0ol3o`?o0ol3o`?o0043ooh3o`?o0ol3oP410nP01@83j
o`B0P?l0P?Go0T00@?[o003nP09c7XB1ooSo0A?0o`30oP00`?co083m02g0ol3o
`?o0ol3o`?o0ol3ool3o`?o0oh3o`?o0ol3ool3o@020ol3o`?o0`810nP01P83f
o`B0P?l0P?Co0T00@?_o003mo`7V2H7o]ol0`?h00<3lo`20o@0]`?o0ol3o`?o0
ol3o`?o0ooo0ol3o`?n0ol3o`?o0ooo0od00P?o0ol3o`<20@?X00H20m_l4P83o
083do`90043ko`00oOl1iPV1okOo0<3n0030o?l0P?d0;L3o`?o0ol3o`?o0ol3o
`?oo`?o0ol3oP?o0ol3o`?oo`?m0083o`?o0ol30P43j0060P?Ko1820o`20m?l2
@010nol00?go0NH9POoho`4a`Ol0`?h00/3o`?ko043n02^0ol3ool30oon0ol3o
`?o0ooo0`?oo`<3ool3o`?o0ol3ool100?o0`?n0P?X00T20`?Oo3:HR029EP?l0
EC`44IGgo`=00030oOl00?go0MdAPOnho`30oP02`?o0o_l0@?h0:h3o`?oo`<3o
oh3o`?o0ol3ool30ooo0`?oo`?o0ol3o`?oo`400ol30oh20nP02@830mol<YR80
8UF0o`1E?0@AUOOo0d000<3mo`00oOl1gA61okSo0<3n00;0ol3no`10oP0[P?o0
ooo0`?ooP?o0ol3o`?oo`<3ool30ooo0ol3o`?o0ooo0@03o`<3oP83j0090P<3g
o`bV8P0REH3o05Dl116Emol3@000`?go003mo`7M4H7on?l1;/;o083n0030oOl0
`?h0:D30oh3o`?o0ol3ool3o`?o0ol3o`?o0ol3o`?oo`?o0ol3oP?o00420P?X0
0T20P?Co3]dAX_O<4H3o001<P2H0dOOo0d000<3no`00oX02N1j8POnio`20oP00
`?go0<3n02U0`?n0ol3o`?o0ooo0ol3o`?o0ol3o`?o0ol3ool3o`?o0oh3o`010
P83j0090P83do`kM4J;gc160o`00C80V0=7go`=00030o_l00?j00WPNR87o^Ol0
P?h00<3mo`30oP0Y@<3oP?o0ol3o`?oo`?o0ol3o`?o0ol3o`?o0ooo0ol3o`?n0
ol00@820nP02@820m?l>gA6Rml`AP?l004b09P3Amol3@000`?ko003nP09h7XR1
ooSo0AW3o`10oP05`?o0ol20oP0V@<3o`?oo`<3ool30ooo0ol3o`?n0ooo0`?oo
`?o0ol3o`?o0ol20n@01P<3`o`6<J_ko2Fn0o`1RoooQ08Sfo`F00030ooolP030
POnio`10oP05`?o0ol20oP0V@<3o`?oo`<3ool30ooo0ol3o`?n0ooo0`?oo`?o0
ol3o`?o0ol20n@01P<3`o`6<J_ko2Fn0o`1RoooQ08Sfo`F00030ooolP030POni
o`10oP05`?o0ol20oP0V@<3o`?oo`<3ool30ooo0ol3o`?n0ooo0`?oo`?o0ol3o
`?o0ol20n@01P<3`o`6<J_ko2Fn0o`1RoooQ08Sfo`F00030ooolP030POogo`3V
a?l0P?h0083mood00H20oOl0P?ko083no`20o_l0P?go083no`20o_l0P?ko0H20
n03/o`60P?ko1820o`20o_l1083eo`:00021ok;o083n0020oOom0060P?go083n
o`20o_l0P?ko083mo`20o_l0P?ko083no`60P?P0k?l1P83no`B0P?l0P?ko0@20
mOl2P000POnbo`20oP00P?goo@01P83mo`20o_l0P?ko083no`20oOl0P?ko083n
o`20o_l1P83h0>co0H20o_l4P83o083no`40P?Go0X00087okol0n<Co0d00043n
o`70@?h08d3ool30ooo0ol3o`?o0ooo0`?oo`<3ool3o`?o0oh3ool10@?X00H20
j_l1R6[no`UZP?l0G_oog@2<m?l2@010POnco`=00010o_l1`43n02=0ooo0`?oo
`?o0ol3o`?oo`<3ool30ooo0ol3o`?n0ooo0@43j0060P>[o0HQZo_l9JX3o05ko
omd0S?Co0T00@87o/ol3@000@?ko0L10oP0S@?oo`<3ool3o`?o0ol3ool30ooo0
`?oo`?o0ol3oP?oo`410nP01P83Zo`68J_ko2FZ0o`1NoooM08cdo`900421oo3o
0>c5o`10oP03`?o0`?d0o/0Mooo0`?oo`?o0ol3oP?oo`<3ool3o`?o0ol3o`810
nP02@000iol>d@fRmlP=P?l004b09P3Mlol2@010POneo`10oP03`?o0`?d0o/0M
ooo0`?oo`?o0ol3oP?oo`<3ool3o`?o0ol3o`810nP02@000iol>d@fRmlP=P?l0
04b09P3Mlol2@010POneo`10oP03`?o0`?d0o/0Mooo0`?oo`?o0ol3oP?oo`<3o
ol3o`?o0ol3o`810nP02@000iol>d@fRmlP=P?l004b09P3Mlol2@010POoao`3_
a_l3@000@?ko043n01j0ol3ool30oon0ol3o`?o0ooo0`?oo`<3ool3o`810nP01
@83no`40P>Ko39dR03=VP?l0EC`44Igao`900421okOo0d00043no`10oP0NP?o0
ooo0`?ooP?o0ol3o`?oo`<3ool30ooo0ol20@?X00D20o_l1083Vo`bM8P0cIX3o
05Dl116MlOl2@010POngo`=00010o_l0@?h07X3o`?oo`<3ooh3o`?o0ol3ool30
ooo0`?oo`?o0P43j0050P?ko0@20i_l<WB80<fJ0o`1E?0@AWO7o0T00@87ol_l0
_lOo1d00043ooh10oP0LP?n0ooo0`?oo`?o0ol3o`?o0ol3ool30ool0P43k0090
P<3lo`:00838o`900421okWo1d00043ooh10oP0LP?n0ooo0`?oo`?o0ol3o`?o0
ol3ool30ool0P43k0090P<3lo`:00838o`900421okWo1d00043ooh10oP0LP?n0
ooo0`?oo`?o0ol3o`?o0ol3ool30ool0P43k0090P<3lo`:00838o`900421oo?o
0;?8o`I00010oon0o@0Dol3ool30ooo0`?oo`?o0ol3o`?ooo/01P43k0090P<3h
o`600<Ko0d000<21okco1T00043ooh3m01Co`?oo`<3ool30ooo0ol3o`?o0ooon
`060@?/00T20`?So0H00a_l3@000`87o_?l6@000@?ooP?d05?o0ooo0`?oo`<3o
ol3o`?o0ol3oook00H10n`02@830n?l1P036o`=00030POoeo`2TbOl5@000@?o0
o@0DP?o0ol3ool30ooo0`?oo`?o0ol3ooX3j0060P?Co0D00aOl3@000`87o__l5
@000@?o0o@0DP?o0ol3ool30ooo0`?oo`?o0ol3ooX3j0060P?Co0D00aOl3@000
`87o__l5@000@?o0o@0DP?o0ol3ool30ooo0`?oo`?o0ol3ooX3j0060P?Co0D00
aOl3@000`87om_l0W/_o0<3m007oP?d05<30ol3o`?o0ooo0`?ooP?o0ol20P?X0
0H20l?l10434o`>00030POo1o`30o@01oh3m01C0`?o0ol3o`?oo`<3ooh3o`?o0
P83j0060P?3o0@10a?l3P000`87o`Ol0`?d00On0o@0D`<3o`?o0ol3ool30oon0
ol3o`820nP01P83`o`40@<Co0h000<21ooOo08W;ood00H20o@01oh3no`20oOl0
P?ko083no`20n@00P>go0@20`ol2P000POo1ood00H20o@01oh3no`20oOl0P?ko
083no`20n@00P>go0@20`ol2P000POo1ood00H20o@01oh3no`20oOl0P?ko083n
o`20n@00P>go0@20`ol2P000POogo`2Ec?l0`?h00D20oP0A@?oo`?o0ol3oP?o0
ol3o`<20n@01P<3/o`800832o`900421ol?o0<3n0050P?h04D3ool3o`?o0oh3o
`?o0ol30P?T00H30k?l20020`_l2@010POo3o`30oP01@83n0150ooo0ol3o`?n0
ol3o`?o0`83i0060`>co0P00P<;o0T00@87on?l0RLgo0<3n0050@?h03X3oP?oo
`<3ool3o`?o0P?T00H30j?l10030o`900421olGo0<3n0050@?h03X3oP?oo`<3o
ol3o`?o0P?T00H30j?l10030o`900421olGo0<3n0050@?h03X3oP?oo`<3ool3o
`?o0P?T00H30j?l10030o`900421ooWo07[>o`30nP0=@<3o`?o0ol3o`?o0P83j
0050P>Go0X000;oo0T00@87oaol0`?X03D30ol3o`?o0ol3o`820nP01@83Uo`:0
002oo`900421olOo0<3j00e0`?o0ol3o`?o0ol20P?X00D20iOl2P000_ol2@010
POojo`1acol0`?X02T30ol3ool30ol10nP01@83Qo`:0082no`900421olWo0<3j
00Y0`?o0ooo0`?o0@?X00D20hOl2P020__l2@010POo9o`30nP0:@<3o`?oo`<3o
`43j0050P>7o0X00P;ko0T00@87onol0VM3o0<3j00S0`?o0ol3oP43j0060`=ko
0P00P;go0d000<3no`30m_l2fLSooH01VN61onCo0<3j00S0`?o0ol3oP43j0060
`=ko0P00P;go0d000<3no`30m_l2fLSooH01VN61onCo0<3j00S0`?o0ol3oP43j
0060`=ko0P00P;go0d000<3no`30m_l2fLSooH01VN6Eo`2FdOl0`?/01X30`?o0
P43j0060`=[o0@00^ol7@000`?ooP83go`TlP?o^07OcI@WIPOoVo`30n`06P<30
ol20@?X00H30f_l1002ko`M00030oon0P?Oo2Cb0onh0Mo=U2MV1onKo0<3k00J0
`<3o`810nP01P<3Jo`400;_o1d000<3ooh20mol9?83okP1glfD9fIKo08gBo`20
n`03`?n0P?X00D20eol2P000^_l6P000`?l0@?Oo2H20ool0P?og08B1onOo083k
00?0oh20nP01@83Go`:0002jo`J00030o`10mol9P83oo`20ooL0Q87oiol0P?/0
0l3oP83j0050P=Oo0X000;[o1X000<3o043go`V0P?oo083om`24U_l0U^3o1<`Z
02[<nOl0P?/00?oh0=?o0H00^?l5P000o`00n_l<^`P@IX3oo`20onh0P87omOl4
c2X0:/cio`20n`00ooP0dol1P02ho`F0003o003jo`bk211VP?oo083okP20POoe
o`C<:P0Zc?Wo083k003on03Co`600;So1H000?l00?[o3;/846J0ool0P?o^082F
o`2OhOl6`0UAP5X8Y_[o083e0090P<3Bo`600;Oo1D00@000P?co3Nh[hNi4P?oo
083cI@3APOofo`K02E60FPRVn_l0P?D00T20`=;o0H00]ol5@0100020o?l=kR_Q
kTB0ool0P?=U0=61ooKo1/09DH1J2:Kjo`20m@02@830d_l1P02go`E00400083l
o`g^:n7^A83oo`20lfD0dIKo09KRo`;V4K_no`;01<cko`10n001P83>o`400;Ko
043m0?co39U_oon0P?oo0420P=61ooKo0^HA^oko0/04c?_o043h0060P<ko0@00
]_l0@?d0o?l<VFoooh20ool0@820dH7om_l2iQ6ko_l2`0C<nol0@?P00H20c_l1
002fo`10o@3lo`bIKoooP83oo`10P83AUOl0SN;o0Da8o?l1DB[looX00H20b_l1
082ho`;0P83m0020oOl9P7cooh20ool0P87olol1C4Slo`5A:_conP01P83:o`40
P;So0/20P?d0083mo`V0O?ooP83oo`20POoco`5<B?co0E4Zo?oj0060P<[o0@20
^?l2`820o@00P?go2H1loon0P?oo082Bo`2=h_l1083lo`600?cooP02P830b?l2
P020^_l0@?P00<3no`VZ<oooP7coo`20POoco`40P?co0H00o?on00:0P<38o`:0
082jo`10n000`?ko2JXcoon0O?oo0821oo?o0@20o?l1P03looh00X20`<So0X00
P;[o043h0030o_l9ZS?ooh1lool0P9;o07GRo`4ALoco0FHI_Ol1P02go`70P?/0
043mo`UJDIUAF_m_02o0POodo`4ALoco0FHI_Ol1P02go`70P?/0043mo`UJDIUA
F_m_02o0POodo`4ALoco0FHI_Ol1P02go`70P?/0043mo`UJDIUAF_m_02o0Tol0
C^;o0XPNnoko0_LFX[go0@00]?l1`83m087oi_l2R1kko_l2maJR_Ol1002do`70
P?d0POoVo`:87__no`;g5Z:mo`400;Co0L20o@25o`18hOl16I3no`68<kco0@20
/Ol3P000P87oi_l16I3no`68<kco0@20/Ol3P000P87oi_l16I3no`68<kco0@20
/Ol3P000P8Ko04GQo`JV25j0GQ70_Ol2`020[ol1`<21onKo1ZH8GX1N4L2mo`;0
082_o`70`87oi_l6YPQNP5hA`;go0/00P:oo0L30Q_l0<^3o1>JAP9W^_?l2P030
POnAo`CVTH2Ik[co0X00`87oTOl4iY60VNjlo`:00<21ok;o01^Fo`50087oPOo6
o`50087oPOo6o`50087o/Ol06iKo0@10POn1olKo0@10POn1olKo0@10POnao`0N
Uol2`020POn1olOo0/00P87oPOo7o`;00821ok7o01jGo`:00<21oh7oaol2P030
POn1olOo0X00`87o/Ol06iOo0H00POn1olKo0H00POn1olKo0H00POn`o`0KUol1
0021oh7oa_l10021oh7oa_l10021ok3o01^Go`40@87oPOo6o`40@87oPOo6o`40
@87o/?l09i_o1H20ol00P87oPOo:o`F0P?o00821oh7ob_l5P83o`020POn`o`0W
Vol5P020P030POn1ol[o1H00P800`87oPOo:o`F008200<21ok3o032Ko`S00010
0?ooP<21oh7ocOl8`000@03ooh30POn1olgo2<000400oon0`87o/ol099[oo@02
@020POn1ol_oo@02@020POn1ol_oo@02@020POnbo`0NV_ol0010POn1ol[oo000
@87oPOo:oo`00421ok7o01RJoo`0POn1olWoo021oh7obOol087o/?l07Y[oo@00
@87oPOo9ood00421oh7obOom0010POn`o`0HV_om087oPOo8ood0POn1olSoo@21
ojoo026Jo`>00030POn1olSo0h000<21oh7ob?l3P000`87o[ol06iWo0@20POn1
olKo0@20POn1olKo0@20POn^o`0HVOl0@87oPOo5o`10POn1olGo0421ojgo01RI
o`30POn1olGo0<21oh7oaOl0`87o[Ol0487oPOn1oh7oPOn1oh7ob_l0;I7o0[:@
oo`00B[<POn1olko0[:@oo`00B[<POn1olko0[:@oo`00B[<POnno`0fTOl:?83o
kP1_onil2M61oh7ocol:?83okP1_onil2M61oh7ocol:?83okP1_onil2M61okoo
03JAo`Z0P?oo083ooo/0P87oPOo?o`Z0P?oo083ooo/0P87oPOo?o`Z0P?oo083o
oo/0P87o_ol0?iCo3G=VMd20ool0P?oof@2oPOn1om;o3G=VMd20ool0P?oof@2o
POn1om;o3G=VMd20ool0P?oof@2oPOnoo`0oUOl=a4CoogN0ool0@7=EIl21oh7o
d_l=a4CoogN0ool0@7=EIl21oh7od_l=a4CoogN0ool0@7=EIl21okko03bEo`b4
P?ooP83oo`20C01NPOn1om7o38B0oon0P?oo081<05j1oh7odOl<Q83ooh20ool0
P4`0GX7o_Ol0?iGo3HQRoon0P?oo083cC02IPOn1om;o3HQRoon0P?oo083cC02I
POn1om;o3HQRoon0P?oo083cC02IPOnno`1>UOl>hAGAoeXlonh0KoooGP2kg_ol
087oPOoko`kQ5M7oFScokP1_oomN0;_Noo`0POn1oo_o3^4EdOmJ??o^06oooeh0
^mkoo021onOo04jDo`FR039^/_on00F0ooL00;_Ooo`0POn1oo[o1J80<Vjbooh0
1H3om`00^mooo021oh7on_l5XP0bK[;ooP05P?og002kgool087oiol06X7ohool
087oPOo9oo`0POn1olWoo021onOo01Z1on?oo021oh7obOol087oPOo9oo`0POoW
o`00o`\>"], "Graphics",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    ImageSize->{232, 191.313},
    ImageMargins->{{302, 0}, {0, 4}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "\n"
}], "Graphics",
  Editable->False,
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{317, 262},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0006=T0@0005P0000I00005@000202003a0@00
00000000002[>`00KSH00215CDH00040I6<008@100060000000000000000000000@00003000>0@00
b`0004H0001T6`00F1/004M4BD<1002000<000do6W/00000@1/000402@000j0=000601`0000000D0
000;0_ooool5000030:<0K81100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@040000104700@000040@d0100002d10`040000l04000P0003j0PD0
00000?ooo`840000;@4000L0000K1<T0W02c08401@0000T200000P@0000^0@00100002d11@040000
l04201`0003k0^ko00000000T04000000000<T5bJF5/000000000000000000000000000000000000
100002d10P0700008@D106Co]02100D000090P0000840000;P4000@0000]0@D010000?010P0L0000
n`;^o`0000000;`2000000000391LVUQK0000000000000000000000000000000000000@0000]0@80
1`0002450@1Sok@0R`040000;@4400@0003`0@401@00004200000PD000090_ooo`8]0000@P430000
:00000P0000800000@010000000P0000000000000000000000000000003oool00@0000P000200000
40000080001000001000020000040000;@4100`0000T0`@0:P0k0JX0f@3G00/1:P0k0@@0000]0@<0
10000?0100080000nP8000400@000002100002d1000<00009@<402X0>`6Z0=T0e`0;0BX0>`440000
;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00100002d110040000l04100D000010P00
008500002@;oool2;@0004810`0002P000080000200000400@000000800000000000000000000000
00000000oooo000000000000000000P0000000000000000000200000100002d10@0<000090<402X0
>`6Z0=T0e`1m02X0>`440000;@4300@0003`0@0020000?X20001004000000P@0000]0@00300002D3
100Z03/1ZP3I0=L0O@0Z03/1100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000@0
000]0@@010000?010@0500000@8000021@0000T2oooo0Rd000120@<0000X0000200000P000010040
0000020000000000000000000000000000000?ooo`010000PP0004@0000X0000400002P000140000
PP0000@0000]0@40300002@3103G07d0ZP3I0=L02`7G07d0100002d10`040000l04000P0003j0P00
0@01000000840000;@4000`0000U0`@0e`1m0:X0f@3G00/1e`1m00@0000]0@<010000?0100080000
nP850000003oool2100002d100040000;@4400@0003`0@401`000?`200000000S8d40000;@4100h0
000T0`D0?@4A03H18`0a0Ah0;04I03d14@040000;@4300@0003`0@0020000?X20001004000000P@0
000]0@003P0002D31@0m0A40=P4S03417P0/0AT0?@4A00@0000]0@<010000?0100080000nP8000<0
0`000002100002d1000800009@<202X0>04b0Ad0100002d10`040000l04000P0003j0PD000000?oo
o`840000;@4000@0000]0@@010000?010@070000o0800?ooo`2<S@@0000]0@401`0001/41@6Y0>h0
R`0500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@000000000b
@G9YHF`00000000000000000000000000000000000040000;@4200L0000Q1@8086C_08/01@0000T2
00000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000_08000000000<T5bJF5/0000
00000000000000000000000000000000100002d10P0700008@D1067ok`2J00L0000K12d1c00F0K40
1@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000T04000000000<T5b
JF5/000000000000000000000000000000000000100002d10P0700008@D106Co5`6a00D000090P00
00840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000;`2000000000391LVUQK0000000
000000000000000000000000000000@0000]0@801`0002450@1RoaL1^`040000;@4400@0003`0@40
1`000?`200000000S8d40000;@4100h0000T0`D0e@230=@0T`3>0940b@2>0=D0P`040000;@4300@0
003`0@0020000?X20001004000000P@0000]0@003P0002D31@3E08<0e02C0<h0T@3908h0e@2300@0
000]0@<010000?0100080000nP8000800P000002100002d1000800009@<20:/0f`3>0900100002d1
0`040000l04000P0003j0PD000000?ooo`840000;@4000@0000]0@@010000?010@070000o0800?oo
o`2<S@@0000]0@401`0001/4`@3?0:X0]00500002@800002100002h100040000;@4500@0003`0@80
70000?/2k_l00000002@0@000000000b@G9YHF`00000000000000000000000000000000000040000
;@4200L0000Q1@40I?n[0;@01@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko
00000000_08000000000<T5bJF5/000000000000000000000000000000000000100002d10P070000
8@D107?oZ`2n00@0000]0@@010000?010@070000o0800000002<S@@0000]0@403P0002@31@3E00P1
aP010L/0o@3?0?T0e@080@@0000]0@<010000?0100080000nP8000400@000002100002d1000>0000
9@<50=D020760041b`3m0<l0n@3E00P1100002d10`040000l04000P0003j0P000P02000000840000
;@4000P0000U0`80Z`3K0<`0oP040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00
100002d110040000l04100L0003l0P00oooo08b=100002d10@0700006`Cl0<`0iP2g00D000090P00
00840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000901000000000391LVUQK0000000
000000000000000000000000000000@0000]0@801`0002450@1TonL0]`0500002@800002100002h1
00040000;@4500@0003`0@8070000?/2k_l00000002l0P000000000b@G9YHF`00000000000000000
000000000000000000040000;@4200L0000Q1@40L_oW0<401`0001/4B`4U03D14P0500002@800002
100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@000000000b@G9YHF`000000000
00000000000000000000000000040000;@4200L0000Q1@40Colf0A801`0001/4h02Z0<X0VP050000
2@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@000000000b@G9YHF`0
0000000000000000000000000000000000040000;@4200L0000Q1@40@Oo;09X01`0001/49P7]0101
g00500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@000000000b
@G9YHF`00000000000000000000000000000000000040000;@4200L0000Q1@40@_lA0M`01`0001/4
NP3M06@0b`0500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@00
0000000b@G9YHF`00000000000000000000000000000000000040000;@4200L0000Q1@40@omU0</0
100002d110040000l04100L0003l0P00000008b=100002d10@0>000090<504L0[01F0;80CP2c04d0
^`170:`0100002d10`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0A`2/05H0
/P1>0;<0C@2k04L0[0040000;@4300@0003`0@0020000?X20002008000000P@0000]0@00200002D3
0P1>0;<0P`3Y00@0000]0@<010000?0100080000nP850000003oool2100002d1000>000090<50901
;@260Cd0PP4h07d1<P2@0Bd0100002d10`040000l04000P0003j0P000@01000000840000;@4000h0
000U0`D0T04]08H1?@220CP0O@4b0901;@040000;@4300@0003`0@0020000?X2000300<000000P@0
000]0@00200002D30P0X03/1P`4g00@0000]0@<010000?0100080000nP850000003oool2100002d1
000>000090<507d1f@1^0ND0K07N06X1e`1m0MT0100002d10`040000l04000P0003j0P000@010000
00840000;@4000h0000U0`D0O@7I06h1i@1/0Mh0JP7G07d1f@040000;@4300@0003`0@0020000?X2
000300<000000P@0000]0@00200002D30P0[03X1KP7N00@0000]0@<010000?0100080000nP850000
003oool2100002d100040000;@4400@0003`0@401`000?`2003oool0S8d40000;@4100L0000K1:`0
F02F03d01@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000T0400000
0000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d10P0700008@D106CoUP0m00D0
00090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000;`200000000039DJFeU
Lb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`0002450@1AoiH0AP040000;@4400@0
003`0@401`000?`200000000S8d40000;@4100h0000T0`D0N`1N0GT0CP5m05@1Q01A0G/0GP440000
;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@1k05h1N@1>0Gd0E0640541
N`1N0@@0000]0@<010000?0100080000nP8000800P000002100002d1000800009@<207d0E@6?00/1
100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000@0000]0@@010000?010@070000
o0800?ooo`2<S@@0000]0@401`0001/4M@6L05l1P@0500002@800002100002h100040000;@4500@0
003`0@8070000?/2k_l00000002@0@000000000bE6U]IG<PCVEg859_KF5^00000000000000000000
00040000;@4200L0000Q1@40I?mO0H401@0000T200000P@0000^0@00100002d11@040000l04201`0
003k0^ko00000000_08000000000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d1
0P0700008@D105;oG`6:00@0000]0@@010000?010@070000o0800000002<S@@0000]0@403P0002@3
1@3j0441j`0k0O<0>P7d0381nP110@@0000]0@<010000?0100080000nP8000400@000002100002d1
000>00009@<50?X0@@7[03/1l`0j0O@0<P7j0441100002d10`040000l04000P0003j0P000P020000
00840000;@4000P0000U0`80a`0>0O<0>P440000;@4300@0003`0@0020000?X21@000000oooo0P@0
000]0@003P0002@31@0>0KH00`7200D1^P3n0;L03P6f00@0000]0@<010000?0100080000nP800040
0@000002100002d1000>00009@<500h1]P030L801@6j0?h0]`0>0KH0100002d10`040000l04000P0
003j0P000P02000000840000;@4000P0000U0`80bP3E00H1^P040000;@4300@0003`0@0020000?X2
1@000000oooo0P@0000]0@00100002d110040000l04100L0003l0P00oooo08b=100002d10@070000
6`A60AX1<07o00D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000901
00000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`0002450@1Toc01
o`0500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002l0P000000000b
E6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40D?l`0@P11`0001/4
`00]0JX04P4500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@00
0000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40I?nZ0181
1@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000_08000000000<UAY
KFEc84iUMb1BKfeQKP0000000000000000000000100002d10P0700008@D104KoZP0K0@@0000]0@@0
10000?010@070000o0800000002<S@@0000]0@403P0002@31@3800h1`P080L002@7600l1b00>0@h0
000T0`D0^`010KD0n`2c0?`0^@020K/00@4>000090<50:l0m@2Y0>l0Y`3`0:d0mP2_0?D0100002d1
0`040000l04000P0003j0P000P02000000840000;@4000P0000U0`80S0080I803P4800009@<208`0
3P6B00P1200002D30P200>D0QP3Z00P0000U0`80P03Z08H0i@0800009@<20<P0e03>0=T0200002D3
0P380=T0cP3D00P0000U0`80YP3]0:`0lP0800009@<20:H0lP2/0>d01@0000T200000P@0000^0@00
100002d11@040000l04201`0003k0^So00000000_08000000000<TeQM6QUKF5dJF=Q=de_KVl00000
0000000000000000100002d10P0700008@D106Go`P1?0@D000090_l000840000;P4000@0000]0@D0
10000?010P0L0000n`;bo`000000090100000000039DJFeULb1>IGLPDVm]HFh00000000000000000
000000@0000]0@801`0002450@0bolh0GP4500002@800002100002h100040000;@4500@0003`0@80
70000?/2j?l00000002l0P000000000bCF5dJ6E]HGAYHf4gCFm^K`00000000000000000000040000
;@4200L0000Q1@40IOll08811@0000T2o`000P@0000^0@00100002d11@040000l04201`0003k0_;o
00000000T04000000000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d10P070000
8@D1037oB02A0@D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;Xo`0000000;`2
00000000039=HGAXIFeQM6USHCM=Kfi_0000000000000000000000@0000]0@801`0002450@1Uo`l0
204500002@;o0002100002h100040000;@4500@0003`0@8070000?/2l_l00000002@0@000000000b
E6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40<olK01L1100002L1
ool40000l04000@0003`0@4010000?010P040000l04300@0003`0@@010000?011@030000000A0000
300000P0000;0000400004<2000?0P002@00010000130P003`8000X0000@0000ooooooooool90000
40000;81002<0@004P0000`0000100008@0000P0000D0000300000L0000D0000300000d0000V0000
700000400005000000000000003oool29@0000`0000100009@0000`000000020:`0001P000210000
/`0009/000380000600000`000000002DP0004`100020000k_ooo`00000000000000090100000000
0000<T40LP1Y0640K00000Dj2SXH>Qdj:cX`>W0jPcZ9>YPjWSZW>PPk7c]S>j8k]S^m>lHkfC_O>nDk
n3_n>`@l000001ll:C`_?3@l?Sa4?4XlICa^?7HlP3b;?9DlZSbb?;Tl_Sc3?=4lfCcR?1Pm@3e=?Elm
LCeh?GlmQSf=?I@mX3f`?Khme3dL?R@nVCjg?]8nk3kb?P`o:cm0?i/oYcn^?l0ob3o>?mHojCo_?oho
070003@20008<0h`7C0W<000=c0o<4T`DC1S<6``LS24<8d`U32J<:D`]333<<T`cc3E<=/`k33e<?h`
1c4E<DPaKC60<J4aYc6c<K/afS40000000000000000000000000000000010@410@410@41WS8U0000
30000080001D0000E0000:d0003a0000^P0000/100010000_K@<@XZd34:10000]0000040001<0000
000000000000000000000000001@0000I03V=0X0001B0000C04000<0000000000000000000000000
GP4000000000004P003`=OTe13H>=QHf83HX=S8f?3I;=UDfGcI^=WdfPcJ9=XlfUCJV=Zlf^3K1=//f
dCH4=bTg?3MV=hHgScL00000eCOM=oLg0CPQ>3`h@SQ<>58hGCQ/>7/hPCR7>8dhTcRV>:`h/SRh>;hh
ccSJ>>DhkSSd>?`h:CTd>E0iMcVB>JHi[SVd>L4id3WO>NDijcWa>OLi13X:>Q/j9cX_>T<jC3YF>WXj
YSZ]>[ljac[=>]Djfc[S>^TjlCX=>a8k000P>bHk;c]:>edkOS^5>l4kkC/B?4@lHcaY?8TlScb`?>0l
0cdB?Bhm@ceG?F`mLcei?GlmQCf;?IPm[CgS?@00000000000000000000000000000000410@410@41
0@4^?bD0000<00000`0002P0000<00000P000580001<0@000P000>koool0000000000000002l0P00
0000000003910780J@1Q06`0000l<U4bJS9m<Y8bYC:i</`bhC;d<Plc5c<M<bDc:c<j<dLcDS=P<fHc
Kc=e<h0cU3>K<`00003J<ndc3S@E=2Ld;c@e=3hdA3AB=8DdZSBm=000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000040P0004X0001b1`004@0=0545002J3P000000000000000000000004=_
MG9YIG8PCVEg00000000000000000000000000000000000000000000000000000@410@410@410@00
9@0000`000020000E00005@0002k0000l@000<L0000=0@000@000;fd34::]0a2R`000;@000010000
C0000000000000000000000000000000D00006<0000:00006@0000`000000002600000`0003oool2
G@000700000400000P000200000`0000D0000200000X0000200000P0000100400000000000000000
000000000000000000000?ooo`01000020000800000@00000P00040000040000800002D0000<0000
100005H0000/0000>@000281000P0@00Y@4000@0000Z03/1ZP3I0=L02`4Z03/19P0001`000050000
000000400001000000000RD0000<00001@0002P0000<00000@0002H0000L00000@00000000010000
0@000000008U000030000040001G0000;00003T0000R0@0080400:D100040000:P0k0JX0f@3G00/1
:P0k0BD0000<00001@0002P0000<00000@0002D0000<00000000P2P0000<0000100002H0000L0000
100000D00000000000000?ooo`8U0000300000@0001M0000L00000400002000080000300001@0000
800002P000080000200000400@00000000000000000000000000000000000000oooo000000000000
000000P00000000000000000002000009@0000`000010000EP0002`0000i0000Z0000201002U0@00
100002X0>`6Z0=T0e`1m02X0>`4U0000300000D0000X0000300000@0000V0000700000@000000000
0@000040000000029@0000`000040000E`0002`0000i0000Z0000201002U0@00100002X0>`6Z0=T0
e`1m02X0>`4U0000300000D0000X0000300000@0000U000030000000080X000030000040000V0000
700000400005000000000000003oool29@0000`000010000G@000700000400000P000200000`0000
D0000200000X0000200000P0000100400000000000000000000000000000000000000?ooo`010000
PP0004@0000X0000400002P000140000PP0002D0000<0000100005H0000/0000i0000:P0000P0@00
I@4000@0003G07d0ZP3I0=L02`7G07d09@0000`000050000:00000`0000100009P0001`000010000
000000400001000000000RD0000<00000@0005L0000/0000i0000:P0000P0@00I@4000@0003G07d0
ZP3I0=L02`7G07d09@0000`000050000:00000`0000100009@0000`000000020:00000`000040000
9P0001`0000400001@00000000000000oooo0RD0000<0000100002D0000<00001000P5H0000`0000
TP4001P0002X0@00<00000D0000m0A40=P4S03417P0/0AT0?@4A02D0000<00001@0002P0000<0000
100002H0000L000010000000000100000@000000008U0000300000@0001G0000<0000981000H0000
Z040030000050000?@4A03H18`0a0Ah0;04I03d14@0U0000300000D0000X0000300000@0000V0000
700000@0000000000`0000<0000000029@0000`000040000E`0002@0000g00009P0009`1002S0@00
0P0002X0>04b0Ad09@0000`000050000:00000`0000400009P0001`0000400001@00000000000000
oooo0RD0000<0000100002D0000<00000000P2/0000H0000R`000>h0002X0000104001P0000<0000
00000RD0000<00000`0002P0000<00000P000580001<0@000P000>koool0000000000000002@0@00
0000000003910780J@1Q06`000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00080000200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0
200800P0200800P0200800P0200000P0200800P0200800P0200800P0200800P0200800P0200800P0
200800P0200800P0200800P0200800P0000000000000000000000000000000000@410@410@410@P0
9@0000`000020000E00005P0002k0000?`400<l0001I0@000@000;fd34::]0a2R`000>l000020000
C0000000000000000000000000000000D0000200I00600002P0002D0000<00000`0002P0000<0000
0P000580001<0@000P000>koool0000000000000002l0P000000000003910780J@1Q06`0000800P0
200800P0200800P0200800P0200800P0200800P0200800P0200800P020080000000800P0200800P0
200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0
200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200000P0
200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0
000000000000000000000000000000000@410@410@410@P09@0000`000020000E00005@0003?0000
?`400=/0001K0@000@000;fd34::]0a2VP000>l000010000C0000000000000000000000000000000
D0000640200:0000:`0001P0002a00005P400</0000/0@009@0000`000030000:00000`000020000
DP0004`100020000k_ooo`000000000000000901000000000000<T40LP1Y0640K00000P0200800P0
200800P0200800P0200800P0200800P0200800P0200800P0200800P0000000P0200800P0200800P0
200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0
200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P020080000200800P0
200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P020000000
00000000000000000000000000010@410@410@41200U000030000080001D0000E0000>d0001e0@00
nP0008l100010000_K@<@XZd34:a00005`400040001<0000000000000000000000000000001@0000
I00800X0000U0000300000<0000X000030000080001B0000C0400080003^oooo0000000000000000
_08000000000000b@@1b06T0H@1/0000200800P0200800P0200800P0200800P0200800P0200800P0
200800P0200800P020000000200800P0200800P0200800P0200800P0200800P0200800P0200800P0
200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0200800P0
200800P0200800P0200800P0200800P0000800P0200800P0200800P0200800P0200800P0200800P0
200800P0200800P0200800P0200800P020080000000000000000000000000000000000410@410@41
0@4802D0000<00000P0005@0001D0000n`0007D100090@00T@400040002m]0a2R[@<@[/0000G0@00
0@0004`000000000000000000000000000000500001R00P02`0002D0000<00001000P5H0000`0000
3@400;00000M0@00a@0000D0003E08<0e02C0<h0T@3908h0e@2302D0000<00001@0002P0000<0000
100002H0000L000010000000000100000@000000008U0000300000@0001G0000<00000d1002`0000
7@400<D000050000e@230=@0T`3>0940b@2>0=D0P`0U0000300000D0000X0000300000@0000V0000
700000@0000000000P000080000000029@0000`000040000E`0002@0003T0000`00001D1000V0@00
0P000:/0f`3>09009@0000`000050000:00000`0000400009P0001`0000400001@00000000000000
oooo0RD0000<0000100002D0000<00000000P2/0000H0000]0000:X0003>0000`00002D0000<0000
0`0002P0000<00000P000580001<0@000P000>koool0000000000000002@0@000000000003910780
J@1Q06`00027>8lhU3RQ>:Lh`CSH>=hh03T;>Ali9CT]>C8i?cU9>EHiG3Uf>G/iR3VB>IliYCW1>@00
0006>Q@j6CX/>S/j@3YC>V@jJCYc>X0jQSZW>Zdj^c[1>]`joSX<>aXk83]A>fDkKS]f>h<kRC^S>j`k
]3_1>lLkiS_`>ohk13`O?2/l>Sa>?60lOSb4?:Pl_Cc3?<TllScn?3Hm?Se4?F<mM3fM?K8me3g[?O/m
33hX?T8nFch007hnQcj??Y`nXSjl?/8ne3kP?^ln03lB?bdo<cmA?f<oJCm_?kLoeSoM?n<olCog?`00
060205`1000?<1/`000000000000000000000000000000000@410@410@410I`a9@0000`000020000
E00005@0003a0000i@000?h0003o00000@000;fd34::]0a2]0000:/000010000C000000000000000
0000000000000000D00006@003D:00009@0000`000030000:00000`000020000DP0004`100020000
k_ooo`000000000000000;`2000000000000<T40LP1Y0640K000060hLCR2>9LhXcR/>>Dh5STM>D8i
E3UP>FliP3VB>Jdi/cWA>N<ijCW_>@hj5CXR>Rlj000006TjNSZ:>[djaS[?>^<jjCX1>a0kES]k>hdk
]c_8>mHkg3_c>`4l>Sa;?5TlGcb6?;DlaScD?=XllC`5?APmASeY?G<mP3fC?kHo07020>010001<0L`
5S0L<4D`L32T<<8``34`<THbC3:4<XlbV3:Q<ZXb/c:j</hbgC;[<P000C<D<adc<3<i<ddcFS>7<i<c
Uc>K<ilcXc>W<j/c[c>c<kLc03@<=1/dAcA?=5ddISAb=:0dZSBg=;ddeC@000000000000000000000
0000000000010@410@410@41jCDU000030000080001D0000E0000?l0003U00002`40004100010000
_K@<@XZd34:n0000Z`000040001<0000000000000000000000000000001@0000L`1S>0X0000U0000
300000@0081F0000<00000T1001=0@007@40064100050000e@080LH00@7;0?d0c`3i0=D0204U0000
300000D0000X0000300000@0000V0000700000@0000000000@000040000000029@0000`000040000
E`00030000090@00C@4001d1001Q0@001@000=D020760041b`3m0<l0n@3E00P19@0000`000050000
:00000`0000400009P0001`000040000000000800002000000000RD0000<0000100005L0000T0000
i00002@1000B0@00E0400080002[0=/0c03n02D0000<00001@0002P0000<0000100002H0000L0000
100000D00000000000000?ooo`8U0000300000@0000U000030000000080[000060000;L0003V0000
b`000?/0000U0000300000<0000X000030000080001B0000C0400080003^oooo0000000000000000
T04000000000000b@@1b06T0H@1/00006SPW>2dhASQ<>5/hJCQc>80hQSRO>:Ph]cRm><8hacSB>00i
2STG>Adi=CU4>G0iNST00000VSVW>JdiaCWD>MXijCT@>QPj8SX_>SDjCCYL>V8jKSYl>XPjU3ZP>Z`j
^3[4>]0jgcX1>`dk4C/E>aTk7C/Q>bDk:C/]>c4k=C]L>hdkUC^K>l0kbS_G>mdkmS_k>a4l6c`V?3@l
>Ca??5XlIcab?:0lZSbg?;dleScK??8l0005?A`m:Se@?EXmJce`?GXmQcf=?JDm]3fj?LTmd3gH?Mhm
43hJ?RLn;3hf?T<nBCiQ?WHnOSj4?YTnXCk@?P00000000000000000000000000000000410@410@41
0@6f?bD0000<00000P0005@0001D0000m@0003D100020@00C`400040002m]0a2R[@<@[L0003W0000
0@0004`000000000000000000000000000000500001T0;la2P0002D0000<00000`0002P0000<0000
0P000580001<0@000P000>koool0000000000000002l0P000000000003910780J@1Q06`0002R=:Ld
]CCP=>XdmcCm=1@e6SDW=CDe>SE7=E8eEcER=FLeMCFP=JXe^cG1=LdeecGT=@000000=Q4f5cHS=Rdf
>SI0=UPfIcI]=W`fPSJA=YLfYSJ]=[`fbSKI=^Lfm3H6=`lg6CLY=cHg?SM5=e8gFSMQ=g4gOSN6=hdg
VSNR=jLg[CO2=o0gnSL;>14h7CPW>3@h>SQB>64hIcQf>7dhS3RJ>:Th]cS4>=0heCSO>>ThnCP000hi
5CTR>BXi<CU1>DhiESUM>FXiLSUg>GdiTSW0>MHig3WX>Ohi13X@>RHj;3Xh>ThjE3ZF>ZHjcC[M>_Dj
000000000000000000000000000000000@410@410@410NDk9@0000`000020000E00005@000030@00
=@4000/1001A0@000@000;fd34::]0a2`@000>L000010000C0000000000000000000000000000000
D0000780ACl70000:`0001P0000B0000=@4002@0001:0@009@0000`000030000:00000`000020000
DP0004`100020000k_ooo`000000000000000901000000000000<T40LP1Y0640K0000</bl389<`lc
<c=A<jTc`3?a<oXc2C@C=1hd9c@h=3hdASAE=5hdI3A^=7@dOCB8=9<d00000;@di3C[=?Pdoc@<=B8e
<SE==HDeZ3F_=KHe_SG9=M0ef3GQ=N/elcGm=@Df2cHC=QTf8cIZ=W@fPCJ6=Y0fWCJS=[`f`cK;=]4f
ecKN=^DfkCKd=P@g7SL^=dXgD3M_=i@g[CNc=l`gfcOZ=o4g;SPg>4HhD3QK>6@hMCR4>000TcRM>:<h
[3Rg><0haSS@>=lhjcSa>?/h0ST:>A4i63TP>CLiAcUH>FliOcV@>JLi]cW8>MlikcT0>PLj3SX00000
00000000000000000000000000010@410@410@41lCXU000030000080001D0000E00001T0002N0@00
:`000;P100010000_K@<@XZd348B0000=P400040001<0000000000000000000000000000001@0000
C`1R?@h0000[0000600009X0003:0000Z@000=l0000U0000300000<0000X000030000080001B0000
C0400080003^oooo0000000000000000T04000000000000b@@1b06T0H@1/0000jSoa?oPo0000/080
4080000`1c0G<38`@S1N<6@`Pc2X<<4`ac3P<>l`oS05<D8aBS400000MC60<HTaV36Q<JLa/C6g<Lda
eS7L<NHamC41<PLb4C8P<RLb;c8f<SdbAC9<<U<bFc9R<VTbLC:8<YPbZC;0<]0bhC;h<PPc6C<`<d0c
DC=H<elcIc=b<gTcPC>:<i@cW3>V<jhc^C?1<lTce3?L<nHc7S@X=3Dd>cAC=68d001j=8TdSSBH=:Dd
ZcC3==8decC]=?<d3CDF=AheCCEF=FXeL3F:=ILeXcFb=NXel3D1=QXf<3Hf=S`fB3IK=P0000000000
0000000000000000000000410@410@410@4Z>BD0000<00000P0005@0001D0000c`0000l1003M0000
:@400040002m]0a2R[@<@YX0003;00000@0004`00000000000000000000000000000050000110:Xk
2`0002/0000H0000g0000101003]00009P4002D0000<00000`0002P0000<00000P000580001<0@00
0P000>koool0000000000000002@0@000000000003910780J@1Q06`0002B?YPnYSk<?]4nfckX?^hn
o3h??a@o7Sl[?c4o?cmB?eLoHCm^?g@oPSnE?iXoY3na?`00003A?oXo0000`080]04001T`830o<4D`
QC2?<9d`/c31<24a<S50<EhaK37<<Mdajc4e<SlbCC9S<W4bdC;R<_0b3S<L<g`cSC>K<k0cdS?P<o4c
0C@;=1Ld7c@[=5TdKCAd=:Hd_CC3=>TdlS@T=C/e@CEI=FdeM3FV=Kde`cD001hf;CHk=TXfLcIo=Z<f
]cKB=]Xfj3K_=_Lfo3H2=a4g5SLP=bdg<cM1=ddgEcMT=fXgN3N5=h/gT3NJ=jLg0000000000000000
00000000000000000@410@410@410MDh9@0000`000020000E00005@0000W0@00K@4003H100270@00
0@000;fd34::]0a2g000014100010000C0000000000000000000000000000000D0000480Qc/<0000
:`0001P0003;0000I0000=`0001i00009@0000`000030000:00000`000020000DP0004`100020000
k_ooo`000000000000000901000000000000<T40LP1Y0640K0000;Tnc3kB?^4nich<?kXob3o^?o`o
0=0207@10001<10`5C0T<60`YS2[<<l`fc3W<00a000004haLc5h<GhaRC6?<IXaX36[<K4a_371<NXa
l37f<O`a9S9B<W0bV39/<g/cRS>/<lhcfc<4=0Xd43@A=[df`SKA=_TfocHS=c@gH3M/=g/gR3N==ilg
^SO?=m/gh3L=>1/h83Q3>58hLcQi>9dh[SSK>>@hk3Sh>0Li53TQ>@00<cTi>E`iJcV3>IHi^cW5>Mdi
l3TE>R/j=cY6>U<j`3[<>]/ji3XA>adk>C/n>d/kFC]O>fhkOC^E>j8k/3/000000000000000000000
0000000000010@410@410@41kc`U000030000080001D0000E00001010028000080400:8000010000
_K@<@XZd34;;0000I@000040001<0000000000000000000000000000001@0000@`1^?`d0000U0000
300000@0081F0000<0000600003V0000M0000?X000050000A`2/05H0/P1>0;<0C@2k04L0[00U0000
300000D0000X0000300000@0000V0000700000@0000000000@000040000000029@0000`000040000
E`000300001P0000iP0007@0003j00001@0004L0[01F0;80CP2c04d0^`170:`09@0000`000050000
:00000`0000400009P0001`000040000000000800002000000000RD0000<0000100005L0000T0000
J0000>l0002a0000>0400080001>0;<0P`3Y02D0000<00001@0002P0000<0000100002H0000L0000
100000D00000000000000?ooo`8U0000300000@0001F0000<0000?h1000m00005`8005<000050000
T04]08H1?@220CP0O@4b0901;@0U0000300000D0000X0000300000@0000V0000700000@000000000
0@000040000000029@0000`000040000E`000300003n0@00?@0001L2001C00001@000901;@260Cd0
PP4h07d1<P2@0Bd09@0000`000050000:00000`0000400009P0001`000040000000000<000030000
00000RD0000<0000100005L0000T0000=@0004T000080P00Y`400080000X03/1P`4g02D0000<0000
1@0002P0000<0000100002H0000L0000100000D00000000000000?ooo`8U0000300000@0001F0000
<0000>@1000O0@00oP40038100050000O@7I06h1i@1/0Mh0JP7G07d1f@0U0000300000D0000X0000
300000@0000V0000700000@0000000000@000040000000029@0000`000040000E`000300003T0@00
7`400?h1000b0@001@0007d1f@1^0ND0K07N06X1e`1m0MT09@0000`000050000:00000`000040000
9P0001`000040000000000<00003000000000RD0000<0000100005L0000T0000>@0002L1003/0@00
Y@400080000[03X1KP7N02D0000<00001@0002P0000<0000100002H0000L0000100000D000000000
00000?ooo`8U0000300000@0000U000030000000080[0000600003d0002F0000E`000:/0000U0000
300000<0000X000030000080001B0000C0400080003^oooo0000000000000000T04000000000000b
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0003ooh?416JS9?2Z0@no1BC`ZP65`0n41@000>TT
00000000X0:[0HG03h`70000I_l=X0:[0H]528]09XU52>W?n_ooIZ4Tl:X1j@00001OGU_9`lc<c<c<
c<c<c<c<c<aERnaCEUMVa`F0ojX10@1Va`DDlJX15PAVXACaZP5@j6aPoOn3a0BSi?2Z0J7Tl:X1R`f8
ojX1>l4?Q`80002;0028ojX1XMSnZP5@JP5Z16STl:X1j<I?oOn3a12S6?2Z0H<m6?2Z0@0?S`h0001V
a`DTl:X13@3Y@`400:7HoP00000000000000000000000000000000410@410@410@4>02D0000<0000
0P0005@0001D0000D`000<T0001N0000h`000040002m]0a2R[@<@Sd0002F00000@0004`000000000
000000000000000000000500001T0:=P2@0002D0000<00000`0002P0000<00000P000580001<0@00
0P000>koool0000000000000002l0P0000000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP0001S`ZP403hl>0000I/L59?2Z0@d0jD<0002;A@R;@000003`ZP6Qf?jZ0E1Z0FX2J63`ZP7XPdkm
oh?44:<Hl:X1PcdHl:X100n?3P0006K71BC`ZP4=0>T00000IZ4Tl:X1j@00001OGU_9`eF;k8?/45=F
EfK7AOP106K71BC`ZP4008]5253X[`_ooh?418]5253X4k;ooh?418]526H0039VRDGlRdD8IX]0=6J9
AOj;AOa@j:420023a0AVXbC`ZP4?_`DTl:X1QL0?Q0D0003Y0`4008]526J;@2iV0000000000000000
00000000000000000@410@410@410@DT9@0000`000020000E00005@0001O0000b@000740003R0000
0@000;fd34::]0a2AP0009H000010000C0000000000000000000000000000000D0000540JPP>0000
9@0000`000040020EP000300002S0000_P400;40003C0@001@0007/0GP5i04h1O@1D0H@0D@5k05h1
9@0000`000050000:00000`0000400009P0001`000040000000000400001000000000RD0000<0000
100005L0000`0000X`000;h1002a0000d`4000D0001k05h1N@1>0Gd0E0640541N`1N0BD0000<0000
1@0002P0000<0000100002H0000L000010000000000200000P000000008U0000300000@0001G0000
90000:L0001T0@00`@000<P100020000O@1E0Hl02`4U0000300000D0000X0000300000@0000V0000
700000@00005000000000000003oool29@0000`0000400009@0000`000000020:`0001P000210000
G`4009/0001d0@009@0000`000030000:00000`000020000DP0004`100020000k_ooo`0000000000
00000901000000000000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000j@00001VXBC`ZP7Y
000005mNFlW3c<c<c<c<c<c<00000<c<EH_/DeIGI/L59?2Z0@00I/L51?2Z0A@2IZ44l:X1D>R/Fogo
Pl@4XcC`ZP6QR?nZ0H/==?2Z0C_13hL20000Rl6SR?nZ0J7HoZX1D6X1JPAX=?2Z0NP6BogoPl@@XaS`
ZP63?AS`ZP403hl>0000I/L59?2Z0@d0jKT00000f?jZ0E1Z0FX2J0C`ZP7Xcd[moh?44:<Hl:X1PcdH
l:X100n?3P0006K71BC`ZP4=0>V20000IX]52VJSN?00000000000000000000000000000000010@41
0@410@41ZP4U000030000080001D0000E0000:d0003D0@00^0000>h100010000_K@<@XZd34:10000
G`400040001<0000000000000000000000000000001@0000I02Z0@T0000U0000300000<0000X0000
30000080001B0000C0400080003^oooo0000000000000000_08000000000000bE01Y06d0I@1c0200
CP1U07L0801B06l0K@1Q06h00015252;A@R:@2i@RdD8Rd0`D>RZ2?ooPl@<I/L5R?000000IZ68l:X1
D>P2F_goPl@4XdS`ZP6QR?nZ0H/=B?2Z0C_13hL20000Rl6SR?nZ0J7HoZX1D6X1JPAXB?2Z0NQLBOgo
Pl@@XaS`ZP63?AS`ZP403hl>0000I/L59?2Z0@d0jGD4002Qf?jZ0E1Z0FX2J8S`ZP7X9DWmoh?44:<H
0001PcdHl:X100n?3P0006K71BC`ZP4=0>Tn1000RdD8D>QY]oooPl@4RdD8RP0Uo`0008G03hDE0@00
RdD8IP00000000000000000000000000000000410@410@410@7`ZRD0000<00000P0005@0001D0000
^@000=@100390000k@400040002m]0a2R[@<@XX0001O0@000@0004`0000000000000000000000000
00000500001B003Y3@0002D0000<00001000P5H0000`0000>`4009T1001?0@00[@4000D0003j0441
j`0k0O<0>P7d0381nP110BD0000<00001@0002P0000<0000100002H0000L00001000000000010000
0@000000008U0000300000@0001G0000<00003/1002I0@00C`400:d100050000nP110N/0>`7c03X1
m00b0OX0@@4U0000300000D0000X0000300000@0000V0000700000@0000000000P00008000000002
9@0000`000040000E`0002@0000:0@00J04004L1002T0@000P000<L03P7c03X19@0000`000050000
:00000`0000400009P0001`0000400001@00000000000000oooo0RD0000<0000100005H0000`0000
E0400?@0001Z0@00104000D0000>0KH00`7200D1^P3n0;L03P6f02D0000<00001@0002P0000<0000
100002H0000L000010000000000100000@000000008U0000300000@0001G0000<00005@1003d0000
JP4000@1000500003P6f00<1`P050KX0oP2g00h1]P0U0000300000D0000X0000300000@0000V0000
700000@0000000000P000080000000029@0000`000040000E`0002@0000>0@00n0000601000N0@00
0P000<X0e@060KX09@0000`000050000:00000`0000400009P0001`0000400001@00000000000000
oooo0RD0000<0000100002D0000<00000000P2/0000H0000o`000301000J0@00A@4002D0000<0000
0`0002P0000<00000P000580001<0@000P000>koool0000000000000002@0@0000000000039D06T0
K@1U07<0801>06D0M`0P0580K`1]0640KP00000Uo`0008G03hD;0000RdD8aP0>j@H0002;A@S60000
002:02Go0000QL0?QAL0002;A@Q@j<[7oOn3a0AVXbC`ZP7Y4P0008]5253XXmGmoh?416JS9?2Z0@no
1BC`ZP65`0n41@000>TB0000RdD8D>RMmokoPl@4IZ<Tl:X1IZ4Tl:X1j@00001OGU_9`lc<c<aERnb3
k0ACEUMVa`D00:X1002;A@Q@j<G`oOn3a0B9AOb3OO`03hEM0`003kl5XP:[0HG03hE>0`00RdD8D>S]
0OooPl@4RdD8D8]5000000000000000000000000000000000@410@410@410@5@9@0000`000020000
E00005@0001F0@00UP400641002`0@000@000;fd34::]0a2o`00030100010000C000000000000000
0000000000000000D00006@0lP8900009@0000`000030000:00000`000020000DP0004`100020000
k_ooo`000000000000000;`2000000000000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
oOn3a12S6?2Z0H<m6?2Z0@0?S`h0001Va`DTl:X10000008008]526J;@3QVXi3`ZP6Qf?jZ0E1Z0FX2
J93`ZP7X>T?moh?44:<Hl:X1PcdHl:X100n?3P0006K71BC`ZP4=0>TW0P00RdD8IX]0=P0000000000
001=HGAXIFeQM6USHC5=Kfi_000000000000000000000>8300000000000000000000000000000000
000l100090@0000000000000000000000000000000000000000^1000000000000000000000000000
0000000000010@410@410@41000U000030000080001D0000E0000681002F0@00L0400:l100010000
_K@<@XZd34880@00<0400040001<0000000000000000000000000000001@0000D00000/0000[0000
60000181002Z0000;0400;l0000U0000300000<0000X000030000080001B0000C0400080003^oooo
0000000000000000T04000000000000bE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000:00001@0500/02`0;00/02`0;00/02`0;00/0000;00/02`0;00/02`0;00/02`0;00/0
2`0;00/02`0;00/02`0;00/02`0;00/02`0;00/02`0;00/02`0;0000000000000000000000000000
000000410@410@410@4;02D0000<00000P0005@0001D0000K`400>@0001j0@00oP000040002m]0a2
R[@<@Q81002Z00000@0004`000000000000000000000000000000500001T00l02@0002D0000<0000
0`0002P0000<00000P000580001<0@000P000>koool0000000000000002l0P0000000000039D06T0
K@1U07<0801>06D0M`0P0580K`1]0640KP0000/0100<00/01P0<00/02`0;00/0300<00/04`0;0000
000;00/02`0;00/02`0?00d02`0;00/03@0=00l03P0;00h02`0;00/02`0;00/0300;00/02`0;00/0
2`0;00/02`0;00/02`0=01404@0A00/02`0;00/02`0;00/02`0;014000000000000000000@l83gP0
oh61PH61PH400861PH7o000930b@0<0_1gS1f0l0H0l0/1/1/1l0h0000@P<2600080<06oooo060<08
0PD80Q00ool00087000000000000000000000000000000000@410@410@410@009@0000`000020000
E00005@0001k0@00i00008T1003m00000@000;fd34::]0a26`400:X000010000C000000000000000
0000000000000000D00004H0000;00009@0000`000040020EP00030000010@00H@4000`1001Z0@00
1@000<P03P7200P1`0090LH03`7800h1EP000300003`0000C`400?/0001I0@001@000;/00@6e0?/0
/`3l0;T00P6k0041EP000300003P0000?`400>/000190@001@000:l0m@2Y0>l0Y`3`0:d0mP2_0?D0
9@0000`000050000:00000`0000400009P0001`000040000000000800002000000000RD0000<0000
100005L0000T0000^`00060100350000JP400080002<00P1TP0>0EL0000T0000^`00060100350000
JP400080002<00h1TP080EL0000T0000Z`000341002e0000>P40008000200>D0QP3Z05L0000T0000
Z`000341002e0000>P40008000200>X0QP3U05L0000T00002`4001X1000E0@008`40008000380=@0
cP3I05L0000T00002`4001X1000E0@008`40008000380=T0cP3D05L0000T0000gP0003`1003X0000
A0400080002V0>d0[03b05L0000T0000gP0003`1003X0000A0400080002V0?80[03]02D0000<0000
0`0002P0000<00000P000580001<0@000P000>Soool0000000000000002l0P0000000000039=0640
M01X06D0K@1Q07@0J@1S0640=`1=06l0KP1_00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000@410@410@410@009@0000`000020000
E00005@000300@0010400=81000W0@000@000;fd34::]0a2C`400<8000010000C000000000000000
0000000000000000D00006D0000>0000600000`0003o00029@0000`000030000:00000`000020000
DP0004`100020000l_ooo`000000000000000901000000000000<U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000010@410@410@411@0U000030000080001D0000E0000=@1000C0@00
g04002L100010000_K@<@XZd349N0@00cP000040001<0000000000000000000000000000001@0000
<P0;00L0000H000030000000008U0000300000<0000X000030000080001B0000C0400080003Xoooo
0000000000000000_08000000000000bC@1Q07@0J01U06d0H@1d06T0H`1Q03L0C@1_06h0K`0000/0
1P0600H04@0;00/02`0;00/02`0;00/020000000200800l03`0?00/02`0;00/02`0;00/02`0<01D0
300?00`05`0G01L02`0;00/02`0;00/02`0;0140700A01D04@0Q02408@0;00/02`0;00/02`0;00/0
2`0;00D02`0;00P0300A00/02`0;00/02`0;00@02`0;00P0000@00l03`0=00d0300A01P08`0G01l0
5`0Q01L08@0@01T0400I00/02`0;00/02`0;00h05@0L00/02`0;0000000000000000000000000000
000000410@410@410@4002D0000<00000P0005@0001D000010800540000F0P00M0000040002m]0a2
R[@<@X81000l00000@0004`000000000000000000000000000000500001U00003P0001P0000<0000
o`000RD0000<00000`0002P0000<00000P000580001<0@000P000?;oool0000000000000002@0@00
00000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000@410@410@410@00
9@0000`000020000E00005@0000H0P00H@000202001e00000@000;fd34::]0a2T@4004P000010000
C0000000000000000000000000000000D000034000070000600000`0000000029@0000`000030000
:00000`000020000DP0004`100020000j?ooo`000000000000000;`2000000000000<Td0H@1d06P0
I@1]0640M01Y06<0H@0g04d0K`1^06l0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010@410@410@41000U000030000080001D0000
E0000681000E0000M04003P000010000_K@<@XZd34880@003`000040001<00000000000000000000
00000000001@0000I@0000h0000H000030000?l0008U0000300000<0000X000030000080001B0000
C0400080003boooo0000000000000000T04000000000000bE01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000410@410@410@4002D0000<00000P0005@0001D0000MP4002D0001n0@00
>@000040002m]0a2R[@<@QL1000K00000@0004`000000000000000000000000000000500000c0000
1`000280000<0000ooooobP0000<0000100002P0000<00000P0002P0000<00001@0002P0000<0000
0`0004/0000@0000000000D0000>000050000000000@00005000
\>"], "Graphics",
  Editable->False,
  ImageSize->{236, 216.375},
  ImageMargins->{{293, 0}, {0, 12}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
To the triangle ABC, corresponds the area element d\[DoubleStruckCapitalA]:\
\>", "Text"],

Cell[BoxData[
    \( (*\[IndentingNewLine]d\[DoubleStruckCapitalA] = \(1\/2\) 
          d\[DoubleStruckR]\[Cross]
            d\[DoubleStruckS]\[IndentingNewLine]*) \)], "Input"],

Cell[TextData[{
  StyleBox["d\[DoubleStruckCapitalA]",
    FontWeight->"Bold"],
  " can also be expressed as functions of the vectors ",
  StyleBox["d\[DoubleStruckA], d\[DoubleStruckB], d\[DoubleStruckC] ",
    FontWeight->"Bold"],
  ": ",
  StyleBox["d\[DoubleStruckR] = d\[DoubleStruckB] \[Dash] d\[DoubleStruckA]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["d\[DoubleStruckS] = d\[DoubleStruckC] \[Dash] d\[DoubleStruckA]",
    FontWeight->"Bold"],
  ","
}], "Text"],

Cell[BoxData[
    \(d\[DoubleStruckA] =. \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d\[DoubleStruckCapitalA] = \(1\/2\) \((d\[DoubleStruckB] - \ 
                d\[DoubleStruckA])\)\[Cross]\((d\[DoubleStruckC] - 
                d\[DoubleStruckA])\) // \(LinearBreakout[Cross]\)[
          d\[DoubleStruckA], d\[DoubleStruckB], d\[DoubleStruckC]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\(1\/2\ \((d\[DoubleStruckA]\[Cross]d\[DoubleStruckA] - 
                d\[DoubleStruckA]\[Cross]d\[DoubleStruckC] - 
                d\[DoubleStruckB]\[Cross]d\[DoubleStruckA] + 
                d\[DoubleStruckB]\[Cross]d\[DoubleStruckC])\)\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "If we chose the basis vectors along the three directions ",
  StyleBox["d\[DoubleStruckA]",
    FontWeight->"Bold"],
  ", ",
  StyleBox["d\[DoubleStruckB]",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["d\[DoubleStruckC]",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(d\[DoubleStruckA] = dau[red@1]\ \[DoubleStruckE]d[red@1]; 
    d\[DoubleStruckB] = dbu[red@2]\ \[DoubleStruckE]d[red@2]; 
    d\[DoubleStruckC] = 
      dcu[red@3]\ \[DoubleStruckE]d[red@3];\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckCapitalA] // \(LinearBreakout[
          Cross]\)[\[DoubleStruckE]d[_]]\), "\[IndentingNewLine]", 
    \(\(\(\(% // CrossProductExpansion[\[DoubleStruckE], e, k]\) // 
          EinsteinSum[]\) // LeviCivitaSimplify[e]\) // Factor\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckE]", 
                          InterpretationBox[
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            SequenceForm[ 
                              red[ 1]],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ 1], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckE], 
                          SequenceForm[ 
                            red[ 1]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "\[Cross]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckE]", 
                          InterpretationBox[
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            SequenceForm[ 
                              red[ 1]],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ 1], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckE], 
                          SequenceForm[ 
                            red[ 1]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], " ", 
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["da", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["1",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ 
                                        red[ 1], ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["1",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    SequenceForm[ 
                                      red[ 1]],
                                    Editable->False]],
                                Subsuperscript[ da, 
                                  SequenceForm[ 
                                    StyleForm[ 
                                      red[ 1], ShowContents -> False]], 
                                  SequenceForm[ 
                                    red[ 1]]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckE]", 
                          InterpretationBox[
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            SequenceForm[ 
                              red[ 2]],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ 2], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckE], 
                          SequenceForm[ 
                            red[ 2]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "\[Cross]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckE]", 
                          InterpretationBox[
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            SequenceForm[ 
                              red[ 1]],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ 1], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckE], 
                          SequenceForm[ 
                            red[ 1]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["db", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ db, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["da", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 1]],
                          Editable->False]],
                      Subsuperscript[ da, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1]]],
                      Editable->False],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckE]", 
                          InterpretationBox[
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            SequenceForm[ 
                              red[ 1]],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ 1], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckE], 
                          SequenceForm[ 
                            red[ 1]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "\[Cross]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckE]", 
                          InterpretationBox[
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            SequenceForm[ 
                              red[ 3]],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ 3], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckE], 
                          SequenceForm[ 
                            red[ 3]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["dc", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ dc, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["da", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 1]],
                          Editable->False]],
                      Subsuperscript[ da, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckE]", 
                          InterpretationBox[
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            SequenceForm[ 
                              red[ 2]],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ 2], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckE], 
                          SequenceForm[ 
                            red[ 2]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "\[Cross]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckE]", 
                          InterpretationBox[
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            SequenceForm[ 
                              red[ 3]],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ 3], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckE], 
                          SequenceForm[ 
                            red[ 3]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["db", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ db, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["dc", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ dc, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"]}]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["e", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["1",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["2",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["3",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ 1], 
                      red[ 2], 
                      red[ 3]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 1], ShowContents -> False], 
                      StyleForm[ 
                        red[ 2], ShowContents -> False], 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ e, 
                  SequenceForm[ 
                    red[ 1], 
                    red[ 2], 
                    red[ 3]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 1], ShowContents -> False], 
                    StyleForm[ 
                      red[ 2], ShowContents -> False], 
                    StyleForm[ 
                      red[ 3], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["db", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ db, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["dc", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ dc, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckE]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 1]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["da", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 1]],
                          Editable->False]],
                      Subsuperscript[ da, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["dc", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ dc, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckE]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["da", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 1]],
                          Editable->False]],
                      Subsuperscript[ da, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["db", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ db, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckE]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"]}]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The covariant components ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["dA", 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["h",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ h]],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["h",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ h], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " of the vector ",
  StyleBox["d\[DoubleStruckCapitalA]",
    FontWeight->"Bold"],
  " element of surface"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(d\[DoubleStruckCapitalA] = %\),
      FontWeight->"Bold"]], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["e", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["1",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["2",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["3",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ 1], 
                      red[ 2], 
                      red[ 3]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 1], ShowContents -> False], 
                      StyleForm[ 
                        red[ 2], ShowContents -> False], 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ e, 
                  SequenceForm[ 
                    red[ 1], 
                    red[ 2], 
                    red[ 3]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 1], ShowContents -> False], 
                    StyleForm[ 
                      red[ 2], ShowContents -> False], 
                    StyleForm[ 
                      red[ 3], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["db", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ db, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["dc", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ dc, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckE]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 1]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["da", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 1]],
                          Editable->False]],
                      Subsuperscript[ da, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["dc", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ dc, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckE]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["da", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 1]],
                          Editable->False]],
                      Subsuperscript[ da, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["db", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ db, 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckE]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"]}]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(dAvald[l_] := 
      d\[DoubleStruckCapitalA] . \[DoubleStruckE]d[
          l]\), "\[IndentingNewLine]", 
    RowBox[{\({dAvald[red@1], dAvald[red@2], dAvald[red@3]}\), "=", 
      RowBox[{
        RowBox[{
          RowBox[{\({dAvald[red@1], dAvald[red@2], dAvald[red@3]}\), 
            StyleBox["//",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox["ExpandAll",
              FontColor->RGBColor[0, 0, 1]]}], 
          "//", \(EvaluateDotProducts[\[DoubleStruckE], g]\)}], "//", 
        "Factor"}]}]}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{\(1\/2\), " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["db", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["2",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ 2]],
                        Editable->False]],
                    Subsuperscript[ db, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 2], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ 2]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["dc", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["3",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ 3]],
                        Editable->False]],
                    Subsuperscript[ dc, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 3], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ 3]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ 1], 
                          red[ 2], 
                          red[ 3]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 2], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ 1], 
                        red[ 2], 
                        red[ 3]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 1], ShowContents -> False], 
                        StyleForm[ 
                          red[ 2], ShowContents -> False], 
                        StyleForm[ 
                          red[ 3], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{\(1\/2\), " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["da", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["1",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ 1]],
                        Editable->False]],
                    Subsuperscript[ da, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 1], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ 1]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["dc", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["3",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ 3]],
                        Editable->False]],
                    Subsuperscript[ dc, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 3], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ 3]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ 1], 
                          red[ 2], 
                          red[ 3]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 2], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ 1], 
                        red[ 2], 
                        red[ 3]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 1], ShowContents -> False], 
                        StyleForm[ 
                          red[ 2], ShowContents -> False], 
                        StyleForm[ 
                          red[ 3], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{\(1\/2\), " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["da", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["1",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ 1]],
                        Editable->False]],
                    Subsuperscript[ da, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 1], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ 1]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["db", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["2",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ 2]],
                        Editable->False]],
                    Subsuperscript[ db, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 2], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ 2]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ 1], 
                          red[ 2], 
                          red[ 3]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 2], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ 1], 
                        red[ 2], 
                        red[ 3]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 1], ShowContents -> False], 
                        StyleForm[ 
                          red[ 2], ShowContents -> False], 
                        StyleForm[ 
                          red[ 3], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["For instance :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(dAvald[red@1]\), "\[IndentingNewLine]", 
    \(\(% /. \(LeviCivitaRule[e, \[Epsilon]]\)[\[ScriptG], red]\) /. 
      PermutationSymbolRule[\[Epsilon]]\), "\[IndentingNewLine]", 
    \(% /. \[ScriptG] -> g\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["db", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["2",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 2], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["2",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 2]],
                    Editable->False]],
                Subsuperscript[ db, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 2], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 2]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["dc", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["3",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["3",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 3]],
                    Editable->False]],
                Subsuperscript[ dc, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 3], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 3]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["e", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["1",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["2",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["3",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ 1], 
                      red[ 2], 
                      red[ 3]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 1], ShowContents -> False], 
                      StyleForm[ 
                        red[ 2], ShowContents -> False], 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ e, 
                  SequenceForm[ 
                    red[ 1], 
                    red[ 2], 
                    red[ 3]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 1], ShowContents -> False], 
                    StyleForm[ 
                      red[ 2], ShowContents -> False], 
                    StyleForm[ 
                      red[ 3], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["db", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["2",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 2], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["2",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 2]],
                    Editable->False]],
                Subsuperscript[ db, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 2], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 2]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["dc", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["3",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["3",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 3]],
                    Editable->False]],
                Subsuperscript[ dc, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 3], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 3]]],
                Editable->False],
              "TraditionalForm"], " ", \(\@\(\[ScriptG](red)\)\)}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(3\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["db", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["2",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 2], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["2",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 2]],
                    Editable->False]],
                Subsuperscript[ db, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 2], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 2]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["dc", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["3",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["3",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 3]],
                    Editable->False]],
                Subsuperscript[ dc, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 3], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 3]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
On the other hand, the triangle OAB can be represented by its outer normal,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\((\(1\/2\) 
                d\[DoubleStruckB]\[Cross]
                  d\[DoubleStruckA] // \(LinearBreakout[
                  Cross]\)[\[DoubleStruckE]d[_]])\) // 
          CrossProductExpansion[\[DoubleStruckE], e, k]\) // EinsteinSum[]\) // 
      LeviCivitaSimplify[e]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(-\(1\/2\)\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["da", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["1",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 1], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["1",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 1]],
                    Editable->False]],
                Subsuperscript[ da, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 1], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 1]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["db", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["2",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 2], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["2",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 2]],
                    Editable->False]],
                Subsuperscript[ db, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 2], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 2]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["e", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["1",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["2",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["3",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ 1], 
                      red[ 2], 
                      red[ 3]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 1], ShowContents -> False], 
                      StyleForm[ 
                        red[ 2], ShowContents -> False], 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ e, 
                  SequenceForm[ 
                    red[ 1], 
                    red[ 2], 
                    red[ 3]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 1], ShowContents -> False], 
                    StyleForm[ 
                      red[ 2], ShowContents -> False], 
                    StyleForm[ 
                      red[ 3], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckE]", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["3",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["3",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 3]],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckE], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 3], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 3]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["and we can verify that,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["%",
        FontFamily->"Courier",
        FontSize->16], 
      "-", \(\((\(-dAvald[red[3]]\))\)*\[DoubleStruckE]u[red[3]]\)}]], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox["0",
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The four vectors, ",
  StyleBox["d\[DoubleStruckCapitalA]",
    FontWeight->"Bold"],
  " and ",
  Cell[BoxData[
      \(\(1\/2\) d\[DoubleStruckB]\[Cross]d\[DoubleStruckA]\)]],
  ", ",
  Cell[BoxData[
      \(\(1\/2\) d\[DoubleStruckC]\[Cross]d\[DoubleStruckA]\)]],
  ", and ",
  Cell[BoxData[
      \(\(1\/2\) d\[DoubleStruckC]\[Cross]d\[DoubleStruckB]\)]],
  "   ",
  StyleBox["add to zero",
    FontColor->RGBColor[1, 0, 0]],
  ".\nEach force d",
  StyleBox["P",
    FontWeight->"Bold"],
  ", d",
  StyleBox["Q",
    FontWeight->"Bold"],
  ", d",
  StyleBox["R",
    FontWeight->"Bold"],
  " and d",
  StyleBox["F",
    FontWeight->"Bold"],
  " shown in the Figure, in an equilibrium stressed material, are ",
  StyleBox["proportional to the area on which it acts",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ", and can be resolved into contravariant components,"
}], "Text"],

Cell[BoxData[{
    \(d\[DoubleStruckCapitalP] := \(-\[Sigma]uu[red@1, red@j]\) 
        d\[ScriptCapitalA]d[red@1] \[DoubleStruckE]d[
          red@j]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckCapitalQ] := \(-\[Sigma]uu[red@2, red@j]\) 
        d\[ScriptCapitalA]d[red@2] \[DoubleStruckE]d[
          red@j]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckCapitalR] := \(-\[Sigma]uu[red@3, red@j]\) 
        d\[ScriptCapitalA]d[red@3] \[DoubleStruckE]d[red@j]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(d\[DoubleStruckCapitalF] := \(-d\[DoubleStruckCapitalP]\) - 
        d\[DoubleStruckCapitalQ] - 
        d\[DoubleStruckCapitalR]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckCapitalF]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["d\[ScriptCapitalA]", 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["1",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ 1]],
                      Editable->False], 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 1], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ d\[ScriptCapitalA], 
                    SequenceForm[ 
                      red[ 1]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 1], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckE]", 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ j]],
                      Editable->False], 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckE], 
                    SequenceForm[ 
                      red[ j]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Sigma]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 1], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["1",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ 1], 
                        red[ j]],
                      Editable->False]],
                  Subsuperscript[ \[Sigma], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 1], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ 1], 
                      red[ j]]],
                  Editable->False],
                "TraditionalForm"]}], "+", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["d\[ScriptCapitalA]", 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["2",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ 2]],
                      Editable->False], 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 2], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ d\[ScriptCapitalA], 
                    SequenceForm[ 
                      red[ 2]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 2], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckE]", 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ j]],
                      Editable->False], 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckE], 
                    SequenceForm[ 
                      red[ j]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Sigma]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 2], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["2",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ 2], 
                        red[ j]],
                      Editable->False]],
                  Subsuperscript[ \[Sigma], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 2], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ 2], 
                      red[ j]]],
                  Editable->False],
                "TraditionalForm"]}], "+", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["d\[ScriptCapitalA]", 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["3",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ 3]],
                      Editable->False], 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 3], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ d\[ScriptCapitalA], 
                    SequenceForm[ 
                      red[ 3]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckE]", 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ j]],
                      Editable->False], 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckE], 
                    SequenceForm[ 
                      red[ j]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Sigma]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 3], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["3",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ 3], 
                        red[ j]],
                      Editable->False]],
                  Subsuperscript[ \[Sigma], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 3], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ 3], 
                      red[ j]]],
                  Editable->False],
                "TraditionalForm"]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(d\[DoubleStruckCapitalF] := \[Sigma]uu[red@i, red@j] 
        d\[ScriptCapitalA]d[red@i] \[DoubleStruckE]d[
          red@j]\), "\[IndentingNewLine]", 
    \(ResultFrame["\<d\[DoubleStruckCapitalF]\>" == 
        d\[DoubleStruckCapitalF]]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  RowBox[{"\<\"d\[DoubleStruckCapitalF]\"\>", "==", 
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["d\[ScriptCapitalA]", 
                            InterpretationBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              SequenceForm[ 
                                red[ i]],
                              Editable->False], 
                            InterpretationBox[
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ d\[ScriptCapitalA], 
                            SequenceForm[ 
                              red[ i]], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"], " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[DoubleStruckE]", 
                            InterpretationBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              SequenceForm[ 
                                red[ j]],
                              Editable->False], 
                            InterpretationBox[
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[DoubleStruckE], 
                            SequenceForm[ 
                              red[ j]], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ j], ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"], " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Sigma]", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                red[ i], 
                                red[ j]],
                              Editable->False]],
                          Subsuperscript[ \[Sigma], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              StyleForm[ 
                                red[ j], ShowContents -> False]], 
                            SequenceForm[ 
                              red[ i], 
                              red[ j]]],
                          Editable->False],
                        "TraditionalForm"]}]}], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "1", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  Equal[ "d\[DoubleStruckCapitalF]", 
                    Times[ 
                      Tensor[ d\[ScriptCapitalA], {Void}, {
                        red[ i]}], 
                      Tensor[ \[DoubleStruckE], {Void}, {
                        red[ j]}], 
                      Tensor[ \[Sigma], {
                        red[ i], 
                        red[ j]}, {Void, Void}]]], "      (4.", 1, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["So",
        FontSize->18], 
      StyleBox[",",
        FontSize->18], 
      StyleBox[" ",
        FontSize->18], 
      StyleBox[
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Sigma]", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
                
                SequenceForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                Editable->False]], " ", "are", " ", "the", " ", "components", 
            " ", "of", " ", "a", " ", "second"}], "-", \(order\ tensor\)}],
        FontSize->18], 
      StyleBox[",",
        FontSize->18], 
      StyleBox[" ",
        FontSize->18], 
      RowBox[{
        RowBox[{
          StyleBox["the",
            FontSize->18], 
          StyleBox[" ",
            FontSize->18], 
          StyleBox["stress",
            FontSize->18,
            FontSlant->"Italic",
            FontVariations->{"Underline"->True}], 
          StyleBox[" ",
            FontSize->18,
            FontSlant->"Italic",
            FontVariations->{"Underline"->True}], 
          RowBox[{
            StyleBox["tensor",
              FontSize->18,
              FontSlant->"Italic",
              FontVariations->{"Underline"->True}], 
            StyleBox[".",
              FontSize->18], 
            StyleBox[" ",
              FontSize->18,
              FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
            StyleBox["If",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]]}], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["we",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["choose",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["as",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["reference",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["frame",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          SubsuperscriptBox[
            StyleBox["g",
              FontColor->GrayLevel[0]], 
            InterpretationBox[
              TagBox[
                StyleBox["j",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              SequenceForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
              Editable->False], 
            InterpretationBox[
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)],
              SequenceForm[ 
                StyleForm[ 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False]],
              Editable->False]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["a",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["cartesian",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["system",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["of",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["unit",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["vectors",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[
            TagBox[
              RowBox[{
                RowBox[{
                  StyleBox["{",
                    FontFamily->"Courier",
                    FontSize->16,
                    FontWeight->"Plain"], 
                  StyleBox[
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[DoubleStruckI]", 
                            InterpretationBox["x",
                              SequenceForm[ x],
                              Editable->False], 
                            InterpretationBox[
                              TagBox[
                                StyleBox["x",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[DoubleStruckI], 
                            SequenceForm[ x], 
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[DoubleStruckI]", 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False], 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[DoubleStruckI], 
                            SequenceForm[ y], 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[DoubleStruckI]", 
                            InterpretationBox["z",
                              SequenceForm[ z],
                              Editable->False], 
                            InterpretationBox[
                              TagBox[
                                StyleBox["z",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ z, ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[DoubleStruckI], 
                            SequenceForm[ z], 
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    FontFamily->"Courier",
                    FontSize->16], 
                  StyleBox["}",
                    FontFamily->"Courier",
                    FontSize->16,
                    FontWeight->"Plain"]}], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontSize->16,
                  FontWeight->"Plain"]}],
              (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)],
            FontColor->GrayLevel[0]], 
          StyleBox["the",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["stresses",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[
            SubsuperscriptBox["\[Sigma]", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
                
                SequenceForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                Editable->False]],
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["become",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["identical",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["with",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["the",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["commonly",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["used",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[" ",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox[
            RowBox[{"stresses", ":", "\[IndentingNewLine]", 
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["1",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["1",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ 1, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ 1, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox["1",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["1",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1.0, 0.0, 0.0]]&)]}],
                  SequenceForm[ 
                    StyleForm[ 1, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ 1, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                  Editable->False]]}],
            FontWeight->"Plain",
            FontColor->GrayLevel[0]]}], 
        StyleBox["=",
          FontWeight->"Plain",
          FontColor->GrayLevel[0]], 
        RowBox[{
          StyleBox[
            SubsuperscriptBox[
              StyleBox["\[Sigma]",
                FontWeight->"Plain"], 
              InterpretationBox[\(x\[InvisibleSpace]x\),
                SequenceForm[ x, x],
                Editable->False], 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox["x",
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox["x",
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ x, ShowContents -> False], 
                  StyleForm[ x, ShowContents -> False]],
                Editable->False]],
            FontColor->GrayLevel[0]], 
          StyleBox["=",
            FontColor->GrayLevel[0]], 
          StyleBox[
            TagBox[
              StyleBox[
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox["x",
                        SequenceForm[ x],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox["x",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ x], 
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"],
                FontFamily->"Courier",
                FontSize->16],
              (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)],
            FontWeight->"Plain",
            FontColor->GrayLevel[0]]}]}], 
      StyleBox[",",
        FontWeight->"Plain",
        FontColor->GrayLevel[0]], 
      RowBox[{
        StyleBox[
          SubsuperscriptBox[
            StyleBox["\[Sigma]",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    TagBox[
                      StyleBox["1",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    TagBox[
                      StyleBox["2",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                StyleForm[ 
                  StyleForm[ 1, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False], 
                StyleForm[ 
                  StyleForm[ 2, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox["1",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox["2",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
              SequenceForm[ 
                StyleForm[ 1, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                StyleForm[ 2, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
              Editable->False]],
          FontColor->GrayLevel[0]], 
        StyleBox["=",
          FontWeight->"Plain",
          FontColor->GrayLevel[0]], 
        RowBox[{
          StyleBox[
            SubsuperscriptBox["\[Sigma]", 
              InterpretationBox[\(x\[InvisibleSpace]y\),
                SequenceForm[ x, y],
                Editable->False], 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox["x",
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox["y",
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ x, ShowContents -> False], 
                  StyleForm[ y, ShowContents -> False]],
                Editable->False]],
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          StyleBox["=",
            FontWeight->"Plain",
            FontColor->GrayLevel[0]], 
          RowBox[{
            StyleBox[
              SubsuperscriptBox["\[Tau]", 
                InterpretationBox[\(x\[InvisibleSpace]y\),
                  SequenceForm[ x, y],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox["x",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["y",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ x, ShowContents -> False], 
                    StyleForm[ y, ShowContents -> False]],
                  Editable->False]],
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["which",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox[" ",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["is",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], " ", 
            StyleBox[\(symmetrical . \[IndentingNewLine]\ A\),
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox[" ",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["similar",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox[" ",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["relation",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox[" ",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["holds",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox[" ",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["between",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["  ",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1.0, 0.0, 0.0]]&)]}],
                  SequenceForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                  Editable->False]],
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["and",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox[
              RowBox[{
                StyleBox[" ",
                  FontWeight->"Plain",
                  FontColor->GrayLevel[0]], 
                StyleBox[" ",
                  FontColor->GrayLevel[0]]}]], 
            RowBox[{
              StyleBox[
                SubsuperscriptBox[
                  StyleBox["\[Sigma]",
                    FontWeight->"Plain",
                    FontColor->GrayLevel[0]], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], 
                      StyleForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)]}],
                    SequenceForm[ 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                    Editable->False]],
                FontWeight->"Bold",
                FontColor->GrayLevel[0]], 
              StyleBox[".",
                FontWeight->"Plain",
                FontColor->GrayLevel[0]], 
              StyleBox[" ",
                FontWeight->"Plain",
                FontColor->GrayLevel[0]], 
              StyleBox["To",
                FontWeight->"Plain",
                FontColor->GrayLevel[0]]}], 
            StyleBox[" ",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["show",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox[" ",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]], 
            StyleBox["this",
              FontWeight->"Plain",
              FontColor->GrayLevel[0]]}]}]}], 
      StyleBox[",",
        FontWeight->"Plain",
        FontColor->GrayLevel[0]], 
      StyleBox[\(we\ study\ the\ moment\ equilibrium\ of\ the\ \
parallelepipedon\ shown\ \(\(below\)\(.\)\)\),
        FontWeight->"Plain",
        FontColor->GrayLevel[0]]}]], "Text",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[GraphicsData["PICT", "\<\
HKh0B03G0IP2DP0A0_l<0?ooool0e`0004P0009B0001V0000000000N00402P18
0=L1V09B09X0003oQN`0B03G0IP2DP0000@0000004P000180000400P00<02000
0005o9k81ObNN0180=L1V09B04P0e`6H0U80000H0?j1oh7oQol0mH7oPOn7o`3V
POn1ohOo01P0oX7oPOn7o`3ePOn1ohOo0>J1oh7oQol0603nPOn1ohOo0?F1oh7o
Qol0iX7oPOn7o`0H0?j1oh7oQol0mH7oPOn7o`3VPOn1ohOo01P0oX7oPOn7o`3e
POn1ohOo0>J1oh7oQol0603nPOn1ohOo0?F1oh7oQol0iX7oPOn7o`0H0?j1oh7o
Qol0mH7oPOn7o`3VPOn1ohOo01P0oX7oPOn7o`3ePOn1ohOo0>J1oh7oQol0603n
POn1ohOo0?F1oh7oQol0iX7oPOn7o`0H0?j1oh7oQol0mH7oPOn7o`3VPOn1ohOo
01P0oX7oPOn7o`3ePOn1ohOo0>J1oh7oQol0603nPOn1ohOo0?F1oh7oQol0iX7o
POn7o`0H0?j1oh7oQol0mH7oPOn7o`3VPOn1ohOo01P0oX7oPOn7o`3ePOn1ohOo
0>J1oh7oQol0603nPOn1ohOo0?F1oh7oQol0iX7oPOn7o`0H0?j1oh7oQol0mH7o
POn7o`3VPOn1ohOo01P0oX7oPOn7o`3ePOn1ohOo0>J1oh7oQol0603nPOn1ohOo
0?F1oh7oQol0iX7oPOn7o`1>0?j1ojOo1F8c2?ooKoh01G>0;b]kmh7ol?l0mH7o
Yol5HS<8oom_oP05Lh0_:g_gPOo`o`3VPOnWo`ER<`Soofon00EcP2l[NoN1oo3o
04/0oX7oYol2m`00o_on00Gool`006J1oo3o0?F1ojOo0_L00?kooP05ooo<001V
POo`o`3VPOnWo`;g003nooh01Oooc000IX7ol?l0A@3nPOnVo`400?kooP02oook
oP21oo3o0?F1ojKo0@00o_on00;ooo_n087ol?l0iX7oY_l1003nooh00_oonoh0
POo`o`180?j1ojKo0@00o_on00GoooL00261oo3o0?F1ojKo0@00o_on00GoooL0
0261oo3o0>J1ojKo0@00o_on00GoooL00261oo3o05@0oX7oZ_l5iV:0N`00o_on
00GogH@09]B1oo3o0?F1oj[o1NIRP7/00?kooP05omf402KDPOo`o`3VPOnZo`GV
HX1k003nooh01OoMQ00Ve87ol?l0B03nPOnZo`D@Z_o^003noo/00GOgPOo_o`3e
POnZo`D@Z_o^003noo/00GOgPOo_o`3VPOnZo`D@Z_o^003noo/00GOgPOo_o`1D
0?j1oj_o1[80k_oo003nooh01;/001WQPOo_o`3ePOn[o`Jb0>koo`00o_on00Bk
000IhH7okol0iX7oZol6/P3^ool00?kooP04^`006N61onoo0600oX7o^?oh0?go
0H00o_l1003nooh01?mg001_POo_o`3ePOnhooP0oOl1P03no`400?kooP04ogL0
06n1onoo0>J1okSon03mo`600?ko0@00o_on00CoM`00Kh7okol0E`3nPOn[o`J8
0>7oo`00o_on00Gooc<03MB1oo3o0?F1oj_o1XP0hOoo003nooh01Ooo<`0=e87o
l?l0iX7oZol6R03Qool00?kooP05oolc00gDPOo`o`1M0?j1oj_o2L<0VOoo003g
ooon00;ook?n003gPOoao`3ePOn[o`W309Woo`00mooooP02ooncoP00mh7olOl0
iX7oZol9``2Iool00?Ooooh00_oo/oh00?N1oo7o05d0oX7oZ_l8R2]gV@P[G_m_
oP07KookI@00BK^1oo;o0?F1oj[o28P[MiT8:ekoKoh01foonfD004VkPOobo`3V
POnZo`R8:gNI22]Nofon00M_oo]U0019^h7ol_l0603nPOn1ohOo0?F1oh7oQol0
iX7oPOn7o`0H0?j1oh7oQol0mH7oPOn7o`3VPOn1ohOo01P0oX7oPOn7o`3ePOn1
ohOo0>J1oh7oQol0603nPOn1ohOo0?F1oh7oQol0iX7oPOn7o`0H0?j1oh7oQol0
mH7oPOn7o`3VPOn1ohOo01P0oX7oPOn7o`3ePOn1ohOo0>J1oh7oQol0903nPOnf
o`10POoCo`3ePOnfo`10POoCo`3VPOnfo`10POoCo`0W0?j1okOo0@00POoCo`3e
POngo`40087odol0iX7o]ol10021om?o02X0oX7o^?l2P000POoCo`3ePOnho`:0
0021om?o0>J1okSo0X00087odol0903nPOnhooh0POoCo`3ePOnhooh0POoCo`3V
POnhooh0POoCo`0T0?j1okWoo021omCo0?F1okWoo021omCo0>J1okWoo021omCo
02X0oX7o^_l0P?`0POoDo`3ePOnjo`20o021omCo0>J1ok[o083l087oe?l0:P3n
POnko`20n`21omCo0?F1ok_o083k087oe?l0iX7o^ol0P?/0POoDo`0T0?j1ok_o
nP21omCo0?F1ok_onP21omCo0>J1ok_onP21omCo02X0oX7o_?l0@?X0POoDo`3e
POnlo`10nP21omCo0>J1okco043j087oe?l0903nPOnlooT0POoDo`3ePOnlooT0
POoDo`3VPOnlooT0POoDo`0i0?j1okko0<3l00=0P000POoDo`3ePOnno`30o003
@800087oe?l0iX7o__l0`?`00d200021omCo03`0oX7o__on00CoP020ooh0POoE
o`3ePOnnooh01?n0083ooP21omGo0>J1okkooP04oh00P?on087oeOl0@P3nPOnn
o`20o_l60020oh00087oeOl0mH7o__l0P?ko1P00P?n00021omGo0>J1okko083n
o`H0083oP000POoEo`0f0?j1ok[o0@00o_l10021omGo0?F1ok[o0@00o_l10021
omGo0>J1ok[o0@00o_l10021omGo03<0oX7o^_l1003mo`00POoEo`3ePOnjo`40
0?go0021omGo0>J1ok[o0@00oOl0087oeOl0=P3nPOnko`:0003mo`20POoEo`3e
POnko`:0003mo`20POoEo`3VPOnko`:0003mo`20POoEo`0T0?j1ok_ooP21om3o
0?F1ok_ooP21om3o0>J1ok_ooP21om3o02L0oX7o^ol10021oloo0?F1ok_o0@00
POo?o`3VPOnko`40087ocol0:P3nPOnlo`:00021oloo0?F1okco0X00087ocol0
iX7o_?l2P000POo?o`0Z0?j1okco0X00@87ocol0mH7o_?l2P010POo?o`3VPOnl
o`:00421oloo02X0oX7o_?l2P020POo?o`3ePOnlo`:00821oloo0>J1okco0X00
P87ocol0:P3nPOnlo`800821oloo0?F1okco0P00P87ocol0iX7o_?l20020POo?
o`0W0?j1okco0@00POo>o`3ePOnlo`40087oc_l0iX7o_?l10021olko02X0oX7o
_Ol2P000POo>o`3ePOnmo`:00021olko0>J1okgo0X00087oc_l0903nPOnmooh0
POo>o`3ePOnmooh0POo>o`3VPOnmooh0POo>o`0W0?j1okgo0@00POo=o`3ePOnm
o`40087ocOl0iX7o_Ol10021olgo02L0oX7o_Ol10021olgo0?F1okgo0@00POo=
o`3VPOnmo`40087ocOl0:P3nPOnno`:00021olgo0?F1okko0X00087ocOl0iX7o
__l2P000POo=o`0Z0?j1okko0X00P87ocOl0mH7o__l2P020POo=o`3VPOnno`:0
0821olgo0300oX7o__l2P020Zoo^0;Ko0?F1okko0X00P:_okP2fo`3VPOnno`:0
082[onh0]_l0``3nPOnno`80083go`30g800@?b0003mP010o800@?f0043lP010
oH000?f00On0oOl1P<3no`70P?ko0X20@;Ko0?F1okko0P00P?Oo0<3LP010o800
0?f0043lP010oH00@?b0043mP000oH01oh3mo`60`?ko0L20o_l2P810]_l0iX7o
__l20020mol0`=b0043lP000oH00@?b0043mP010o800@?f0003mP07oP?go0H30
o_l1`83no`:0P42fo`3o0?j1olGo083^0020oOl00?go083lo`00oOl0P?co083m
o`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?ko0`20
oh2fo`3ePOo5o`20kP00P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00
o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083no`<0P?n0]_l0iX7oaOl0
P>h0083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00o?l0
P?go003mo`20o?l00?go083lo`20o_l3083oP;Ko0Dd0oX7oa_l90?ooP<3ooh00
0?go083mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083m
o`70P?go083mo`60P?go083mo`60`?ko0L20oOl1P<3no`W0P?oo`820`?n0]_l0
mH7oa_l90?ooP<3ooh000?go083mo`70P?go083mo`60`?go083mo`60`?ko0L20
oOl1P<3no`70P?go083mo`70P?go083mo`60P?go083mo`60`?ko0L20oOl1P<3n
o`W0P?oo`820`?n0]_l0iX7oa_l90?ooP<3ooh000?go083mo`70P?go083mo`60
`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60P?go083m
o`60`?ko0L20oOl1P<3no`W0P?oo`820`?n0]_l18`3nPOo7o`>00?l0oOon0?ko
003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go
083lo`00oOl0P?co083mo`20o?l0P?go003no`20]_l0mH7oaol3P03o0?gooP3n
o`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003m
o`20o?l00?go083lo`20oOl0P?co083mo`00o_l0P;Ko0>J1olOo0h00o`3mooh0
o_l00?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00
oOl0P?co003mo`20o?l0P?go083lo`20oOl00?ko082fo`5@0?j1olWo1<20@?n0
oOl2`000o_l0P?go0H20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20
oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go
082fo`3ePOo9o`C0P43oP?go0/000?ko083mo`60P?go083mo`60`?go083mo`60
`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko0L20
oOl1P<3no`70P?go083mo`20]_l0iX7obOl4`810oh3mo`;0003no`20oOl1P83m
o`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1
P<3mo`20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl0P;Ko0B<0oX7obOl3P?n0
0?cooP02ool0oOl0P?co003mo`20o?l00?go083lo`20oOl00?co083mo`00o?l0
P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P;Ko0?F1olWo0h3o
P03looh00_oo0?go083lo`00oOl0P?co003mo`20o?l0P?go003lo`20oOl00?co
083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co082fo`3VPOo9o`>0
oh00o?on00;oo`3mo`20o?l00?go083lo`00oOl0P?co083mo`00o?l0P?go003l
o`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20]_l1EP3nPOo;
o`C0P?ooP?go1/20P000oh3mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go
083mo`70P?go083mo`60P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70
P?go083mo`;0P82fo`3ePOo;o`C0P?ooP?go1/20P000oh3mo`60`?go083mo`60
`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60P?go083mo`60`?go083m
o`60`?ko0L20oOl1P<3no`70P?go083mo`;0P82fo`3VPOo;o`C0P?ooP?go1/20
P000oh3mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083m
o`60P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`;0P82f
o`4b0?j1olco0@20o_l0P?go1H3oP0200?go083lo`00oOl0P?co083mo`20o?l0
P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go003lo`F0oh3o
o`3lo`600;Go0?F1olco0@20o_l0P?go1H3oP0200?go083lo`00oOl0P?co083m
o`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go003l
o`F0oh3oo`3lo`600;Go0>J1olco0@20o_l0P?go1H3oP0200?go083lo`00oOl0
P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0
P?go003lo`F0oh3oo`3lo`600;Go0El0oX7ocOl0P?ko2l3oP?ooP83oo`00@?go
0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0
P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go1/20`83ooh3mo`>0P?l0]Ol0mH7o
cOl0P?ko2l3oP?ooP83oo`00@?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20
oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go
1/20`83ooh3mo`>0P?l0]Ol0iX7ocOl0P?ko2l3oP?ooP83oo`00@?go0H30oOl0
P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30
o_l1`83mo`60`?ko0L20oOl0P?go1/20`83ooh3mo`>0P?l0]Ol1=@3nPOo>o`00
nol2P?n0oOl2P020o_l0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00
oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co1H3oP?oo0?go083no`00]Ol0
mH7oc_l00?_o0X3oP?go0X00P?ko083lo`00oOl0P?co083mo`20o?l0P?go003l
o`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`F0oh3oo`3mo`20
o_l00;Go0>J1olko003ko`:0oh3mo`:0083no`20o?l00?go083lo`20oOl0P?co
083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l5P?n0
ool0oOl0P?ko002eo`5O0?j1om3o0H20n_l2P830oOl1P83no`60`?ko0L20oOl1
P<3no`70P?go0H30o_l1`83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`70
P?go0H30o_l1`83mo`20oOl0`?j00_ooP?go0H30o_l00;Go0?F1om3o0H20n_l2
P830oOl1P83no`60`?ko0L20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1P83m
o`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl0`?j00_ooP?go
0H30o_l00;Go0>J1om3o0H20n_l2P830oOl1P83no`60`?ko0L20oOl1P<3no`70
P?go0H30o_l1`83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30
o_l1`83mo`20oOl0`?j00_ooP?go0H30o_l00;Go0CD0oX7odOl0P?co083no`00
o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`00
oOl0P?co083mo`20o?l0P?go003lo`600?ko003mo`20o?l00;Go0?F1om7o083l
o`20o_l00?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003m
o`20o?l00?go083lo`20oOl0P?co083mo`00o?l1P03no`00oOl0P?co002eo`3V
POoAo`20o?l0P?ko003lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go
083lo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co0H00o_l00?go083l
o`00]Ol1G03nPOoBo`60`?Wo0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0
P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl1P<3no`70
P?go083mo`:0083no`20oOl1P<3mo`50P;Go0?F1om;o0H30nOl1P<3mo`20oOl1
P<3no`70P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70
P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0X00P?ko083mo`60`?go0D20]Ol0
iX7od_l1P<3io`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go
083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl2
P020o_l0P?go0H30oOl1@82eo`4Y0?j1om?o003go`00oOl00?go083lo`20oOl0
P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0
P?go003mo`20o?l00?go083lo`40P;Co0?F1om?o003go`00oOl00?go083lo`20
oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00
o?l0P?go003mo`20o?l00?go083lo`40P;Co0>J1om?o003go`00oOl00?go083l
o`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083m
o`00o?l0P?go003mo`20o?l00?go083lo`40P;Co0F/0oX7oeOl2P830oOl0P?go
1L00ooo0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0
P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30
o_l3`83oP;Co0?F1omGo0X20`?go083mo`G00?oo`83mo`60`?ko0L20oOl1P<3n
o`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go
083mo`70P?go083mo`60`?go083mo`60`?ko0l20oh2do`3VPOoEo`:0P<3mo`20
oOl5`03ool20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3m
o`20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1
P<3no`?0P?n0]?l1;03nPOoFo`20m?l30?ooP?go083lo`20oOl00?co083mo`00
o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20
o?l00?go083lo`>0oon0]?l0mH7oe_l0P?Co0`3ooh3mo`20o?l0P?go003lo`20
oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00
oOl0P?co003mo`20o?l3P?ooP;Co0>J1omKo083do`<0oon0oOl0P?co083mo`00
o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20
oOl00?go083lo`00oOl0P?co0h3ooh2do`4/0?j1omKo083do`80o`3lo`20oOl0
0?go083lo`00oOl0P?co003mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0
P?co003mo`20o?l0P?go083lo`20oOl00?ko082do`3ePOoFo`20m?l20?l0o?l0
P?go003mo`20o?l00?go083lo`00oOl0P?co083mo`00o?l0P?go003lo`20oOl0
0?go083lo`00oOl0P?co083mo`20o?l0P?go003no`20]?l0iX7oe_l0P?Co0P3o
0?co083mo`00oOl0P?co003mo`20o?l00?go083lo`20oOl00?co083mo`00o?l0
P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o_l0P;Co0F/0oX7of?l2
P830oOl0`?co1<3oP?n0oOl1P03mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30
o_l1`83mo`20oOl1`83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`60P?go
0H30o_l1`83mo`20oOl0P;Co0?F1omSo0X20`?go0<3lo`C0oh3oP?go0H00oOl0
P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H20
oOl0P?go0H30oOl0P?go0H30o_l1P83mo`60`?ko0L20oOl0P?go082do`3VPOoH
o`:0P<3mo`30o?l4`?n0oh3mo`600?go083mo`60`?go083mo`60`?ko0L20oOl1
P<3no`70P?go083mo`70P?go083mo`60P?go083mo`60`?go083mo`60`?ko0H20
oOl1P<3no`70P?go083mo`20]?l1;`3nPOoIo`00l_l1P03lo`400?ko003mo`20
o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`00
oOl0P?go0@20oOl00?co083mo`00o?l0P;Co0?F1omWo003bo`600?co0@00o_l0
0?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0
P?co003mo`20oOl1083mo`00o?l0P?go003lo`20]?l0iX7ofOl00?;o0H00o?l1
003no`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co
003mo`20o?l00?go083mo`40P?go003lo`20oOl00?co082do`5[0?j1om[o0H20
o?l0`?go083mo`20oOl6P8000?ooP?go0H30oOl0P?go0H30o_l1`83mo`60`?ko
0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0D20oOl0
P?go0L20oOl0P?gooX2do`3ePOoJo`60P?co0<3mo`20oOl0P?go1X20003ooh3m
o`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go
083mo`60`?ko0L20oOl1P<3no`50P?go083mo`70P?go083mooj0]?l0iX7of_l1
P83lo`30oOl0P?go083mo`J0P000oon0oOl1P<3mo`20oOl1P<3no`70P?go0H30
o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1@83m
o`20oOl1`83mo`20oOonP;Co0C/0oX7og?l1P03`o`20o_l6P?l00?oo0?go083l
o`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083m
o`20oOl1083mo`00o?l0P?go003mo`>0oon0]?l0mH7og?l1P03`o`20o_l6P?l0
0?oo0?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00
oOl0P?co083mo`20oOl1083mo`00o?l0P?go003mo`>0oon0]?l0iX7og?l1P03`
o`20o_l6P?l00?oo0?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl0
0?go083lo`00oOl0P?co083mo`20oOl1083mo`00o?l0P?go003mo`>0oon0]?l1
G`3nPOoMo`60`>oo2H3ooh30o`00oh3mo`60`?ko0L20oOl1P<3no`70P?go0H30
o_l1`83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1@83m
o`20oOl1`83mo`20oOl4P<3ooh2do`3ePOoMo`60`>oo2H3ooh30o`00oh3mo`60
`?ko0L20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1P83mo`20oOl1P<3mo`20
oOl1P<3no`70P?go0H30o_l1@83mo`20oOl1`83mo`20oOl4P<3ooh2do`3VPOoM
o`60`>oo2H3ooh30o`00oh3mo`60`?ko0L20oOl1P<3no`70P?go0H30o_l1`83m
o`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1@83mo`20oOl1
`83mo`20oOl4P<3ooh2do`5I0?j1omko0X3oP?co083mo`20o?l:P?n0oh3oo`00
P03mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l00?go
083lo`20oOl0P?go0@20oOl00?co083mo`00oOl0P?go082do`3ePOoNo`:0oh3l
o`20oOl0P?co2X3oP?n0ool00800oOl0P?co083mo`20o?l0P?go003lo`20oOl0
0?go083lo`00oOl0P?co003mo`20o?l0P?go083mo`40P?go003lo`20oOl00?go
083mo`20]?l0iX7og_l2P?n0o?l0P?go083lo`Z0oh3oP?oo00200?go083lo`20
oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`00oOl0P?co083mo`20
oOl1083mo`00o?l0P?go003mo`20oOl0P;Co0F80oX7oh?l2`830kOl7P830ool0
043mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60
`?ko0L20oOl1P<3no`70P?go1X30oon0@83mo`20oOl1P83mo`20oOl1P<3no`60
`;Co0?F1on3o0/20`>go1h20`?oo0010oOl1P<3no`70P?go0H30o_l1`83mo`20
oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1`83mo`J0`?ooP420
oOl0P?go0H20oOl0P?go0H30o_l1P<2do`3VPOoPo`;0P<3]o`N0P<3oo`00@?go
0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1
`83mo`60`?ko0L20oOl6P<3ooh10P?go083mo`60P?go083mo`60`?ko0H30]?l1
;03nPOoPo`20jol00?ko0X000?go083lo`20oOl0P?co083mo`00o?l0P?go003m
o`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083l
o`00/ol0mH7oh?l0P>_o003no`:0003mo`20o?l0P?go083lo`20oOl00?co083m
o`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003m
o`20o?l00;?o0>J1on3o083[o`00o_l2P000oOl0P?co083mo`20o?l0P?go003l
o`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083l
o`00oOl0P?co002co`6<0?j1on;o1<20ooo0oOl0P?co0<3mo`20o_l1P<3no`;0
P03no`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60
`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko0/20
0;?o0?F1on;o1<20ooo0oOl0P?co0<3mo`20o_l1P<3no`;0P03no`60`?ko0L20
oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3n
o`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko0/200;?o0>J1on;o1<20
ooo0oOl0P?co0<3mo`20o_l1P<3no`;0P03no`60`?ko0L20oOl1P<3no`70P?go
083mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70
P?go083mo`60`?go083mo`60`?ko0/200;?o0Bl0oX7ohol1083Zo`00oOl0P?go
083lo`20oOl00?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co
083mo`00o?l0P?go003mo`20o?l00?go083lo`:0o`2co`3ePOoSo`40P>[o003m
o`20oOl0P?co083mo`00o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083m
o`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co0X3o0;?o0>J1on?o0@20
j_l00?go083mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20
o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l2P?l0/ol1]P3n
`ol2hK>8oOl6mk>=P8fcmk7o1<20oon0oOl0`?co0<3mo`30o?l5`03ool20oOl1
P<3no`70P?go083mo`70P?go083mo`60P?go083mo`60`?ko0L20oOl1P<3no`70
P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`C0P?oo0;?o
0?G3o`;Q/hSmo`Kg/hf0SK?g/Ol4`83ooh3mo`30o?l0`?go0<3lo`G00?oo`83m
o`60`?ko0L20oOl0P?go0L20oOl0P?go0H20oOl0P?go0H30o_l1`83mo`60`?ko
0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko1<20ool0
/ol0i/?o0^6cR?go1_NcSH2=/oNao`C0P?ooP?go0<3lo`30oOl0`?co1L00ooo0
P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P83mo`20oOl1P<3no`70P?go0H30
o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l4`83o
o`2co`5F0?k3ooh0oOl6A02Zoj80?;7o083Wo`<0oon0oOl0P?co083mo`00o?l0
P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go0@20oOl0P?go
003mo`20o?l00?go083lo`20o_l00;?o0?G3ooh0oOl6A02Zoj80?;7o083Wo`<0
oon0oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083m
o`00o?l0P?go0@20oOl0P?go003mo`20o?l00?go083lo`20o_l00;?o0>K3ooh0
oOl6A02Zoj80?;7o083Wo`<0oon0oOl0P?co083mo`00o?l0P?go003mo`20o?l0
0?go083lo`20oOl0P?co083mo`00o?l0P?go0@20oOl0P?go003mo`20o?l00?go
083lo`20o_l00;?o0Hl0o/?o2?/00?oohB/4`oko0k/4:mfeo`60P>Ko0P30P?go
0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1
`83mo`20oOl1`83mo`J0P<3ooh20oOl0P?go0H30o_l1`83mo`60`?ko0L20o_l0
0;;o0?G3o`Sk003oon4[1<?no`>k12_M]Ol1P83Vo`80`83mo`60`?ko0L20oOl0
P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20
oOl6P830oon0P?go083mo`60`?ko0L20oOl1P<3no`70P?ko002bo`3V`ol8n`00
oooQ:`C3o_l3^`@[gKGo0H20i_l20<20oOl1P<3no`70P?go083mo`70P?go083m
o`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go1X20`?ooP83m
o`20oOl1P<3no`70P?go0H30o_l1`83no`00/_l1TP3n`_l6003oogL0A?co0S`0
KkKo003no`00o?l0P?go003lo`20oOl50?ooP?n0oOl00?co083mo`00o?l0P?go
003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go0@20o_l0P?co003m
o`20o?l0P?go083lo`20oOl00;;o0?G2o`H00?ooM`14o?l2?01_]_l00?ko003l
o`20oOl00?co083mo`D0oon0oh3mo`00o?l0P?go003lo`20oOl00?go083lo`00
oOl0P?co083mo`20o?l0P?go003lo`20oOl1083no`20o?l00?go083lo`20oOl0
P?co083mo`00/_l0i/;o1P00oomg04Clo`8l06nfo`00o_l00?co083mo`00o?l0
P?go1@3ooh3oP?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go
083lo`20oOl00?co083mo`40P?ko083lo`00oOl0P?co083mo`20o?l0P?go002b
o`5L0?k2o`H00?ooA01Mo?l2G@14]ol0P>Co0H00oOl0P?co003mo`20o?l00?go
083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go0X00P?ko083mo`20
o?l0P?go003lo`20oOl00?go0H00/_l0mL;o1P00oom405glo`9M04Bgo`20i?l1
P03mo`20o?l00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go
083lo`00oOl2P020o_l0P?go083lo`20oOl00?co083mo`00oOl1P02bo`3V`_l6
003ood@0GOco0Ud0A;Oo083To`600?go083lo`00oOl0P?co003mo`20o?l0P?go
083lo`20oOl00?co083mo`00oOl0P?co003mo`:0083no`20oOl0P?co083mo`00
o?l0P?go003mo`600;;o0I80o/Ko2^IRP7/00?oo3@1lo?l2O00=^Ol2`830i?l0
P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl1P<3no`70P?go083mo`60
P?go083mo`60`?go083mo`60@?ko0L20oOl1P<3no`70P?go083mo`70P?go083m
o`:0`02bo`3ea_l:iV:0N`00ool=07clo`9l00fio`;0P<3To`20oOl1P<3mo`20
oOl1P<3no`70P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0H20oOl0P?go0H30
oOl0P?go0H10o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0X300;;o0>K6
o`[VHX1k003oo`d0O?co0W`03KWo0/20`>Co083mo`60`?go083mo`60`?ko0L20
oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P43n
o`70P?go0H30o_l1`83mo`20oOl1`83mo`20oOl2P<00/_l1Y03na_l:4:[okP00
ool0083lo`:0002io`20o_l0P?co003mo`20o?l0P?go083lo`00o_l0P?co003m
o`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l00?go0H00
oOl0P?go083lo`20oOl00?co083mo`00oOl3P?oo0;;o0?G6o`X@Z_o^003oo`00
P?co0X000;Wo083no`20o?l00?go083lo`20oOl0P?co003no`20o?l00?go083l
o`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`00oOl1P03mo`20
oOl0P?co083mo`00o?l0P?go003mo`>0ool0/_l0i/Ko2Q2Zonh00?oo0020o?l2
P000^Ol0P?ko083lo`00oOl0P?co083mo`20o?l00?ko083lo`00oOl0P?co083m
o`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`600?go083mo`20
o?l0P?go003lo`20oOl00?go0h3oo`2bo`6H0?k7o`^b0>koo`00ool907clo`9l
00Vko`70P>7o1H3ooh10P?ko083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70
P?go083mo`60`?go083mo`60`?ko0L20oOl1P83no`70P?go0H30o_l1`83mo`20
oOl1P83mo`20oOl4P<3o`82bo`3eaol;/P3^ool00?oo2@1lo?l2O009^ol1`83Q
o`F0oon0@83no`20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1
P<3mo`20oOl1P<3no`70P?go0H20o_l1`83mo`60`?ko0L20oOl0P?go0H20oOl0
P?go1830ol20/_l0i/Oo2k80k_oo003oo`T0O?co0W`02K_o0L20hOl5P?ooP420
o_l0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go
0H30o_l1`83mo`60P?ko0L20oOl1P<3no`70P?go083mo`60P?go083mo`B0`?o0
P;;o0Fh0o/Oo0H00o_l6003oob/0GOco0Ud0:kco0@20h?l8P?n0o`00P?l0oOl0
P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0
P?go003lo`20oOl00?go083lo`00oOl0P?ko082ao`3eaol1P03no`H00?oo:`1M
o?l2G@0[_?l1083Po`R0oh3o0020o`3mo`20o?l0P?go083lo`20oOl00?co083m
o`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003m
o`20o_l0P;7o0>K7o`600?ko1P00ool[05glo`9M02^lo`40P>3o283oP?l0083o
0?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0
P?co083mo`00o?l0P?go003mo`20o?l00?go083no`20/Ol1e03naol;R03Qool0
0?ooP00Zo?l2:P1k_Ol0P?co0<3mo`20o?l0`?go083lo`30oOl:P?ooP830o`00
@83mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60
`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko082a
o`3eaol;R03Qool00?ooP00Zo?l2:P1k_Ol0P?co0<3mo`20o?l0`?go083lo`30
oOl:P?ooP830o`00@83mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083m
o`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go
083mo`60`?ko082ao`3Vaol;R03Qool00?ooP00Zo?l2:P1k_Ol0P?co0<3mo`20
o?l0`?go083lo`30oOl:P?ooP830o`00@83mo`60`?ko0L20oOl1P<3no`70P?go
083mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70
P?go083mo`60`?go083mo`60`?ko082ao`5[0?k7o`c309Woo`00moog8@27o_l3
Q`0Qmkko003Mo`00o_l20020oOl0P?co083mo`00o?l0P?go003lo`20oOl00?go
083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co
002ao`3eaol<``2Iool00?Oomb40Qoko0hL08ONno`00gOl00?ko0P00P?go083l
o`20oOl00?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083m
o`00o?l0P?go003mo`20o?l00?go083lo`00/Ol0i/Oo3<<0VOoo003gooLQ08On
o`>7027g__l00=go003no`80083mo`20o?l0P?go003lo`20oOl00?co083mo`00
oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20
o?l00;7o0MX0o/Ko4HP[MiT8:ekoooMc25J0EQ5^mkoo0H20oOl0P?go0<3lo`20
oOl0`?co0<3mo`30oOl3P<3oooh0oOl1P<3no`70P?go083mo`70P?go083mo`60
P?go083mo`60`?ko0L20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1`83mo`20
oOl1P<3mo`20oOl1P<3no`;0P82ao`3ea_lAR2]gV@P[G_oomg<8EX1F4Fkg_ol1
P83mo`20oOl0`?co083mo`30o?l0`?go0<3mo`>0`?oooP3mo`60`?ko0L20oOl0
P?go0L20oOl0P?go0H20oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl1P<3no`70
P?go083mo`70P?go083mo`60`?go083mo`60`?ko0/20P;7o0>K6oa68:gNI22]N
ooogL`QFP5HAK_Noo`60P?go083mo`30o?l0P?go0<3lo`30oOl0`?go0h30ooon
0?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P83mo`20oOl1P<3no`70P?go0H30
o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l2`820
/Ol1?P3n^_l3:`00V;ko083Ko`00o_on0?ko083lo`20oOl00?co083mo`00oOl0
P?co003mo`20o?l0P?go083lo`20o_l1P03lo`20oOl00?co083mo`00oOl0P?co
003mo`20o?l2P?n0/Ol0mK[o0b/009Rno`20fol00?kooP3no`20o?l0P?go003l
o`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?ko0H00o?l0P?go003lo`20
oOl00?go083lo`00oOl0P?co0X3oP;7o0>Jjo`<[002H__l0P=_o003nooh0o_l0
P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083no`600?co
083mo`00o?l0P?go003mo`20o?l00?go083lo`:0oh2ao`5j0?jjo`KIKb/0?820
`_l1P<3Ko`D0ooo0003no`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go
0H30o_l1`83mo`60`?ko1/20ooo0P43mo`70P?go083mo`60P?go083mo`60`?ko
0L20oOl1P<3no`C0P?ooP;7o0?Fjo`KIKb/0?820`_l1P<3Ko`D0ooo0003no`60
`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko1/20
ooo0P43mo`70P?go083mo`60P?go083mo`60`?ko0L20oOl1P<3no`C0P?ooP;7o
0>Jjo`KIKb/0?820`_l1P<3Ko`D0ooo0003no`60`?ko0L20oOl0P?go0L20oOl0
P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko1/20ooo0P43mo`70P?go083mo`60
P?go083mo`60`?ko0L20oOl1P<3no`C0P?ooP;7o0HH0oX7omOl1003mo`20o?l0
P?go003lo`20oOl00?co083mo`@0o`3oooh00_oo0?co083mo`00o?l0P?go003m
o`20o?l00?go083lo`20oOl0P?co083no`600?co083mo`00oOl0P?co003mo`20
o?l0P?go083lo`20o_l0P;7o0?F1ooGo0@00oOl0P?co083mo`00o?l0P?go003l
o`20oOl40?l0ooon00;oo`3lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0
P?go083lo`20o_l1P03lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?ko
082ao`3VPOoeo`400?go083lo`20oOl00?co083mo`00o?l0P?go103o0?oooP02
ool0o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?ko0H00
o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083no`20/Ol1F@3nPOogo`60
P=So1`30P?n0@?n0oOl1`83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`70
P?go0H30o_l3`83oooj0oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30
o_l1`83mo`20/Ol0mH7omol1P83Ho`L0`83oP43oP?go0L20oOl0P?go0H20oOl0
P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0l20ooonP?go0L20oOl0P?go0H30
oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P;7o0>J1ooOo0H20f?l70<20oh10
oh3mo`70P?go083mo`60P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`?0
P?oooX3mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go082a
o`4b0?j1ooSo083Go`:0oh3mo`00o?l0P?go003mo`20o?l00?go083lo`00oOl0
P?co083mo`00o?l5P?oo0?l0o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co
083mo`40P;7o0?F1ooSo083Go`:0oh3mo`00o?l0P?go003mo`20o?l00?go083l
o`00oOl0P?co083mo`00o?l5P?oo0?l0o?l0P?go003mo`20o?l00?go083lo`20
oOl0P?co083mo`40P;7o0>J1ooSo083Go`:0oh3mo`00o?l0P?go003mo`20o?l0
0?go083lo`00oOl0P?co083mo`00o?l5P?oo0?l0o?l0P?go003mo`20o?l00?go
083lo`20oOl0P?co083mo`40P;7o0KT0oX7on_l3`830P?co0<3mo`20oOl0`?co
083mo`30o?l0`?go0<3no`500?ko0H10oOl1`83mo`20oOl1P<3mo`20oOl1P<3n
o`70P?go0H30o_l1`83mo`20oOl6`83ooh3oP?go0H20oOl0P?go0H30oOl0P?go
0H30o_l1`83mo`60`?ko0L20oOl2P?n0/Ol0mH7on_l3`830P?co0<3mo`20oOl0
`?co083mo`30o?l0`?go0<3no`500?ko0H10oOl1`83mo`20oOl1P<3mo`20oOl1
P<3no`70P?go0H30o_l1`83mo`20oOl6`83ooh3oP?go0H20oOl0P?go0H30oOl0
P?go0H30o_l1`83mo`60`?ko0L20oOl2P?n0/Ol0iX7on_l3`830P?co0<3mo`20
oOl0`?co083mo`30o?l0`?go0<3no`500?ko0H10oOl1`83mo`20oOl1P<3mo`20
oOl1P<3no`70P?go0H30o_l1`83mo`20oOl6`83ooh3oP?go0H20oOl0P?go0H30
oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl2P?n0/Ol1<P3nPOojo`20eOl60020
oh000?go083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00
oOl0P?co003mo`20o?l00?go083lo`20oOl00?co083mo`80o`2`o`3ePOojo`20
eOl60020oh000?go083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co
083mo`00oOl0P?co003mo`20o?l00?go083lo`20oOl00?co083mo`80o`2`o`3V
POojo`20eOl60020oh000?go083mo`00oOl0P?co003mo`20o?l0P?go083lo`20
oOl00?co083mo`00oOl0P?co003mo`20o?l00?go083lo`20oOl00?co083mo`80
o`2`o`6l0?joo`20_ol2`830o?l0P?go0<3lo`30oOl0P?co0<3mo`20o?l0`?go
2h1000200010oon0P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go
083mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70
P?go0h3oo`2`o`3e_ol0P;oo0/20`?co083mo`30o?l0`?go083lo`30oOl0P?co
0<3mo`^0@000P000@?ooP83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1
`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1`83mo`20
oOl1`83mo`>0ool0/?l0i[oo082oo`;0P<3lo`20oOl0`?co0<3mo`20o?l0`?go
083lo`30oOl;P4000800043ooh20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60
`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20
oOl0P?go0L20oOl3P?oo0;3o0CD0o[ko0@00`Ol0P=?o083l00;ooh3lo`00oOl0
P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0
P?go083lo`20oOl00?co083mo`00o_l00;3o0?Fno`400<7o083Co`20o002oon0
o?l00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00
oOl0P?co083mo`20o?l0P?go003lo`20oOl00?ko002`o`3V__l10031o`20dol0
P?`00_ooP?co003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003m
o`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003no`00/?l1>03n__om
0<Go0H00d_l1P?on0?ko083mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0
P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20oOl0
0;3o0?Fnood0aOl1P03Bo`60ooh0o_l0P?go083lo`20oOl00?co083mo`00o?l0
P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l0
0?go083mo`00/?l0i[koo@35o`600=;o0H3ooP3no`20oOl0P?co083mo`00o?l0
P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl0
0?go083lo`00oOl0P?go002`o`7D0?jno`10o@01P839o`>0`?o0oOl0P?co0<3m
o`20oOl0`?co083mo`30o?l0`?go0<3no`10o001P83mo`60`?ko0L20oOl0P?go
0L20oOl0P?go0H20oOl0P?go0H30o_l2`820o_l1P<3no`70P?go0H30o_l1`83m
o`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`700;3o0?Fno`10o@01P839o`>0
`?o0oOl0P?co0<3mo`20oOl0`?co083mo`30o?l0`?go0<3no`10o001P83mo`60
`?ko0L20oOl0P?go0L20oOl0P?go0H20oOl0P?go0H30o_l2`820o_l1P<3no`70
P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`700;3o0>Jn
o`10o@01P839o`>0`?o0oOl0P?co0<3mo`20oOl0`?co083mo`30o?l0`?go0<3n
o`10o001P83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H20oOl0P?go0H30o_l2
`820o_l1P<3no`70P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1
P<3no`700;3o0Ch0o[ko083j0020c?l0P<oooP00ooh0oOl0P?co083mo`00o?l0
P?go003mo`20o?l00?go083lo`600?ko083lo`20oOl00?co083mo`00o?l0P?go
003mo`20o?l00?go083lo`600;3o0?Fno`20nP00P<co083?ooh00?on0?go083l
o`20oOl00?co083mo`00oOl0P?co003mo`20o?l1P03no`20o?l0P?go003lo`20
oOl00?co083mo`00oOl0P?co003mo`20o?l1P02`o`3V__l0P?X0083<o`20coon
003ooP3mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co0H00o_l0P?co
083mo`00o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co0H00/?l1M`3n__l0
`?P00T20P=;o0/20`<oo0`00`?on0?ko0H30o_l1`83mo`20oOl1`83mo`20oOl1
P<3mo`20oOl1P<3no`;0P83no`60`?ko0L20oOl0P?go0L20oOl0P?go0H20oOl0
P?go0H30o_l1`83mo`60`?ko0/20P:oo0?Fno`30n002@820d_l2`830col30030
ooh0o_l1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko0/20P?ko
0H30o_l1`83mo`20oOl1`83mo`20oOl1P83mo`20oOl1P<3no`70P?go0H30o_l2
`820[ol0i[ko0<3h0090P83Bo`;0P<3?o`<00<3ooP3no`60`?ko0L20oOl0P?go
0L20oOl0P?go0H30oOl0P?go0H30o_l2`820o_l1P<3no`70P?go083mo`70P?go
083mo`60P?go083mo`60`?ko0L20oOl1P<3no`;0P82_o`6Q0?jmoo@0dol3P?oo
0?go083lo`00oOl0P?co083mo`00o?l0P?go003lo`20oOon00Oooh000?oo0?co
083mo`00o?l0P?go003mo`20o?l00?go083lo`400?ko083lo`20oOl00?co083m
o`00oOl0P?co003mo`20o?l0P?go083lo`:0oh2_o`3e_Ood0=?o0h3oo`3mo`20
o?l00?go083lo`20oOl00?co083mo`00o?l0P?gooP07oon0003oo`3lo`20oOl0
0?co083mo`00oOl0P?co003mo`20o?l1003no`20o?l0P?go003lo`20oOl00?go
083lo`00oOl0P?co083mo`20o?l2P?n0[ol0i[gom03Co`>0ool0oOl0P?co003m
o`20o?l0P?go003lo`20oOl00?co083mooh01oooP000ool0o?l0P?go003lo`20
oOl00?go083lo`00oOl0P?co0@00o_l0P?co083mo`00o?l0P?go003mo`20o?l0
0?go083lo`20oOl0P?co0X3oP:oo0Fh0o[con`00@?j0dol1P83=o`@0ooo00?go
083mo`70P?go083mo`60P?go083mo`60`?go083mo`60`?ko0/00`?ko0H30o_l1
`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l4`83ooh2_
o`3e_?ok0010oX3Co`60P<go103ool00oOl0P?go0L20oOl0P?go0H20oOl0P?go
0H30oOl0P?go0H30o_l2`030o_l1P<3no`70P?go083mo`70P?go083mo`60`?go
083mo`60`?ko0L20oOl1P<3no`C0P?ooP:oo0>Jloo/0043nP=?o0H20cOl40?oo
`03mo`20oOl1`83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`;00<3no`60
`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko1<20
oon0[ol1A`3n_?ok0020dOl00<_o103ooh00o_l00?co083mo`00oOl0P?co003m
o`20o?l00?go083lo`00oOl00?ko1`00P?n00800o?l0P?go003mo`20o?l00?go
083lo`20oOl0P?co083no`20[ol0mKcon`00P=7o003;o`@0oon00?ko003lo`20
oOl00?go083lo`00oOl0P?co003mo`20o?l00?go003no`L0083oP0200?co083m
o`00oOl0P?co003mo`20o?l0P?go083lo`20o_l0P:oo0>Jloo/0083Ao`00bol4
0?ooP03no`00o?l0P?go003mo`20o?l00?go083lo`00oOl0P?co003mo`00o_l7
0020oh00P03lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?ko082_o`7/
0?jlo`20oP03@000P=Co0L20o_l0`?co0<3mo`20o?l0`?go083mo`30o?l0P?go
0<3lo`30oOl:`?oo0<20o`3ooh3mo`70P?go083mo`60`?go083mo`60`?ko0L20
oOl1P<3no`70P?go083mo`H004200010oOl1P83mo`20oOl1P<3mo`20oOl1P<3n
o`70P?go0H30o_l1`83mo`10[ol0mKco083n00=00020e?l1`83no`30o?l0`?go
083lo`30oOl0P?go0<3lo`20oOl0`?co0<3mo`[0ool0`83o0?ooP?go0L20oOl0
P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go1P00@800043mo`60
P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go042_o`3V_?l0P?h0
0d00083Do`70P?ko0<3lo`30oOl0P?co0<3mo`20oOl0`?co083mo`30o?l0`?go
2/3oo`30P?l0oon0oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1
`83mo`20oOl60010P000@?go0H20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60
`?ko0L20oOl0@:oo0Ch0o[_ooP00ooh0083Eo`20b_l7P?n0ool0o`3lo`20oOl0
0?go083lo`00oOl0P?co083mo`20o?l0P?go003loo/0oOl0P?co003mo`20o?l0
0?go083lo`20oOl00?co083mo`40P:oo0?Fkooh00?on0020eOl0P<[o1h3oP?oo
0?l0o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?ok0?go083l
o`00oOl0P?co003mo`20o?l0P?go003lo`20oOl1082_o`3V^oon003ooP00P=Go
083:o`N0oh3oo`3o0?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl0
0?con`3mo`20o?l00?go083lo`00oOl0P?co083mo`00o?l0P?go0@20[ol1k03n
^oon00Good00083Ho`B0P?oo`?co083mo`30o?l0P?go0<3lo`30oOl0P?co0<3m
o`20o?l0`?ko0H20o_l1083mo`60P?go083mo`60`?go083mo`60`?ko0L20oOl1
P<3no`70P?go083mo`;0P?ol00B0P?n0`?go083mo`60`?ko0L20oOl1P<3no`70
P?go083mo`70P?go0X3oP:oo0?Fkooh01Ooo@000P=So1820ooo0o?l0P?go0<3l
o`20oOl0`?co0<3mo`20o?l0`?go083lo`30o_l1P83no`40P?go0H20oOl0P?go
0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0/20oo`01820oh30oOl0
P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl2P?n0[ol0i[_ooP05oom0
0020f?l4P83ool3lo`20oOl0`?co083mo`30o?l0`?go083lo`30oOl0P?co0<3n
o`60P?ko0@20oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1`83m
o`20oOl2`83oo004P83oP<3mo`20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1
`83mo`:0oh2_o`4h0?jjo`400?koo@3Jo`00aol0P?go003mo`20o?l00?go083l
o`00oOl0P?co083mo`20o?l0P?go003lo`:0oh3h0?go003mo`20o?l0P?go083l
o`20oOl00?co083mo`<0oon0[ol0mK[o0@00o_om0=[o0037o`20oOl00?go083l
o`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co0X3oP?P0oOl00?go083l
o`20oOl0P?co083mo`00o?l0P?go0`3ooh2_o`3V^_l1003nood0f_l00<Oo083m
o`00oOl0P?co003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l2P?n0n03m
o`00oOl0P?co083mo`20o?l0P?go003lo`20oOl30?ooP:oo0G@0o[[o003lo`=0
0010g?l0P<Ko083no`600?ko0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl6
P<3ooh30P?go083mo`N0P?oo0010P?T00H10oOl1P<3no`70P?go0H30o_l1`83m
o`20oOl1`83mo`20o_l0P:oo0?Fjo`00o?l3@000@=co0836o`20o_l1P03no`60
`?go083mo`60`?ko0L20oOl1P<3no`70P?go1X30oon0`83mo`20oOl7P83oo`00
@83i0060@?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?ko082_o`3V
^_l00?co0d00043Lo`20a_l0P?ko0H00o_l1P<3mo`20oOl1P<3no`70P?go0H30
o_l1`83mo`J0`?ooP<20oOl0P?go1h20ool00420n@01P43mo`60`?ko0L20oOl1
P<3no`70P?go083mo`70P?go083no`20[ol1cP3n^_l0P?_oo@3Oo`600?go083m
o`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`Z0oh3oo`3o0?oo
P?co003mo`20o?l0P?go083lo`20oOl00?ko0X3oP?go003mo`20o_on00Kooh00
0?n0nP01oh3lo`20oOl0P?co083mo`00o?l0P?go003mo`20[ol0mK[o083kood0
gol1P03mo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl:
P?n0ool0o`3ooh3lo`00oOl0P?co083mo`20o?l0P?go003no`:0oh3mo`00oOl0
P?kooP06oon0003oP?X00On0o?l0P?go083lo`20oOl00?co083mo`00oOl0P:oo
0>Jjo`20noom0=oo0H00oOl0P?go083lo`20oOl00?co083mo`00oOl0P?co003m
o`20o?l0P?go2X3oP?oo0?l0oon0o?l00?go083lo`20oOl0P?co083mo`00o_l2
P?n0oOl00?go083nooh01_ooP000oh3j007oP?co083mo`20o?l0P?go003lo`20
oOl00?go082_o`5a0?jjo`30n_l3P000@>7o0H30a?l8P?n0ol20oh30oOl0P?go
0H30o_l1`83mo`60`?ko0L20oOl0P?kooX3mo`20oOl<P<3oP83o@83ool00`?ko
oX3l0?j00L20oOl1P<3no`70P?go083mo`60P?go083mo`60`:oo0?Fjo`30n_l3
P000@>7o0H30a?l8P?n0ol20oh30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0
P?kooX3mo`20oOl<P<3oP83o@83ool00`?kooX3l0?j00L20oOl1P<3no`70P?go
083mo`60P?go083mo`60`:oo0>Jjo`30n_l3P000@>7o0H30a?l8P?n0ol20oh30
oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?kooX3mo`20oOl<P<3oP83o@83o
ol00`?kooX3l0?j00L20oOl1P<3no`70P?go083mo`60P?go083mo`60`:oo0C/0
o[7o083n0>?o0832o`J00?ooP?n0o?l00?go083lo`20oOl0P?co083mo`00o_l2
P?n0oOl00?go1X3oo`3oo`3mo`20o?l0P?gon@3no`00o?l0P?go003mo`20o?l0
0?go0H00[_l0mK7o083n0>?o0832o`J00?ooP?n0o?l00?go083lo`20oOl0P?co
083mo`00o_l2P?n0oOl00?go1X3oo`3oo`3mo`20o?l0P?gon@3no`00o?l0P?go
003mo`20o?l00?go0H00[_l0i[7o083n0>?o0832o`J00?ooP?n0o?l00?go083l
o`20oOl0P?co083mo`00o_l2P?n0oOl00?go1X3oo`3oo`3mo`20o?l0P?gon@3n
o`00o?l0P?go003mo`20o?l00?go0H00[_l1lP3n/?l3P000@>Ko0/20`?go083m
o`30o?l0P?go0<3lo`20oOl0`?co0<3mo`20o?l0`?go083lo`30o_l0@?ko0X20
`?ko0L20oOl1P<3no`70P?go0H30o_l1`83mo`20o_onP?go083mo`J0`820oon0
oOl1P<3no`70P?go1H30oh20@?`00D20o_l1`83mo`20oOl1P<3mo`20oOl2P<00
[_l0mK3o0h00043Vo`;0P<3mo`20oOl0`?co083mo`30o?l0P?go0<3lo`30oOl0
P?co0<3mo`20o?l0`?ko043no`:0P<3no`70P?go0H30o_l1`83mo`60`?ko0L20
oOl0P?kooX3mo`20oOl6P<20P?ooP?go0H30o_l1`83mo`F0`?n0P43l0050P?ko
0L20oOl0P?go0H30oOl0P?go0X300:ko0>J`o`>00010i_l2`830oOl0P?go0<3l
o`20oOl0`?co083mo`30o?l0`?go083lo`30oOl0P?co0<3no`10o_l2P830o_l1
`83mo`60`?ko0L20oOl1P<3no`70P?go083nooj0oOl0P?go1X30P83ooh3mo`60
`?ko0L20oOl5P<3oP810o001@83no`70P?go083mo`60`?go083mo`:0`02^o`54
0?j_o`20oP3Wo`20`?l0P?ko083lo`20oOl0P?co083mo`00o?l0P?go003no`80
oh3mo`00oOl2P?l0o_l00?go083lo`20oOl0P?co0X3oP?X00On0oOl00?go083l
o`00oOl3P?oo0:ko0?F_o`20oP3Wo`20`?l0P?ko083lo`20oOl0P?co083mo`00
o?l0P?go003no`80oh3mo`00oOl2P?l0o_l00?go083lo`20oOl0P?co0X3oP?X0
0On0oOl00?go083lo`00oOl3P?oo0:ko0>J_o`20oP3Wo`20`?l0P?ko083lo`20
oOl0P?co083mo`00o?l0P?go003no`80oh3mo`00oOl2P?l0o_l00?go083lo`20
oOl0P?co0X3oP?X00On0oOl00?go083lo`00oOl3P?oo0:ko0Ch0oZkooP00P>Wo
0030o`00oOl00?go003lo`20oOl00?go083lo`00oOl0P?ko0X3o0?go083lo`60
0?ko003lo`20oOl00?co083mo`00oOl0P?X0o_l0P?co083mo`20o?l3P?oo0:ko
0?F^ooh0083Yo`00`?l00?go003mo`00o?l0P?go003mo`20o?l00?go083no`:0
o`3mo`20o?l1P03no`00o?l0P?go003lo`20oOl00?go083j0?ko083lo`20oOl0
P?co0h3oo`2^o`3V[_on0020jOl00<3o003mo`00oOl00?co083mo`00oOl0P?co
003mo`20o_l2P?l0oOl0P?co0H00o_l00?co083mo`00o?l0P?go003mo`20nP3n
o`20o?l0P?go083lo`>0ool0[_l1lP3n[Ol3@000P>cooX3mo`30o?l0`?go0<3l
o`30oOl0P?co0<3mo`20oOl0`?co083mo`30o?l0`?go1/00ooo0P83no`20oOl1
`83mo`20oOl1P<3mo`20oOl3P<3oooj0oOl1P<3no`;0083no`20oOl1`83mo`20
oOl1P83mo`20oOl5P<3o`820o006P420ooo0P?go0H30o_l1`83no`00[_l0mJgo
0d00083/ooj0oOl0`?co0<3mo`30o?l0`?go083lo`30oOl0P?go0<3lo`20oOl0
`?co0<3mo`K00?oo`820o_l0P?go0L20oOl0P?go0H30oOl0P?go0h30ooonP?go
0H30o_l2`020o_l0P?go0L20oOl0P?go0H20oOl0P?go1H30ol20P?`01X10P?oo
`83mo`60`?ko0L20o_l00:ko0>J]o`=00020k?onP?go0<3lo`30oOl0`?co0<3m
o`20o?l0`?go083mo`30o?l0P?go0<3lo`30oOl6`03ool20P?ko083mo`70P?go
083mo`60`?go083mo`>0`?oooX3mo`60`?ko0/00P?ko083mo`70P?go083mo`60
P?go083mo`F0`?o0P83l00J0@83ool20oOl1P<3no`70P?ko002^o`4h0?j/ooh0
083^o`00_Ol80?ooP?n0ool0o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co
003mo`00o?l0P?go003mo`20o?l00?go083lo`80oooi0020oOl00?co083no`20
[Ol0mJcooP00P>ko002mo`P0oon0oh3oo`3lo`20oOl00?go083lo`00oOl0P?co
083mo`20o?l00?go003lo`20oOl00?go083lo`00oOl0P?co0P3oooT0083mo`00
o?l0P?ko082]o`3V[?on0020k_l00;go203ooh3oP?oo0?co083mo`00oOl0P?co
003mo`20o?l0P?go083lo`00oOl00?co083mo`00oOl0P?co003mo`20o?l20?oo
n@00P?go003lo`20o_l0P:go0N`0oZ_o0d00083`o`60P?co0<3mo`20oOl0`?co
083mo`30o?l0P?go0<3lo`30oOl0P?co0<3mo`20o?l:`?oo0<20oon0oh3mo`60
P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`;00<3no`20oOl1`83mo`20
oOl1P<3mo`20oOl1P<3no`70P?gooX00@?`0oX3mo`70P?go042]o`3eZol3@000
P?3o0H20o?l0`?go083mo`30o?l0P?go0<3lo`20oOl0`?co0<3mo`20o?l0`?go
083lo`[0ool0`83ooh3oP?go0H20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60
`?ko0/00`?ko083mo`70P?go083mo`60`?go083mo`60`?ko0L20oOonP010o03n
P?go0L20oOl0@:go0>J[o`=00020l?l1P83lo`30oOl0P?go0<3lo`20oOl0`?co
083mo`30o?l0`?go083lo`30oOl0P?co2/3oo`30P?ooP?n0oOl1P83mo`20oOl1
P<3mo`20oOl1P<3no`70P?go0H30o_l2`030o_l0P?go0L20oOl0P?go0H30oOl0
P?go0H30o_l1`83mooj0043l0?j0oOl1`83mo`10[Ol1<P3nZ_on0020l_l00;co
0X3oP?ko0H00oOl0P?co003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0
P?go003mo`20o?l00?go083lo`20oOl0P?con@3no`20oOl1082]o`3eZ_on0020
l_l00;co0X3oP?ko0H00oOl0P?co003mo`20o?l00?go083lo`20oOl0P?co083m
o`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?con@3no`20oOl1082]o`3V
Z_on0020l_l00;co0X3oP?ko0H00oOl0P?co003mo`20o?l00?go083lo`20oOl0
P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?con@3no`20oOl1
082]o`5X0?jYo`=00020mOl1P82ko`60P?go043mo`60`?go083mo`60`?ko0L20
oOl6P<20ooo0P?go0H30o_l1P83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3n
o`70P?go0H30o_l5`83ool20nP00P?ko0X3oP:go0?FYo`=00020mOl1P82ko`60
P?go043mo`60`?go083mo`60`?ko0L20oOl6P<20ooo0P?go0H30o_l1P83mo`20
oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l5`83ool20nP00P?ko
0X3oP:go0>JYo`=00020mOl1P82ko`60P?go043mo`60`?go083mo`60`?ko0L20
oOl6P<20ooo0P?go0H30o_l1P83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3n
o`70P?go0H30o_l5`83ool20nP00P?ko0X3oP:go0ML0oZSooP00P?Oo0X3oP?co
003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go
083mo`40P?ko083lo`00oOl0P?co083mo`:0oh3no`20oOl00?go0@20oOl00?go
083lo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl30?ooP?T00_ooP:go0?FX
ooh0083go`:0oh3lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083l
o`00oOl0P?co083mo`20oOl1083no`20o?l00?go083lo`20oOl2P?n0o_l0P?go
003mo`40P?go003mo`20o?l00?go083lo`00oOl0P?co083mo`20o?l0P?go0`3o
oh3i00;ooh2]o`3VZ?on0020mol2P?n0o?l00?go083lo`20oOl0P?co083mo`00
o?l0P?go003mo`20o?l00?go083lo`20oOl0P?go0@20o_l0P?co003mo`20o?l0
P?go0X3oP?ko083mo`00oOl1083mo`00oOl0P?co003mo`20o?l00?go083lo`20
oOl0P?co083mo`<0oon0n@02oon0[Ol1J`3nYol3@000P?[o0/20`;Wo083no`J0
oh3ooh30oOl0P?go0H30o_l1`83mo`J0`830ol20oOl0P?ko0X10P?go083mo`60
`?go083mo`60`?ko0L20oOl1P<3no`70P?go0H30o_l1`83mo`20oOomP?/00D20
[_l0mJOo0d00083jo`;0P<2io`20o_l6P?n0oon0`?go083mo`60`?ko0L20oOl6
P<20`?o0P?go083no`:0@83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1
`83mo`60`?ko0L20oOl0P?gooH3k0050P:ko0>JWo`=00020n_l2`830^Ol0P?ko
1X3oP?ooP<3mo`20oOl1P<3no`70P?go1X30P<3o`83mo`20o_l2P420oOl0P?go
0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl1P<3no`70P?go083moof0n`01
@82^o`510?jVood0nol0P;Oo283oo`3ooh3oP?co003mo`20o?l0P?go0X3o0?ko
083mo`00o_l2P?n0oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20
oOl00?go083lo`40P?X0/?l0mJKoo@3ko`20]ol8P?oo0?ooP?n0o?l00?go083l
o`20oOl2P?l0o_l0P?go003no`:0oh3mo`00oOl0P?co003mo`20o?l0P?go083l
o`20oOl00?co083mo`00oOl0P?co0@20nP2`o`3VY_om0?_o082go`R0ool0oon0
oh3lo`00oOl0P?co083mo`:0o`3no`20oOl00?ko0X3oP?go003mo`20o?l00?go
083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l1083j0;3o0Ql0oZGo0d00
043no`C0P?oo`?go083lo`30oOl0P?go0<3lo`20oOl0`?co083mo`30o?l0`?go
083lo`30oOl0P?co1<3oP?n0o_l2P830o_l1`83mo`60`?ko0L20oOonP0?ool20
oOl2P?oooH3mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1`83mo`20oOl1
`83mo`20oOl1P<3mo`20o_l0`?X00H20l_l0P<Co0?FUo`=00010o_l4`83ool3m
o`20o?l0`?go083mo`30o?l0P?go0<3lo`20oOl0`?co0<3mo`20o?l0`?go083l
o`C0oh3oP?ko0X20`?ko0L20oOl1P<3no`70P?gooX03ooo0P?go0X3ooof0oOl0
P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30
oOl0P?ko0<3j0060P?;o0834o`3VYOl3@000@?ko1<20ooo0oOl0P?co0<3mo`20
oOl0`?co083mo`30o?l0P?go0<3lo`30oOl0P?co0<3mo`20o?l4`?n0oh3no`:0
P<3no`70P?go0H30o_l1`83mooj00ooo`83mo`:0ooomP?go083mo`60`?go083m
o`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083no`30nP01
P83bo`20a?l1F@3nY?om00;ooh2eo`600?go003lo`20oOl0P?co083mo`80oh3n
o`20oOl60?ooP?ooP?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0
P?go003mo`20o?l00?go183oP?n0nP3co`20aOl0mJCoo@02oon0]Ol1P03mo`00
o?l0P?go083lo`20oOl20?n0o_l0P?go1P3ooh3ooh3mo`00oOl0P?co003mo`20
o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`B0oh3oP?X0lol0P<Go
0>JTood00_ooP;Go0H00oOl00?co083mo`20o?l0P?go0P3oP?ko083mo`H0oon0
oon0oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083l
o`00oOl4P?n0oh3j0??o0835o`8d0?jSo`20oP02P?n0oOl0`?co083mo`30o?l0
`?go0<3lo`30oOl0P?co0<3mo`20oOl0`?co083mo`30o?l0`?go043mo`60P?ko
0L20oOl1P<3no`70P?gooX03ooo0P?go1X3o`830P83mo`20oOl1P<3no`70P?go
0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0h30oh3n
o`;0P83k0060P?So0@20a_l0mJ?o083n00:0oh3mo`30o?l0P?go0<3lo`30oOl0
`?co0<3mo`20o?l0`?go083mo`30o?l0P?go0<3lo`30oOl0@?go0H20o_l1`83m
o`60`?ko0L20oOonP0?ool20oOl6P?o0P<20P?go083mo`60`?ko0L20oOl1P<3n
o`70P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl3P<3oP?ko0/20
P?/00H20n?l10836o`3VXol0P?h00X3oP?go0<3lo`20oOl0`?co0<3mo`30o?l0
`?go083lo`30oOl0P?go0<3lo`20oOl0`?co0<3mo`10oOl1P83no`70P?go0H30
o_l1`83mooj00ooo`83mo`J0ol20`820oOl0P?go0H30o_l1`83mo`60`?ko0L20
oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`>0`?n0o_l2`820n`01
P83ho`40P<Ko0ET0oZ;o083n0;Co083no`:0oh3no`20oOl0P?co083mo`00o?l0
P?go1@3ooh3oP?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00o?l0P?go
003mo`20o?l00?go083no`20nOoi0?[o0X000<Oo0?FRo`20oP2do`20o_l2P?n0
o_l0P?go083lo`20oOl00?co083mo`D0oon0oh3lo`00oOl0P?co083mo`20o?l0
P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20o_l0P?Won@3jo`:00037
o`3VX_l0P?h0]?l0P?ko0X3oP?ko083mo`20o?l0P?go003lo`20oOl50?ooP?n0
o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003lo`20oOl00?go083lo`00
oOl0P?ko083iooT0n_l2P000aol1WP3nX_l4P800042fo`00o_l6P<20`?o0P?go
0H30o_l1`83mo`20oOl1`83mo`J0oh20oh30oOl0P?go0H30o_l1`83mo`60`?ko
0L20oOl0P?go0L20oOl0P?go0H20oOl0P?go0H30o_l1`83mo`B0`?oo0?Ko0/20
@?`00H20o_l0`?h00<39o`3eX_l4P800042fo`00o_l6P<20`?o0P?go0H30o_l1
`83mo`20oOl1`83mo`J0oh20oh30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0
P?go0L20oOl0P?go0H20oOl0P?go0H30o_l1`83mo`B0`?oo0?Ko0/20@?`00H20
o_l0`?h00<39o`3VX_l4P800042fo`00o_l6P<20`?o0P?go0H30o_l1`83mo`20
oOl1`83mo`J0oh20oh30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20
oOl0P?go0H20oOl0P?go0H30o_l1`83mo`B0`?oo0?Ko0/20@?`00H20o_l0`?h0
0<39o`840?jTo`@00?ooP?h00_ooP?go003lo`20oOl00?go083lo`00oOl0P?co
003mo`20o?l0P?go003lo`20oOl00?co2X00oon0ool0oon0oOl00?co083mo`00
o?l0P?go1@3o0?ooP?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0
P?co003mo`20o?l0P?go083mo`00l_l0P?X00Oooo03:o`3eY?l4003ooh3n00;o
oh3mo`00o?l0P?go003mo`20o?l00?go083lo`00oOl0P?co083mo`00o?l0P?go
003lo`Z00?ooP?oo0?ooP?go003lo`20oOl00?co083mo`D0o`3ooh3lo`00oOl0
P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20oOl0
0?;o083j007ooo`0b_l0iZCo1000oon0oP02oon0oOl00?co083mo`00oOl0P?co
003mo`20o?l00?go083lo`20oOl00?co083mo`00o?l:P03ooh3oo`3ooh3mo`00
o?l0P?go003lo`20oOl50?l0oon0o?l00?go083lo`20oOl0P?co083mo`00o?l0
P?go003mo`20o?l00?go083lo`20oOl0P?go003bo`20nP01oool0<[o0E`0oZGo
083looh0082ho`P0oon0ool0o`3mo`20o?l00?go083lo`00oOl2P?l0o_l0P?go
083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co
083mo`00l?l0P?D0083;o`3eYOl0P?cooP00P;So203ooh3oo`3o0?go083lo`00
oOl0P?co003mo`:0o`3no`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go
083lo`20oOl0P?co083mo`00o?l0P?go003`o`20m@00P<_o0>JUo`20o?on0020
^?l80?ooP?oo0?l0oOl0P?co003mo`20o?l00?go0X3o0?ko083mo`20o?l0P?go
003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?3o
083e0020bol1b`3n`ol00>Go0H30nol3@000P;Wo0P30P?ko0@20oOl1P<3mo`20
o_l2P830o_l1`83mooj00ooo`83mo`60`?ko0L20oOl0P?go0H20oOl0P?go0H30
oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl1P03^o`;0P43h0020
j_l=Kd@8ooo0G@00?7LEA<3ao`3e`ol00>Go0H30nol3@000P;Wo0P30P?ko0@20
oOl1P<3mo`20o_l2P830o_l1`83mooj00ooo`83mo`60`?ko0L20oOl0P?go0H20
oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl1P03^
o`;0P43h0020j_l=Kd@8ooo0G@00?7LEA<3ao`3V`ol00>Go0H30nol3@000P;Wo
0P30P?ko0@20oOl1P<3mo`20o_l2P830o_l1`83mooj00ooo`83mo`60`?ko0L20
oOl0P?go0H20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go
0L20oOl1P03^o`;0P43h0020j_l=Kd@8ooo0G@00?7LEA<3ao`8[0?k3o`00i_l0
0?go083mooh00X3oP?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0
P?co003mo`20o?l5P?ooP?n0oOl00?go083lo`00o_l1083lo`20oOl2P020o_l0
P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl0
0?co083mo`80o`3YooP0j_l1M`3mo`H0083oE@0llOl0mL?o003Vo`00oOl0P?go
oP02P?n0o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go
083lo`F0oon0oh3mo`00oOl0P?co003no`40P?co083mo`:0083no`20oOl00?co
083mo`00oOl0P?co003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go
0P3o0>Won03Zo`5g0?go1P00P?mE03cao`3V`ol00>Ko003mo`20oOon00:0oh3l
o`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co1H3o
oh3oP?go003mo`20o?l00?ko0@20o?l0P?go0X00P?ko083mo`00o?l0P?go003m
o`20o?l00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl20?l0jOoh
0>[o0GL0oOl60020oeD0??7o0O80o/So1NjEP:;o0?go1O^kR82AgO;o0L20m_l3
@000P;co0H20oOl1P03no`60`?go083no`:0P<3no`70P?go0H10o_l1`83mo`20
oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1`83mo`60`?ko0L20
oOl0P?go0H20oOl3P?o0P>[o0H10n000`>co0H00oOl60020og`01?7o0?G8o`G^
UH2Ro`3mo`Gk^hR0TMgbo`70P?Ko0d00082lo`60P?go0H00o_l1P<3mo`20o_l2
P830o_l1`83mo`60@?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1
`83mo`60`?ko0L20oOl1P<3no`70P?go083mo`60P?go0h3o`83Zo`60@?P00<3/
o`600?go1P00P?ml00Cao`3Vb?l5kYF0X_l0oOl5nk^8P97Ml_l1`83fo`=00020
_?l1P83mo`600?ko0H30oOl0P?ko0X20`?ko0L20oOl1P43no`70P?go083mo`70
P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go0H30o_l1`83mo`20
oOl1P83mo`>0ol20j_l1P43h0030k?l1P03mo`H0083oO004lOl1/03nbOl0i_d0
0ED0oOl0R?`00:[co`20m?on0020_Ol0P?go1@3o0?ooP?co003no`40P?co083m
o`600?go083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00
o?l0P?go003mo`20o?l30?ooP>[ol`3]o`600?go1P00P?n0003ao`3ebOl0i_d0
0ED0oOl0R?`00:[co`20m?on0020_Ol0P?go1@3o0?ooP?co003no`40P?co083m
o`600?go083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00
o?l0P?go003mo`20o?l30?ooP>[ol`3]o`600?go1P00P?n0003ao`3VbOl0i_d0
0ED0oOl0R?`00:[co`20m?on0020_Ol0P?go1@3o0?ooP?co003no`40P?co083m
o`600?go083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00
o?l0P?go003mo`20o?l30?ooP>[ol`3]o`600?go1P00P?n0003ao`:_0?k9o`I_
2;_ob1T0o_l7c0T0GX0l03ceo`60P?go0<3mo`30o?l5@000P?n0o?l0`?go083m
o`30o?l0P?go0<3lo`20oOl0`?co0<3mo`20o?l0`?go083lo`10o_l6P?oo0?n0
`?ko0L20o_l7P830ol3o`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0
P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?ko083/
o`60@?h0nX00`>ko1NIVKgM00?go1P00P?mV02Kao`3ebOl6K`RkolPI0?ko1l`9
05j0?00lmOl1P83mo`30oOl0`?co1D00083oP?co0<3mo`20oOl0`?co083mo`30
o?l0P?go0<3lo`30oOl0P?co0<3mo`20o?l0@?ko1X3oo`3oP<3no`70P?ko1h20
`?o0ol20oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko0L20
oOl1P<3no`70P?go083mo`70P?go083mo`60`?go083no`20k?l1P43n0?Z00<3^
o`GVIVmg@03mo`H0083oIP0VlOl0i/Wo1Vl8^oo86@3no`O<2@1NP3`0??Go0H20
oOl0`?go0<3lo`E00020oh3lo`30oOl0P?go0<3lo`20oOl0`?co083mo`30o?l0
`?go083lo`30oOl0P?co043no`J0ool0oh30o_l1`83no`N0P<3o`?o0P?go0H30
o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1`83m
o`20oOl1`83mo`20oOl1P<3mo`20o_l0P>co0H10oP3jP030k_l5iVI_Md00oOl6
0020ofH09_7o0K00o/Wo0B:Ho_l1Z@3no`M407Ooonh00?Ko003_ooh0082oo`J0
ool0oon0n003oh00P?co083no`600?co083mo`00o?l0P?go003mo`20o?l00?go
083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083<o`D@EOooK`3m
o`H0083<4@28lOl0mLWo0B:Ho_l1Z@3no`M407Ooonh00?Ko003_ooh0082oo`J0
ool0oon0n003oh00P?co083no`600?co083mo`00o?l0P?go003mo`20o?l00?go
083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083<o`D@EOooK`3m
o`H0083<4@28lOl0i/Wo0B:Ho_l1Z@3no`M407Ooonh00?Ko003_ooh0082oo`J0
ool0oon0n003oh00P?co083no`600?co083mo`00o?l0P?go003mo`20o?l00?go
083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083<o`D@EOooK`3m
o`H0083<4@28lOl2R`3nbOl11>kno`7g0?ko0PP0i_;o083mo`20o?l0`?go083m
o`I00020oon0oOl0`?co0<3mo`30o?l0`?go083lo`30oOl0P?go0<3lo`20oOl1
`?omP0E0P?n0oh3no`:0P<3no`70P?go0@30o_l1`83no`60@?go0L20oOl0P?go
0H20oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go
083mo`60`?go083mo`60@<go1[80gOooP03mo`H00420P;?klOl0mLWo0@C^o_l1
m`3no`880>Kbo`20oOl0P?co0<3mo`20oOl6@000P?ooP?go0<3lo`30oOl0`?co
0<3mo`20o?l0`?go083mo`30o?l0P?go0L3ooH05@83oP?n0o_l2P830o_l1`83m
o`40`?ko0L20o_l1P43mo`70P?go083mo`60P?go083mo`60`?ko0L20oOl1P<3n
o`70P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P43=o`Jb0=go
oh00oOl60010P82cno7o0>K9o`44k_ko0OL0o_l2203Vl_l0P?go083lo`30oOl0
P?go1T00083ooh3mo`30o?l0`?go0<3lo`30oOl0P?co0<3mo`20oOl0`?co083m
o`70oof01D20oh3oP?ko0X20`?ko0L20oOl10<3no`70P?ko0H10oOl1`83mo`20
oOl1P83mo`20oOl1P<3no`70P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20
oOl0P?go0H30oOl0P?go0H10cOl6/P3Moon00?go1P00@820/o_ao`6o0?k9o`00
o?l00?ko0@00lol1P03[ooh0083Good0nOon0?[o0H00oOl0P?co083mo`600?go
083no`400?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083m
o`00o?l0P?go003mo`20o?l00?go0X3oP=[on03mo`600?ko0H00oOl20020kOl0
mLWo003lo`00o_l1003co`600>_ooP00P=Ooo@3iooh0n_l1P03mo`20o?l0P?go
0H00oOl0P?ko0@00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00
o?l0P?go003lo`20oOl00?go083lo`00oOl2P?n0f_oh0?go0H00o_l1P03mo`80
083]o`3VbOl00?co003no`400??o0H00joon0020eoom0?WooP3jo`600?go083l
o`20oOl1P03mo`20o_l1003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0
P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`:0oh3JooP0oOl1P03no`60
0?go0P00P>go0NT0o/Wo0@fko_l1^`3no`LI0<?oooN0P?[o0H30jOl3@000P=go
o83[o`10oOl1P43no`70P?go2h300?oo`83ool20P?go0L20oOl0P?go0H30oOl0
P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H20oOl0P?go0H30
o_l1`83mo`>0`?n0cOl6R033oon00?go0P00P>go0?G9o`4=^oko0K/0o_l76@33
ooogP83jo`60`>Wo0d00083Moob0jol0@?go0H10o_l1`83mo`^0`03ool20ooo0
P83mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70
P?go083mo`60P?go083mo`60`?ko0L20oOl3P<3oP<go1XP0`oooP03mo`80083]
o`3VbOl13K_no`6k0?ko1aT0`ooomh20n_l1P<3Yo`=00020gOolP>_o043mo`60
@?ko0L20oOl;P<00ooo0P?oo`820oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70
P?go0H30o_l1`83mo`20oOl1`83mo`20oOl1P83mo`20oOl1P<3no`70P?go0h30
oh3=o`J80<?ooh00oOl20020kOl2I03nbOl1A27no`4Q0?ko1hL00<coO`0[nol1
P03mo`20o?l0P?go083lo`20oOom00;ooh3mo`00oOl0P?con002ool0oOl0P?co
083mo`00o?l0P?go003lo`20o_l2P?n0o_l0P?go2`3oo`3ooh3oo`200?co083m
o`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003m
o`20o?l0P?go083no`20cOl7``0boon00?Ono`80083]o`3ebOl1A27no`4Q0?ko
1hL00<coO`0[nol1P03mo`20o?l0P?go083lo`20oOom00;ooh3mo`00oOl0P?co
n002ool0oOl0P?co083mo`00o?l0P?go003lo`20o_l2P?n0o_l0P?go2`3oo`3o
oh3oo`200?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083m
o`00oOl0P?co003mo`20o?l0P?go083no`20cOl7``0boon00?Ono`80083]o`3V
bOl1A27no`4Q0?ko1hL00<coO`0[nol1P03mo`20o?l0P?go083lo`20oOom00;o
oh3mo`00oOl0P?con002ool0oOl0P?co083mo`00o?l0P?go003lo`20o_l2P?n0
o_l0P?go2`3oo`3ooh3oo`200?co083mo`00oOl0P?co003mo`20o?l0P?go083l
o`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083no`20cOl7``0boon0
0?Ono`80083]o`810?k9o`Jc04V0BD`0o_l1mcOl002MoOl2P830jol2`830o_l3
@000@?R00<3?o`00o_l6P<3oP?o0P?go2h3ool20`83ooh3oP?go0H20oOl0P?go
0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0
P?go0H30o_l1`83mo`60`?ko083<o`f8:e6IDB]Nol1M000_P>ko0?G9o`Jc04V0
BD`0o_l1mcOl002MoOl2P830jol2`830o_l3@000@?R00<3?o`00o_l6P<3oP?o0
P?go2h3ool20`83ooh3oP?go0H20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60
`?ko0L20oOl0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko083<
o`f8:e6IDB]Nol1M000_P>ko0>K9o`Jc04V0BD`0o_l1mcOl002MoOl2P830jol2
`830o_l3@000@?R00<3?o`00o_l6P<3oP?o0P?go2h3ool20`83ooh3oP?go0H20
oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20oOl0P?go
0H30oOl0P?go0H30o_l1`83mo`60`?ko083<o`f8:e6IDB]Nol1M000_P>ko0H`0
o/So1MdR06Go0?go1NiV200cgOco003]ood0083kood0a_l30?ooP?ko0X3oP?go
003no`N0oh3oP03o0?go083lo`00oOl0P?co003mo`20o?l0P?go003lo`20oOl0
0?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20Zol0mLSo1MdR06Go0?go
1NiV200cgOco003]ood0083kood0a_l30?ooP?ko0X3oP?go003no`N0oh3oP03o
0?go083lo`00oOl0P?co003mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0
P?co003mo`20o?l0P?go083lo`20Zol0i/So1MdR06Go0?go1NiV200cgOco003]
ood0083kood0a_l30?ooP?ko0X3oP?go003no`N0oh3oP03o0?go083lo`00oOl0
P?co003mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0
P?go083lo`20Zol2:03n/ol00?b0043nP070P?co0<3nP07oP?go0<3lo`F00010
ol3lo`30oOl0`?co0<3mo`20o?l0`?go083mo`30o?l0P?go0<3lo`G0o`3oP<3n
o`60P?go083mo`J0P<20`?n0oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l1`83m
o`20oOl1`83mo`20oOl1P83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30o_l2
`820Zol0mK?o003lP010oX01`83lo`30oX01oh3mo`30o?l5P000@?o0o?l0`?go
0<3lo`30oOl0P?co0<3mo`20oOl0`?co083mo`30o?l5`?l0oh30o_l1P83mo`20
oOl6P830P<3oP?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0L20
oOl0P?go0H20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`60`?ko0/20P:_o0>Jc
o`00o800@?j00L20o?l0`?j00On0oOl0`?co1H00043o`?co0<3mo`30o?l0`?go
083lo`30oOl0P?go0<3lo`20oOl0`?co1L3o0?n0`?ko0H20oOl0P?go1X20`830
oh3mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?go083mo`60
P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`;0P82[o`4k0?jdo`20gol0
P?h0b?l1083lo`00oOl00?co1@3oP?oo0?go083lo`00oOl0P?co083mo`20o?l0
P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go003lo`600:[o
0?Fdo`20gol0P?h0b?l1083lo`00oOl00?co1@3oP?oo0?go083lo`00oOl0P?co
083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go
003lo`600:[o0>Jdo`20gol0P?h0b?l1083lo`00oOl00?co1@3oP?oo0?go083l
o`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co003m
o`20o?l0P?go003lo`600:[o0Rh0o[Co083no`20oOl0`?co0<3mo`30o?l0`?go
083mo`J00010oon0oOl0`?co083mo`30o?l0P?go0<3lo`30oOl0P?co0<3mo`20
o_l20030o_l2`820o_l0P?go1X20@83ooh3mo`60`?go083mo`60`?ko0L20oOl1
P<3no`70P?go083mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70
P?go083mo`?0P?l0Z_l0mKCo083no`20oOl0`?co0<3mo`30o?l0`?go083mo`J0
0010oon0oOl0`?co083mo`30o?l0P?go0<3lo`30oOl0P?co0<3mo`20o_l20030
o_l2`820o_l0P?go1X20@83ooh3mo`60`?go083mo`60`?ko0L20oOl1P<3no`70
P?go083mo`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083m
o`?0P?l0Z_l0i[Co083no`20oOl0`?co0<3mo`30o?l0`?go083mo`J00010oon0
oOl0`?co083mo`30o?l0P?go0<3lo`30oOl0P?co0<3mo`20o_l20030o_l2`820
o_l0P?go1X20@83ooh3mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083m
o`70P?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`?0P?l0
Z_l1A03n]?l0P=go083n0<_o003lo`F0oh3oo`3mo`:0o`3no`00oOl0P?co003m
o`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083l
o`20oOl00?co0h3oo`2Zo`3e]?l0P=go083n0<_o003lo`F0oh3oo`3mo`:0o`3n
o`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003m
o`20o?l0P?go083lo`20oOl00?co0h3oo`2Zo`3V]?l0P=go083n0<_o003lo`F0
oh3oo`3mo`:0o`3no`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083m
o`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co0h3oo`2Zo`540?jdo`20
g?on0020c?l00?go1@3ooh3oP?co0H00o_l0P?co083mo`00o?l0P?go003lo`20
oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00
o_l00:[o0?Fdo`20g?on0020c?l00?go1@3ooh3oP?co0H00o_l0P?co083mo`00
o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20
oOl00?go083lo`00o_l00:[o0>Jdo`20g?on0020c?l00?go1@3ooh3oP?co0H00
o_l0P?co083mo`00o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20
o?l0P?go003lo`20oOl00?go083lo`00o_l00:[o0Rh0o[Co0H00o?l0`?go083l
o`30oOl0P?go0<3lo`20oOl2@000oX05`?o0P830o?l0`?go083lo`30oOl0P?go
0<3lo`20oOl0`?co0L00o_l0P?ko0X20`?ko0/00P?ko0H30o_l1`83mo`20oOl1
`83mo`20oOl1P83mo`20oOl1P<3no`c0P?o0P<20`820ol20oOl1P<3no`70P?go
083mo`70P?go083mo`60`?go083mo`00Z_l0mKCo0H00o?l0`?go083lo`30oOl0
P?go0<3lo`20oOl2@000oX05`?o0P830o?l0`?go083lo`30oOl0P?go0<3lo`20
oOl0`?co0L00o_l0P?ko0X20`?ko0/00P?ko0H30o_l1`83mo`20oOl1`83mo`20
oOl1P83mo`20oOl1P<3no`c0P?o0P<20`820ol20oOl1P<3no`70P?go083mo`70
P?go083mo`60`?go083mo`00Z_l0i[Co0H00o?l0`?go083lo`30oOl0P?go0<3l
o`20oOl2@000oX05`?o0P830o?l0`?go083lo`30oOl0P?go0<3lo`20oOl0`?co
0L00o_l0P?ko0X20`?ko0/00P?ko0H30o_l1`83mo`20oOl1`83mo`20oOl1P83m
o`20oOl1P<3no`c0P?o0P<20`820ol20oOl1P<3no`70P?go083mo`70P?go083m
o`60`?go083mo`00Z_l1F@3n]?l2P000g?ol0060ooh0eOl4P03oo`3mo`00o?l0
0?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l;P?ooP000oh000?n0
oOl00?co083mo`00o?l0P?go003mo`20o?l00?go0H00Z_l0mKCo0X000=coo001
P?on0=Go1800ool0oOl00?co003mo`20o?l0P?go003lo`20oOl00?go083lo`00
oOl0P?co2h3ooh000?n0003oP?go003lo`20oOl00?co083mo`00oOl0P?co003m
o`600:[o0>Jdo`:0003Loo`00H3ooP3Eo`B00?oo0?go003lo`00oOl0P?co083m
o`00o?l0P?go003mo`20o?l00?go083lo`^0oon0003oP000oh3mo`00o?l0P?go
003lo`20oOl00?go083lo`00oOl1P02Zo`5a0?jeo`20oP3Ko`10nP00P=Go0h3o
oh3mo`60P?ko0/20`?ko0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1
P<3no`70P?ko0<3k0020oOl0P?go0L20oOl0P?go0H20oOl0P?go0H30o_l1`83m
o`60@:Wo0?Feo`20oP3Ko`10nP00P=Go0h3ooh3mo`60P?ko0/20`?ko0H30o_l1
`83mo`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?ko0<3k0020oOl0P?go
0L20oOl0P?go0H20oOl0P?go0H30o_l1`83mo`60@:Wo0>Jeo`20oP3Ko`10nP00
P=Go0h3ooh3mo`60P?ko0/20`?ko0H30o_l1`83mo`20oOl1`83mo`20oOl1P<3m
o`20oOl1P<3no`70P?ko0<3k0020oOl0P?go0L20oOl0P?go0H20oOl0P?go0H30
o_l1`83mo`60@:Wo0Nl0o[Goo@01o`3mo`20o?l0P?go083lo`20oOl00?co083m
oo/0o?l00?go083lo`00oOl0P?co083mo`00o?l0P?go1@3ooh3o0?go0X3oP?ko
083mo`00o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`60ood0083m
o`00o?l0P?go003mo`20o?l00?go083lo`20oOl2P?n0ZOl0mKGoo@01o`3mo`20
o?l0P?go083lo`20oOl00?co083moo/0o?l00?go083lo`00oOl0P?co083mo`00
o?l0P?go1@3ooh3o0?go0X3oP?ko083mo`00o?l0P?go003lo`20oOl00?go083l
o`00oOl0P?co083mo`60ood0083mo`00o?l0P?go003mo`20o?l00?go083lo`20
oOl2P?n0ZOl0i[Goo@01o`3mo`20o?l0P?go083lo`20oOl00?co083moo/0o?l0
0?go083lo`00oOl0P?co083mo`00o?l0P?go1@3ooh3o0?go0X3oP?ko083mo`00
o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`60ood0083mo`00o?l0
P?go003mo`20o?l00?go083lo`20oOl2P?n0ZOl1F@3n]_l0P?d0083Jo`10o03D
P000o8050820@800o800@?f0043lP010oH000?b0043mP000o800@?f0003mP010
o801083l0030o_l0P?go0L20oOl0P?go0H30oOl0P?go0H30o_l1`83mo`>0`?n0
ZOl0mKKo083m0020f_l0@?`0e8000?b01@20P4200?b0043mP010o800@?f0003l
P010oH000?b0043mP000oH00@?b00@20o000`?ko083mo`70P?go083mo`60`?go
083mo`60`?ko0L20oOl3P<3oP:Wo0>Jfo`20o@00P=[o043l0=B0003lP0D0P810
P03lP010oH00@?b0043mP000o800@?f0003lP010oH000?f0043lP040P?`00<3n
o`20oOl1`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0h30oh2Yo`540?jfoo`0
083JooX0eOl00?go083no`:0083mo`00o?l0P?go003mo`20o?l00?go083lo`00
oOl0P?co083mo`80oh3k00;oo`3lo`20oOl00?go083lo`00oOl0P?co083mo`20
o_l0P:Wo0?Ffoo`0083JooX0eOl00?go083no`:0083mo`00o?l0P?go003mo`20
o?l00?go083lo`00oOl0P?co083mo`80oh3k00;oo`3lo`20oOl00?go083lo`00
oOl0P?co083mo`20o_l0P:Wo0>Jfoo`0083JooX0eOl00?go083no`:0083mo`00
o?l0P?go003mo`20o?l00?go083lo`00oOl0P?co083mo`80oh3k00;oo`3lo`20
oOl00?go083lo`00oOl0P?co083mo`20o_l0P:Wo0R/0o[Oo083k0?ko0<3mo`20
o?l0`?go083mo`30o?l0P?go0<3no`80043m0030o?l0`?go083lo`30oOl0P?go
0<3lo`20oOl0`?co083no`J0`?ooP420oOl0P?ko0P30P?go083mo`60`?go083m
o`60`?ko0L20oOl1P<3no`70P?go1h3ooh000810oP00P?go0H20oOl0P?go0H30
oOl0P?go0H30o_l1`83mo`60`?ko082Yo`3e]ol0P?/0o_l0`?go083lo`30oOl0
P?go0<3lo`20oOl0`?ko0P00@?d00<3lo`30oOl0P?co0<3mo`20oOl0`?co083m
o`30o?l0P?ko1X30oon0@83mo`20o_l20<20oOl0P?go0H30oOl0P?go0H30o_l1
`83mo`60`?ko0L20oOl7P?ooP000P43n0020oOl1P83mo`20oOl1P<3mo`20oOl1
P<3no`70P?go0H30o_l0P:Wo0>Jgo`20n`3no`30oOl0P?co0<3mo`20oOl0`?co
083mo`30o_l20010o@00`?co0<3mo`20o?l0`?go083mo`30o?l0P?go0<3lo`20
o_l6P<3ooh10P?go083no`80`83mo`20oOl1P<3mo`20oOl1P<3no`70P?go0H30
o_l1`83mo`N0oon00020@?h0083mo`60P?go083mo`60`?go083mo`60`?ko0L20
oOl1P<3no`20ZOl1G03n^?l0P?X0f_l6003ooh000=Go0h3ooh3no`:0083mo`00
oOl1083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?ko1800P?ooo@3n
o`20o?l00?go083lo`00oOl0P?co083mo`00o?l0P:Wo0?Fho`20nP3Jo`H00?oo
P000eOl3P?ooP?ko0X00P?go003mo`40P?go003mo`20o?l00?go083lo`20oOl0
P?co083mo`00o_l4P020ooom0?ko083lo`00oOl0P?co003mo`20o?l0P?go003l
o`20ZOl0i[So083j0=[o1P00oon0003Eo`>0oon0o_l2P020oOl00?go0@20oOl0
0?go083lo`00oOl0P?co083mo`20o?l0P?go003no`B0083oood0o_l0P?co003m
o`20o?l00?go083lo`20oOl00?co082Yo`8L0?jho`10nP00P?go0<3lo`30oOl0
`?co0<3mo`20o?l0`?go083mo`30o?l0P?go0<3lo`20oOl0`?co0<3mo`20o?l0
`?go2h3oP83oP<3o`8200?go083mo`600?go083mo`60`?go083mo`60`?ko0L20
oOl1P<3no`70P?go083mo`70P?goo@02`830oOl0P?go0H30o_l1`83mo`60`?ko
0L20oOl0P?go0/20P:Wo0?Fho`10nP00P?go0<3lo`30oOl0`?co0<3mo`20o?l0
`?go083mo`30o?l0P?go0<3lo`20oOl0`?co0<3mo`20o?l0`?go2h3oP83oP<3o
`8200?go083mo`600?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go
083mo`70P?goo@02`830oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0/20
P:Wo0>Jho`10nP00P?go0<3lo`30oOl0`?co0<3mo`20o?l0`?go083mo`30o?l0
P?go0<3lo`20oOl0`?co0<3mo`20o?l0`?go2h3oP83oP<3o`8200?go083mo`60
0?go083mo`60`?go083mo`60`?ko0L20oOl1P<3no`70P?go083mo`70P?goo@02
`830oOl0P?go0H30o_l1`83mo`60`?ko0L20oOl0P?go0/20P:Wo0CP0o[Son02Y
o`80P03no`>0oh00o_l00?go0X3o0?ko003mo`20o?l00?go083lo`20oOl0P?co
083mo`00o?l0P?go0@3oo@3lo`00oOl0P?co083mo`20o?l0P?go003lo`:0oh2Y
o`3e^?oh0:Wo0P200?ko0h3oP03no`00oOl2P?l0o_l00?go083lo`00oOl0P?co
083mo`20o?l0P?go003lo`20oOl10?om0?co003mo`20o?l0P?go083lo`20oOl0
0?co0X3oP:Wo0>JhooP0ZOl20800o_l3P?n00?ko003mo`:0o`3no`00oOl0P?co
003mo`20o?l0P?go083lo`20oOl00?co083mo`40ood0o?l00?go083lo`20oOl0
P?co083mo`00o?l2P?n0ZOl1L@3n^_l0`?/00on0002Yo``0@?ooP830P?l0oon0
oOl6P<20P?ooP?go0H30o_l1`83mo`60`?ko0L20oOl1P<3no`70P?go083mo`60
P?go1X3ooh00043mP010o800@?f0003lP010oX05@000P800o804@8200<2Yo`3e
^_l0`?/00on0002Yo``0@?ooP830P?l0oon0oOl6P<20P?ooP?go0H30o_l1`83m
o`60`?ko0L20oOl1P<3no`70P?go083mo`60P?go1X3ooh00043mP010o800@?f0
003lP010oX05@000P800o804@8200<2Yo`3V^_l0`?/00on0002Yo``0@?ooP830
P?l0oon0oOl6P<20P?ooP?go0H30o_l1`83mo`60`?ko0L20oOl1P<3no`70P?go
083mo`60P?go1X3ooh00043mP010o800@?f0003lP010oX05@000P800o804@820
0<2Yo`750?jjo`B0003oP?h01Ol0083oP?go003lo`20oOl00?go083lo`00oOl0
P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?go2`3o003ooh3o
o`3o0?go1X3oo`3oo`3mo`20o?l0P?go083lo`20f`01o`3mo`20o?l0P?go083l
o`20oOl00?co002Wo`3e^_l4P000oh3n00Go0020oh3mo`00o?l0P?go003mo`20
o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083mo`/0
o`00oon0ool0o`3mo`J0ool0ool0oOl0P?co083mo`20o?l0P=/00Ol0oOl0P?co
083mo`20o?l0P?go003lo`00Yol0i[[o18000?n0oP05o`00P?n0oOl00?co083m
o`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003m
o`20oOl;0?l00?ooP?oo0?l0oOl6P?oo0?oo0?go083lo`20oOl0P?co083K007o
0?go083lo`20oOl0P?co083mo`00o?l00:Oo0ET0o[[o2`20`?n0083ool00P:_o
0/00@?j0003nP040@?b0kP3lP010oH000?b0043mP3d0P830ol3ooh3ooh3ool3o
`?ooP?oo`?o0ooo0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?o0oon0oon0`:Oo
0?Fjo`/0P<3oP020ooo0082[o`;0043nP000oX01043lP>h0o800@?f0003lP010
oH0m0820`?o0oon0oon0ooo0ol3ooh3ool3o`?oo`?ooP?oo`?o0oon0oon0ooo0
ol3ooh3ool3o`?ooP?ooP<2Wo`3V^_l;0830oh00P?oo`020Zol2`010oX000?j0
0@10o83^0?b0043mP000o800@?f0?@20P<3o`?ooP?ooP?oo`?o0oon0ooo0ol3o
ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ol3ooh3ooh30Yol1;03n]_l2P020
oOl00:_o083g0020o?l5P?oo0?n0o?l0P?go003lo`20oOl00?go083lo`00oOl0
P?co083mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co0@20YOl0mKKo
0X00P?go002[o`20m`00P?co1H3oo`3oP?co083mo`00o?l0P?go003mo`20o?l0
0?go083lo`20oOl0P?co083mo`00o?l0P?go003lo`20oOl00?go083lo`40P:Go
0>Jfo`:0083mo`00Zol0P?L0083lo`F0ool0oh3lo`20oOl00?co083mo`00oOl0
P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00o?l0P?go003mo`20o?l1
082Uo`7h0?jfo`:0083no`40P?ko083lo`20oOl0P?co083mo`00o?l0P?go003m
o`20o?l00?go083lo`00oOl0P?co083mo`00o?l0P?go0@00o_l00?go0H00oOl0
P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl0
0?co083mo`00oOl0P?co003mo`20o?l3P?ooP:Go0?Ffo`:0083no`40P?ko083l
o`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`00oOl0P?co083m
o`00o?l0P?go0@00o_l00?go0H00oOl0P?go003lo`20oOl00?co083mo`00oOl0
P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l3
P?ooP:Go0>Jfo`:0083no`40P?ko083lo`20oOl0P?co083mo`00o?l0P?go003m
o`20o?l00?go083lo`00oOl0P?co083mo`00o?l0P?go0@00o_l00?go0H00oOl0
P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl0
0?co083mo`00oOl0P?co003mo`20o?l3P?ooP:Go0ID0o[Ko0X00P?go0<2]ogF0
0420`?oo`?o0oh20ooo0ol3ooh3oP83ool3o`?ooP?oo`?o0ooo0oon0ooo0ol3o
oh3ooh3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3ool3o`?ooP?oo`?o0
oon0oon0ooo0ol3ooh3ool3o`820Y?l0mKKo0X00P?go0<2]ogF00420`?oo`?o0
oh20ooo0ol3ooh3oP83ool3o`?ooP?oo`?o0ooo0oon0ooo0ol3ooh3ooh3ool3o
`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3ool3o`?ooP?oo`?o0oon0oon0ooo0
ol3ooh3ool3o`820Y?l0i[Ko0X00P?go0<2]ogF00420`?oo`?o0oh20ooo0ol3o
oh3oP83ool3o`?ooP?oo`?o0ooo0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?o0
oon0oon0ooo0ol3ooh3ool3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3o
`820Y?l1:@3n]_l20020ZOol0?co1H3oP?oo0?go083lo`00oOl0P?co083mo`20
o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co1@3oo`00P?co083mo`20o?l0
P?go0`3ooh2Ro`3e]_l20020ZOol0?co1H3oP?oo0?go083lo`00oOl0P?co083m
o`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co1@3oo`00P?co083mo`20
o?l0P?go0`3ooh2Ro`3V]_l20020ZOol0?co1H3oP?oo0?go083lo`00oOl0P?co
083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co1@3oo`00P?co083m
o`20o?l0P?go0`3ooh2Ro`8m0?jfo`<00<20o?l0`?go083lo`30oOl0P?go0<3l
o`20oOl0`?co0<3mo`30o?l0`?go083lo`30oOl0P?go0<3lo`B0ooo0P?d01H3o
oh3o`?ko5d3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0
ooo0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3nooh0143o`?o0o_l7`?n0
ooo0ol3no`K0ol3o`830X_l0mKKo0`00`83lo`30oOl0P?co0<3mo`20oOl0`?co
083mo`30o?l0`?go0<3lo`30oOl0P?co0<3mo`20oOl0`?co183ool20o@05P?oo
P?o0o_lG@?o0oon0oh3ool3ool3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0ol3o
ol3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh3ool3o`?kooP04@?o0ol3no`O0oh3o
ol3o`?ko1/3o`?o0P<2Ro`3V]_l30030P?co0<3mo`20o?l0`?go083mo`30o?l0
P?go0<3lo`30oOl0`?co0<3mo`20o?l0`?go083mo`30o?l4P?oo`83m00F0oon0
ol3noaM0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo
`?o0o_l7`?o0oon0oh3no`c0ol3ooh3oP?oo`?o0o_on00A0ol3o`?ko1l3oP?oo
`?o0o_l6`?o0ol20`:;o0C80o[Ko0@00[Ol0P?X00X3oP?co0@20o_l0P?co083m
o`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go0H3o
oP01oh3mo`00o?l0P?go003mo`20X?l0mKKo0@00[Ol0P?X00X3oP?co0@20o_l0
P?co083mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0
P?go0H3ooP01oh3mo`00o?l0P?go003mo`20X?l0i[Ko0@00[Ol0P?X00X3oP?co
0@20o_l0P?co083mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003m
o`20o?l0P?go0H3ooP01oh3mo`00o?l0P?go003mo`20X?l2=`3ndOl0`?Z0k_l1
003mo`20oOl0`?co0<3mo`30o?l0`?go083lo`30oOl0P?go0<3lo`20oOl0`?co
083mo`30o?l0`?gooX3h0030o_l7P?n0oon0ol3no`O0ol3ooh3o`?ko1l3o`?oo
P?n0o_l<`?o0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3o
oh3oP?ko083n01C0P?n0ooo0ooo0oon0oh3ool3oP82Oo`3edOl0`?Z0k_l1003m
o`20oOl0`?co0<3mo`30o?l0`?go083lo`30oOl0P?go0<3lo`20oOl0`?co083m
o`30o?l0`?gooX3h0030o_l7P?n0oon0ol3no`O0ol3ooh3o`?ko1l3o`?ooP?n0
o_l<`?o0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3o
P?ko083n01C0P?n0ooo0ooo0oon0oh3ool3oP82Oo`3VdOl0`?Z0k_l1003mo`20
oOl0`?co0<3mo`30o?l0`?go083lo`30oOl0P?go0<3lo`20oOl0`?co083mo`30
o?l0`?gooX3h0030o_l7P?n0oon0ol3no`O0ol3ooh3o`?ko1l3o`?ooP?n0o_l<
`?o0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko
083n01C0P?n0ooo0ooo0oon0oh3ool3oP82Oo`510?kJo`20lP3]o`400;;o083f
0?ko083mo`:0oh3no`20oOl00?co083mo`00oOl0P?co003mo`20o?l00?go083l
o`20oOl00?co083mo`00o?l0P?kooP3no`20o?l00?go083no`20W_l0mM[o083b
0>go0@00/_l0P?H0o_l0P?go0X3oP?ko083mo`00o?l0P?go003mo`20o?l00?go
083lo`00oOl0P?co083mo`00o?l0P?go003lo`20o_on0?ko083lo`00oOl0P?ko
082No`3Vf_l0P?80kOl1002bo`20mP3no`20oOl2P?n0o_l0P?go003lo`20oOl0
0?go083lo`00oOl0P?co003mo`20o?l0P?go003lo`20oOl00?co083nooh0o_l0
P?co003mo`20o_l0P9ko0LD0o_3o1>k4R?oonh01[_Ogo`20m@00P>go0X000:oo
0X20@?`00d20oh3no`c0ol3oP83oP?oo`?o0o_l7P?n0ooo0ol3no`O0ol3ool3o
`?ko1l3o`?ooP?n0o_l<`?o0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?n0ooo0
oh3n00O0ol3ooh3o`?ko1L3o`?o0P9go0?G`o`C^a8Sooo^00Jkgmol0P?D0083]
o`:0002_o`:0P43l00=0P?n0o_l<`?o0oh20oh3ool3o`?ko1h3oP?oo`?o0o_l7
`?o0ooo0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko
1l3oP?oo`?n0oP07`?o0oon0ol3no`G0ol3o`82Mo`3Vl?l4k/B8oookP06^moOo
083e0020kOl2P000[ol2P810o003@83oP?ko3<3o`?n0P?n0ooo0ol3no`N0oh3o
ol3o`?ko1l3o`?oo`?o0o_l7`?o0oon0oh3no`c0ol3ooh3oP?oo`?o0o_l7P?n0
ooo0ol3no`O0oh3ool3oP?h01l3o`?ooP?o0o_l5`?o0ol20WOl26@3nl?on00;o
omgn00C^8@0QmoOo083g0>_ooP01o`3lo`20oOl00?co083mo`00oOl0P?co003m
o`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?ko0@3onP00P?go003lo`00
oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00
oOl0P?co003mo`400?go083mo`20o?l0P9co0?G`ooh00_oogOh01>hQ027gmol0
P?L0joon007o0?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co
083mo`00o?l0P?go003mo`20o_l10?oj0020oOl00?co003mo`00oOl0P?co003m
o`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go0@00
oOl0P?go083lo`20W?l0i_3ooP02oooMoP04kR408OOgo`20m`3[ooh00Ol0o?l0
P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl0
0?go083no`40ooX0083mo`00o?l00?go003mo`20o?l00?go083lo`00oOl0P?co
083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl1003mo`20oOl0P?co082L
o`7G0?k_o`5l0?kooP04ol`00:;fo`60@?P00H20k_l1002ao`>0P?o0oP00P?h0
K?oo`?o0ooo0oon0P?o0ol3ooh3ood3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3o
oh3ool3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3o`?oo`?ooP?oo@?o0
oon0oon0ooo0ol3oP82Ko`3ekol1O03nooh01?o<002Rm_l1P43h0060P>ko0@00
/Ol3P83o`?h0083n06cool3o`?oo`?ooP83o`?o0oon0oom0ooo0ol3ooh3ool3o
`?ooP?ooP?oo`?o0oon0ooo0ooo0ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0
ol3ool3ooh3ood3o`?ooP?ooP?oo`?o0oh20Vol0i^oo0G`0o_on00Coc000X_Ko
0H10n001P83^o`400;7o0h20ol3n0020oP1/ooo0ol3ool3ooh20ol3o`?ooP?oo
@?oo`?o0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?oo`?o0oon0ooo0ol3ooh3o
oh3ool3o`?ooP?oo`?o0ooo0oon0oom0ol3ooh3ooh3ool3o`?n0P9_o0G40o^oo
0H00o_on00Coo`00P?Com03`o`400;;o003nooh00ooo003no`20o?l50?ooP?n0
o?l5P?n0oon0o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0
P?go003lo`20oOl00?co083mo`00VOl0mNoo0H00o_on00Coo`00P?Com03`o`40
0;;o003nooh00ooo003no`20o?l50?ooP?n0o?l5P?n0oon0o?l0P?go003lo`20
oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?co083mo`00
VOl0i^oo0H00o_on00Coo`00P?Com03`o`400;;o003nooh00ooo003no`20o?l5
0?ooP?n0o?l5P?n0oon0o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083m
o`20o?l0P?go003lo`20oOl00?co083mo`00VOl2R`3nl_l4iXf8L`3nooh01?og
0028lol0P?d00d3oP83l0060P?Co0@00o?l0P?go0<3lo`30oOl0`?co0<3mo`20
o?l0`?go083mo`30o?l0P?go0<3lo`20oOl0`?co1<20P?ooo@06`83o003o`?ko
1l3oP?oo`?m0o_l4`?o0ooonP?ko5l3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko
1h3oP?oo`?o0o_l7`?o0oon0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3n
o`>0oh20V?l0mO;o1>J=R7<0o_on00Com`00R??o083m00=0oh20o001P83do`40
0?co083mo`30o?l0`?go0<3lo`30oOl0P?co0<3mo`20oOl0`?co083mo`30o?l0
P?go0<3lo`C0P83oood01/20o`00ol3no`O0oh3ool3o@?ko1<3o`?oooX3noaO0
ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?ooP?o0o_l7
`?o0oon0oh3no`c0ol3ooh3oP?oo`?o0o_l3P?n0P9So0>Kbo`CVSHQc0?kooP04
ooL008Sco`20o@03@?n0P?`00H20m?l1003lo`20oOl0`?co0<3mo`30o?l0`?go
083lo`30oOl0P?go0<3lo`20oOl0`?co083mo`30o?l4`820ooom00K0P?l00?o0
o_l7`?n0ooo0od3no`C0ol3oooj0o_lG`?o0oon0oh3ool3ool3ooh3oP?oo`?o0
o_l7P?n0ooo0ol3no`O0ol3ooh3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh3ool3o
`?ko0h3oP82Ho`6B0?kco`G<0<?M6@3nooh01?nY002klOom0?conP3fo`400;Go
083no`20oP3no`F0083oo`3lo`20o_l1P03mo`20o_l2P?l0oOl0P?co083mo`20
o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003mo`00
Uol0mO?o1L`0`mdI0?kooP04ojT00;_aood0o?oj0?Ko0@00]Ol0P?ko083n0?ko
1H00P?oo0?co083no`600?go083no`:0o`3mo`20o?l0P?go083lo`20oOl00?co
083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?go002Go`3Vlol5c033
gAT0o_on00CoZ@00^o7oo@3looX0m_l1002eo`20o_l0P?h0o_l5P020ool0o?l0
P?ko0H00oOl0P?ko0X3o0?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20
o?l00?go083lo`20oOl0P?co083mo`00oOl009Oo0Yd0o_Co1^H8R?ooM`3nooh0
17<A6XSkl?l0@?h0nol1P83l0090P<3lo`F0003ooh3lo`30oOl0P?co0<3mo`20
oOl0`?co083mo`30o?l0`?go0<3lo`30oOl0P?co0<3mo`J0`830ol20oP0=P?o0
ool0`?o0oon0oh3no`c0oh3ooh3oP?oo`?m0o_l7P?n0ooo0ol3no`O0oh3ool3o
`?ko1l3o`?ooP?o0o_lG`?o0oon0oh3ool3ool3ooh3oP?oo`?o0o_l7P?n0ooo0
ol3no`O0ol3oP<3oP9Ko0?Gdo`KV28SoogL0o_on00Ac4AZ8no3o043n0?_o0H20
o002@830o?l5P000oon0o?l0`?go083lo`30oOl0P?go0<3lo`20oOl0`?co0<3m
o`30o?l0`?go083lo`30oOl6P<20`?o0P?h03H3o`?oo0<3o`?ooP?n0o_l<`?n0
oon0oh3ool3o@?ko1h3oP?oo`?o0o_l7`?n0ooo0ol3no`O0ol3ooh3o`?ko5l3o
`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0oh30oh2Fo`3V
m?l6iPR8oomg0?kooP04La4JR?_`o`10oP3ko`60P?`00T20`?co1H000?ooP?co
0<3mo`20o?l0`?go083mo`30o?l0P?go0<3lo`30oOl0`?co0<3mo`20o?l0`?go
1X30P<3o`83n00f0ol3oo`30ol3ooh3oP?ko3<3oP?ooP?n0ooo0od3no`N0oh3o
ol3o`?ko1l3oP?oo`?o0o_l7`?o0oon0ol3noaO0ol3ooh3oP?oo`?oo`?ooP?n0
ooo0ol3no`N0oh3ool3o`?ko1l3o`?n0`?n0U_l1S`3nm?l1V@3no`600?kooP3Y
o`400?OonP00P?ko0X00P;Oo083no`20o@3mo`600?go083mo`20o_l2P?n0oOl6
0?ooP?ooP?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003m
o`20o?l00?go083mo`<00800UOl0mOCo0IT0o_l1P03nooh0jOl1003gooX0083n
o`:0082go`20o_l0P?d0oOl1P03mo`20oOl0P?ko0X3oP?go1P3ooh3ooh3mo`00
oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20
oOl3002009Go0>Kdo`6I0?ko0H00o_on0>Wo0@00mooj0020o_l2P020]ol0P?ko
083m0?go0H00oOl0P?go083no`:0oh3mo`H0oon0oon0oOl00?go083lo`00oOl0
P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?go0`00P02Eo`7G
0?kdo`J00?Oooh00o_on0>Wo0/00P?Ko0H20o004@810082io`60P?ko0h00043m
o`30oOl0P?go0<3lo`F0P?o0ol3no`O00<3ool3o`?ko1l3o`?ooP?n0o_lG`?o0
oon0oh3ool3ool3ooh3oP?oo`?o0o_l7`?n0ooo0ol3no`O0ol3ooh3o`?ko2<3o
`?ooP?n0`?h0082Eo`3em?l6P03goon00?kooP3Yo`;0083fo`60P?`01420@020
^Ol1P83no`>00010oOl0`?go083mo`30o?l5P83o`?o0o_l7`030ooo0ol3no`O0
ol3ooh3oP?ko5l3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko1l3oP?oo`?o0o_l7
`?o0oon0ol3no`S0ol3ooh3oP<3n0020UOl0i_Co1X00moooP03nooh0jOl2`020
m_l1P83l00A0P400P;Wo0H20o_l3P000@?go0<3mo`20oOl0`?co1H20ol3o`?ko
1l00`?oo`?o0o_l7`?o0oon0oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3n
o`O0oh3ool3o`?ko1l3o`?ooP?o0o_l8`?o0oon0oh30oP00P9Go0N00o_Co1Y00
V?ooP03nooh0eooh0020o_l00?go083lo`20oOl0P?co083mo`00o?l0P?go003m
o`20o?l00?go083lo`00oOl1P03mo`20oP3no`00kol00?co1H3oo`3o0?co083m
o`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003m
o`20o@00P9Ko0?Gdo`J@09Sooh00o_on0=Oon000P?ko003mo`20o?l0P?go083l
o`20oOl00?co083mo`00oOl0P?co003mo`20o?l00?go0H00oOl0P?h0o_l00>oo
003lo`F0ool0o`3lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083l
o`20oOl00?co083mo`00oOl0P?d0082Fo`3Vm?l6T02Hoon00?kooP3GooP0083n
o`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co003m
o`600?go083n0?ko003_o`00o?l5P?oo0?l0o?l0P?go003lo`20oOl00?go083l
o`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083m0020U_l1C@3nm?l9
``0boon00?Ooooh0eOog0;oo003looh0oOl00?7o0X3oP?ko083mo`00o?l0P?go
003mo`20o?l00?go083lo`00oOl0P?co083mo`00o?l0P?go003lo`20oOl00?go
183oP?oooP2Fo`3em?l9``0boon00?Ooooh0eOog0;oo003looh0oOl00?7o0X3o
P?ko083mo`00o?l0P?go003mo`20o?l00?go083lo`00oOl0P?co083mo`00o?l0
P?go003lo`20oOl00?go183oP?oooP2Fo`3Vm?l9``0boon00?Ooooh0eOog0;oo
003looh0oOl00?7o0X3oP?ko083mo`00o?l0P?go003mo`20o?l00?go083lo`00
oOl0P?co083mo`00o?l0P?go003lo`20oOl00?go183oP?oooP2Fo`6l0?kco`R8
:e6IDB]Nofon001_e?l3P000@?/00H20aOl1`83mo`30oP00`?go003`o`T0oh3o
P?oo`?o0o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko1l3o`?ooP?n0o_l<`?o0oon0
oh3ool3o`?ko1h3oP?oo`?o0o_l7`?n0ooo0ol3no`O0ol20`?oo`?h00<2Ho`3e
lol8R2]AVE4[G_m_oP00KmCo0h00043k0060P<Go0L20oOl0`?h00<3mo`00l?l9
0?n0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko3<3o
`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3oP?oo`?o0o_l7`?o0P<3ool3n0030
V?l0i_?o28P[DIUA:ekoKoh006oDo`>00010n`01P835o`70P?go0<3n0030oOl0
0?3o2@3oP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0oon0oh3n
o`c0ol3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0oh3ool3o`?ko1l3o`830ooo0
oP00`9So0L/0o[So1000P?oonP3mo`00o?l0P?go003mo`20o?l00?go083lo`20
oOl0P?co083mo`00oOl1083looh01_nI00Qgo`3mo`Fj:P00A<cjo`40P?go003m
o`20o?l00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083l
o`00oOl0P?ko083kooh0V?l0mKSo1000P?oonP3mo`00o?l0P?go003mo`20o?l0
0?go083lo`20oOl0P?co083mo`00oOl1083looh01_nI00Qgo`3mo`Fj:P00A<cj
o`40P?go003mo`20o?l00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20
oOl00?go083lo`00oOl0P?ko083kooh0V?l0i[So1000P?oonP3mo`00o?l0P?go
003mo`20o?l00?go083lo`20oOl0P?co083mo`00oOl1083looh01_nI00Qgo`3m
o`Fj:P00A<cjo`40P?go003mo`20o?l00?go083lo`00oOl0P?co083mo`20o?l0
P?go003lo`20oOl00?go083lo`00oOl0P?ko083kooh0V?l1[@3n^?l1003lo`C0
P400`<So083lo`30oP07`7L=IWPR:`3no`20o0012J;koeH0ooo0ol3ooh3ool3o
ol3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3ool3o`?ooP?oo`?o0oon0oon0
ooo0ol3ooh3ool3o`?oo`?ooP?oo`?o0P<3ko`30oP00`9[o0?Fho`400?co1<20
@030b?l0P?co0<3n00O0M`eVN28[0?ko083l0049X__oEP3ool3o`?ooP?oo`?oo
`?o0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?oo`?o0oon0ooo0ol3ooh3ooh3o
ol3o`?ooP?oo`?o0ooo0oon0ooo0ol20`?_o0<3n0030V_l0i[So0@00o?l4`810
0<38o`20o?l0`?h01l1g3FIh8R/0o_l0P?`00@VRnomF0?oo`?o0oon0ooo0ooo0
ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ooo0ol3ooh3ool3o`?ooP?ooP?oo
`?o0oon0ooo0ol3ool3ooh3ool3o`830nol0`?h00<2Jo`5I0?jho`400?3o0H00
dol1003kooh00oo<07ono`4b0?ko1aT0Moo^Q`00nol30?ooP?co083mo`20o?l0
P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20o_l0
P?OooP2Jo`3e^?l1003`o`600=?o0@00noon00?oc01oo_l1<P3no`LI07OokXL0
0?_o0`3ooh3lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20
oOl0P?co083mo`00o?l0P?ko083gooh0V_l0i[So0@00l?l1P03Co`400?_ooP03
ol`0Ooko0C80o_l76@1gonj7003ko`<0oon0o?l0P?go083lo`20oOl00?co083m
o`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083no`20moon09[o0Rh0
o[So0P00`?co083mo`30oOl0P?d00H10o?l0`?go083lo`30oOl0P?go0<3lo`20
oOl0`?ko0X3oP?go083n00C0oiD0gOko0L`0o_l7P83ggLb8003lo`;00<3no`O0
ol3ooh3oP?ko5l3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7
`?o0oon0ol3no`O0ol3ooh3oP?ko2<3o`?ooP<00`?Oo0<3n0030W?l0mKSo0P00
`?co083mo`30oOl0P?d00H10o?l0`?go083lo`30oOl0P?go0<3lo`20oOl0`?ko
0X3oP?go083n00C0oiD0gOko0L`0o_l7P83ggLb8003lo`;00<3no`O0ol3ooh3o
P?ko5l3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0oon0
ol3no`O0ol3ooh3oP?ko2<3o`?ooP<00`?Oo0<3n0030W?l0i[So0P00`?co083m
o`30oOl0P?d00H10o?l0`?go083lo`30oOl0P?go0<3lo`20oOl0`?ko0X3oP?go
083n00C0oiD0gOko0L`0o_l7P83ggLb8003lo`;00<3no`O0ol3ooh3oP?ko5l3o
`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0oon0ol3no`O0
ol3ooh3oP?ko2<3o`?ooP<00`?Oo0<3n0030W?l1A`3n^?l1003`ooT0g?l1P03j
ooh0o_l1P03lo`00o_l2mgL8o03ko`80o`3mo`20o?l00?go083lo`20oOl0P?co
083mo`00o?l0P?go003mo`20o?l00?go083lo`20oOl0P?ko083cooh0W?l0mKSo
0@00l?oi0=co0H00n_on0?ko0H00o?l00?ko0_Mg2?`0nol20?l0oOl0P?co003m
o`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083n
o`20loon09co0>Jho`400?3on@3Lo`600?[ooP3no`600?co003no`;gM`Sl0?_o
0P3o0?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00
oOl0P?co083mo`20o_l0P??ooP2Lo`8I0?jiooh0o_l0P?co0<3mo`20oOl1P43l
0?go0<3lo`20oOl0`?co0<3mo`30o?l5`?ooP<20o?l0P?h00<3no`:00?Ono`7^
0?ko1dT0FXRRc000nol;0<3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0oh3ool3o
`?ko1l3o`?ooP?o0o_lG`?o0oon0oh3ool3ool3ooh3oP?oo`?o0o_l6P?n0oon0
P?;o0<3n0030W_l0mKWooP3no`20o?l0`?go083mo`60@?`0oOl0`?co083mo`30
o?l0`?go0<3lo`G0oon0`83lo`20oP00`?ko0X00moko0Nh0o_l7B@1JR:;<003k
o`/0`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3oP?oo`?o0o_l7`?o0oon0ol3n
oaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3no`J0oh3ooh20l_l0`?h00<2No`3V
^Oon0?ko083lo`30oOl0P?go0H10o03mo`30o?l0P?go0<3lo`30oOl0`?co1L3o
oh30P?co083n0030o_l2P03go_l1kP3no`M905Z8X/`00?_o2`30oon0oh3ool3o
`?ko1h3oP?oo`?o0o_l7`?n0ooo0ol3no`O0ol3ooh3o`?ko5l3o`?ooP?n0ooo0
ooo0oon0oh3ool3o`?ko1X3oP?ooP83bo`30oP00`9ko0E00o[Wo0@00jOl1083N
o`00n_ol0?go0YT0c?ko0IP0o_l1003no`:Y003ko`<0oon0oOl00?co083mo`00
oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co0@20koon
09ko0?Fio`400>Wo0@20g_l00?[oo03mo`:I0<cno`6H0?ko0@00o_l2Z@00nol3
0?ooP?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20
oOl00?go083lo`40P>oooP2No`3V^Ol1003Yo`40P=ko003joo`0oOl2V@3<o_l1
V03no`400?ko0ZT00?_o0`3ooh3mo`00o?l0P?go003mo`20o?l00?go083lo`20
oOl0P?co083mo`00o?l0P?go003mo`20o?l1083_ooh0W_l1Y03n^Ol1003Oo`60
`>[o0H20n_l0@?h00<3lo`OM25[^mj8A0?ko10T0FX1FoP3lo`K0P?oo`?o0o_l7
@?o0ooo0ol3no`O0ol3ooh3oP?ko5l3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko
1l3oP?oo`?o0o_l:`?o0oon0ol3o`83^o`30oP00`:3o0?Fio`400=oo0H30j_l1
P83jo`10oP00`?co1md8F^kgXQ40o_l42@1JP5Kn0?co1/20ooo0ol3no`M0ol3o
ol3o`?ko1l3o`?ooP?n0o_lG`?o0oon0oh3ool3ool3ooh3oP?oo`?o0o_l7`?n0
ooo0ol3no`[0ol3ooh3o`?o0P>ko0<3n0030X?l0i[Wo0@00gol1P<3Zo`60P?[o
043n0030o?l7g@QJk_NR4@3no`@905Z0E_h0o?l6`83ool3o`?ko1d3o`?oo`?o0
o_l7`?o0oon0oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3no`O0oh3ool3o
`?ko2/3o`?ooP?o0ol20k_l0`?h00<2Po`7;0?jio`<00?n0o?l00?go083lo`20
oOl0P?co083no`20o@02P?n0oOl00?go083lo`D0o`3ooh3looh00X3oP?_o0<cm
006H0?ko06Km00>Y003MoOl2P?n0o?l5P?n0ool0o?l0P?go003lo`20oOl00?go
083lo`00oOl0P?co083mo`20o?l0P?go003lo`20joon0:3o0?Fio`<00?n0o?l0
0?go083lo`20oOl0P?co083no`20o@02P?n0oOl00?go083lo`D0o`3ooh3looh0
0X3oP?_o0<cm006H0?ko06Km00>Y003MoOl2P?n0o?l5P?n0ool0o?l0P?go003l
o`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20joon0:3o0>Ji
o`<00?n0o?l00?go083lo`20oOl0P?co083no`20o@02P?n0oOl00?go083lo`D0
o`3ooh3looh00X3oP?_o0<cm006H0?ko06Km00>Y003MoOl2P?n0o?l5P?n0ool0
o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20
joon0:3o0LP0o[Wo0@00h?l0@?T0083lo`V0P?ooP83ooh20n_l0`?h00h30ol3j
o`G8P8SDoh3no`ScXX20c?n8P<3modj0oon0ooo0ol3oP83ooh3ool3o`?ooP?oo
`?o0ooo0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3o
ol3ooh20j_l0`?h00<2Ro`3e^Ol1003Po`10n@00P?co2H20oon0P?ooP83jo`30
oP03P<3o`?[o1LR0R=CoP?ko2?>RP83<ohR0`?goCX3ooh3ool3o`?n0P?ooP?oo
`?o0oon0ooo0ol3ool3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ol3ooh3ooh3o
ol3o`?ooP?oo`?ooP83Zo`30oP00`:;o0>Jio`400>3o043i0020o?l9P83ooh20
oon0P?[o0<3n00>0`?o0n_l5b828e?n0o_l8lj:0P<coR830oOm>P?ooP?oo`?o0
oh20oon0ooo0ol3ooh3ool3o`?oo`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3o
`?ooP?ooP?oo`?o0oon0ooo0oon0P>[o0<3n0030X_l1:@3n^_l2P000gOok0020
o?l20020oP01oh3hooh00H00hOl0P?go003mo`00o?l00?go083lo`20oOl0P?co
083mo`00o?l0P?go003mo`20o?l00?go083lo`40P>OooP2Ro`3e^_l2P000gOok
0020o?l20020oP01oh3hooh00H00hOl0P?go003mo`00o?l00?go083lo`20oOl0
P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`40P>OooP2Ro`3V^_l2P000
gOok0020o?l20020oP01oh3hooh00H00hOl0P?go003mo`00o?l00?go083lo`20
oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083lo`40P>OooP2Ro`840?jj
o`:0043mo`20o?l0`?go083lo`30oOl0P?go0<3lo`F0oon0P<3lo`10o001P<3n
o`30o_l0`?h01X30oon0oh3UoaV0ol3o`?ooP?n0P?o0ooo0oon0oh3ool3o`?ko
1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko3L3o`?ooP?n0ooo0ol20
iOl0`?h0083Qo`;ge9klo`GAVH20Y^kBo`3e^_l2P010oOl0P?co0<3mo`20o?l0
`?go083mo`30o?l5P?ooP830o?l0@?`00H30o_l0`?ko0<3n00J0`?ooP?n0iOlI
P?o0ol3ooh3oP83o`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0
o_l7`?o0oon0oh3no`g0ol3ooh3oP?oo`?o0P>Go0<3n0020hOl2mmBNo?l5dIV0
P:K^d_l0i[[o0X00@?go083lo`30oOl0P?co0<3mo`20oOl0`?co1H3ooh20`?co
043l0060`?ko0<3no`30oP06P<3ooh3oP>Go6H3o`?o0oon0oh20ol3ool3ooh3o
P?oo`?o0o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko1l3o`?ooP?n0o_l=`?o0oon0
oh3ool3o`83Uo`30oP00P>7o0_ODW_co1M6IP82Vk];o0E00o[[o0X00P=3oo@00
P?SooP3mo`20h_l1P03mo`20o_l2P?n0oOl0P?co083mo`00o?l0P?go003lo`20
oOl00?go083lo`00oOl0P?co0X3oP>;ooP00P?[o083Zo`:0003mo`N707O^gC<0
Mm?o0?Fjo`:0083@ood0083hooh0oOl0P>;o0H00oOl0P?ko0X3oP?go083lo`20
oOl00?co083mo`00o?l0P?go003mo`20o?l00?go083lo`:0oh3Rooh0083jo`20
j_l2P000oOl7Q`1gk]dc07OCo`3V^_l2P020d?om0020n?on0?go083Ro`600?go
083no`:0oh3mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20
o?l2P?n0h_on0020n_l0P>[o0X000?go1hL0MnkM<`1gdol1C@3n^_l2P020d?om
0?SooP03P?ooP>3o083no`20oOl1083mo`20o?l0P?go003lo`20oOl00?go083l
o`00oOl0P?co083mo`20o?l3P?oo0>7o083n0?[o003Yo`7^0?ko0ZX0A?ko0k/0
0:[Do`3e^_l2P020d?om0?SooP03P?ooP>3o083no`20oOl1083mo`20o?l0P?go
003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l3P?oo0>7o083n0?[o003Y
o`7^0?ko0ZX0A?ko0k/00:[Do`3V^_l2P020d?om0?SooP03P?ooP>3o083no`20
oOl1083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l3
P?oo0>7o083n0?[o003Yo`7^0?ko0ZX0A?ko0k/00:[Do`9K0?jjo`B0083o`?co
083mo`30o?l0`?go0<3lo`30oOl0P?co0<3mo`>0oom0o@03@?ooP?go043n007o
P?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3oP?ooP?o0o_l7`?o00?n0
oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo
P?o0o_l6`?o0oon0P=oo083n0030oOl1P03Xo`H0ooog8P2VoOl3A00Nk]Go0?Fj
o`B0083o`?co083mo`30o?l0`?go0<3lo`30oOl0P?co0<3mo`>0oom0o@03@?oo
P?go043n007oP?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3oP?ooP?o0
o_l7`?o00?n0oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o
`?ko1l3o`?ooP?o0o_l6`?o0oon0P=oo083n0030oOl1P03Xo`H0ooog8P2VoOl3
A00Nk]Go0>Jjo`B0083o`?co083mo`30o?l0`?go0<3lo`30oOl0P?co0<3mo`>0
oom0o@03@?ooP?go043n007oP?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko
1l3oP?ooP?o0o_l7`?o00?n0oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3n
o`N0oh3ool3o`?ko1l3o`?ooP?o0o_l6`?o0oon0P=oo083n0030oOl1P03Xo`H0
ooog8P2VoOl3A00Nk]Go0I80o[[o0X00P=7o0P00P?h0noon0020o_l00?go083l
o`20oOl00?co083mo`00o?l5P?n0ool0oOl1P03mo`00oOl0P?co083mo`20o?l0
P?go003lo`20oOl00?go083lo`00oOl3P?oo0=cooP3mooh0jOl60?ooQ`00gOgo
0kX008OEo`3e^_l2P020dOl20020oP3kooh0083no`00oOl0P?co083mo`00o?l0
P?go003lo`F0oh3oo`3mo`600?go003mo`20o?l0P?go083lo`20oOl00?co083m
o`00oOl0P?co003mo`>0ool0g?on0?gooP3Yo`H0oon7003MoOl3^P00QmGo0>Jj
o`:0083Ao`80083n0?_ooP00P?ko003mo`20o?l0P?go003lo`20oOl00?co1H3o
P?oo0?go0H00oOl00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l0
0?go0h3oo`3Looh0oOon0>Wo1P3oohL00=gmo`>j0027eOl2GP3n^_l20020oOl0
P?co0<3mo`20o?l0`?go083mo`30o?l0P?go0<3lo`D00?oo003lo`I00020`?o0
o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko1l3o`?ooP?n0o_l<P?o0oon0oh3ool3o
`?ko1h3oP?oo`?o0o_l7`?n0ooo0ol3no`O0ol3ooh3o`?ko5L3o`?ooP?n0ooo0
ooo0oon0oh3oP83Ko`30oP02`?oooP3^o`_cIUelO`3ooaT00?_mo`?g000IeOl0
mK[o0P00P?go083lo`30oOl0P?co0<3mo`20oOl0`?co083mo`30o?l5003oo`00
o?l6@000P<3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko383o
`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3oP?oo`?o0o_l7`?o0oon0ol3noaG0
ol3ooh3oP?oo`?oo`?ooP?n0oh20fol0`?h00/3oooh0k_l;lfIMO7l0oolI003k
oOl3m`006MGo0>Jjo`80083mo`20o?l0`?go083lo`30oOl0P?go0<3lo`20oOl0
`?co1@00ool00?co1T000830ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0
oon0oh3no`b0ol3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0oh3ool3o`?ko1l3o
`?ooP?o0o_lE`?o0oon0oh3ool3ool3ooh3oP?n0P=_o0<3n00;0ooon0>ko2o=V
GGao0?oo6@00nogo0oL001WEo`5j0?jjo`400<KooP01P03lo`20oOl00?go083l
o`00oOl0P?co083mo`:0oh3no`20oOl00?co083mo`00oOl0P?co003mo`20o?l0
P?go083lo`20oOl00?co083no`20eoon007oooh0083_o`N8EOoog@3oooh0noon
0=Go0?Fjo`400<KooP01P03lo`20oOl00?go083lo`00oOl0P?co083mo`:0oh3n
o`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083n
o`20eoon007oooh0083_o`N8EOoog@3oooh0noon0=Go0>Jjo`400<KooP01P03l
o`20oOl00?go083lo`00oOl0P?co083mo`:0oh3no`20oOl00?co083mo`00oOl0
P?co003mo`20o?l0P?go083lo`20oOl00?co083no`20eoon007oooh0083_o`N8
EOoog@3oooh0noon0=Go0Md0o[[o0@00aol=@000P?oo`?o0ooo0ol3no`O0ol3o
oh3oP?ko3<3o`?ooP?n0ooo0ol3nooj01?oo`?o0o_l7`?o0ooo0ol3no`O0ol3o
oh3oP?ko5l3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko2L3oP?oo`?o0P<3Go`30
oP00@?h0043_o`4cgOko1P3ooa400?_mo`?g000AeOl0mK[o0@00aol=@000P?oo
`?o0ooo0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3nooj01?oo`?o0o_l7
`?o0ooo0ol3no`O0ol3ooh3oP?ko5l3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko
2L3oP?oo`?o0P<3Go`30oP00@?h0043_o`4cgOko1P3ooa400?_mo`?g000AeOl0
i[[o0@00aol=@000P?oo`?o0ooo0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0
ol3nooj01?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko5l3o`?ooP?n0ooo0
ooo0oon0oh3ool3o`?ko2L3oP?oo`?o0P<3Go`30oP00@?h0043_o`4cgOko1P3o
oa400?_mo`?g000AeOl1n03n^_l4003ooh3lo`00oOl0P?co083mo`20o?l0P?go
003lo`20oOl00?go083looh00X3oP?go003lo`20oOl00?go083lo`00oOl0P?co
1@3ooh3oP?co083mo`00o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083m
o`20o_l0P=?onP3mo`20n@3lo`00oOl60?ooE@00gOgo0kX005GEo`3e^_l4003o
oh3lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083looh00X3oP?go
003lo`20oOl00?go083lo`00oOl0P?co1@3ooh3oP?co083mo`00o?l0P?go003l
o`20oOl00?go083lo`00oOl0P?co083mo`20o_l0P=?onP3mo`20n@3lo`00oOl6
0?ooE@00gOgo0kX005GEo`3V^_l4003ooh3lo`00oOl0P?co083mo`20o?l0P?go
003lo`20oOl00?go083looh00X3oP?go003lo`20oOl00?go083lo`00oOl0P?co
1@3ooh3oP?co083mo`00o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083m
o`20o_l0P=?onP3mo`20n@3lo`00oOl60?ooE@00gOgo0kX005GEo`7J0?jjo`40
0<WoLD000830ol3ooh3ooh3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3o
ol3o@?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3o`?oo`?ooP?oo`?o0oon0oon0
ooo0ol3ooh3ool3o`?ooP?ooP?n0`=Go0X20@?/0083`o`49`oko1P3oomdA0:[m
o`=D00gMeOl0mK[o0@00bOma@000P<3o`?ooP?ooP?oo`?o0oon0ooo0ol3ooh3o
oh3ool3o`?ooP?oo`?oo`?m0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?o0ooo0
oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?o0oon0oon0oh30eOl2P810n`00P?3o
0@W3o_l60?oogA40Z_go0e@03MgEo`3V^_l10039og500020`?o0oon0oon0ooo0
ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ooo0od3ooh3ool3o`?ooP?ooP?oo
`?o0oon0ooo0ol3ool3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ol3ooh3ooh3o
P<3Eo`:0P43k0020l?l12L?no`H0oooM4@2ZoOl3E00=gMGo0F/0o[_ooP3:ooh0
0H00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003m
o`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?go083Foo@0l?l1A3;no`H0
k_ooR014o_l3``00R=Co0?Fkooh0b_on00600?go083lo`00oOl0P?co083mo`20
o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20
oOl00?go083mo`20e_od0?3o0D@bo_l60>koohP0A?ko0l<008SDo`3V^oon0<[o
oP01P03mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l0
0?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20oOl0P=Kom03`o`54<_ko
1P3^oon804Cno`?30028e?l2B@3n^ol30020`?go083lo`30oOl0P?co0<3mo`20
oOl0`?co083mo`30o?l0`?go6D000830oon0oh3ool3ool3ooh3oP?oo`?o0o_l7
`?n0ooo0ol3nob;0ol3ooh3o`?n0ol3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko
1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko0/20`=Go0H20m`00P?7o
4/@[:hRI6Tbgoo^I:SahKbM<T?_Do`3e^ol30020`?go083lo`30oOl0P?co0<3m
o`20oOl0`?co083mo`30o?l0`?go6D000830oon0oh3ool3ool3ooh3oP?oo`?o0
o_l7`?n0ooo0ol3nob;0ol3ooh3o`?n0ol3o`?ooP?n0ooo0ooo0oon0oh3ool3o
`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko0/20`=Go0H20m`00
P?7o4/@[:hRI6Tbgoo^I:SahKbM<T?_Do`3V^ol30020`?go083lo`30oOl0P?co
0<3mo`20oOl0`?co083mo`30o?l0`?go6D000830oon0oh3ool3ool3ooh3oP?oo
`?o0o_l7`?n0ooo0ol3nob;0ol3ooh3o`?n0ol3o`?ooP?n0ooo0ooo0oon0oh3o
ol3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko0/20`=Go0H20
m`00P?7o4/@[:hRI6Tbgoo^I:SahKbM<T?_Do`5:0?jko`400<_ooP00P?ko083l
o`20oOl0P?co083mo`00o?l0P?go003mo`20oOl1P03mo`20o?l0P?go083lo`20
oOl00?co083mo`00o?l0P?go003mo`20o?l1003?ooT0083Uo`=E001<dOl0mK_o
0@00boon0020o_l0P?co083mo`20o?l0P?go003lo`20oOl00?go083mo`600?go
083lo`20oOl0P?co083mo`00o?l0P?go003lo`20oOl00?go083lo`400<oon@00
P>Go0eD004cAo`3V^ol1003;ooh0083no`20o?l0P?go083lo`20oOl00?co083m
o`00oOl0P?go0H00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?co083mo`00
oOl0P?co0@00cooi0020iOl3E@00C=7o0QT0o[_o0@00o_l0`?co083mo`30o?l0
`?go0<3lo`30oOl0P?co0<3mo`20oOl0`?h00h30ol3no`O0ol3ooh3o`?ko5l3o
`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko1h3o0<3o`?o0o_l7@?o0oon0ol3no`O0
ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1<3o`820cOl1P83k
0>Co1Y4l3B9EP83Eo`3e^ol1003no`30o?l0P?go0<3lo`30oOl0`?co0<3mo`20
o?l0`?go083mo`30oP03P<3o`?ko1l3o`?ooP?o0o_lG`?o0oon0oh3ool3ool3o
oh3oP?oo`?o0o_l7P?l0`?o0ol3no`M0ol3ooh3o`?ko1l3o`?ooP?n0o_l<`?o0
oon0oh3ool3o`?ko1h3oP?oo`?o0o_l4`?o0P83=o`60P?/0i?l6TC`=8UF0P=Go
0>Jko`400?ko0<3lo`20oOl0`?co0<3mo`30o?l0`?go083lo`30oOl0P?go0<3n
00>0`?o0o_l7`?o0oon0ol3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3no`N0
o`30ol3o`?ko1d3o`?ooP?o0o_l7`?o0oon0oh3no`c0ol3ooh3oP?oo`?o0o_l7
P?n0ooo0ol3no`C0ol20P<go0H20n`3To`JA?0dREH20eOl1;`3n^ol1003=ood0
o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083no`40P?co1H3oP?oo0?co
083mo`00oOl0P?co003mo`20o?l00?go083lo`20o_l0P<So083m0;7o0?Fko`40
0<goo@3lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?ko0@20o?l5P?n0
ool0o?l0P?go003mo`20o?l00?go083lo`00oOl0P?co083no`20b?l0P?d0/Ol0
i[_o0@00cOom0?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20o_l1083l
o`F0oh3oo`3lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?ko0838o`20
o@2ao`6B0?jlo`;0003?o`10oP0;P<3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0
ol3ooh3o`?ko1l3o`?ooP?n0o_l<`030oon0oh3ooh3o`?ko1h3oP?oo`?o0o_l7
`?o0ooo0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0P<36o`?0P400/_l0mKco
0/000<oo043n00^0`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?ooP?o0o_l7
`?o0oon0oh3no`c00<3ooh3oP?ooP?o0o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko
1l3o`?ooP?n0o_l<`?o0oon0oh3ool20`<Ko0l20@02bo`3V_?l2`000col0@?h0
2h30oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0oon0ol3no`O0ol3ooh3oP?ko
3<00`?ooP?n0oon0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0oon0oh3n
o`c0ol3ooh3oP?oo`830a_l3`8100;;o0I80o[co18000?n0oOl00?co083mo`00
o?l0P?go003mo`20o?l00?go083mood0oOl0P?go003mo`20o?l00?go083lo`20
oOl0P?co083mo`H0ool0oon0oOl1083no`20o?l00?go083lo`00oOl0P?co083m
o`20o?l0P?go0@20POoao`3e_?l4P000oh3mo`00o?l0P?go003lo`20oOl00?go
083lo`00oOl0P?goo@3mo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go
1P3oo`3ooh3mo`40P?ko083lo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl1
0821oo7o0>Jlo`B0003oP?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20
oOom0?go083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl60?oo0?ooP?go
0@20o_l0P?co003mo`20o?l00?go083lo`20oOl0P?co083mo`40P87olOl1P`3n
_?l2P020dOma@000P?n0oon0ooo0ol3ooh3ool3ool3o`?ooP?oo`?o0oon0oon0
ooo0ol3ooh3ool3o`820`030P<3o`?o0oh20ooo0ooo0ol3ooh3ool3o`?ooP?oo
P?oo`?o0oon0ooo0ooo0ol3ooh3ool3o`830POoao`3e_?l2P020dOma@000P?n0
oon0ooo0ol3ooh3ool3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3o`820
`030P<3o`?o0oh20ooo0ooo0ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ooo0
ol3ooh3ool3o`830POoao`3V_?l2P020dOma@000P?n0oon0ooo0ol3ooh3ool3o
ol3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3o`820`030P<3o`?o0oh20ooo0
ooo0ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ooo0ol3ooh3ool3o`830POoa
o`4k0?jlo`:0083Booh0083no`00oOl0P?co083mo`20o?l0P?go003lo`20oOl0
0?go1H3oP000P?h00X3oP?ko0X3oP?go083lo`20oOl00?co083mo`00oOl0P?co
003mo`:0oh21onoo0?Flo`:0083Booh0083no`00oOl0P?co083mo`20o?l0P?go
003lo`20oOl00?go1H3oP000P?h00X3oP?ko0X3oP?go083lo`20oOl00?co083m
o`00oOl0P?co003mo`:0oh21onoo0>Jlo`:0083Booh0083no`00oOl0P?co083m
o`20o?l0P?go003lo`20oOl00?go1H3oP000P?h00X3oP?ko0X3oP?go083lo`20
oOl00?co083mo`00oOl0P?co003mo`:0oh21onoo0H`0o[co0X00P?ko083lo`00
oOl0P?co083mo`20o?l0P?go003lo`20o_l0P?h00_ooP?go083lo`20oOl00?co
083mo`00oOl0P?co003mo`20o_l0P?X0o?l0P?go003lo`20oOl00?co083mo`00
oOl0P?co003mo`B0ool0P87okol0mKco0X00P?ko083lo`00oOl0P?co083mo`20
o?l0P?go003lo`20o_l0P?h00_ooP?go083lo`20oOl00?co083mo`00oOl0P?co
003mo`20o_l0P?X0o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`B0
ool0P87okol0i[co0X00P?ko083lo`00oOl0P?co083mo`20o?l0P?go003lo`20
o_l0P?h00_ooP?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o_l0P?X0
o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`B0ool0P87okol1O@3n
_?l2P020e?lgP000@?o0ol3ool3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ol3o
oh3ooh3ool3o`?ooP?oo`83m03B0oh3ool3o@?ooP?ooP?oo`?o0oon0ooo0ol3o
ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0P87okOl0mKco0X00P=Co=h00043o`?o0
ooo0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool20
o@0dP?n0ooo0od3ooh3ooh3ool3o`?ooP?oo`?o0ooo0oon0ooo0ol3ooh3ooh3o
ol3o`?ooP821ongo0>Jlo`:0083DocN00010ol3o`?oo`?ooP?oo`?o0oon0oon0
ooo0ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0P?d0=83oP?oo`?m0oon0oon0
ooo0ol3ooh3ool3o`?oo`?ooP?oo`?o0oon0oon0ooo0ol3ooh20POo]o`4/0?jl
o`80083Eo`20oP01o`3lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go
0P3oood0oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`>0ool0POo/
o`3e_?l20020eOl0P?h00Ol0o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co
083mo`80ooom0?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l3P?oo
087ok?l0i[co0P00P=Go083n007o0?co083mo`00oOl0P?co003mo`20o?l0P?go
083lo`20oOl20?ooo@3mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co
0h3oo`21onco0M40o[co1000`?o0oOl0P?co0<3mo`20o?l0`?go083mo`30o?l0
P?ko2X00043o`?ooP?n0o_lG`?o0oon0oh3ool3ool3ooh3oP?oo`?o0o_l7`?n0
ooo0ol3no`C0ol3o`?/05h3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko1h3oP?oo
`?o0o_l7`?o0ooo0ol3no`10POo[o`3e_?l40030ol3mo`20o?l0`?go083lo`30
oOl0P?go0<3lo`20o_l:P000@?o0oon0oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0
ooo0ol3no`O0oh3ool3o`?ko1<3o`?o0n`0GP?o0oon0oh3ool3ool3ooh3oP?oo
`?o0o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko0421on_o0>Jlo`@00<3o`?go083l
o`30oOl0P?co0<3mo`20oOl0`?co083no`Z00010ol3ooh3oP?ko5l3o`?ooP?n0
ooo0ooo0oon0oh3ool3o`?ko1l3oP?oo`?o0o_l4`?o0ol3k01N0ol3ooh3oP?oo
`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l0@87ojol1;03n
_?l1003Fo`20oP3mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003m
o`N00020o`00P?ko083lo`20oOl0P?co083mo`00o?l0P?go003lo`20oOl0087o
j_l0mKco0@00e_l0P?h0oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083m
o`00oOl7P000P?l0083no`20o?l0P?go083lo`20oOl00?co083mo`00o?l0P?go
0021on[o0>Jlo`400=Ko083n0?go083lo`00oOl0P?co083mo`20o?l0P?go003l
o`20oOl00?go1h00083o0020o_l0P?co083mo`20o?l0P?go003lo`20oOl00?co
083mo`00POoZo`7A0?jlo`400?go0<3lo`20oOl0`?co0<3mo`30o?l0`?go083m
o`N00010ol3o`?ko1l3oP?oo`?o0o_l7`?o0oon0ol3noa_0ol3ooh3oP?oo`?oo
`?ooP?n0ooo0ol3oP000oX03043o`?ko1l3o`?ooP?o0o_l7`?o0oon0oh3no`c0
ol3ooh3oP?oo`?o0o_l3P?n0P87ojOl0mKco0@00oOl0`?co083mo`30o?l0`?go
0<3lo`30oOl0P?go1h00043o`?o0o_l7`?n0ooo0ol3no`O0ol3ooh3o`?ko6l3o
`?ooP?n0ooo0ooo0oon0oh3ool3o`?n0003nP0<0@?o0o_l7`?o0oon0ol3no`O0
ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3no`>0oh20POoYo`3V_?l1003mo`30o?l0
P?go0<3lo`30oOl0`?co0<3mo`20oOl7P000@?o0ol3no`O0oh3ool3o`?ko1l3o
`?ooP?o0o_lK`?o0oon0oh3ool3ool3ooh3oP?oo`?o0oh000?j00`10ol3no`O0
ol3ooh3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh3ool3o`?ko0h3oP821onWo0BT0
o[co0@00f?l0P?h0083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go
083looh00X3oP?co083mo`00o?l0P?go003mo`20o?l00?go083lo`00o_l0087o
j?l0mKco0@00f?l0P?h0083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l0
0?go083looh00X3oP?co083mo`00o?l0P?go003mo`20o?l00?go083lo`00o_l0
087oj?l0i[co0@00f?l0P?h0083lo`20oOl0P?co083mo`00o?l0P?go003mo`20
o?l00?go083looh00X3oP?co083mo`00o?l0P?go003mo`20o?l00?go083lo`00
o_l0087oj?l1P03n_Ol2P000fOlJP000@?o0oon0oh3ool3ool3ooh3oP?oo`?o0
o_l7P?n0ooo0ol3no`O0ol3ooh3o`?ko5l3o`?ooP?n0P000`?o0oon0oh3ool3o
`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`_0ol3ooh3oP?ooP821onOo0?Fmo`:0
003IoaZ00010ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o
`?ooP?o0o_lG`?o0oon0oh200030ol3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0
ol3ool3o`?ko2l3o`?ooP?n0oon0P87oiol0i[go0X000=Wo6X00043o`?ooP?n0
ooo0ooo0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0oon0ol3noaO0ol3ooh3o
P8000<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l;`?o0oon0
oh3ooh20POoWo`5^0?jmooh00_ooP?go003lo`20oOl00?co083mo`00oOl0P?go
o@3mo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20o_on0?go
083mo`00oOl0P?co003mo`20o?l00?go083lo`20oOl0P87oiOl0mKgooP02oon0
oOl00?co083mo`00o?l0P?go003mo`20oOom0?go083mo`00o?l0P?go003mo`20
o?l00?go083lo`20oOl0P?co083nooh0oOl0P?go003mo`20o?l00?go083lo`00
oOl0P?co083mo`20POoUo`3V_Oon00;ooh3mo`00o?l0P?go003lo`20oOl00?go
083mood0oOl0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?ko
oP3mo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go0821onGo0Gd0o[go
0@00f_m`@000@?o0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?oo`?o0oon0ooo0
ol3ooh3ooh3ool3o`?ooP?oo`?l00830oon0ooo0ol3ooh3ool3ool3o`?ooP?oo
`?o0oon0oon0ooo0ol3ooh3ool3oP<21onGo0?Fmo`400=[oL400043o`?ooP?oo
`?o0oon0oon0ooo0ol3ooh3ool3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3o
ol3o0020`?ooP?oo`?o0oon0ooo0ooo0ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0
ooo0oh30POoUo`3V_Ol1003Jog100010ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0
ooo0ooo0ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0o`00P<3ooh3ool3o`?oo
P?oo`?oo`?o0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?n0`87oiOl1;03n_Ol1
003Kood0o_l00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go
1X3o003oo`3mo`:0oh3no`20oOl0P?co083mo`00o?l0P?go003mo`60087ohol0
mKgo0@00foom0?ko003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go
003mo`J0o`00ool0oOl2P?n0o_l0P?go083lo`20oOl00?co083mo`00oOl1P021
on?o0>Jmo`400=_oo@3no`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co
083mo`00oOl6P?l00?oo0?go0X3oP?ko083mo`20o?l0P?go003lo`20oOl00?go
0H00POoSo`750?jmo`80083mo`30o?l0P?go0<3lo`30oOl0`?co0<3no`]00020
P?n0ooo0ol3no`O0ol3ool3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh3ool3o`?ko
2H3oP?oo`?o0ooon00F0ooo0ol3no`N0ol3ooh3oP?ko6L3o`?ooP?n0ooo0ooo0
oon0oh3ool3o`?n0POoRo`3e_Ol20020oOl0`?co083mo`30o?l0`?go0<3lo`30
o_l;@000P83oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0
ooo0ol3no`V0oh3ool3o`?oooP05P?oo`?o0o_l7P?o0oon0oh3noaW0ol3ooh3o
P?oo`?oo`?ooP?n0ooo0ol3oP87oh_l0i[go0P00P?go0<3lo`20oOl0`?co0<3m
o`30o?l0`?ko2d000820oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0oon0oh3no`c0
ol3ooh3oP?oo`?o0o_l9P?n0ooo0ol3oooh01H3ool3o`?ko1h3o`?ooP?n0o_lI
`?o0oon0oh3ool3ool3ooh3oP?oo`?o0oh21on;o0B`0o[go0@00gOon0020oOl0
P?go003mo`20o?l00?go083lo`00oOl0P?co083mo`00o?l0P?go1P3o003ooh3m
o`D0oon0oh3lo`00oOl0P?co083mo`20o?l0P?go0021on7o0?Fmo`400=gooP00
P?go083mo`00oOl0P?co003mo`20o?l00?go083lo`20oOl00?co083mo`H0o`00
oon0oOl50?ooP?n0o?l00?go083lo`20oOl0P?co083mo`00POoQo`3V_Ol1003M
ooh0083mo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go003lo`20oOl6
0?l00?ooP?go1@3ooh3oP?co003mo`20o?l0P?go083lo`20oOl0087ohOl1a@3n
__l2P000o_l0`?go083lo`30oOl0P?co0<3mo`20oOl7@000P?n0ol3no`O0ol3o
oh3oP?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0
ool0083no`C0ol3oooj01?oo`?o0o_l7P?n0ooo0ol3no`O0oh3ool3o`?ko0/20
P87oh?l0mKko0X000?ko0<3mo`20o?l0`?go083lo`30oOl0P?go1d00083oP?o0
o_l7`?o0oon0oh3no`c0ol3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0ol3ool3o
`?ko1l3o`?oo0020o_l4`?o0ooonP0Cool3o`?ko1h3oP?oo`?o0o_l7`?n0ooo0
ol3no`;0P821on3o0>Jno`:0003no`30oOl0P?co0<3mo`20o?l0`?go083mo`M0
0020oh3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7
`?o0ooo0ol3no`O0ol3oo`00P?ko1<3o`?oooX04ooo0ol3no`N0oh3ool3o`?ko
1l3oP?oo`?o0o_l2`820POoPo`4Y0?jno`:0083Oooh00X3oP?go083lo`20oOl0
0?co083mo`00o?l0P?go003mo`20o?l00?go083looh00_ooP?co0H00o_l00?co
083mo`00oOl0P?co003mo`:0oh21omko0?Fno`:0083Oooh00X3oP?go083lo`20
oOl00?co083mo`00o?l0P?go003mo`20o?l00?go083looh00_ooP?co0H00o_l0
0?co083mo`00oOl0P?co003mo`:0oh21omko0>Jno`:0083Oooh00X3oP?go083l
o`20oOl00?co083mo`00o?l0P?go003mo`20o?l00?go083looh00_ooP?co0H00
o_l00?co083mo`00oOl0P?co003mo`:0oh21omko0H00o[ko0X00P>7o083n0120
ooo0ooo0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3o
P?ko3<3o`?ooP?n0oon0043no`N0oh3ool00`?ko1l3o`?oo`?o0o_l7`?o0oon0
oh3no`K0ol3ooh30POoNo`3e__l2P020hOl0P?h0483ool3ool3ooh3oP?oo`?o0
o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh3ooh00
@?ko1h3oP?oo`030o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko1/3o`?ooP<21omko
0>Jno`:0083Qo`20oP0@P?oo`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o
`?oo`?o0o_l7`?o0oon0oh3no`c0ol3ooh3oP?ooP010o_l7P?n0ooo00<3no`O0
ol3ool3o`?ko1l3o`?ooP?n0o_l6`?o0oon0`87og_l1M03n__l3P0200?go083l
o`00oOl0P?co083mo`20o_l0P?h00X3oP?co003mo`20o?l0P?go083lo`20oOl0
0?co083mo`00oOl0P?co003mo`J0oh00P?l0oOl6P?oo0?ooP?go003lo`20oOl0
0?co083mo`40P87og?l0mKko0h00P03mo`20o?l00?go083lo`20oOl0P?ko083n
00:0oh3lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl6
P?n0083o0?go1X3oo`3ooh3mo`00o?l0P?go003lo`20oOl10821omco0>Jno`>0
0800oOl0P?co003mo`20o?l0P?go083no`20oP02P?n0o?l00?go083lo`20oOl0
P?co083mo`00o?l0P?go003mo`20o?l00?go1X3oP020o`3mo`J0ool0oon0oOl0
0?co083mo`00o?l0P?go0@20POoLo`4b0?jno`:0083Rooh00On0o?l00?go083l
o`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083no`80083mo`20o_l2
P?n0oOl00?co083mo`00oOl0P?co0`3ooh21omco0?Fno`:0083Rooh00On0o?l0
0?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083no`80083m
o`20o_l2P?n0oOl00?co083mo`00oOl0P?co0`3ooh21omco0>Jno`:0083Rooh0
0On0o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083n
o`80083mo`20o_l2P?n0oOl00?co083mo`00oOl0P?co0`3ooh21omco0H00o[ko
0T00P>Co0<3n00O0ol3ooh3oP?ko5l3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko
1h3oP?oo`?o0o_l7`?o0oon0ol3no`o0ol3ooh000<3ool3o`?oooX04ooo0ol3n
o`N0oh3ool3o`?ko2/3o`?oo`?o0ol20POoKo`3e__l2@020i?l0`?h01l3o`?oo
P?n0o_lG`?o0oon0oh3ool3ool3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0ol3o
oh3o`?ko3l3o`?ooP000`?oo`?o0ooonP0Cool3o`?ko1h3oP?oo`?o0o_l:`?o0
ooo0ol3o`821om_o0>Jno`90083To`30oP07`?o0oon0oh3noaO0ol3ooh3oP?oo
`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?ooP?o0o_l?`?o0oon00030
ooo0ol3oooj01?oo`?o0o_l7P?n0ooo0ol3no`[0ol3ool3o`?o0P87ofol1G`3n
__l20020o_l0P?go003lo`20oOl00?co083nooh0o?l0P?go083lo`20oOl00?co
083mo`00oOl0P?co003mo`20o?l0P?go083lo`F0o`00o`3lo`20oOl00?go083l
o`00oOl0P?co003mo`20POoJo`3e__l20020o_l0P?go003lo`20oOl00?co083n
ooh0o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083l
o`F0o`00o`3lo`20oOl00?go083lo`00oOl0P?co003mo`20POoJo`3V__l20020
o_l0P?go003lo`20oOl00?co083nooh0o?l0P?go083lo`20oOl00?co083mo`00
oOl0P?co003mo`20o?l0P?go083lo`F0o`00o`3lo`20oOl00?go083lo`00oOl0
P?co003mo`20POoJo`5j0?jno`400>Go0<3n04:0ol3ooh3ool3ool3o`?ooP?oo
`?o0oon0oon0ooo0ol3ooh3ool3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3o
oP0S`?oo`?ooP?oo`?o0oon0ooo0ooo0ol3ooh3ool3o`?ooP?oooX21omWo0?Fn
o`400>Go0<3n04:0ol3ooh3ool3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3o
ol3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ooP0S`?oo`?ooP?oo`?o0oon0
ooo0ooo0ol3ooh3ool3o`?ooP?oooX21omWo0>Jno`400>Go0<3n04:0ol3ooh3o
ol3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3ool3o`?ooP?oo`?o0oon0
oon0ooo0ol3ooh3ooP0S`?oo`?ooP?oo`?o0oon0ooo0ooo0ol3ooh3ool3o`?oo
P?oooX21omWo0B00o[ko0@00iOon0?go003mo`20o?l00?go083lo`00oOl0P?co
083mo`20o?l0P?go003lo`20oOl00?ko0@00o?l00?go083lo`20oOl0P?co083m
o`00oOl0087oeol0mKko0@00iOon0?go003mo`20o?l00?go083lo`00oOl0P?co
083mo`20o?l0P?go003lo`20oOl00?ko0@00o?l00?go083lo`20oOl0P?co083m
o`00oOl0087oeol0i[ko0@00iOon0?go003mo`20o?l00?go083lo`00oOl0P?co
083mo`20o?l0P?go003lo`20oOl00?ko0@00o?l00?go083lo`20oOl0P?co083m
o`00oOl0087oeol1[@3n__l3003oP?go0<3lo`20oOl0`?co0l3ool3n00S0P?n0
ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0oon0oh3no`c0ol3ooh3o
P?oo`?o0o_lBP?n0ooo0oh000?o0oh3ool3o`?ko1l3o`?ooP?n0o_l=`?o0oon0
oh3ool3ood21omKo0?Fno`<00?n0oOl0`?co083mo`30o?l3`?oo`?h02<20oh3o
ol3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0
ooo0ol3noa:0oh3ool3oP000ol3oP?oo`?o0o_l7`?o0oon0oh3no`g0ol3ooh3o
P?oo`?oo@87oe_l0i[ko0`00oh3mo`30o?l0P?go0<3lo`?0ooo0oP08`83oP?oo
`?o0o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh3o
ol3o`?ko4X3oP?oo`?n0003o`?n0ooo0ol3no`O0ol3ooh3oP?ko3L3o`?ooP?n0
ooo0oom0POoFo`4S0?jno`400>OooP3lo`20oOl00?co083mo`00oOl0P?co003m
o`20o?l00?go083lo`20oOl00?co083no`:0003mo`20oOl00?go083lo`00oOl0
P?co083no`00POoEo`3e__l1003Wooh0o?l0P?go003lo`20oOl00?go083lo`00
oOl0P?co003mo`20o?l0P?go003lo`20o_l2P000oOl0P?go003mo`20o?l00?go
083lo`20o_l0087oeOl0i[ko0@00ioon0?co083mo`00o?l0P?go003mo`20o?l0
0?go083lo`00oOl0P?co083mo`00o?l0P?ko0X000?go083mo`00oOl0P?co003m
o`20o?l0P?ko0021omGo0JL0o[oooP3mo`30oOl0P?co0<3mo`20o_l0P?h01<3o
`?o0o_l7`?o0oon0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3no`N0oh3o
ol3o`?ko1l3o`?oo`?o0o_l7`?m00820oh3no`c0ol3ooh3oP?oo`?o0o_l7P?n0
ooo0ol3no`60P87oe?l0mKoooP3mo`30oOl0P?co0<3mo`20o_l0P?h01<3o`?o0
o_l7`?o0oon0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o
`?ko1l3o`?oo`?o0o_l7`?m00820oh3no`c0ol3ooh3oP?oo`?o0o_l7P?n0ooo0
ol3no`60P87oe?l0i[oooP3mo`30oOl0P?co0<3mo`20o_l0P?h01<3o`?o0o_l7
`?o0oon0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko
1l3o`?oo`?o0o_l7`?m00820oh3no`c0ol3ooh3oP?oo`?o0o_l7P?n0ooo0ol3n
o`60P87oe?l1;`3n_ol1003Yo`20oP02ool0oOl0P?co083mo`20o?l0P?go003l
o`20oOl00?co083mo`00oOl0P?co003mo`20o_l20020oOl0P?co083mo`00o?l0
P?go003mo`:0oh21om?o0?Foo`400>Wo083n00;oo`3mo`20o?l0P?go083lo`20
oOl00?co083mo`00o?l0P?go003mo`20o?l00?go083no`80083mo`20o?l0P?go
003lo`20oOl00?go0X3oP87odol0i[oo0@00jOl0P?h00_oo0?go083lo`20oOl0
P?co083mo`00o?l0P?go003lo`20oOl00?go083lo`00oOl0P?ko0P00P?go083l
o`20oOl00?co083mo`00oOl2P?n0POoCo`5j0?joo`400>[o083n0020o_lG`?o0
oon0oh3ool3ool3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko1l3o
`?ooP?n0o_l<`?o0oon0oh00083o`?ko1h3oP?ooP?o0o_l7`?o0ooo0ol3no`G0
ol3oP821om;o0?Foo`400>[o083n0020o_lG`?o0oon0oh3ool3ool3ooh3oP?oo
`?o0o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh00
083o`?ko1h3oP?ooP?o0o_l7`?o0ooo0ol3no`G0ol3oP821om;o0>Joo`400>[o
083n0020o_lG`?o0oon0oh3ool3ool3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0
ol3ool3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh00083o`?ko1h3oP?ooP?o0o_l7
`?o0ooo0ol3no`G0ol3oP821om;o0ET0o[oo1000ool0oOl0P?co003mo`20o_l0
P?h0o_l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003m
o`20o?l00?go0@00oOl00?go0X3oP?ko083mo`00o?l0P?go0021om3o0?Foo`@0
0?oo0?go083lo`00oOl0P?ko083n0?ko083mo`00oOl0P?co003mo`20o?l0P?go
083lo`20oOl00?co083mo`00oOl0P?co003mo`400?go003mo`:0oh3no`20oOl0
0?co083mo`00POo@o`3V_ol4003oo`3mo`20o?l00?go083no`20oP3no`20oOl0
0?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl1
003mo`00oOl2P?n0o_l0P?go003lo`20oOl0087od?l1M`3n_ol1003/odb00010
ooo0ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ol3ool3ooh3ool3o`?ooP?oo
P?oo`?o0oon0ooo0ol3ooh3ooh3ool3o`?h07_oo`?oo`?o0oon0P?o0ol3ooh3o
oh3ool3o`?ooP821oloo0?Foo`400>coC800043ool3o`?ooP?oo`?o0oon0oon0
ooo0ol3ooh3ool3o`?oo`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3o`?ooP?oo
P?oo`?o0oP0Nooo0ooo0ol3ooh20ol3o`?ooP?ooP?oo`?o0oon0P87ocol0i[oo
0@00k?m<P000@?oo`?o0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?o0ooo0oon0
ooo0ol3ooh3ooh3ool3o`?ooP?oo`?o0oon0oon0ooo0ol3n01kool3ool3o`?oo
P83o`?o0oon0oon0ooo0ol3ooh20POo?o`4_0?k0o`:0003]o`20oP02ool0oOl0
P?co083mo`00o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l5
P000ool0o?l0P?ko0H00oOl0P?co003mo`60087oc_l0mL3o0X000>go083n00;o
o`3mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go
083lo`F0003oo`3lo`20o_l1P03mo`20o?l00?go0H00POo>o`3V`?l2P000kOl0
P?h00_oo0?go083lo`20oOl00?co083mo`00o?l0P?go003mo`20o?l00?go083l
o`20oOl0P?co1H000?oo0?co083no`600?go083lo`00oOl1P021olko0I/0o/3o
0X00@?co0<3mo`20o?l8`?ooP000@?o0o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko
1l3o`?ooP?n0o_lG`?o0oon0oh3ool3ool3ooh3oP?oo`?o0o_lB`?n0ooo0ol3o
`000ol3ooh3o`?ko4l20P?ooP?n0ooo0ooo0oon0oh20POo=o`3e`?l2P010o?l0
`?go083lo`S0oon00010ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0oon0
oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3noa;0oh3ool3o`?o0003o`?oo
P?o0o_lC`820oon0oh3ool3ool3ooh3oP821olgo0>K0o`:0043lo`30oOl0P?co
2<3ooh00043o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko5l3o
`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko4/3oP?oo`?o0ol000?o0oon0ol3noa?0
P83ooh3oP?oo`?oo`?ooP?n0P87ocOl1<P3n`?l2P020kol0P?h0083mo`20o?l0
P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003lo`20o_l2
P000o_l0P?co1@3o0?ooP?co083mo`>0ool0POo<o`3e`?l2P020kol0P?h0083m
o`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go003l
o`20o_l2P000o_l0P?co1@3o0?ooP?co083mo`>0ool0POo<o`3V`?l2P020kol0
P?h0083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0
P?go003lo`20o_l2P000o_l0P?co1@3o0?ooP?co083mo`>0ool0POo<o`4V0?k0
o`:0083_ooh0oOl00?co083mo`00oOl0P?co003mo`20o?l00?go083lo`20oOl0
P?co083mo`00o?l0P?go1@20083oP?co003no`40P?co083mo`20o_l0P87obol0
mL3o0X00P>oooP3mo`00o?l0P?go003mo`20o?l00?go083lo`00oOl0P?co083m
o`20o?l0P?go003lo`20oOl50800P?n0o?l00?ko0@20o?l0P?go083no`20POo;
o`3V`?l2P020koon0?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0
P?go083lo`20oOl00?co083mo`D0P020oh3lo`00o_l1083lo`20oOl0P?ko0821
ol_o0I/0o/3o1H00P?ooP?go0<3lo`>0ooo0oP03`83oP?ko3<3o`?ooP?n0ooo0
ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0oon0oh3no`c0ol3ooh3oP?oo
`?o0o_l7P?n0oom0043noa;0oh3ool3o`03ool3o`?ooP?n0o_l2P830POo;o`3e
`?l5P020oon0oOl0`?co0h3ool3n00?0P?n0o_l<`?o0oon0oh3ool3o`?ko1h3o
P?oo`?o0o_l7`?o0ooo0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3no`N0
oh3ood00@?ko4/3oP?oo`?o00?oo`?o0oon0oh3no`:0P<21ol_o0>K0o`F0083o
oh3mo`30o?l3P?oo`?h00l20oh3no`c0ol3ooh3oP?oo`?o0o_l7P?n0ooo0ol3n
o`O0ol3ool3o`?ko1l3o`?ooP?n0o_l<`?o0oon0oh3ool3o`?ko1h3oP?oo@010
o_lB`?n0ooo0ol00ooo0ol3ooh3oP?ko0X20`87obol1803n`?l2P020lOon0?co
083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go
003lo`F0o`00P03lo`20oOl00?go083lo`<0oon0POo9o`3e`?l2P020lOon0?co
083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go
003lo`F0o`00P03lo`20oOl00?go083lo`<0oon0POo9o`3V`?l2P020lOon0?co
083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co003mo`20o?l0P?go
003lo`F0o`00P03lo`20oOl00?go083lo`<0oon0POo9o`6B0?k0o`80043lo`30
oOl0P?ko043n00C0ol3o`?ko1h3oP?oo`?o0o_l7`?o0oon0ol3no`O0ol3ooh3o
P?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l70030oon0
oh3noa30ol20oh3oP?oo`?o0ooo0P87ob?l0mL3o0P00@?co0<3mo`20o_l0@?h0
1<3o`?o0o_l7P?n0ooo0ol3no`O0ol3ooh3o`?ko1l3o`?ooP?n0o_l<`?o0oon0
oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0ol3no`L00<3ooh3oP?ko4<3o`83o
P?n0ooo0ol3ool20POo8o`3V`?l20010o?l0`?go083no`10oP04`?o0ol3no`N0
oh3ool3o`?ko1l3o`?ooP?o0o_l7`?o0oon0oh3no`c0ol3ooh3oP?oo`?o0o_l7
P?n0ooo0ol3no`O0ol3ool3o`?ko1`00`?ooP?n0o_l@`?o0P?n0oh3ool3o`?oo
`821olSo0B<0o/3o0@00loom00;oo`3mo`20o?l00?go083lo`20oOl0P?co083m
o`00o?l0P?go003lo`20oOl00?go083lo`00oOl6P?l00?ooP?go083lo`20oOl0
0?co0821olOo0?G0o`400??oo@02ool0oOl0P?co003mo`20o?l0P?go083lo`20
oOl00?co083mo`00o?l0P?go003mo`20o?l00?go1X3o003ooh3mo`20o?l0P?go
003lo`20POo7o`3V`?l1003cood00_oo0?go083lo`00oOl0P?co083mo`20o?l0
P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`J0o`00oon0oOl0P?co083m
o`00o?l0P87oaol1M`3n`?l1003do`A00020`?ko1l3o`?ooP?o0o_lG`?o0oon0
oh3ool3ool3ooh3oP?oo`?o0o_l7P?n0ooo0ol3no`O0ol3ool3o`?ko1l3o`?oo
P?n0o_l4`?o0ooon00Cool3o`?ko1h3oP?oo`?o0o_l4`?o0P821olKo0?G0o`40
0?Co14000830o_l7`?o0oon0ol3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3n
o`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0oon0oh3no`C0ol3oooh01?oo`?o0
o_l7P?n0ooo0ol3no`C0ol20P87oa_l0i/3o0@00m?l4@000P<3no`O0ol3ooh3o
`?ko5l3o`?ooP?n0ooo0ooo0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?o0ooo0
ol3no`O0ol3ooh3oP?ko1<3o`?oooP04ooo0ol3no`N0oh3ool3o`?ko1<3o`820
POo6o`4n0?k0o`400?ko003mo`20o_on0020o_l0P?go003lo`20oOl00?go083l
o`00oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`D0o`00oh3lo`00
oOl0P?co083no`20POo4o`3e`?l1003no`00oOl0P?kooP00P?ko083mo`00o?l0
P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l5
0?l00?n0o?l00?go083lo`20o_l0P87oa?l0i/3o0@00o_l00?go083nooh0083n
o`20oOl00?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co083m
o`00oOl0P?co1@3o003oP?co003mo`20o?l0P?ko0821olCo0GL0o/3o0@00mol0
`?d0J_oo`?o0oon0ooo0ooo0ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ol3o
ol3ooh3ool3o`?ooP?ooP?oo`?o0oon0ooo0ol3ooh3ooh3ooh000?ooP?oo`?oo
`?o0oon0ooo0ol3o`030POo4o`3e`?l1003go`30o@1Zooo0ol3ooh3ool3ool3o
`?ooP?oo`?o0oon0oon0ooo0ol3ooh3ool3o`?oo`?ooP?oo`?o0oon0oon0ooo0
ol3ooh3ool3o`?ooP?ooP?ooP000oon0ooo0ooo0ol3ooh3ool3o`?o00<21olCo
0>K0o`400?Oo0<3m06[ool3o`?ooP?oo`?oo`?o0oon0ooo0ol3ooh3ooh3ool3o
`?ooP?oo`?o0ooo0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?o0oon0oon0oon0
003ooh3ool3ool3o`?ooP?oo`?o0ol00`87oa?l18`3n`Oon0?OooP03P?oo0?go
083lo`00oOl0P?co083mo`00o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co
083mo`20o_l2P000oOl00?co083mo`00oOl0P87o`_l0mL7ooP3gooh00h3oo`3m
o`20o?l00?go083lo`20oOl00?co083mo`00o?l0P?go003mo`20o?l00?go083l
o`20oOl0P?ko0X000?go003lo`20oOl00?go0821ol;o0>K1ooh0moon00>0ool0
oOl0P?co003mo`20o?l0P?go003lo`20oOl00?co083mo`00oOl0P?co003mo`20
o?l0P?go083no`:0003mo`00o?l0P?go003mo`20POo2o`630?k1o`<00830o?l2
`?o0oP0=P<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0
oon0oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3noa;0oh3ool3oP020ol3o
`?ooP?o0o_l7`?o0oon0`821ol7o0?G1o`<00830o?l2`?o0oP0=P<3o`?ooP?n0
ooo0ol3no`N0oh3ool3o`?ko1l3o`?oo`?o0o_l7`?o0oon0oh3noaO0ol3ooh3o
P?oo`?oo`?ooP?n0ooo0ol3noa;0oh3ool3oP020ol3o`?ooP?o0o_l7`?o0oon0
`821ol7o0>K1o`<00830o?l2`?o0oP0=P<3o`?ooP?n0ooo0ol3no`N0oh3ool3o
`?ko1l3o`?oo`?o0o_l7`?o0oon0oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0
ol3noa;0oh3ool3oP020ol3o`?ooP?o0o_l7`?o0oon0`821ol7o0B<0o/7o0@00
n?on007o0?go083lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go083l
o`20oOl0P?co083mo`00o?l5P?l00800oOl0P?co003mo`:0oh21ol3o0?G1o`40
0?SooP01o`3mo`20o?l0P?go083lo`20oOl00?co083mo`00oOl0P?co003mo`20
o?l0P?go083lo`20oOl00?co1H3o00200?go083lo`00oOl2P?n0POo0o`3V`Ol1
003hooh00Ol0oOl0P?co083mo`20o?l0P?go003lo`20oOl00?go083lo`00oOl0
P?co083mo`20o?l0P?go003lo`F0o`00P03mo`20o?l00?go0X3oP87o`?l1P03n
`Ol1003mo`>0ooo0oP05`?oo`?o0o_l7`?o0oon0oh3no`c0ol3ooh3oP?oo`?o0
o_l7P?n0ooo0ol3no`O0oh3ool3o`?ko1l3o`?ooP?o0o_lG`?o0oon0oh3ool3o
ol3ooh000<3o`?o0o_l:P?n0oon0ol3o`821okoo0?G1o`400?go0h3ool3n00G0
ooo0ol3no`O0ol3ooh3oP?ko3<3o`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko1l3o
P?oo`?o0o_l7`?o0oon0ol3noaO0ol3ooh3oP?oo`?oo`?ooP000`?o0ol3no`Z0
oh3ooh3o`?o0P87o_ol0i/7o0@00oOl3P?oo`?h01L3ool3o`?ko1l3o`?ooP?n0
o_l<`?o0oon0oh3ool3o`?ko1h3oP?oo`?o0o_l7`?n0ooo0ol3no`O0ol3ooh3o
`?ko5l3o`?ooP?n0ooo0ooo0oon00030ol3o`?ko2X3oP?ooP?o0ol20POnoo`4S
0?k1o`400?[ooP02ool0o?l0P?go003lo`20oOl00?go083lo`00oOl0P?co083m
o`20o?l0P?go003lo`20oOl00?go083lo`80ooom0?go083mo`:0oh3no`20POnn
o`3e`Ol1003jooh00_oo0?co083mo`00o?l0P?go003mo`20o?l00?go083lo`20
oOl0P?co083mo`00o?l0P?go003mo`20o?l20?ooo@3mo`20oOl2P?n0o_l0P87o
__l0i/7o0@00n_on00;oo`3lo`20oOl00?co083mo`00oOl0P?co003mo`20o?l0
P?go083lo`20oOl00?co083mo`00oOl0P?co0P3oood0oOl0P?go0X3oP?ko0821
okko0GX0o/;o0X000?co0<3n00:0ol3no`N0oh3ool3o`?ko1l3oP?oo`?o0o_l7
`?o0oon0oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko
2L3o`?ooP?o0ooon0020oP01P83no`O0ol3oP830P87o_Ol0mL;o0X000?co0<3n
00:0ol3no`N0oh3ool3o`?ko1l3oP?oo`?o0o_l7`?o0oon0oh3noaO0ol3ooh3o
P?oo`?oo`?ooP?n0ooo0ol3no`N0oh3ool3o`?ko2L3o`?ooP?o0ooon0020oP01
P83no`O0ol3oP830P87o_Ol0i/;o0X000?co0<3n00:0ol3no`N0oh3ool3o`?ko
1l3oP?oo`?o0o_l7`?o0oon0oh3noaO0ol3ooh3oP?oo`?oo`?ooP?n0ooo0ol3n
o`N0oh3ool3o`?ko2L3o`?ooP?o0ooon0020oP01P83no`O0ol3oP830P87o_Ol1
6P3n`_on007oP?koo@3lo`20oOl00?go083lo`00oOl0P?co083mo`20o?l0P?go
003lo`20oOl00?go083lo`00oOl0P?co083mo`:0003noo/00Oooo000P87o_?l0
mL;ooP01oh3nood0o?l0P?go003mo`20o?l00?go083lo`20oOl0P?co083mo`00
o?l0P?go003mo`20o?l00?go083lo`20oOl2P000o_ok007ooo`00821okco0>K2
ooh00On0o_om0?co083mo`00oOl0P?co003mo`20o?l0P?go083lo`20oOl00?co
083mo`00oOl0P?co003mo`20o?l0P?go0X000?kon`01oool0020POnlo`5O0?k2
o`80083no`30oP1AP?ooP?ooP?oo`?o0oon0ooo0ol3ool3ooh3ool3o`?ooP?oo
`?oo`?o0oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?oo`?o0oon0ooo0ol3oooj0
003nP0400?f0nP01P821okSo0?G2o`80083no`30oP1AP?ooP?ooP?oo`?o0oon0
ooo0ol3ool3ooh3ool3o`?ooP?oo`?oo`?o0oon0ooo0ol3ooh3ooh3ool3o`?oo
P?oo`?oo`?o0oon0ooo0ol3oooj0003nP0400?f0nP01P821okSo0>K2o`80083n
o`30oP1AP?ooP?ooP?oo`?o0oon0ooo0ol3ool3ooh3ool3o`?ooP?oo`?oo`?o0
oon0ooo0ol3ooh3ooh3ool3o`?ooP?oo`?oo`?o0oon0ooo0ol3oooj0003nP040
0?f0nP01P821okSo0@h0o/;o0P00P?kooP3lo`20oOl0P?co083mo`00o?l0P?go
003mo`20o?l00?go083lo`00oOl0P?co083mo`20o_oh0?_o083a0020oOl1083n
o`40087oaOl0mL;o0P00P?kooP3lo`20oOl0P?co083mo`00o?l0P?go003mo`20
o?l00?go083lo`00oOl0P?co083mo`20o_oh0?_o083a0020oOl1083no`40087o
aOl0i/;o0P00P?kooP3lo`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go
083lo`00oOl0P?co083mo`20o_oh0?_o083a0020oOl1083no`40087oaOl1503n
eol6gD@0025EgO?o1000P?oooP00P?ko083mo`20o?l0P?go003lo`20oOl00?go
083lo`00oOl0P?co083mo`20o?of00;ooh3T0?co0@20o_l10021olGo0?GGo`KM
A0008EGMlol40020ooon0020o_l0P?go083lo`20oOl00?co083mo`00oOl0P?co
003mo`20o?l0P?go083looH00_ooP>@0o?l1083no`40087oaOl0i]Oo1]e4000Q
EMgco`@0083oooh0083no`20oOl0P?co083mo`00o?l0P?go003mo`20o?l00?go
083lo`20oOl0P?comP02oon0i03lo`40P?ko0@00POo5o`4n0?kHo`U_0420P5d[
3HSkmOl40020od3n02gool3o`?ooP?ooP?oo`?o0oon0ooo0ooo0ol3ooh3ool3o
`?ooP?ooP?oo`?m0o800@?j0g000@?j0043k0090P<3ko`40P?ko0@00POo5o`3e
f?l9K`10P81M:`f8noGo1000P?m0oP0]ooo0ol3ooh3ooh3ool3o`?ooP?oo`?oo
`?o0oon0ooo0ol3ooh3ooh3ool3o@?b0043nP=`0043nP010n`02@830nol1083n
o`40087oaOl0i]So2Fl0@820GB/=R?_eo`@0083o@?h0;Ooo`?o0oon0oon0ooo0
ol3ooh3ool3ool3o`?ooP?oo`?o0oon0oon0ooo0od3lP010oX3L0010oX00@?/0
0T20`?_o0@20o_l10021olGo0@/0o]Wo0WL0^_co0VH0X_Ko0h00083n00>0ool0
oOl0P?co003mo`20o?l00?go083lo`20e@3fo`80083noo/0o?l6kUD04;/0P?ko
1`00ofD027OgPOo;o`3efOl2M`2jo?l2IP2Rm_l3P000P?h00h3oo`3mo`20o?l0
0?go083lo`00oOl0P?co083E0?Ko0P00P?kon`3lo`K^E@0@^`20o_l7003oI@08
MoN1ol_o0>KIo`9g0;[lo`9V0:;fo`>00020oP03P?oo0?go083lo`00oOl0P?co
003mo`20o?l0P=D0m_l20020o_ok0?co1^iE012k083no`L00?mU00Qgmh7obol1
0P3nf_l2g@1knol2lb]=m_l0P?`02830ol3ooh3oP?ko1L3o`?n00?f0043lP>D0
m83Yo`@00?oo`?d00H30nol6?1UcKbL0P?ko0P00:od003b1ol_o0?GJo`;M07_k
o`;c:dgfo`20o008P<3o`?ooP?n0o_l5`?o0oh00oH00@?b0i@3dP>Wo1000ooo0
o@01P<3ko`Hl6G=_9`20o_l2000[o@00?87obol0i][o0]d0No_o0_<[COKo083l
00R0`?o0oon0oh3no`G0ol3oP03mP010o83U0?B0jOl4003ool3m0060`?_o1S`I
LflW083no`8002_m000lPOo;o`2g0?kJo`:I0<cjo`6Y6OKo083m00>00?oof@3@
ooh00Oooo@3io`NH2>kooiT0P?kooP05Z_nZ002HPOo<o`3ef_l2V@3<n_l1ZAWf
o`20o@03P03oomT0d?on007oood0nOl7V0S^oonI083nooh01J[oZP00V87oc?l0
i][o0YT0c?[o0JTIm_l0P?d00h00oooI0=3ooP01ooom0?Wo1iP8k_ooV@20o_on
00FZojX009R1olco0;40o][o0X00mo[o0OL0mol1P43[0?B0`ol60020o`10P?Oo
0BYNo_l2iP20o_l2002Ao_l2T@0RPOo<o`3ef_l2P03gn_l1m`3go`60@>/0m833
o`H0083o0420mol1:Ukno`;V083no`80097no`:A02:1olco0>KJo`:00?Ojo`7g
0?Oo0H10j`3dP<?o1P00P?l0@83go`4ZG_ko0^H0P?ko0P00TOko0Y408X7oc?l0
RP3nf_l1P03ho`00m_l0P?P0ZOl1003bo`40P?go0@20o_l1003lo`40087oc?l0
mM[o0H00n?l00?Ko083h0:Wo0@00l_l1083mo`40P?ko0@00o?l10021olco0>KJ
o`600?So003fo`20n02Yo`400?;o0@20oOl1083no`400?co0@00POo<o`2:0?kJ
o`:<0>Kjo`6b5IGo0X000?;o0@1go_l2m`20o_l2003Vo_l2iP08POo<o`3ef_l2
S03Vn_l1/QFEo`:0003bo`40Moko0_L0P?ko0P00i_ko0^H0287oc?l0i][o0X`0
i_[o0K8EUOl2P000l_l107Ono`;g083no`800>Kno`;V00R1olco08X0o][o0/<0
Z_[o0C9<UOl2P020l_l1<Tcno`;<083no`8004Cno`9E05F1olco0?GJo`;30:[j
o`4bC9Go0X00P?;o0C9<o_l2c020o_l20014o_l2E@1EPOo<o`3Vf_l2``2Zn_l1
<TbEo`:0083bo`4bC?ko0/`0P?ko0P00A?ko0UD0EH7oc?l0S@3nf_l3mc<ci_co
0Yh0WYGo0X00P?;o1k/=X_O^FP20o_on00EAP5X03MB1olco0?GJo`?g<c?Vo?l2
WP2NUOl2P020l_l7^`fRmniJ083nooh01E60FP0=e87oc?l0i][o0oLc<nKlo`:N
09jEo`:0083bo`Nk3J;gkUX0P?kooP05DH1J00gDPOo<o`270?kIo`W^4@2@ooo<
IP1EU?l20020lOl0I_h00T`0P?ko0P00EOd008R1ol_o0?GIo`W^4@2@ooo<IP1E
U?l20020lOl0I_h00T`0P?ko0P00EOd008R1ol_o0>KIo`W^4@2@ooo<IP1EU?l2
0020lOl0I_h00T`0P?ko0P00EOd008R1ol_o08@0o]So1leM7P006C>ETol20030
lOl6mj:0T>Z0`?ko1h20ojj0Q;_kPOo;o`3ef?l7cEdN000I<iFCo`800<3ao`Kg
XX2@jX30o_l7P83o[X24^o^1ol_o0>KHo`O=GAh001TcUI?o0P00`?7o1_NRP93Z
P<3no`N0P?n^P8Bknh7obol09`3nPOoRo`40087oZ?l0mH7oh_l10021ojSo0>J1
on;o0@00POnXo`0T0?j1on?ooP21ojSo0?F1on?ooP21ojSo0>J1on?ooP21ojSo
02L0oX7ohol10021ojOo0?F1on?o0@00POnWo`3VPOoSo`40087oYol0<`3nPOoX
o`00oOl10021ojOo0?F1onSo003mo`40087oYol0iX7oj?l00?go0@00POnWo`0c
0?j1onSo0`10ooon087oYol0mH7oj?l3043oooh0POnWo`3VPOoXo`<0@?oooP21
ojOo03<0oX7oj?on00?o0020POnWo`3ePOoXooh00ol00821ojOo0>J1onSooP03
o`00P87oYol0?`3nPOoWo`L00800083oooj0POn/o`3ePOoWo`L00800083oooj0
POn/o`3VPOoWo`L00800083oooj0POn/o`0f0?j1onOoo004P?l00821oj_o0?F1
onOoo004P?l00821oj_o0>J1onOoo004P?l00821oj_o02@0oX7oiooh087oZ_l0
mH7oiooh087oZ_l0iX7oiooh087oZ_l0903nPOoWooT0POnYo`3ePOoWooT0POnY
o`3VPOoWooT0POnYo`0`0?j1onOo043k0020POnYo`3ePOoWo`10n`00P87oZOl0
iX7oiol0@?/00821ojWo02X0oX7oiol0P?/0POnXo`3ePOoWo`20n`21ojSo0>J1
onOo083k087oZ?l0<03nPOoWo`20o@00@87oYol0mH7oiol0P?d00421ojOo0>J1
onOo083m0010POnWo`0`0?j1onOo083m0020POnWo`3ePOoWo`20o@00P87oYol0
iX7oiol0P?d00821ojOo0300oX7oiol0P?h00821ojKo0?F1onOo083n0020POnV
o`3VPOoWo`20oP00P87oY_l0903nPOoVooh0POnUo`3ePOoVooh0POnUo`3VPOoV
ooh0POnUo`0W0?j1onKo0@10POnTo`3ePOoVo`40@87oY?l0iX7oi_l10421ojCo
02@0oX7oi_l0087oXol0mH7oi_l0087oXol0iX7oi_l0087oXol0903nPOoVo`20
POnSo`3ePOoVo`20POnSo`3VPOoVo`20POnSo`0H0?j1oh7oQol0mH7oPOn7o`3V
POn1ohOo01P0oX7oPOn7o`3ePOn1ohOo0>J1oh7oQol0?`3nPOoKo`C^a8SoooZ0
0IgMPOnko`3ePOoKo`C^a8SoooZ00IgMPOnko`3VPOoKo`C^a8SoooZ00IgMPOnk
o`1;0?j1om_ooP02oooMoP05c?nH002@POnlo`3ePOoKooh00_oogOh01LcoV000
T87o_?l0iX7ofoon00;oomgn00G<oiP00921okco04D0oX7of_l1O03nooh0o_l2
HP0JPOnlo`3ePOoJo`5l0?kooP3no`9R01Z1okco0>J1om[o0G`0o_on0?ko0V80
6X7o_?l0A@3nPOoJo`600?kooP3no`:00021okco0?F1om[o0H00o_on0?ko0X00
087o_?l0iX7of_l1P03nooh0o_l2P000POnlo`1>0?j1omgo1>J=R7<0o_on0?ko
0V80<h7o_?l0mH7ogOl4iXf8L`3nooh0o_l2HP0cPOnlo`3VPOoMo`CVSHQc0?ko
oP3no`9R03>1okco05@0oX7og_l5iP33gAT0o_on00GogGL00<b1okco0?F1omko
1NH0`mdI0?kooP05omeg003<POnlo`3VPOoNo`GV0<?M6@3nooh01OoMM`00c87o
_?l0D@3nPOoNo`EZR?ooM`3nooh0180902_gPOnko`3ePOoNo`EZR?ooM`3nooh0
180902_gPOnko`3VPOoNo`EZR?ooM`3nooh0180902_gPOnko`1A0?j1omko01Wn
o`600?kooP04ofH008N1ok_o0?F1omko01Wno`600?kooP04ofH008N1ok_o0>J1
omko01Wno`600?kooP04ofH008N1ok_o05@0oX7og_l50?Oooh00o_on00Gog@P0
0<B1okco0?F1omko1@3goon00?kooP05omd80034POnlo`3VPOoNo`D0moooP03n
ooh01OoM2000a87o_?l0E03nPOoNo`DAV?ooP03nooh01Ooo^P00EH7o_?l0mH7o
g_l54ISooh00o_on00GookX005F1okco0>J1omko1A6Hoon00?kooP05oonj001E
POnlo`1M0?j1omko26XIdOmJ07cok_h01mgooeT009WgPOnno`3ePOoNo`QZ6M7o
FP1lonkn00OMoomI002Imh7o__l0iX7og_l8JQWAoeX0O?o^oP07gOooF@00VON1
okko05L0oX7og_l7meD0<ViE^ool00:0omgn000lPOnno`3ePOoNo`OgE@0bKUFk
oo`00X3ogOh003b1okko0>J1omko1oME039^EK_oo002P?oMoP00?87o__l0603n
POn1ohOo0?F1oh7oQol0iX7oPOn7o`0H0?j1oh7oQol0mH7oPOn7o`3VPOn1ohOo
01P0oX7oPOn7o`3ePOn1ohOo0>J1oh7oQol0603nPOn1ohOo0?F1oh7oQol0iX7o
POn7o`0H0?j1oh7oQol0mH7oPOn7o`3VPOn1ohOo01P0oX7oPOn7o`3ePOn1ohOo
0>J1oh7oQol0603nPOn1ohOo0?F1oh7oQol0iX7oPOn7o`0H0?j1oh7oQol0mH7o
POn7o`3VPOn1ohOo01P0oX7oPOn7o`3ePOn1ohOo0>J1oh7oQol0603nPOn1ohOo
0?F1oh7oQol0iX7oPOn7o`0H0?j1oh7oQol0mH7oPOn7o`3VPOn1ohOo01P0oX7o
POn7o`3ePOn1ohOo0>J1oh7oQol0603nPOn1ohOo0?F1oh7oQol0iX7oPOn7o`0H
0?j1oh7oQol0mH7oPOn7o`3VPOn1ohOo01P0oX7oPOn7o`3ePOn1ohOo0>J1oh7o
Qol0603nPOn1ohOo0?F1oh7oQol0iX7oPOn7o`3o\>"], "Graphics",
  Editable->False,
  ImageSize->{215, 190.313},
  ImageMargins->{{189, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0005c/0@0005P0000G00005`0001T2003@0@00
000000000003>P00TS800215CDH00040k5`009/100060000000000000000000000@00003000>0@00
b`0004H0002T6`00V1/004M4BD<1002000<000MAQ1H00000P1/000402@000l0=000601`0000000D0
000;0_ooool50000309`0JH1100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@040000104700@000040@d0100002d10`040000l04000P0003j0PD0
00000?ooo`840000;@4000L0000K1;00F@2I03h01@0000T200000P@0000^0@00100002d11@040000
l04201`0003k0^ko00000000T04000000000<T5bJF5/000000000000000000000000000000000000
100002d10P0700008@D106CoVP0n00D000090P0000840000;P4000@0000]0@D010000?010P0L0000
n`;^o`0000000;`2000000000391LVUQK0000000000000000000000000000000000000@0000]0@80
1`0002450@1SoiX0B0040000;@4400@0003`0@401@00004200000PD000090_ooo`8]0000@P430000
:00000P0000800000@010000000P0000000000000000000000000000003oool00@0000P000200000
40000080001000001000020000040000;@4100h0000T0`D0A00Z0K@0^`0f0KL0`@0Q0D@0:P440000
;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@1402X1]02k03H1]`310241
A00Z0@@0000]0@<010000?0100080000nP850000003oool2100002d100040000;@4400@0003`0@40
1@00004200000PD000090_ooo`8]0000@P430000:00000P0000800000@010000000P000000000000
0000000000000000003oool0000000000000000020000000000000000000080000040000;@4100h0
000T0`D0A@0Y0KL0_03;04D0EP2V04D0:@440000;@4300@0003`0@0020000?X20001004000000P@0
000]0@003P0002D31@1502T1]`2l0</0A@1F0:H0A@0Y0@@0000]0@<010000?0100080000nP850000
003oool2100002d100040000;@4400@0003`0@401`000?`2003oool048`40000;@4100L0000K1>80
_P3<0:001@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000T0400000
0000<T5bJF5/000000000000000000000000000000000000100002d10P0700008@D2021Tc@2P00D0
00090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000;`2000000000391LVUQ
K0000000000000000000000000000000000000@0000]0@801`0002450@1Qold0[`0700006`@i0MX0
8P6o00D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`000000090100000000
0391LVUQK0000000000000000000000000000000000000@0000]0@801`0002450@1Tob<1_`050000
2@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002l0P000000000b@G9YHF`0
0000000000000000000000000000000000040000;@4200L0000Q1@40H_lS0LT01`0001/4>@4o02<1
;00500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@000000000b
@G9YHF`00000000000000000000000000000000000040000;@4200L0000Q1@40ColT0B`0100002d1
10040000l04100L0003l0P000000012<100002d10@0>000090<50:P0A06V03@1ZP0j0K40=`6X04@1
100002d10`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0Z0140JH0=06Z03X1
/@0g0JP0A0440000;@4300@0003`0@0020000?X20002008000000P@0000]0@00200002D30P2Z03/1
_03b00@0000]0@<010000?0100080000nP850000003oool2100002d100040000;@4400@0003`0@40
1`000?`2003oool048`40000;@4100L0000K15`1bP160Jl01@0000T200000P@0000^0@00100002d1
1@040000l04201`0003k0^ko00000000T04000000000<UAYKFEc84iUMb1BKfeQKP00000000000000
00000000100002d10P0700008@D106CoAP6_00D000090P0000840000;P4000@0000]0@D010000?01
0P0L0000n`;^o`0000000;`200000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0
000]0@801`0002450@1BodH1^0040000;@4300@0003`0@0020000?X20002008000000P@0000]0@00
200002D30P2j0>l0_`3e00P0000U0`80^P3e0;l0k`040000;@4300@0003`0@0020000?X21@000000
oooo0P@0000]0@00100002d110040000l04100L0003l0P000000012<100002d10@0>000090<504T0
MP1H07`0D01m04l0Q@1907H0100002d10`040000l04000P0003j0P000@01000000840000;@4000h0
000U0`D0B@1f05P0O01@07d0C`2504T0MP040000;@4300@0003`0@0020000?X20002008000000P@0
000]0@00200002D30P1@07d0QP2c00@0000]0@<010000?0100080000nP850000003oool2100002d1
00040000;@4400@0003`0@401`000?`2003oool048`40000;@4100L0000K17D0F`1P04001@0000T2
00000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000T04000000000<UAYKFEc84iU
Mb1BKfeQKP0000000000000000000000100002d10P0700008@D106CoH01000D000090P0000840000
;P4000@0000]0@D010000?010P0L0000n`;^o`0000000;`200000000039DJFeULb1>IGLPDVm]HFh0
0000000000000000000000@0000]0@801`0002450@1Aof00B@040000;@4300@0003`0@0020000?X2
0002008000000P@0000]0@00200002D30P230:h0R02d00P0000U0`80P`2d08P0[P040000;@4300@0
003`0@0020000?X21@000000oooo0P@0000]0@00100002d110040000l04100D000010P0000850000
2@;oool2;@0004810`0002P000080000200000400@00000080000000000000000000000000000000
oooo08000010000080000100000800001000008000010000100002d10@0>000090<50</0A@140D<0
=P6g0;P0^P3:04H0100002d10`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0
b`1504@1@`0f0KL0^02j0<X0AP0800009@<205L0Z01P0:L0200002D30P1Y0:L0LP2V00P0000U0`80
N`2U08@0Y@0800009@<208d0Y02F0:@0200002D30P2O0:<0Z02R00P0000U0`80/@2R0;X0X@080000
9@<20<<0X03<0:00200002D30P3>0:00e@2J00P0000U0`80g02E0><0S`0800009@<20>X0RP3a08@0
200002D30P3h07h0o`1i00P0000U0`801P5c00d1KP0800009@<201@1J00K0F80200002D30P0S0Ed0
:P5G00P0000U0`80<@5B03P1C00800009@<203l1AP130D<0200002D30P3?0:40cP2Z00P0000U0`80
c@2c0<`0_00800009@<20</0a@3:0<h0200002D30P390=L0b03P00P0000U0`80a`3Y0<H0l@080000
9@<20<D0nP3300<1200002D30P3200`1`@0E0@P0000U0`80`00N0L008@440000;@4300@0003`0@00
20000?X21@000000oooo0P@0000]0@00100002d110040000l04100L0003l0P0000000>RJ100002d1
0@0>000090<505H0[01J0;`0E@2f04h0^P1F0:`0100002d10`040000l04000P0003j0P000@010000
00840000;@4000h0000U0`D0EP2/05X0_01E0;H0CP2j05H0[0040000;@4300@0003`0@0020000?X2
0002008000000P@0000]0@00200002D30P1602X1E@2e00@0000]0@<010000?0100080000nP850000
003oool2100002d1000>000090<50;P0_02a0</0/@330:T0`P2h0;`0100002d10`040000l04000P0
003j0P000@01000000840000;@4000h0000U0`D0^02l0;40b`2a0<<0Z@320;P0_0040000;@4300@0
003`0@0020000?X20002008000000P@0000]0@00200002D30P1602X1/@3300@0000]0@<010000?01
00080000nP850000003oool2100002d1000>000090<50<008`6a02X1]P0T0K407P7002<1100002d1
0`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0`00S0K40:P6f02@1/@0N0L00
8`440000;@4300@0003`0@0020000?X20002008000000P@0000]0@00200002D30P1702X1]`0T0@@0
000]0@<010000?0100080000nP850000003oool2100002d1000>000090<50=/0903M03@0f@0^0=80
<@3K02@0100002d10`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0f`0T0=d0
=03I02h0dP0a0=/090040000;@4300@0003`0@0020000?X20002008000000P@0000]0@00200002D3
0P3C04H0f@0]00@0000]0@<010000?0100080000nP850000003oool2100002d100040000;@4400@0
003`0@401`000?`2003oool0j9X40000;@4100L0000K12H00@4@0=P01@0000T200000P@0000^0@00
100002d11@040000l04201`0003k0^ko00000000T04000000000<UAYKFEc84iUMb1BKfeQKP000000
0000000000000000100002d10P0800008@D309HPI?l@0=P01@0000T200000P@0000^0@00100002d1
1@040000l04201`0003k0^ko00000000_08000000000<UAYKFEc84iUMb1BKfeQKP00000000000000
00000000100002d10P0700008@D105;o403_00@0000]0@<010000?0100080000nP8000800P000002
100002d1000800009@<20<<0M@3907/0200002D30P3307/0b@1e00@0000]0@<010000?0100080000
nP850000003oool2100002d100040000;@4400@0003`0@401`000?`200000000j9X40000;@4100h0
000T0`D0dP160=00C`3B0500e0170=80AP0>000090<50<h0E`3;0600c@1Q0=00F03>05L03P0002@3
1@3906T0a`1b0<T0L`3;06X0b@1Y00@0000]0@@010000?010@070000o0800?ooo`3XVP@0000]0@40
1`0001/4l01/0MX0@P4500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000
002@0@000000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@80
UR3J04811@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000T0400000
0000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d10P0700008@D106CofP1@0@D0
00090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000;`200000000039DJFeU
Lb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`0002450@1AomX0F@440000;@4400@0
003`0@401`000?`200000000j9X40000;@4100h0000T0`D0@07/0341iP0i0ND0>P7M0401k0040000
;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@100N`0<@7V03T1i@0j0Md0
@07/00@0000]0@<010000?0100080000nP8000800P000002100002d1000800009@<201l1c00i0ND0
200002D30P010Jh01P6d00P0000U0`800@6d00H1[P040000;@4300@0003`0@0020000?X21@000000
oooo0P@0000]0@003P0002@31@050K802`6h00T1^@030K<01@6b00h0000T0`D04P6n01P1a@0F0LH0
406o0181_P0>000090<501l1b`0Q0Ld07`7>01d1c00O0L/03P0002@31@1P0Ih0D06O05H1V`1C0I@0
H06N00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<50601WP1@0Il0
EP6K05<1U01P0Ih0100002d10`040000l04000P0003j0P000P02000000840000;@4000P0000U0`80
1P6205L1V`040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00100002d110040000
l04100L0003l0P00oooo0>RJ100002d10@0700006`B^0981V01S0@D000090P0000840000;P4000@0
000]0@D010000?010P0L0000n`;^o`000000090100000000039DJFeULb1>IGLPDVm]HFh000000000
00000000000000@0000]0@80200002450`2F86CoV01S0@D000090P0000840000;P4000@0000]0@D0
10000?010P0L0000n`;^o`0000000;`200000000039DJFeULb1>IGLPDVm]HFh00000000000000000
000000@0000]0@801`0002450@1@oiP0NP440000;@4300@0003`0@0020000?X20002008000000P@0
000]0@00200002D30P030Gl0206500P0000U0`800`6500P1O`040000;@4300@0003`0@0020000?X2
1@000000oooo0P@0000]0@001`0001/4f00[0<80400500002@800002100002h100040000;@4500@0
003`0@8070000?/2k_l00000002@0@000000000bE6U]IG<PCVEg859_KF5^00000000000000000000
00040000;@4200L0000Q1@40I?o201001@0000T200000P@0000^0@00100002d11@040000l04201`0
003k0^ko00000000_08000000000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d1
0P0700008@D1053o`P0I00@0000]0@@010000?010@070000o0800000003XVP@0000]0@403P0002@3
1@0]0<80?@3103L0a@0j0<`0;@3200@0000]0@<010000?0100080000nP8000400@000002100002d1
000>00009@<502d0`P0m0<40=`3503X0c00]0<80100002d10`040000l04000P0003j0P000P020000
00840000;@4000P0000U0`80=P350580cP0800009@<208D0f`2:0>40200002D30P250>40RP3K00@0
000]0@<010000?0100080000nP850000003oool2100002d1000>000090<505@0cP1M0=40F`3B0580
c`1D0<h03P0002@31@1U0=<0KP3F06`0e`1S0=@0I@3C00h0000T0`D0MP3I07l0f`1m0=`0M03J07H0
f@0>000090<508L0gP2:0=l0R03P08D0g`270=h0100002d10`040000l04000P0003j0P000@010000
00840000;@4000P0000U0`80Q`3N00D1P@0800009@<208D0/@040K40200002D30P2m0>h0aP1h00@0
000W0Ooo10000?0100040000l04100@0003`0@8010000?010`040000l04400@0003`0@D00`000000
4@0000`0000800002`000100000c0P00jP4000T0000@0000<`800>X1000:000040000?oooooooooo
2@000100002V0@00L0400180000<00000@00024000080000500000`000070000500000`0000=0000
9P0001`0000100001@00000000000000oooo0RD0000<00000@0002D0000<00000000P2/0000H0000
?P0009T0001H0000[`0001P0000<000000000U80001<0@000P000>koool0000000000000002@0@00
0000000003910780J@1Q06`00025=8ddU3BL=:@dZcBc=;/d`SC:==8dfCCQ=>TdlSCj=0<e2cDD=A`e
9CD]=C<e?3E==@00002A=Ile[SFl=LhefSGQ=O<enCD3=PTf<CHi=T0fB3I@=ULfGcIW=VhfMSIn=XDf
SCJE=YhfYSJ_=[Lf`3K8=]4ffCKR=^TfncH1=`/g4CLJ=b0g9cLd=cXg@CM>=eLgGCMU=i8gXCN_=khg
c3ON=nXgl3Oi=bTh<CPh>40hB3P005LhGcQV>6hhMSQm>8DhSCRF>9hhYcR_>;Ph`3S9>=4hecSP>?4h
nSPb>D4iCcUN>F`iOSV:>I0iVCW9>M4i000000000000000000000000000000000@410@410@410F0j
9@0000`000020000E00005@0001D0000cP000640003X00000@0005Be34;Ka`a2?P0009X000010000
C0000000000000000000000000000000D00006@0ac`:0000DP0004`1000300000000000000000000
000005h10000000000018000aCgE?NhmnCd0?R8n;chl?THnE3iM?VXnM3j2?[Hnc3kP?^Dnnch??a@o
:Sln?d<oFCm]?g8oO3n9?hho00000:/o`coB?mPoico]?o`o0?000902000:<3D`?C14<4``E31K<6<`
Jc1b<7X`PS29<94`VC2R<:X`/c2k<<@`c33E<=d`hc3/<?d`1S4B<A/a;C4f<DPaCS5V<F`aQ36D<Jda
^36o<N4akS7k<@Db4c8L<RTb<c91<W0bNS:7<P00US:S<ZTb`C;@<]HbiC;/<_/b2C<H<bHcDC=I<f8c
JC=k<h4cRc>A<iXcXC>Y<k4c^3?0<lPccc?G<mlciS<0000000000000000000000000000000010@41
0@410@41Sc@U0000300000<0000X000030000080001B0000C0400080003^oooo0000000000000000
_08000000000000b@@1b06T0H@1/0000RCJ@=YPfX3JW=Zlf]cJn=/HfcSKE=]dfiCK^=_HfocH7=a0g
63LQ=bTg;cLh=dTg010000000018<70`Y32a<1@a8C4^<CPaC35X<HHaY372<N0ao34G<S<b@39@<Ulb
KC9k<XTbVS;f<PDc5S<g<ddcIS>U<nlcoc<K=9hdaSCj=0Le>SE7=GPeT3FM=J`eaCGE=MleBCJP=_df
RcNH=jLg/3Nh=l8gcCOF=mlgj3O`=oXg000b>7hhbSSH>>8hicP=>A<i=cU8>EliISUj>H8iSSVM>JXi
[cW1>M`ilCWm>@8j4CXH>RXj>CYJ>V0jQ3ZE>P00000000000000000000000000000000410@410@41
0@5S>bD0000<00000P0005@0001D0000H@000<h0001]0000jP000040001D]@a2flL<@TP0002J0000
0@0004`000000000000000000000000000000500001S06Xm2P0001T0000<000000000QP0000<0000
oooo0Ud0001`000010000080000P0000<0000500000P0000:00000P0000800000@01000000000000
000000000000000000000000003oool00Co_?`Po002080004080008`3310<3/`131J<20`RC0U0000
300000@0001F0000<00005`0003e0000W`4008h100050000A00Z0K@0^`0f0KL0`@0Q0D@0:P4V0000
700000D0000000000@000040000000029@0000`000050000:00000`0000100009P0001`000010000
000000400001000000000RD0000<00000@0005L0000`0000G0000?D0002O0@00SP4000D0001402X1
]02k03H1]`310241A00Z0BD0000<00001@0002P0000<00000@0002D0000<00000000P2P0000<0000
100002H0000L0000100000D00000000000000?ooo`8U0000300000@0001M0000L000004000020000
80000300001@0000800002P000080000200000400@00000000000000000000000000000000000000
oooo000jo3X0>a@k03/^>`PkLS/0>h8k03^@>`0k_3^0?3Ll9@0000`000010000EP000300001M0000
G@000101002=0@001@0004D0:@6g0;`0b`1505H0YP1502T19@0000`000050000:00000`000040000
9P0001`000040000000000400001000000000RD0000<0000100005L0000`0000G@0005d0000@0@00
S@4000D0001502T1]`2l0</0A@1F0:H0A@0Y0BD0000<00001@0002P0000<0000100002D0000<0000
0000P2P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U000030000040000U0000
30000000080[000060000:00003<0000_@000>40000H000030000000008U0000300000<0000X0000
30000080001B0000C0400080003^oooo0000000000000000T04000000000000b@@1b06T0H@1/0000
ZSNc=l<gccON=n@gjSOh=ohg13PC>1Th7cP]>3<h>CQ8>4hhECQQ>70hS3RD>9dh]3P00000gSS^>00i
1cTF>BHi<SU0>D`iFcU]>HPiSSV/>Khia3W:>M<ifSWa>@<j;3Xc>SdjBSY@>UhjJSY_>W@jO3Z1>X/j
V3ZN>Z`j^CZo>/LjeS[R>^LjkC[i>PDk2S/@>aDk93/Z>d4kCS]L>f/kNS^9>iPkYS^b>a8l63`S?2Tl
000e?4<lBCaP?6XlKcae?84lQcb??9dlXcba?;dl`ccB?=`lo3`F?A`m:cdo?DDmG3eZ?GXmQcf<?I4m
USfL?@00000000000000000000000000000000410@410@410@4^?RD0000<00000P0005@0001H0000
e`000181003[0000;0400040001D]@a2flL<@Z00003=00000P0004`0000000000000000000000000
00000500000P06@01P0000X0000U0000300000<0000X000030000080001B0000C0400080003^oooo
0000000000000000_08000000000000b@@1b06T0H@1/0000QC>><i/cXc>Y<kXcaS??<m`ci3?Z<o8c
23@P=2Hd;S@d=48dC3AB=5`dJcAh=84dQS@00000WCBR=:/d/SBh=;hda3C:==LdgCCV=>`dmCCk=0@e
2SDC=A/e83DX=Bde=CDj=D8eBCE?=EDeFcEQ=FheM3El=H8eRSF@=IPeWSFV=K0ea3G<=MHejSGb=O`e
43HH=R8f=SHn=TLfFSIR=V/fOSJ6=XlfXSJZ=[<faSK?=^df003k=QXg;CMM=f8gJcO==m@giSO^=`0h
2CP?>24h:SP`>48hBcQA>6<hK3Qd>8<hTSRH>9hhY3RZ>;/h`cS8>000000000000000000000000000
000000410@410@410@5m>BD0000<00000P0005@0001D0000j`000181003g0000;P400040001D]@a2
flL<@Zl0003=00000@0004`000000000000000000000000000000500001Q048k2P0002/0000H0000
_`000281003I0000>04002D0000<00000`0002P0000<00000P000580001<0@000P000>koool00000
00000000002@0@000000000003910780J@1Q06`0000c?S/nA3i]?W8nNckM?^@nmSkn?P@o33lB?aXo
=Slk?d4oBCm??eLoJCmb?gPoRSnC?`00002d?kXoc3oE?mdok3ok?`1@001/0P000C07<0d`4c0T<2d`
@318<54`I31/<7D`R32@<9T`[32d<;d`aC3><=H`gc3W<?0`nC0H<B`a?35?<F8aJ35f<G`aRS6@<Iha
Y36h<KladC7I<N8ajS7c<O/a138=<QDb7S8W<Rlb=c8004@bBC9A<UHbGS9S<VdbLS9l<X4bSS:C<Z0b
YC:d</Lbf3;T<^hblc;m<P8c2S<?<aLc73<R<bdc?3=6<e@c00000000000000000000000000000000
0@410@410@410AXe9@0000`000020000E00005@000000@00Q@4000d1002O0@000@0005Be34;Ka`a2
_`0002<100010000C0000000000000000000000000000000D00006@0=ST:00009@0000`000030000
:00000`000020000DP0004`100020000k_ooo`000000000000000;`2000000000000<T40LP1Y0640
K00002/k<C/l>d8kCc]F>e`kIc]]>gXkPc^A>iHkWC^R>jPk[S^d>kXk`C_6>ldkdS_I>nPk000000ll
8S`X?3@lCSaH?78lScbE?:HlaccF?=`lhSca??Pl23dG?A`m8cdX?Blm=3dk?D0mAceF?E`mHceY?Fhm
M3eo?HDmTSfI?IlmZSf`?Kdma3g:?MDmfcgX?NlmmCd0?PHn4chQ?RHn;Chb?SPn?Si4?TXnDCiF?Udn
HSiY?P00VSj]?[<naSkf?PDo2cl@?alo9ClZ?cTo?cm`?gLoRCnA?iToXSnY?jlo`So8?m/ohCo`?oXo
060001020000000000000000000000000000000000010@410@410@41^C0U000030000080001D0000
E00000d100250@006`400:4100010000E;D<@]_734;900008`400040001<00000000000000000000
00000000001@0000HP0A<`/0000[0000600002`0000S0@00?P0003P1000U0000300000<0000X0000
30000080001B0000C0400080003^oooo0000000000000000T04000000000000b@@1b06T0H@1/0000
fCD3=T8fECI^=W@fSSJD=YXfZ3Je=/@fbcKZ=_8fmcH5=`dg5SMB=gXgQcNN=k0g]CL00000b3O@=mDg
fSOR=nPgkCOe=o`g4cPM>3@hO3R4>?Th4STH>C8i>3UB>EPiLSUh>I8iV3VV>J/i^CVn>L`idCWO>N@i
lSWg>@Dj2SXH>Qdj:cX`>W0jPcZ9>YPjWSZW>PPk7c]S>j8k]S^m>lHkfC_O>nDkn3_n>`@l4c`I?1ll
000_?3@l?Sa4?4XlICa^?7HlP3b;?9DlZSbb?;Tl_Sc3?=4lfCcR?1Pm@3e=?ElmLCeh?GlmQSf=?I@m
X3f`?@00000000000000000000000000000000410@410@410@7>?bD0000<00000P0005@0001D0000
?00008H1001>0000X0400040001D]@a2flL<@R`0000T0@000@0004`0000000000000000000000000
00000500001?0?`a3P0002D0000<00001000P5H0000`0000g`0009/1003]0000/@4000D0002X04@1
YP0d0JX0>P6a03L1Z0140BD0000<00001@0002P0000<00000@0002H0000L00000@00000000010000
0@000000008U000030000040001G0000<0000=l0002K0@00k@000;4100050000Z0140JH0=06Z03X1
/@0g0JP0A04U0000300000D0000X000030000040000V000070000040000000000P00008000000002
9@0000`000010000E`0002@0003S0000@`400?d0002V0@000P000:X0>`6l0?809@0000`000050000
:00000`0000100009P0001`0000100001@00000000000000oooo0RD0000<00000@0002D0000<0000
0000P2/0000H0000[`0004H100390000F`4002D0000<00000`0002P0000<00000P000580001<0@00
0P000>koool0000000000000002@0@0000000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP0009`oY3ng?n/o080001P2000V<3L`?S1o<:L`4S4/<@00001E<F@aO36=<Ida[S6e<K/a`C77<Lda
fS7Z<A<b:38l<U4bJS9m<Y8bYC:i</`bhC;d<Plc5c<M<bDc:c<j<dLcDS=P<fHcKc=e<h0cU3>K<jdc
]S?J<ndc3S@E=2Ld;c@e=3hdA3AB=8DdZSBm=6XaLS6:<IXaY36a<KLac3400?0a0C8B<Q`b:c8g<T4b
HC:><Zhdb3@;=A@e6CDN=B<e:CDc=CdeAcEA=E/eISE_=GPePCF9=I<eWCFW=K8e0000000000000000
00000000000000000@410@410@410Fhf9@0000`000020000E00005@0003[0000/`400?H0003=0@00
0@0005Be34;Ka`a2[`0004H100010000C0000000000000000000000000000000D00006@02C090000
9@0000`000030000:00000`000020000DP0004`100020000k_ooo`000000000000000;`200000000
0000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00008c<`<eDcIS=/<j4cdC?N<n<cl3<E=2Hd
;3Bf=<Dd0000064eIcE/=GLePSF7=HdeTSFg=L8eb3Ge=@DfJcJ?=YTf_SKa=_Tf4cLM=bPgf3OL=n8g
iSO/=o0gmSOj=olg13P9>0lhNcR4><lhH3YX>WljQc[G>]`jh3[T>^Pj?C]`>g@kN3]l>h0khc^a?>Pl
5cg9?M<mfSgQ?N/mmCgl?@003ChG?R4n:3h_?STn@ci:?U4nFciU?VlnMSim?XLnSSjI?ilo[3nn?l/o
d3oP?o8oo3l000<0<04000L`3300000000000000000000000000000000010@410@410@415C4U0000
30000080001D0000E0000?L0002c0@001`400<`100010000E;D<@]_734:h0000AP400040001<0000
000000000000000000000000001@0000DP3]=Pd0000U0000300000D0000X000030000040000V0000
70000040000000000P000080000000029@0000`000010000E`0002@0003h0000?`40004100190@00
0P000;X0k`2o0?D0E`0002@0003h0000?`40004100190@000P000;X0m@2o0>l09@0000`000050000
:00000`0000100009P0001`0000100001@00000000000000oooo0RD0000<00000@0002D0000<0000
1000P5H0000`0000H`0009h0001g0000/P0000D0001907H0F01l0500O@1?08D0B@1f02D0000<0000
1@0002P0000<00000@0002H0000L00000@000000000100000@000000008U000030000040001G0000
<00006<0002N0000M`000;8000050000B@1f05P0O01@07d0C`2504T0MP0U0000300000D0000X0000
30000040000V000070000040000000000P000080000000029@0000`000010000E`0002@0001[0000
Y`000;D0003a00000P000500O@260;<09@0000`000050000:00000`0000100009P0001`000010000
1@00000000000000oooo0RD0000<00000@0002D0000<00000000P2/0000H0000@0000600001J0000
M00002D0000<00000`0002P0000<00000P000580001<0@000P000>koool0000000000000002@0@00
00000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP000:@l^3bm?B@oJ3l0001P0`0X0000
Sc3o<<@a539L<`00002k=J@fSSLK>1lh8cPW>2/h0000L0<0I04004/`NS68<K<adC7U<Ola:39C<WLb
Uc:U<]0bkS82<a`cAC=`<i@c]3?9<mPcjS?i<`Xd6C@U=3<d@cAA=7XdOSB2=8HdRSBF=:<d/SC8==Hd
iSCe=04e3cDh=C`e@3E4=DPeE3D0070eO3F:=IXeZ3Fm=L`emSGj=Ohe0SH6=Q8f7cH]=SdfC3IH=VHf
MSJ5=[@f^3Jl=/0fa3KW=^/fkcKc=_Lf000000000000000000000000000000000@410@410@410Ohj
9@0000`000020000E00005@0001G0000P@000680002K00000@0005Be34;Ka`a2@000060000010000
C0000000000000000000000000000000D00006@0KSh900009@0000`000030000:00000`000020000
DP0004`100020000k_ooo`000000000000000;`2000000000000<U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^0000h33/<?/`:S4^<C8a=S4j<EdaHC5U<FTaKC7><@ld000006HdNSBD=;ldjS@E=D0e
K3FH=L@el3DF=S`fHSJ8=Z@f`3KL=_8f03L[=dTgGCMg=j8gdcL4>3DhIcRI></hoCPS>DTiKcVE>K4i
cCWY>Oli53XS>SDjA3Y@>UljJcYg>X/jUcZe>/@jd3[O>^/jmcX;>aLk<3/o>d/kFS]V>`00QS^B>k0k
_c_;>mXkiS_b>`Hl4Sa9?4dlDCaE?5TlICab?84lSCbL?:Pl]3c8?=@lmc`6?A8m8Cd]?CTmCCd00000
00000000000000000000000000010@410@410@41RchU000030000080001D0000E00006<000210000
M@0009X000010000E;D<@]_734990000H0000040001<0000000000000000000000000000001@0000
D@3I<0h0000U0000300000D0000X000030000040000V000070000040000000000P00008000000002
9@0000`000010000E`0002@0002_0000j0000;P0003b00000P0008<0[P280;@0E`0002@0002_0000
j0000;P0003b00000P0008<0]0280:h09@0000`000050000:00000`000010000600000`0003oool2
9P0001`0000100001@00000000000000oooo0RD0000<00000@0005d0001`000010000080000P0000
<0000500000P0000:00000P0000800000@01000000000000000000000000000000000000003oool0
P3d;?D0m:cdP?E4m43ea?@Pm[Sd4?KHm0SgM?@4miCdU0000300000@0001F0000<0000?L0001K0000
/P400?T000050000b`1504@1@`0f0KL0^02j0<X0AP0U0000300000D0000X000030000040000V0000
70000040000000000@000040000000029@0000`000010000E`000300003g0000F`000;81003i0000
1@000</0A@140D<0=P6g0;P0^P3:04H0E`0002@0001e0000h0000840003Q00000P0005L0Z01P0:L0
E`0002@0002=0000gP0009T0003P00000P0006T0Y`1b0:H0E`0002@0002U0000g@000;40003M0000
0P0007/0Y@240:D0E`0002@0002m0000g0000<T0003L00000P0008d0Y02F0:@0E`0002@0003E0000
f@000>40003J00000P0009l0X`2X0:80E`0002@0003]0000f0000?T0003I00000P000;40XP2j0:40
E`0002@000050@00eP000141003F00000P000<<0X03<0:00E`0002@0000D0@00cP0001h1003F0000
0P000<h0X03E09X0E`0002@0000W0@00`0000301003800000P000=`0U@3S08l0E`0002@0000j0@00
/@0004<1002i00000P000>X0RP3a08@0E`0002@0001<0@00XP0005H1002Y00000P000?P0OP3o07T0
E`0002@0001O0@00U00006P1002J00000P0000H1L`0=0Fh0E`0002@0001b0@00Q00007/1002<0000
0P0001@1J00K0F80E`0002@000260@00M@0008l1001m00000P0002<1G@0Z0EL0E`0002@0002H0@00
I`000:81001_00000P000341DP0h0D`0E`0002@0002[0@00F`000;01001O00000P0003l1AP130D<0
E`0002@0000D0@00f00001D1003T00000P000<l0X@3>0:X0E`0002@0000A0@00l00001<1003l0000
0P000<d0/`3<0;`0E`0002@0000?0@0020400101000D0@000P000</0a@3:0<h0E`0002@0000<0@00
804000d1000/0@000P000<T0e`380>00E`0002@000090@00>04000/100120@000P000<L0j@360?40
E`0002@000050@00CP4000P1001J0@000P000<D0nP3300<1E`0002@000030@00IP4000@1001b0@00
0P000<80307101D1E`0002@000010@00OP40004100220@000P000<007P7002419@0000`000050000
:00000`0000100009@0000`000000020:00000`0000400009P0001`0000400001@00000000000000
oooo0RD0000<0000100002D0000<00001000P5H0000`0000J@000>H0001i0000o00000D0001F0:`0
FP2l05D0]P1>0;X0EP2/02D0000<00001@0002P0000<0000100002H0000L00001000000000010000
0@000000008U0000300000@0001G0000<00006T0003V0000N@000?`000050000EP2/05X0_01E0;H0
CP2j05H0[00U0000300000D0000X0000300000@0000V0000700000@0000000000P00008000000002
9@0000`000040000E`0002@0001N0000l@0007@0002?0@000P0004H0:P5E0;D09@0000`000050000
:00000`0000400009P0001`0000400001@00000000000000oooo0RD0000<0000100005H0000`0000
h`000?`0003g0000404000D0002h0;`0/@3;0;40``2Y0<80^02l02D0000<00001@0002P0000<0000
100002H0000L000010000000000100000@000000008U0000300000@0001G0000<0000><0003l0000
m`00010100050000^02l0;40b`2a0<<0Z@320;P0_00U0000300000D0000X0000300000@0000V0000
700000@0000000000P000080000000029@0000`000040000E`0002@0001N000010400>h0002?0@00
0P0004H0:P6a0<<09@0000`000050000:00000`0000400009P0001`0000400001@00000000000000
oooo0RD0000<0000100005H0000`0000k@0007h100010@00SP4000D0003002<1/@0Z0KH0906a01h1
`00S0BD0000<00001@0002P0000<0000100002H0000L000010000000000100000@000000008U0000
300000@0001G0000<0000>d0001n0@000@4008h100050000`00S0K40:P6f02@1/@0N0L008`4U0000
300000D0000X0000300000@0000V0000700000@0000000000P000080000000029@0000`000040000
E`0002@0001O0000Q@400?H0002?0@000P0004L0:P6g02@19@0000`000050000:00000`000040000
9P0001`0000400001@00000000000000oooo0RD0000<0000100005H0000`00006P400340000X0@00
A`0000D0003K02@0g@0d0=T0;P3B0340f`0T02D0000<00001@0002P0000<0000100002H0000L0000
10000000000100000@000000008U0000300000@0001G0000<00001X1000a0000:04004L000050000
f`0T0=d0=03I02h0dP0a0=/0900U0000300000D0000X0000300000@0000V0000700000@000000000
0P000080000000029@0000`000040000E`0002@0000J0@00?00002@1001P00000P000=<0AP3I02d0
9@0000`000050000:00000`0000400009P0001`0000400001@00000000000000oooo0RD0000<0000
100002D0000<00000000P2/0000H0000f000010000000@009@0001P0000<000000000RD0000<0000
0`0002P0000<00000P000580001<0@000P000>koool0000000000000002@0@0000000000039D06T0
K@1U07<0801>06D0M`0P0580K`1]0640KP000000001o0P000000080200000000P@80000000220P00
000008<200000000Q080000000250P00000008H200000000Q`80000000280P00000008T200000000
RP800000002;0P00000008`200000000S@800000002>0P00000008l200000000T0800000002A0P00
0000098200000000T`800000002D0P00000009D200000000UP800000002G0P00000009P200000000
V@800000002J0P00000000000000000000000000000000000@410@410@410@009@0000`000020000
E0000600000R0@005`0003l1000a00000@0005Be34;Ka`a2f000010000030000C000000000000000
0000000000000000E00001<P801T00002@0000@0000900009@0000`000030000:00000`000020000
DP0004`100020000k_ooo`000000000000000;`2000000000000<U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^000000000;T200000000^P800000002k0P0000000;`200000000_@800000002n0P00
00000;l200000000`080000000310P0000000<8200000000``80000000340P0000000<D200000000
aP80000000370P0000000<P200000000b@800000003:0P0000000</200000000c0800000003=0P00
00000<h200000000c`800000003@0P0000000=4200000000dP800000003C0P0000000=@200000000
00000000000000000000000000010@410@410@41000U000030000080001D0000E0000401000G0000
D040030000010000E;D<@]_734;_000040000040001<0000000000000000000000000000001@0000
DP0000d0000U0000300000D0000X0000300000@0000V0000700000@0000000000P00008000000002
9@0000`000040000E`0002@000040@00W00000h1002V00000P000<<0M@3907/0E`0002@000040@00
W00000h1002V00000P000<<0N`3907D09@0000`000050000:00000`0000400009P0001`000040000
1@00000000000000oooo0RD0000<0000100002D0000<00001000P5H0000`00005`4005l0000L0@00
K00000D0003B04H0d01?0=80D03D04L0dP1605H0000`0000404007D0000G0@00PP0000D0003>05L0
b`1P0<d0H@3@05P0cP1G05H0000`00002`4008d0000@0@00VP0000D0003906T0a`1b0<T0L`3;06X0
b@1Y02D0000<00000000P2/0000H0000@P400=X0001[0@00k`0002D0000<00000`0002P0000<0000
0P000580001<0@000P000>koool0000000000000002@0@0000000000039D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP000283000000008`<00000000T0`00000002D30000000000000000000W0`00
000002P300000000:@<00000000Z0`00000002/300000000;0<00000000]0`00000002h300000000
;`<00000000`0`000000034300000000<P<00000000c0`00000003@300000000=@<0000000000000
000003L300000000>0<00000000i0`00000003X300000000>`<00000000l0`00000003d300000000
000000000000000000000000000000000@410@410@410@009@0000`000020000E00005P0002_0@00
90400<01000n0@000@0005Be34;Ka`a2@P400=X000020000C0000000000000000000000000000000
D00001<P80090000100002D0000<00000`0002P0000<00000P000580001<0@000P000>koool00000
00000000002@0@0000000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP0005/300000000
G0<00000001M0`00000005h30000000000000000001P0`000000064300000000HP<00000001S0`00
000006@300000000I@<00000001V0`00000006L300000000J0<00000001Y0`00000006X300000000
J`<00000001/0`00000006d300000000KP<00000000000000000070300000000L@<00000001b0`00
000007<300000000M0<00000001e0`00000007H30000000000000000000000000000000000000000
0@410@410@410@009@0000`000020000E00005@000320@0090400<d1000n0@000@0005Be34;Ka`a2
D0400=X000010000C0000000000000000000000000000000D00006@0000900009@0000`000030000
:00000`000020000DP0004`100020000k_ooo`000000000000000;`2000000000000<U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^0000000009@300000000U@<00000002F0`00000009L300000000
V0<00000002I0`00000009X300000000V`<00000002L0`00000009d300000000WP<00000002O0`00
00000:0300000000X@<00000002R0`0000000:<300000000Y0<00000002U0`0000000:H300000000
Y`<00000002X0`0000000:T300000000ZP<00000002[0`0000000:`300000000[@<00000002^0`00
00000:l30000000000000000000000000000000000010@410@410@41000U000030000080001D0000
E0000<h1000T0@00h04003d100010000E;D<@]_7349I0@00fP000040001<00000000000000000000
00000000001@0000D@0000h0000U0000300000@0081F0000<00009P1000X0@00[04003`100050000
@07/0341iP0i0ND0>P7M0401k00U0000300000D0000X0000300000@0000V0000700000@000000000
0@000040000000029@0000`000040000E`000300002H0@00:0400:`1000l0@001@000401k00a0NH0
>@7U03X1g@100N`09@0000`000050000:00000`0000400009P0001`0000400000000008000020000
00000RD0000<0000100005L0000T0000O`400101002T0@00<`400080000O0L`0>@7U05L0000T0000
E`400>P0001P0@00lP00008000010Jh01P6d05L0000T0000E`400>P0001P0@00lP00008000010K@0
1P6^02D0000<00001@0002P0000<0000100002H0000L0000100000D00000000000000?ooo`8U0000
300000@0001F0000<00005/1003^0000IP400?P0000500001@6b00/1^0090KT00`6c00D1/P1F0000
<00006`1003n0000M`4000T1000500004P6n01P1a@0F0LH0406o0181_P1F0000<00007h1000@0@00
P`4001@1000500007`7;0241c@0O0Lh07@7<01l1b`1F0000<0000<8100360000e`400=D000050000
H06N0501W`1F0I/0D`6D0601WP0U0000300000D0000X0000300000@0000V0000700000@000000000
0@000040000000029@0000`000040000E`00030000320@00aP000=L1003E00001@000601WP1@0Il0
EP6K05<1U01P0Ih09@0000`000050000:00000`0000400009P0001`0000400000000008000020000
00000RD0000<0000100005L0000T0000GP400:d0003<0@00d@00008000060H80E`6K02D0000<0000
1@0002P0000<0000100002H0000L0000100000D00000000000000?ooo`8U0000300000@0000U0000
30000000080[0000600006<1002H0000TP400:d0000U0000300000<0000X000030000080001B0000
C0400080003^oooo0000000000000000T04000000000000bE01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h0000n0000000003l000000000@0000000001100000000000000000000@`00000000140000
000004D000000000AP00000000170000000004P000000000B@000000001:0000000004/000000000
C0000000001=0000000004h000000000C`000000001@0000000005400000000000000000001C0000
000005@000000000E@000000001F0000000005L000000000F0000000001I00000000000000000000
0000000000000000000000410@410@410@4002D0000<00000P0005@0001P0000f`400<`0003h0@00
iP000040001D]@a2flL<@V<1002H00000`0004`0000000000000000000000000000005@0000C8200
I00000T0000400002@0002D0000<00000`0002P0000<00000P000580001<0@000P000>koool00000
00000000002l0P0000000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP0007P000000000
N@000000001j0000000007/00000000000000000001m0000000007h000000000O`00000000200000
0000084000000000PP00000000230000000008@000000000Q@00000000260000000008L000000000
R000000000290000000008X000000000R`00000000000000000008d000000000SP000000002?0000
0000090000000000T@000000002B0000000009<00000000000000000000000000000000000000000
0@410@410@410@009@0000`000020000E00005@0003j0@00c00000P2003U00000@0005Be34;Ka`a2
NP4009P000010000C0000000000000000000000000000000D0000500000;00009@0000`000050000
:00000`0000400009P0001`000040000000000800002000000000RD0000<0000100005L0000T0000
FP400:T0001S0@00/`00008000030Gl0206505L0000T0000FP400:T0001S0@00/`00008000030HD0
205o02D0000<00001@0002P0000<0000100002H0000L0000100000D00000000000000?ooo`8U0000
300000@0000[00006000010000320000:P000=L0000U0000300000<0000X000030000080001B0000
C0400080003^oooo0000000000000000T04000000000000bE01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h000000000c@000000003>000000000<l000000000d0000000003A000000000=8000000000
d`000000003D000000000=D000000000eP000000003G000000000=P000000000f@000000003J0000
00000=/000000000g0000000003M000000000=h000000000g`000000003P000000000>4000000000
hP000000003S000000000>@000000000i@000000003V000000000>L000000000j000000000000000
0000000000000000000000410@410@410@4002D0000<00000P0005@0001D00005`0000@1000R0000
7P400040001D]@a2flL<@Q00003200000@0004`000000000000000000000000000000500001T0000
2@0002D0000<00000`0002P0000<00000P000580001<0@000P000>koool0000000000000002l0P00
00000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP0000D1000000001P40000000070@00
000000P10000000000000000000:0@00000000/10000000030400000000=0@00000000h100000000
3`400000000@0@0000000141000000004P400000000C0@00000001@1000000005@400000000F0@00
000001L1000000006040000000000000000001X1000000006`400000000L0@00000001d100000000
7P400000000O0@000000020100000000000000000000000000000000000000000@410@410@410@00
9@0000`000020000E00005@0000S000010400340000M0@000@0005Be34;Ka`a26@000<8000010000
C0000000000000000000000000000000D0000500000;00009@0000`000040020EP000300000m0000
0P4005<0000A0@001@0002d0`P0m0<40=`3503X0c00]0<809@0000`000050000:00000`000040000
9P0001`000040000000000400001000000000RD0000<0000100005L0000`0000?@000081001C0000
4@4000D0000]0<80?@3103L0a@0j0<`0;@3202D0000<00001@0002P0000<0000100002H0000L0000
10000000000200000P000000008U0000300000@0001G0000900004P000070@00L00001D100020000
=P350580cP1G000090000;80000T0@00^P0002h100020000Q@3K08X0h@1G000090000;80000T0@00
^P0002h100020000Q@3Q08X0f`0U0000300000D0000X0000300000@0000V0000700000@000050000
00000000003oool29@0000`000040000EP000300001_0000504007d0000I0@001@0005@0cP1M0=40
F`3B0580c`1D0<h0EP000300002500006P4009@0000P0@001@0006D0d`1^0=H0K03G06<0e01U0=<0
EP000300002L00008P400:/0000V0@001@0007H0f@1o0=/0O@3L07@0fP1f0=T0EP000300002c0000
:@400;T0000/0@001@0008L0gP2:0=l0R03P08D0g`270=h09@0000`000050000:00000`000040000
9P0001`000040000000000400001000000000RD0000<0000100005L0000T0000]@000:d0001N0@00
:@40008000270=h01@6105L0000T0000/`000>d0001L0@00k@00008000250;40106a05L0000T0000
o@000:4000090@00?P400080002m0>h0aP1h0280000<0000ooooobP0000<0000100002P0000<0000
0P0002P0000<00001@0002P0000<00000`0004/0000@0000000000D0000>000050000000000@0000
5000
\>"], "Graphics",
  Editable->False,
  ImageSize->{282, 241.938},
  ImageMargins->{{276, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Proof of the symmetry of the stress tensor (",
  Cell[BoxData[
      RowBox[{" ", 
        FormBox[
          TagBox[
            StyleBox[
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            StyleForm[ 
                            i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False], 
                          StyleForm[ 
                            StyleForm[ 
                            j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False], 
                        StyleForm[ 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False]], 
                      SequenceForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        
                        StyleForm[ 
                        j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
                    Editable->False],
                  "TraditionalForm"], "==", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            StyleForm[ 
                            j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False], 
                          StyleForm[ 
                            StyleForm[ 
                            i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False], 
                        StyleForm[ 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False]], 
                      SequenceForm[ 
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        
                        StyleForm[ 
                        i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
                    Editable->False],
                  "TraditionalForm"]}],
              FontFamily->"Courier",
              FontSize->16],
            (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)],
          "TraditionalForm"]}]]],
  " ) :"
}], "Subsubsection"],

Cell["The forces acting on the three faces are", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(d\[DoubleStruckCapitalP] := \[Sigma]uu[red@l, red@m] dbu[red@v] 
        dcu[red@w] 
        eddd[red@l, red@v, red@w] \[DoubleStruckE]d[
          red@m]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckCapitalQ] := \[Sigma]uu[red@l, red@m] dcu[red@w] 
        dau[red@u] 
        eddd[red@l, red@w, red@u] \[DoubleStruckE]d[
          red@m]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckCapitalR] := \[Sigma]uu[red@l, red@m] dau[red@u] 
        dbu[red@v] 
        eddd[red@l, red@u, red@v] \[DoubleStruckE]d[
          red@m]\), "\[IndentingNewLine]", 
    \({d\[DoubleStruckCapitalP], d\[DoubleStruckCapitalQ], 
      d\[DoubleStruckCapitalR]}\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["db", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ v], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["v",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ v]],
                        Editable->False]],
                    Subsuperscript[ db, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ v], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ v]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["dc", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ w], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["w",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ w]],
                        Editable->False]],
                    Subsuperscript[ dc, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ w], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ w]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["v",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["w",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ v], 
                          red[ w]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["v",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["w",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ l], 
                        red[ v], 
                        red[ w]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ v], ShowContents -> False], 
                        StyleForm[ 
                          red[ w], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["m",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ m]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        red[ m]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ m], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["da", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ u], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["u",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ u]],
                        Editable->False]],
                    Subsuperscript[ da, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ u]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["dc", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ w], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["w",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ w]],
                        Editable->False]],
                    Subsuperscript[ dc, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ w], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ w]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["w",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["u",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ w], 
                          red[ u]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["w",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["u",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ l], 
                        red[ w], 
                        red[ u]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ w], ShowContents -> False], 
                        StyleForm[ 
                          red[ u], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["m",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ m]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        red[ m]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ m], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["da", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ u], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["u",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ u]],
                        Editable->False]],
                    Subsuperscript[ da, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ u]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["db", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ v], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["v",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ v]],
                        Editable->False]],
                    Subsuperscript[ db, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ v], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ v]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["u",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["v",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ u], 
                          red[ v]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["u",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["v",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ l], 
                        red[ u], 
                        red[ v]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ u], ShowContents -> False], 
                        StyleForm[ 
                          red[ v], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["m",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ m]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        red[ m]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ m], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]]],
                    Editable->False],
                  "TraditionalForm"]}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
On the opposite faces of the parallelepipedon, there are equal and opposite \
forces and, together, they form three couples, which have the moments\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({d\[DoubleStruckA] = dau[red@u]\ \[DoubleStruckE]d[red@u], 
      d\[DoubleStruckB] = dbu[red@v]\ \[DoubleStruckE]d[red@v], 
      d\[DoubleStruckC] = dcu[red@w]\ \[DoubleStruckE]d[red@w]}\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["da", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ u], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["u",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ u]],
                        Editable->False]],
                    Subsuperscript[ da, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ u]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["u",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ u]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ u], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        red[ u]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["db", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ v], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["v",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ v]],
                        Editable->False]],
                    Subsuperscript[ db, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ v], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ v]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["v",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ v]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ v], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        red[ v]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ v], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["dc", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ w], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["w",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ w]],
                        Editable->False]],
                    Subsuperscript[ dc, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ w], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ w]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["w",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ w]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ w], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        red[ w]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ w], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mset = {\(d\[DoubleStruckA]\[Cross]
              d\[DoubleStruckCapitalP] // \(LinearBreakout[
                Cross]\)[\[DoubleStruckE]d[_]]\) // 
          CrossProductExpansion[\[DoubleStruckE], e, 
            k], \[IndentingNewLine]\(d\[DoubleStruckB]\[Cross]
              d\[DoubleStruckCapitalQ] // \(LinearBreakout[
                Cross]\)[\[DoubleStruckE]d[_]]\) // 
          CrossProductExpansion[\[DoubleStruckE], e, 
            k], \[IndentingNewLine]\(d\[DoubleStruckC]\[Cross]
              d\[DoubleStruckCapitalR] // \(LinearBreakout[
                Cross]\)[\[DoubleStruckE]d[_]]\) // 
          CrossProductExpansion[\[DoubleStruckE], e, k]}\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["da", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ u], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["u",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ u]],
                        Editable->False]],
                    Subsuperscript[ da, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ u]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["db", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ v], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["v",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ v]],
                        Editable->False]],
                    Subsuperscript[ db, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ v], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ v]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["dc", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ w], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["w",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ w]],
                        Editable->False]],
                    Subsuperscript[ dc, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ w], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ w]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["v",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["w",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ v], 
                          red[ w]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["v",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["w",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ l], 
                        red[ v], 
                        red[ w]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ v], ShowContents -> False], 
                        StyleForm[ 
                          red[ w], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["u",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ u], 
                          red[ m], 
                          red[ k]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["u",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["k",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ u], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          StyleForm[ 
                            red[ k], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ u], 
                        red[ m], 
                        red[ k]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False], 
                        StyleForm[ 
                          red[ k], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ k], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ k]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ k], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ k]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["da", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ u], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["u",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ u]],
                        Editable->False]],
                    Subsuperscript[ da, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ u]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["db", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ v], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["v",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ v]],
                        Editable->False]],
                    Subsuperscript[ db, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ v], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ v]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["dc", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ w], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["w",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ w]],
                        Editable->False]],
                    Subsuperscript[ dc, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ w], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ w]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["w",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["u",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ w], 
                          red[ u]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["w",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["u",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ l], 
                        red[ w], 
                        red[ u]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ w], ShowContents -> False], 
                        StyleForm[ 
                          red[ u], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["v",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ v], 
                          red[ m], 
                          red[ k]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["v",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["k",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ v], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          StyleForm[ 
                            red[ k], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ v], 
                        red[ m], 
                        red[ k]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ v], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False], 
                        StyleForm[ 
                          red[ k], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ k], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ k]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ k], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ k]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["da", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ u], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["u",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ u]],
                        Editable->False]],
                    Subsuperscript[ da, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ u]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["db", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ v], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["v",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ v]],
                        Editable->False]],
                    Subsuperscript[ db, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ v], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ v]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["dc", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ w], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["w",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ w]],
                        Editable->False]],
                    Subsuperscript[ dc, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ w], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ w]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["u",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["v",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ u], 
                          red[ v]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["u",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["v",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ l], 
                        red[ u], 
                        red[ v]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ u], ShowContents -> False], 
                        StyleForm[ 
                          red[ v], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["w",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ w], 
                          red[ m], 
                          red[ k]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["w",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["k",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ w], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          StyleForm[ 
                            red[ k], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ w], 
                        red[ m], 
                        red[ k]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ w], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False], 
                        StyleForm[ 
                          red[ k], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ k], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ k]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ k], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ k]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]]],
                    Editable->False],
                  "TraditionalForm"]}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The sum of the three above moments must be zero at equilibrium.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Apply[Plus, Mset] // LeviCivitaSimplify[e]\) // Factor\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{"-", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["da", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["u",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["u",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ u]],
                      Editable->False]],
                  Subsuperscript[ da, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ u], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ u]]],
                  Editable->False],
                "TraditionalForm"]}], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["db", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["v",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ v], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["v",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ v]],
                    Editable->False]],
                Subsuperscript[ db, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ v], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ v]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["dc", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["w",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ w], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["w",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ w]],
                    Editable->False]],
                Subsuperscript[ dc, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ w], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ w]]],
                Editable->False],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ k], 
                            red[ m], 
                            red[ w]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["k",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["w",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ k], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            StyleForm[ 
                              red[ w], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ k], 
                          red[ m], 
                          red[ w]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ k], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["l",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ l], 
                            red[ u], 
                            red[ v]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["u",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["v",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ u], ShowContents -> False], 
                            StyleForm[ 
                              red[ v], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ l], 
                          red[ u], 
                          red[ v]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ k], 
                            red[ m], 
                            red[ v]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["k",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["v",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ k], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            StyleForm[ 
                              red[ v], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ k], 
                          red[ m], 
                          red[ v]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ k], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["l",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ l], 
                            red[ u], 
                            red[ w]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["u",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["w",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ u], ShowContents -> False], 
                            StyleForm[ 
                              red[ w], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ l], 
                          red[ u], 
                          red[ w]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ k], 
                            red[ m], 
                            red[ u]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["k",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["u",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ k], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            StyleForm[ 
                              red[ u], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ k], 
                          red[ m], 
                          red[ u]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ k], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["l",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ l], 
                            red[ v], 
                            red[ w]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["v",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["w",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ v], ShowContents -> False], 
                            StyleForm[ 
                              red[ w], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ l], 
                          red[ v], 
                          red[ w]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}]}], ")"}], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckE]", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ k], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ k]],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckE], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ k], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ k]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ l], ShowContents -> False], 
                      StyleForm[ 
                        red[ m], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ l], 
                      red[ m]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ l], ShowContents -> False], 
                    StyleForm[ 
                      red[ m], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ l], 
                    red[ m]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "so that each component of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox["\[DoubleStruckE]",
            FontSize->18,
            FontWeight->"Plain"], 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["k",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ k], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["k",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ k]],
            Editable->False]], TraditionalForm]]],
  " is zero."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Coefficient[%, \[DoubleStruckE]u[red@k]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{"-", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["da", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["u",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ u], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["u",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ u]],
                      Editable->False]],
                  Subsuperscript[ da, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ u], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ u]]],
                  Editable->False],
                "TraditionalForm"]}], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["db", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["v",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ v], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["v",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ v]],
                    Editable->False]],
                Subsuperscript[ db, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ v], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ v]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["dc", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["w",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ w], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["w",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ w]],
                    Editable->False]],
                Subsuperscript[ dc, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ w], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ w]]],
                Editable->False],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ k], 
                            red[ m], 
                            red[ w]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["k",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["w",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ k], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            StyleForm[ 
                              red[ w], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ k], 
                          red[ m], 
                          red[ w]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ k], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["l",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ l], 
                            red[ u], 
                            red[ v]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["u",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["v",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ u], ShowContents -> False], 
                            StyleForm[ 
                              red[ v], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ l], 
                          red[ u], 
                          red[ v]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "-", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ k], 
                            red[ m], 
                            red[ v]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["k",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["v",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ k], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            StyleForm[ 
                              red[ v], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ k], 
                          red[ m], 
                          red[ v]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ k], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["l",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ l], 
                            red[ u], 
                            red[ w]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["u",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["w",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ u], ShowContents -> False], 
                            StyleForm[ 
                              red[ w], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ l], 
                          red[ u], 
                          red[ w]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["u",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ k], 
                            red[ m], 
                            red[ u]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["k",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["u",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ k], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            StyleForm[ 
                              red[ u], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ k], 
                          red[ m], 
                          red[ u]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ k], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          StyleForm[ 
                            red[ u], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["e", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["l",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["v",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["w",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ l], 
                            red[ v], 
                            red[ w]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["v",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["w",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ v], ShowContents -> False], 
                            StyleForm[ 
                              red[ w], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ e, 
                        SequenceForm[ 
                          red[ l], 
                          red[ v], 
                          red[ w]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ v], ShowContents -> False], 
                          StyleForm[ 
                            red[ w], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}]}], ")"}], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ l], ShowContents -> False], 
                      StyleForm[ 
                        red[ m], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ l], 
                      red[ m]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ l], ShowContents -> False], 
                    StyleForm[ 
                      red[ m], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ l], 
                    red[ m]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
we take here the vector d\[DoubleStruckA], d\[DoubleStruckB], d\
\[DoubleStruckC] along the basis vectors as above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Coefficient[% /. {red@u -> red@1, red@v -> red@2, red@w -> red@3}, 
      dau[red@1] dbu[red@2] dcu[red@3]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["e", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["k",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ k], 
                              red[ m], 
                              red[ 3]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["k",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["3",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ k], ShowContents -> False], 
                              StyleForm[ 
                                red[ m], ShowContents -> False], 
                              StyleForm[ 
                                red[ 3], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ e, 
                          SequenceForm[ 
                            red[ k], 
                            red[ m], 
                            red[ 3]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ k], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], " ", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["e", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ l], 
                              red[ 1], 
                              red[ 2]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["1",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["2",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ l], ShowContents -> False], 
                              StyleForm[ 
                                red[ 1], ShowContents -> False], 
                              StyleForm[ 
                                red[ 2], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ e, 
                          SequenceForm[ 
                            red[ l], 
                            red[ 1], 
                            red[ 2]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ 1], ShowContents -> False], 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], "-", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["e", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["k",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ k], 
                              red[ m], 
                              red[ 2]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["k",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["2",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ k], ShowContents -> False], 
                              StyleForm[ 
                                red[ m], ShowContents -> False], 
                              StyleForm[ 
                                red[ 2], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ e, 
                          SequenceForm[ 
                            red[ k], 
                            red[ m], 
                            red[ 2]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ k], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], " ", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["e", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ l], 
                              red[ 1], 
                              red[ 3]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["1",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["3",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ l], ShowContents -> False], 
                              StyleForm[ 
                                red[ 1], ShowContents -> False], 
                              StyleForm[ 
                                red[ 3], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ e, 
                          SequenceForm[ 
                            red[ l], 
                            red[ 1], 
                            red[ 3]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ 1], ShowContents -> False], 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], "+", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["e", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["k",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ k], 
                              red[ m], 
                              red[ 1]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["k",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["1",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ k], ShowContents -> False], 
                              StyleForm[ 
                                red[ m], ShowContents -> False], 
                              StyleForm[ 
                                red[ 1], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ e, 
                          SequenceForm[ 
                            red[ k], 
                            red[ m], 
                            red[ 1]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ k], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], " ", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["e", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ l], 
                              red[ 2], 
                              red[ 3]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["2",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["3",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ l], ShowContents -> False], 
                              StyleForm[ 
                                red[ 2], ShowContents -> False], 
                              StyleForm[ 
                                red[ 3], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ e, 
                          SequenceForm[ 
                            red[ l], 
                            red[ 2], 
                            red[ 3]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ 2], ShowContents -> False], 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}]}], ")"}]}], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ l], ShowContents -> False], 
                      StyleForm[ 
                        red[ m], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ l], 
                      red[ m]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ l], ShowContents -> False], 
                    StyleForm[ 
                      red[ m], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ l], 
                    red[ m]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["and in the case k = 1.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\((\(% /. {red@k -> red@1} // Expand\) // 
          EinsteinSum[])\);\)\), "\[IndentingNewLine]", 
    \(\(% /. \(LeviCivitaRule[e, \[Epsilon]]\)[\[ScriptG], red]\) /. 
        PermutationSymbolRule[\[Epsilon]] // Factor\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ 2], 
                          red[ 3]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 2], ShowContents -> False], 
                        StyleForm[ 
                          red[ 3], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ 2], 
                        red[ 3]]],
                    Editable->False],
                  "TraditionalForm"], "-", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False], 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ 3], 
                          red[ 2]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 3], ShowContents -> False], 
                        StyleForm[ 
                          red[ 2], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ 3], 
                        red[ 2]]],
                    Editable->False],
                  "TraditionalForm"]}], ")"}], " ", \(\[ScriptG](red)\)}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(The\ same\ proof\ can\ be\ done\ also\ for\ k = 
      2\ and\ 3. \ So\ that, \(\(in\)\(\ \)\(all\)\(\ \)\(generality\)\(\ \
\)\)\)], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\ \[Sigma]uu[red@i, red@j] == \[Sigma]uu[red@j, 
          red@i]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Sigma]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              StyleForm[ 
                                red[ j], ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ i], 
                              red[ j]],
                            Editable->False]],
                        Subsuperscript[ \[Sigma], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              red[ j], ShowContents -> False]], 
                          SequenceForm[ 
                            red[ i], 
                            red[ j]]],
                        Editable->False],
                      "TraditionalForm"], "==", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Sigma]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ j], ShowContents -> False], 
                              StyleForm[ 
                                red[ i], ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ j], 
                              red[ i]],
                            Editable->False]],
                        Subsuperscript[ \[Sigma], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ j], ShowContents -> False], 
                            StyleForm[ 
                              red[ i], ShowContents -> False]], 
                          SequenceForm[ 
                            red[ j], 
                            red[ i]]],
                        Editable->False],
                      "TraditionalForm"]}], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "2", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  Equal[ 
                    Tensor[ \[Sigma], {
                      red[ i], 
                      red[ j]}, {Void, Void}], 
                    Tensor[ \[Sigma], {
                      red[ j], 
                      red[ i]}, {Void, Void}]], "      (4.", 2, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{
      "We", " ", "can", " ", "visualize", " ", "the", " ", "different", 
        " ", \(components . For\), " ", "instance", " ", "on", " ", "an", " ",
         "area", " ", "formed", " ", "by", 
        FormBox[
          StyleBox[
            SubsuperscriptBox["\[DoubleStruckE]", 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["1",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ 1]],
                Editable->False], 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["1",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ 1], ShowContents -> False]],
                Editable->False]],
            FontWeight->"Bold"],
          "TraditionalForm"], "and", 
        FormBox[
          StyleBox[
            SubsuperscriptBox["\[DoubleStruckE]", 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["2",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ 2]],
                Editable->False], 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["2",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ 2], ShowContents -> False]],
                Editable->False]],
            FontWeight->"Bold"],
          "TraditionalForm"]}], ","}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(d\[DoubleStruckCapitalA] := \(\(\((\[DoubleStruckE]d[
                    red@1]\[Cross]\[DoubleStruckE]d[
                    red@2] // \(LinearBreakout[
                    Cross]\)[\[DoubleStruckE]d[_]])\) // 
            CrossProductExpansion[\[DoubleStruckE], e, k]\) // 
          ArrayExpansion[red@k]\) // 
        LeviCivitaSimplify[e]\), "\[IndentingNewLine]", 
    \(dA3rule = 
      Table[d\[ScriptCapitalA]d[red@i] \[Rule] 
          Coefficient[
            d\[DoubleStruckCapitalA][\([i]\)], \[DoubleStruckE]u[red@i]], {i, 
          3}]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["d\[ScriptCapitalA]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["1",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ 1]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ d\[ScriptCapitalA], 
                      SequenceForm[ 
                        red[ 1]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 1], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["d\[ScriptCapitalA]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["2",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ 2]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ d\[ScriptCapitalA], 
                      SequenceForm[ 
                        red[ 2]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 2], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["d\[ScriptCapitalA]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["3",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ 3]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ d\[ScriptCapitalA], 
                      SequenceForm[ 
                        red[ 3]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 3], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["e", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ 1], 
                          red[ 2], 
                          red[ 3]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["1",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["2",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["3",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 2], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ e, 
                      SequenceForm[ 
                        red[ 1], 
                        red[ 2], 
                        red[ 3]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 1], ShowContents -> False], 
                        StyleForm[ 
                          red[ 2], ShowContents -> False], 
                        StyleForm[ 
                          red[ 3], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((d\[DoubleStruckCapitalF] // SumExpansion[red@i])\) /. 
      dA3rule\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["e", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["1",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["2",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["3",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ 1], 
                      red[ 2], 
                      red[ 3]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["1",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["2",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 1], ShowContents -> False], 
                      StyleForm[ 
                        red[ 2], ShowContents -> False], 
                      StyleForm[ 
                        red[ 3], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ e, 
                  SequenceForm[ 
                    red[ 1], 
                    red[ 2], 
                    red[ 3]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 1], ShowContents -> False], 
                    StyleForm[ 
                      red[ 2], ShowContents -> False], 
                    StyleForm[ 
                      red[ 3], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckE]", 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckE], 
                  SequenceForm[ 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["3",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 3], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["3",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ 3], 
                      red[ j]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 3], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 3], 
                    red[ j]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Except the factor ",
  Cell[BoxData[
      SqrtBox[
        StyleBox["g",
          FontWeight->"Plain"]]]],
  ", the ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Sigma]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["3",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ 3, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox["3",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox["j",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
            SequenceForm[ 
              StyleForm[ 3, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
            Editable->False]], TraditionalForm]]],
  " are the contravariant components of ",
  StyleBox["d\[DoubleStruckCapitalF]",
    FontWeight->"Bold"],
  " acting on the parallelogram formed by",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      SubsuperscriptBox[
        StyleBox[
          FormBox["\[DoubleStruckE]",
            "TraditionalForm"],
          "Text"], 
        InterpretationBox[
          TagBox[
            StyleBox["1",
              FontColor->RGBColor[1, 0, 0]],
            (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
          SequenceForm[ 
            StyleForm[ 1, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
          Editable->False], 
        InterpretationBox[
          TagBox[
            StyleBox[
              TagBox[
                StyleBox["1",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              ShowContents->False],
            (StyleForm[ #, ShowContents -> False]&)],
          SequenceForm[ 
            StyleForm[ 
              StyleForm[ 1, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              ShowContents -> False]],
          Editable->False]]],
    FontWeight->"Bold"],
  " and ",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      SubsuperscriptBox[
        FormBox["\[DoubleStruckE]",
          "TraditionalForm"], 
        InterpretationBox[
          TagBox[
            StyleBox["2",
              FontColor->RGBColor[1, 0, 0]],
            (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
          SequenceForm[ 
            StyleForm[ 2, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
          Editable->False], 
        InterpretationBox[
          TagBox[
            StyleBox[
              TagBox[
                StyleBox["2",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              ShowContents->False],
            (StyleForm[ #, ShowContents -> False]&)],
          SequenceForm[ 
            StyleForm[ 
              StyleForm[ 2, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              ShowContents -> False]],
          Editable->False]]],
    FontWeight->"Bold"]
}], "Text",
  Background->RGBColor[1, 0.700008, 0.700008]],

Cell["\<\
It is naturally possible to define the other components of the stresses. The \
stress components shown above are the most appealing.\
\>", "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PICT", "\<\
?1P0MP3S0Hl2Q@0A0_l<0?ooool0h`0007H000:50001S`000000000N00402P1f
0><1S`:509X0003oQXP0MP3S0Hl2Q@0000@0000004P000180000400P00<02000
0005o9i/1ObN_01f0><1S`:507H0h`6?0XD0000DPOn1oh7oPOn1oh7oPOn1oh7o
Vol0587oPOn1oh7oPOn1oh7oPOn1oi_o01B1oh7oPOn1oh7oPOn1oh7oPOnKo`0D
POn1oh7oPOn1oh7oPOn1oh7oVol0587oPOn1oh7oPOn1oh7oPOn1oi_o01B1oh7o
POn1oh7oPOn1oh7oPOnKo`0DPOn1oh7oPOn1oh7oPOn1oh7oVol0587oPOn1oh7o
POn1oh7oPOn1oi_o01B1oh7oPOn1oh7oPOn1oh7oPOnKo`0DPOn1oh7oPOn1oh7o
POn1oh7oVol0587oPOn1oh7oPOn1oh7oPOn1oi_o01B1oh7oPOn1oh7oPOn1oh7o
POnKo`0DPOn1oh7oPOn1oh7oPOn1oh7oVol0587oPOn1oh7oPOn1oh7oPOn1oi_o
01B1oh7oPOn1oh7oPOn1oh7oPOnKo`0DPOn1oh7oPOn1oh7oPOn1oh7oVol0587o
POn1oh7oPOn1oh7oPOn1oi_o01B1oh7oPOn1oh7oPOn1oh7oPOnKo`0DPOn1oh7o
POn1oh7oPOn1oh7oVol0587oPOn1oh7oPOn1oh7oPOn1oi_o01B1oh7oPOn1oh7o
POn1oh7oPOnKo`0DPOn1oh7oPOn1oh7oPOn1oh7oVol0587oPOn1oh7oPOn1oh7o
POn1oi_o01B1oh7oPOn1oh7oPOn1oh7oPOnKo`0DPOn1oh7oPOn1oh7oPOn1oh7o
Vol0587oPOn1oh7oPOn1oh7oPOn1oi_o01B1oh7oPOn1oh7oPOn1oh7oPOnKo`0D
POn1oh7oPOn1oh7oPOn1oh7oVol0587oPOn1oh7oPOn1oh7oPOn1oi_o01B1oh7o
POn1oh7oPOn1oh7oPOnKo`0SPOn1ooGo0JT0POn1oh7ohOl1Z@21oh7oPOoQo`6Y
087okOl0?h7oPOl6gHQIOh1c:o`00B:8POn1oh7okOl6gHQIOh1c:o`00B:8POn1
oh7okOl6gHQIOh1c:o`00B:8POo]o`0lPOn2o`?<002koOl3V00bkX7oPOn1on_o
0l`00;_mo`>H03;^POn1oh7ojol3c000^ogo0iP0<^j1on[o03V1oh;o0UD04?_o
0c<00>J1oh7oPOo/o`9E013ko`<c003VPOn1oh7ok?l2E@0@nol3<`00iX7ojol0
E87oPol3^`00/__o0i4006:1oh7oPOo]o`>k002bnol3T@00H_go28`[C>Koc3a<
c87oPOn1oo[o0k/00;;ko`>A001RoOl8S2]<i_o<?4c<POoho`1APOn3o`8b003j
o`?<000IPOn1oh7okOl2<P00n_l3c0006Ogo24coV83o0<bH087oPOn1oo[o0S80
0?[o0l`001Wmo`Q<oiR0o`3<V021ooSo04B1oh?ooP3jo`3VoP21oh7oPOo]ooh0
n_l0i_h0nol1gHSno`7M487oPOn1oo[ooP3jo`3VoP3ko`7MR?ko0Md@POoho`1@
POn>o`20moon003^n_on087oPOn1ooSo083gooh00>kjooh0o?l7iUGQooocEL>1
oh7oQOl0P?OooP00k_[ooP3lo`OVEN7ooo=E`h7on?l0F87oSol1003go`<Q002Y
n_l2000IPOn1oh7onOl1003go`<Q002Yn_l2000IoOl1meGmo`2RPOn1ohCo0@00
mol38@00ZO[o0P006Ogo0OMEoOl0XX7om_l0GX7oT?l2P000mol3IP00EO_o0nh0
04B1oh7oPOojo`:0003go`=V001Enol3kP00A?go0J[^oOl0XX7oPOn5o`:0003g
o`=V001Enol3kP00A?go0J[^oOl0XX7om_l0JH7oTOl0P?h0mol4kR800=Glo`>o
002RPOn1oh7onol0P?h0mol4kR800=Glo`>o002RoOl9GX20HOm4O81<^h7oPOn9
o`20oP3go`C^8P00eOco0kl00:;mo`UNP81QodAlP4bkPOoio`15POnAood0m_l3
/`00C?co0T`0V87oPOn1oo[oo@3fo`>c001<o?l2C02HPOn1oh7on_om0?Ko0k<0
04clo`9<09R1on[o04^1oi;o083m0?Go2JT@05G<olag2;Z1oh7oPOojo`20o@3e
o`VY401Ec?o<M`RjPOn1oh7on_l0P?d0mOl9ZA00ELcoc7L8^X7ojOl0@X7oTol0
P?`0lol6]hR0P92ZjX7oPOn1oo[o083l0??o1[N8P82@Z^Z1oh7oPOojo`20o03c
o`JgR820T:[ZPOoXo`0NPOnDooX0POn1oh7oi_oj087oPOn1onKonP21om?o02B1
oiConP00P87oPOn1onOonP00P87oPOn1onOonP00P87oe?l0:X7oUOl0@?X00821
oh7oPOoXo`10nP00P87oPOn1onSo043j0020POoDo`0]POnFoo/00h000821oh7o
POoYoo/00h000821oh7oPOoYoo/00h000821omCo03b1oiOo0`00P?on00?00020
POn1oh7oj_l30020ooh00l000821oh7oPOoZo`<0083ooP03`000P87oe?l0<87o
Tol6003oo`00P87oPOn1onKo1P00ool00821oh7oPOoVo`H00?oo0020POoDo`0]
POnDooh0o_l10821oh7oPOoWooh0o_l10821oh7oPOoWooh0o_l10821omCo0321
oiCo0P00@?go0821oh7oPOoWo`80043mo`20POn1oh7oiol20010oOl0P87oe?l0
9h7oUOl3P000P87oPOn1on?o0h000821oh7oPOoSo`>00020POo?o`0WPOnEo`>0
0020POn1oh7ohol3P000P87oPOn1on?o0h000821oloo02B1oiGo0T00087oPOn1
on;o0T00087oPOn1on;o0T00087oc_l07X7oUOon087oPOn1on;ooP21oh7oPOoR
ooh0POo>o`0QPOnEo`40087oPOn1on7o0@00POn1oh7ohOl10021olgo01j1oiKo
oP21oh7oPOoRooh0POn1oh7oh_on087ocOl08H7oU_l10021oh7oPOoQo`40087o
POn1on7o0@00POo<o`0NPOnGooh0POn1oh7oh_on087oPOn1on;ooP21olco02B1
oiOo0P00@87oPOn1on;o0P00@87oPOn1on;o0P00@87oc?l09h7oV?l3P000P87o
POn1on?o0h000821oh7oPOoSo`>00020POo<o`0WPOnHo`>00030POn1oh7ohol3
P000`87oPOn1on?o0h000<21olco01j1oiSooP21oh7oPOoRooh0POn1oh7oh_on
087obol07X7oV?on087oPOn1on;ooP21oh7oPOoRooh0POo;o`0TPOnIo`:00021
oh7oPOoRo`:00021oh7oPOoRo`:00021ol[o01j1oiWooP21oh7oPOoRooh0POn1
oh7oh_on087ob_l0:X7oVOl1002no`6Y087oPOnVo`400;ko0JT0POn1ojKo0@00
__l1Z@2>o`15POnJooh0b_l6kXQMJX20BO`00B:8POn1ojOooP3:o`K^R5eZP819
o0018XR1oh7oYoon0<[o1^j8GFZ0P4Wl004RR8ko04F1oi[o0P00P<[o0T`0Mogo
0iP06Nj1oh7oY?l20020b_l2C01goOl3V00IkX7oPOnTo`80083:o`9<07Omo`>H
01W^Rol0B87oVol3P000P<_o0ZT04?_o0fH00>J1oh7oY_l3P000P<_o0ZT04?_o
0fH00>J1oh7oY_l3P000P<_o0ZT04?_o0fH00>J<o`1QPOnKo`>00030c?l3^`00
/__o0oLF06:1oh7oY_l3P000`<co0k/00;;ko`?g5P1RoOl3c3a<c?ko04B1oh7o
/_l3P000`<co0k/00;;ko`?g5P1RoOl3c3a<c?ko04BHo`1BPOnKooh0bol2<P00
nOl2C00IPOn1ojKooP3;o`8b003io`9<01Wmo`<0c9P0o_l0P87oPOnbooh0bol2
<P00nOl2C00IoOl30<bH0?ko082Ho`18POnKooh0boon0?Wo0VH0087oPOnVooh0
boon0?Wo0VH00?_o0Md@o_l0P87oPOnbooh0boon0?Wo0VH00?_o0Md@o_l0P9So
05J1oico0X000<[ooP00k_[o0X00087oPOnWo`:0003:ooh00>kjo`:0003lo`;c
EL?no`20POn1ok?o0X000<[ooP00k_[o0X000?co0_=E`oko082Ho`1?POnLooh0
b_l38@00ZO[o0X006H7oPOnWooh0b_l38@00ZO[o0X006Oco0:;lo`20POn1ok?o
oP3:o`<Q002Yn_l2P00Io?l0X_co082Ho`1BPOnLo`400<Wo0fH005Gjo`9_04B1
oh7oYol10039o`=V001En_l2K`14o?l0X_co0821oh7o/ol10039o`=V001En_l2
K`14o?l0X_co082Ho`1JPOnMooh0bOl4kT@00:[ko`900::1oh7oZ?on0<Wo1>i4
002Znol2@02RoOl8A7b0C;_ood20POn1okGooP39o`C^A000Z__o0T00X_go24Al
P4bkoom0P9Wo06JUo`Nk<P00<XOgooh0Q?l20020aol3<`00c?go0YP0V87o[ol7
^c8003:7moon08Co0P00P<Oo0c<00<cmo`:H09R1ojoo1k/b000bQoOooP24o`80
0837o`<c003<oOl2V02HRol0LZOo0La<n`01=oOn08Go0h00083Dooj0mol9jXQ<
:fJ0O6IE/h7o/?l1c4ck004gmoh0QOl3P000P=CooX3go`WZR4`[IX1lIUFcPOn`
o`7<C?/00COgoP25o`>00020e?onP?Oo2NZ8C2]VP7aVEK>:o`1IZ?l0i_d01GO^
kWL0<_h0QOl2P000dOon0020POnPo`3Vo@05Mnk^M`0boP25o`:0003Aooh00821
oj3o0>Km00Egk^ig03;n08Go0X000=7ooP00P87onOl0D:So09Wn003<oOl0I_d0
QOon0=7o083m087oXOl0VOh00<cmo`1Vo@25ooh0dOl0P?d0POnQo`2IoP00c?go
06Km08GooP3Ao`20o@21oo[o06FXo`=I0020o?l1kR_n08GooP3XP030j_l0P?`0
0H20POnUo`=I0020o?l1kR_n08GooP3XP030j_l0P?`00H20POnUo`=I0020o?l1
kR_n08GooP3XP030j_l0P?`00H20POono`0oZ?l38P00c?_o0:Wn08Go``00P87o
Z?l38P00c?_o0:Wn08Go``00P87oZ?l38P00c?_o0:Wn08Go``00P87o03nXo`<8
003Vnol0gOh0k_n10:@0POoMo`<8003Vnol0gOh0k_n10:@0POoMo`<8003Vnol0
gOh0k_n10:@0]_l0FZSooP3iooh0kol1P821ookoih3i0060P<ko0021omcooP3i
ooh0kol1P821ookoih3i0060P<ko0021omcooP3iooh0kol1P821ookoih3i0060
P<ko002eo`1LZ?on0?WooP3_o`00POoTooX0083;o`00POoLooh0nOon00Gool`R
07Oeo`00POoTooX0083;o`00POoLooh0nOon00Gool`R07Oeo`00POoTooX0083;
o`00]Ol0JjSo0`P00>kko`2joP3_o`00POoUo`20n`3:o`20POoKo`<8003^nol0
^_h00Oo^o@00^oKo0021onGo083k0<[o0821om_o0`P00>kko`2joP01onkm002k
m_l0087oiOl0P?/0b_l0P;Co07JXo`<[002onol0E?h0l?l0P87oiOl0P?h00D20
b?l0P87ofol3:`00_o_o05Cn00KoC6GcT@20mol0P87oiOl0P?h00D20b?l0P87o
fol3:`00_o_o05Cn00KoC6GcT@20mol0P87oiOl0P?h00D20b?l0P;Co06NXo`=_
001_o?l0c?d0l?l0P87oi_om0<Go0821om_o0fl006olo`3<o@01ok[no`40T?Oo
0821onKoo@35o`20POoKo`=_001_o?l0c?d00Onjo_l1093go`20POoVood0aOl0
P;Co06VXo`BI000Ak_go06Km0?3o0821onKo0@00`ol0P87ofol4V@004Nkmo`1V
o@3mo`;M0;_go`20POoVo`400<?o0821om_o19T0017^oOl0I_d0oOl2g@2kmol0
P87oi_l10033o`20]?l0J:So2_M<0008C7Q_?0VZoP3`o`20POnXo`:00821om_o
2_M<0008C7Q_?0VZoP3no`?g?6kkmol0P87oZ?l2P020POoKo`[gC00024ahKc`9
Z_h0o_l3mca^noOo0821ojSo0X00P;Co05RVo`2Yn`01T?on0?7o0021ojSo0h00
0821omWo0:Wk006@ooh0o_l1T8Ofo`00POnXo`>00020POoIo`2Yn`01T?on0?ko
0I27m_l0087oZ?l3P000P;Co05bUo`Zk<P00A9Soo`00<_7o0021ojSooP00P87o
f?l:^c8004BHool003;no`1=mOl0087oZ?on0020POoHo`Zk<P00A9Soo`00<_ko
04geo`00POnXooh0082do`1FW_l3/P00EO;o0L20POnZo`20o@00P87odOl:/P00
EOoVC4B0P53io`70P87oZ_l0P?d00821om7o2[8005GoiTa4P81@nOl1`821oj[o
083m0020]?l0EJSooP3jo`<b002Yl_l0P87oZOol0020POoKooh0n_l4<P00ZOol
001_nOl0P87oZOol0020POoKooh0n_l4<P00ZOol001_nOl0P87oZOol0020]?l0
H:So33<006oDk_o^e68003?ao`20POnZo`10o000P87ofol<<`00KmC^onkDHP00
<o7o0821oj[o043l0020POoKo``c001_e>kok]AR000clOl0P87oZ_l0@?`0082d
o`0lZ?l0Z_H00<cao`20POn[ooT0POoKo`2ZmP00c?7o0821oj_on@21om_o0:[f
003<lOl0P87oZooi0;Co04:Wo`6Y4?X00B7<l?l0P87o[?oh087of_l1ZA3j004Q
c?3o0821ojcon021om[o0JT@nP018Lc`o`20POn/ooP0]?l0E:Go0LBIoX01VLS_
o`00POn/o`10o000@?h0POoHo`74VOj00IW8kol0087o[?l0@?`0043n087of?l1
a9WnP06Ib>oo0021ojco043l0010oP2do`0lS?l0087o[Oon00CoP000P?h0POno
o`00POn]ooh01?n00020oP21okoo0021ojgooP04oh00083n0;Co04:=o`00POn/
o`X0P?ooP000P?l0087o`?l0087o[?l:083ooh00083o0021ol3o0021ojco2P20
oon00020o`00]?l0=Xgo0021ojSo1T000?ooP021ol3o0021ojSo1T000?ooP021
ol3o0021ojSo1T000?ooP02do`0`S_l0P87oYoon0?ko0821ol7o0821ojOooP3n
o`20POo1o`20POnWooh0o_l0P;Co03>>o`20POnWo`400?go0821ol7o0821ojOo
0@00oOl0P87o`Ol0P87oYol1003mo`20]?l098ko0821ojSooP21okco0821ojSo
oP21okco0821ojSooP2_o`0WS_l0P87oZ?l10021ok_o0821ojSo0@00POnko`20
POnXo`400:ko02B>o`20POnYooh0POnko`20POnYooh0POnko`20POnYooh0[_l0
:Xoo0021ojSo0P00@87o_?l0087oZ?l20010POnlo`00POnXo`80042^o`0]Sol0
087oZOl3P000P87o_?l0087oZOl3P000P87o_?l0087oZOl3P000P:ko02f@o`00
POnXo`>00030POnmo`00POnXo`>00030POnmo`00POnXo`>00030[_l0993o0021
ojSooP21okco0021ojSooP21okco0021ojSooP2]o`0TTOl0P87oYoon087o_Ol0
P87oYoon087o_Ol0P87oYoon0:go02ZAo`20POnXo`:00021okco0821ojSo0X00
087o_?l0P87oZ?l2P000[?l0997o0821ojSooP21okco0821ojSooP21okco0821
ojSooP2/o`0WTOl0P87oZ?l10021ok_o0821ojSo0@00POnko`20POnXo`400:_o
04^Bo`60`87oZOl2P000m_l1b9WiP05ETH7odol1P<21ojWo0X000?Ko0LRInH01
EI61om?o0H30POnYo`:0003fo`78VOV00EFA`_l0Ei;o0021ojSo0X00P?So1[X@
8/coc5Gl0054iX7odol0087oZ?l2P020n?l6^Q0Rc?o<EO`00DCVPOoCo`00POnX
o`:0083ho`Jj42;<olaEo001A>K2o`1DT_l0087oZ?l20020nOl3c000^ogo0d`0
<_N1om3o0021ojSo0P00P?Wo0l`00;_mo`=<03;gPOo@o`00POnXo`80083io`?<
002koOl3C00bmkoo06^Co`00POnWo`800<3jo`?g:`1Do?l4e@00=oN1om;o0021
ojOo0P00`?[o0oL[05Clo`CE000gmoco1]fIoooVP<b1omko0021ojOo0P00`?[o
0oL[05Clo`CE000gmoco1]fIoooVP<c<o`1TTol0087oZ?on0?Wo0hL00<cko`=E
0027POoBo`00POnXooh0nOl3Q`00c?_o0eD008Olo`LQ0?ooC5D0c87ogol0087o
Z?on0?Wo0hL00<cko`=E0027o?l78@3oodaE0<c=o`1OU?l0P87oYoon0?Wo0S80
0?[o0iP003:1om?o0821ojOooP3io`8b003jo`>H000bnol60?ooC?nHP87oh?l0
P87oYoon0?Wo0S800?[o0iP003;ko`H0oom<oiR0cOl0FYCo0821ojSo0X000?So
oP3jo`3VoP21om?o0821ojSo0X000?SooP3jo`3VoP3ko`00oOl1VJJ1on3o0821
ojSo0X000?SooP3jo`3VoP3ko`00oOl1VJK=o`1DU?l0P87oZ?on0?SooP00gO[o
oP21om?o0821ojSooP3hooh00=gjooh0nol00?ko0LaEPOoOo`20POnXooh0n?on
003Mn_on0?_o003no`7<ELco06BDo`20POnYo`>00020n?l38@00ZO[o0P00<X7o
dol0P87oZOl3P000P?So0b400:Wjo`8003;ko`@0ooogEH7og_l0P87oZOl3P000
P?So0b400:Wjo`8003;ko`@0ooogEL_o076Eo`60`87oZOl3P000`?So1:8002_k
o?l3``00^h7oe?l1P<21ojWo0h000<3ho`BR000[noco0l<00;_ko`H0ooncmonc
POoQo`60`87oZOl3P000`?So1:8002_ko?l3``00^o_o1P3ook?gok?=o`1QUOl0
087oZ?on0?Ko0d@00;?lo`9E04b1om?o0021ojSooP3fo`=4002co?l2E@1<nol3
0020ooh005f1on7o0021ojSooP3fo`=4002co?l2E@1<nol30020ooh005g=o`1J
U_l1P821ojSo0P00P?Ko2mUE22JZlooVQ0QMiX7oe?l1P821ojSo0P00P?Ko2mUE
22JZlooVQ0QMiX7oe?l1P821ojSo0P00P?Ko2mUE22JZlooVQ0QMi[oo03nFo`00
POnXooh0l_l5KQ00025oPOoAo`00POnXooh0l_l5KQ00025oPOoAo`00POnXooh0
l_l5KQ00025o_?l099Ko0021ojSooP21okco0021ojSooP21okco0021ojSooP2W
o`0ZUol0P87oZ?l2P000POnlo`20POnXo`:00021okco0821ojSo0X000:Ko02BG
o`20POnXooh0POnlo`20POnXooh0POnlo`20POnXooh0Y_l0:YOo0821ojSo0P00
P87o_?l0P87oZ?l20020POnlo`20POnXo`80082Vo`0]Uol0P87oZOl3P000P87o
_?l0P87oZOl3P000P87o_?l0P87oZOl3P000P:Ko02ZHo`00POnXo`:00021okco
0021ojSo0X00087o_?l0087oZ?l2P000YOl099So0021ojSooP21okco0021ojSo
oP21okco0021ojSooP2Uo`0]VOl1P821ojSo0P00P87o_Ol1P821ojSo0P00P87o
_Ol1P821ojSo0P00P:Go02BIo`00POnXooh0POnlo`00POnXooh0POnlo`00POnX
ooh0Y?l099Wo0021ojSooP21okco0021ojSooP21okco0021ojSooP2To`0ZV_l0
P87oZ?l2P000POnlo`20POnXo`:00021okco0821ojSo0X000:?o02cWo`00]Ol0
P87oZ?on08Wo002eo`20POnXooh0ROl00;Go0821ojSooP2So`0njol3`800@;Co
0821ojWo0l00082=o`?0P010]?l0P87oZOl3`000P8go0l20042do`20POnYo`?0
0020Xol0=Ncoo@2co`20POnYo`>00020S_om0;?o0821ojWo0h00082>ood0/ol0
P87oZOl3P000P:?o03;^oo`0/ol0087oZ?l2P000Sool0;?o0021ojSo0X0008oo
o02co`00POnXo`:0002Ro`14lOl0P?`0042bo`00POnXooh0^OonP=go083l0010
/_l0087oZ?on0;WooX3Mo`20o000@;;o0021ojSooP2iooj0kOl0@OCo082X0020
POnYo`400;Oo083n0>;o082X0020POnYo`400;Oo083n0>;o082X0020POnYo`40
0;Oo083n0>oo03;eojH00821oj[ooP2foo`0iOnV0020POnZooh0]_ol0>GoYP00
P87oZ_on0;Koo03ao`1Lm?l1P83i0;>00P00P87oZ_l20020]Ol0P?`00H20j?l1
P83i0;>00P00P87oZ_l20020]Ol0P?`00H20j?l1P83i0;>00P00P87oZ_l20020
]Ol0P?`00H20mOl0;o3onP2do`40087oZ_nW0>KonP2do`40087oZ_nW0>KonP2d
o`40087oZ_nW0?Oo02c^oo/0]_on087oZ_nU0>Kon`2fooh0POnZojD0i_ok0;Ko
oP21oj[oY@3io`1Ck?l4P800042go`800821oj[o002bP?P00H20hol4P800042g
o`800821oj[o002bP?P00H20hol4P800042go`800821oj[o002bP?P00H20n?l0
>nSo0H00^Oon087oZOl00;?on@3Ko`600;WooP21ojWo002cooT0fol1P02iooh0
POnYo`00/ooi0?Co03:Nooh0POnYo`00]?l0P?/0Soon087oZOl00;Co083k08oo
oP21ojWo002do`20n`3bo`14Wol3`000P87oZ_l0P;Co083n0060P8ko0l000821
oj[o082do`20oP01P82>o`?00020POnZo`20]?l0P?h00H20l?l0>9oo0h000821
oj[o082do`40P8[o0h000821oj[o082do`40P8[o0h000821oj[o082do`40P>co
02ZOo`:00021ojWo0821ok_o0X00087oZOl0P87o^ol2P000POnYo`20WOl09ioo
oP21oj[o0H30POnkooh0POnZo`60`87o^oon087oZ_l1P<2Mo`0WWol10021ojWo
0021ok[o0@00POnYo`00POnjo`40087oZOl009co02NPooh0POnZo`70P87o^oon
087oZ_l1`821ok_ooP21oj[o0L20W?l09j3o0@00POnYo`20POnjo`40087oZOl0
P87o^_l10021ojWo082Ko`0cXOon087oZOl0P=Oo0JT0POoWooh0POnYo`20eol1
Z@21onOooP21ojWo083Go`6Y0<Oo05NQo`800421ojWo083So`KMR5UoP7<[o001
8XR1onOo0P00@87oZOl0P>?o1]f8FGn0Lb_l004RR87oiol20010POnYo`20hol6
gHQIOh1c:o`00B:8aol0Ej;o0h000821ojWo083To`?<002koOl3V00bkX7oiOl3
P000P87oZOl0P>Co0l`00;_mo`>H03;^POoUo`>00020POnYo`20i?l3c000^ogo
0iP0<^k4o`1DX_l3P000P87oZ_l00>?o0UD04?_o0c<00>J1onKo0h000821oj[o
003So`9E013ko`<c003VPOoVo`>00020POnZo`00hol2E@0@nol3<`00i/Go06:R
ooh0POnYo`00i?l3^`00/__o0i4006:1onKooP21ojWo003To`>k002bnol3T@00
H_co0FhIo_l1]aV1oo;ooP21ojWo003To`>k002bnol3T@00H_co0FhIo_l1]aWA
o`1NX_l10021ojWo003So`8b003jo`?<000IPOoVo`40087oZOl00>?o0S800?[o
0l`001Wko`00oOl0087ol_l10021ojWo003So`8b003jo`?<000Inol00?go003A
o`1BXoon087oZOl00>?ooP3jo`3VoP21onOooP21ojWo003Sooh0n_l0i_h0nol0
0?go0021oo?ooP21ojWo003Sooh0n_l0i_h0nol00?go003Ao`1KXol20020POnZ
o`70P>?ooP00k_[ooP21onOo0P00P87oZ_l1`83Sooh00>kjooh0nol00?go0021
oo?o0P00P87oZ_l1`83Sooh00>kjooh0nol00?go003Ao`1KY?on087oZOl0P>;o
0b400:Wjo`8001V1onSooP21ojWo083Ro`<Q002Yn_l2000Inol00?go0021ooCo
oP21ojWo083Ro`<Q002Yn_l2000Inol00?go003Ao`1NY?on087oZOl0P>;o0fH0
05Gko`?^0014POoXooh0POnYo`20h_l3IP00EO_o0nh004Cko`00oOl0087om?on
087oZOl0P>;o0fH005Gko`?^0014nol00?go003Ao`1`YOl3`000P87oZOl0P>;o
1>hR003Eo?l3_`00XX7ojOl3`000P87oZOl0P>;o1>hR003Eo?l3_`00X_co1h00
`?oo`020POofo`?00020POnYo`20h_l4kR800=Glo`>o002Ro?l7P030ooo0083B
o`1DYOl3P000P87oZ_l00>3o0k<004clo`9<09R1onSo0h000821oj[o003Po`>c
001<o?l2C02HPOoXo`>00020POnZo`00h?l3/`00C?co0T`0V<Co056Uo`:00021
ojWo003Oo`VY401Ec?o<M`RjPOoWo`:00021ojWo003Oo`VY401Ec?o<M`RjPOoW
o`:00021ojWo003Oo`VY401Ec?o<M`Rj`ol0AJGooP21oj[o0H20gOl6]hR0P92Z
jX7oi_on087oZ_l1P83Mo`JgR820T:[ZPOoVooh0POnZo`60P=go1[N8P82@Z^[2
o`0WYOl10021ojWo0021ok[o0@00POnYo`00POnjo`40087oZOl009Ko02NVooh0
POnZo`70P87o^oon087oZ_l1`821ok_ooP21oj[o0L20U_l09jKo0@00POnYo`20
POnjo`40087oZOl0P87o^_l10021ojWo082Eo`0TYoon087oZOl0P87o^oon087o
ZOl0P87o^oon087oZOl0P9Go02fXo`?00010POnYo`20POnlo`?00010POnYo`20
POnlo`?00010POnYo`20UOl0;JSo0h000821ojWo0821okco0h000821ojWo0821
okco0h000821ojWo082Eo`0ZZ?l2P000POnYo`00POnko`:00021ojWo0021ok_o
0X00087oZOl009Co02BXooh0POnYo`00POnkooh0POnYo`00POnkooh0POnYo`00
U?l09jSo0@00POnYo`00POnjo`40087oZOl0087o^_l10021ojWo002Co`0TZOon
087oZOl0087o^oon087oZOl0087o^oon087oZOl009?o02fYo`800821oj[o0L20
POnko`800821oj[o0L20POnko`800821oj[o0L20Tol0:Z[o0X00087oZOl0P87o
^ol2P000POnYo`20POnko`:00021ojWo082Bo`0ZZ_l2P000POnYo`20POnko`:0
0021ojWo0821ok_o0X00087oZOl0P9;o02ZZo`900821ojWo0821ok_o0T00P87o
ZOl0P87o^ol2@020POnYo`20T_l0:Z[o0P00P87oZ_l0087o^_l20020POnZo`00
POnjo`800821oj[o002Ao`0f/?l0`?go0X00087oZOl0087o`?l0`?go0X00087o
ZOl0087o`?l0`?go0X00087oZOl0097o03>`o`600?kooP21oj[o0021okoo0H00
o_on087oZ_l0087o_ol1P03nooh0POnZo`00T?l0=[3o1X000?oo0021ojWo0021
okoo1X000?oo0021ojWo0021okoo1X000?oo0021ojWo002@o`12/?l3P000`?h0
o_l0P87o[_l1`821okoo0h000<3n0?ko0821ojko0L20POnoo`>00030oP3no`20
POn^o`70P93o03n`o`V000200020oh00POn]o`20POnno`V000200020oh00POn]
o`20POnno`V000200020oh00POn]o`20Sol0=[3o083l00:00021ojco0821okko
083l00:00021ojco0821okko083l00:00021ojco082?o`0`/?l0P?X00821ojco
0821okko083j0020POn/o`20POnno`20nP00P87o[?l0P8oo02Z`o`20nP21oj_o
0821okko083j087oZol0P87o__l0P?X0POn[o`20Sol09:oon`21oj_o0021okco
n`21oj_o0021okcon`21oj_o002>o`0Z[ool0020POn[o`00POnloo`00821oj_o
0021okcoo000P87oZol008ko02B_oo`0POn[o`00POnkoo`0POn[o`00POnkoo`0
POn[o`00SOl09:ooo@21oj[o0021ok_oo@21oj[o0021ok_oo@21oj[o002=o`0T
[oon087oZ_l0P87o^_on087oZ_l0P87o^_on087oZ_l0P8co02Z_o`800821oj[o
0821ok[o0P00P87oZ_l0P87o^_l20020POnZo`20S?l09joo0@00POnYo`20POnj
o`40087oZOl0P87o^_l10021ojWo082<o`0T[ol0087oZ?l0P87o^_l0087oZ?l0
P87o^_l0087oZ?l0P8co02B`o`20POnXo`00POnjo`20POnXo`00POnjo`20POnX
o`00Rol09;3o0821ojSo0021ok[o0821ojSo0021ok[o0821ojSo002;o`0T/?l0
P87oZOl0P87o^Ol0P87oZOl0P87o^Ol0P87oZOl0P8[o02B`o`20POnYo`20POni
o`20POnYo`20POnio`20POnYo`20R_l0<k7o0H30b_onP87ohol0P87o^_l1P<3:
ooj0POoSo`20POnjo`60`<[ooX21on?o082:o`0f/Ol00<co083n087ohOl0P87o
^_l00<co083n087ohOl0P87o^_l00<co083n087ohOl0P8[o03Jao`00cOom0020
POoQo`20POnjo`00cOom0020POoQo`20POnjo`00cOom0020POoQo`20R_l0?k;o
003@o`60P?`00821on7o0021ok[o003@o`60P?`00821on7o0021ok[o003@o`60
P?`00821on7o0029o`0f/_l00=?o083N087on_l0087o^_l00=?o083N087on_l0
087o^_l00=?o083N087on_l008Wo032co`20doo20020U_l0087o^_l0P=?o`P00
P9Ko0021ok[o083Col80082Fo`00R?l0=[?o0<3@P?P0jX00@>D0UH21ok[o0<3@
P?P0jX00@>D0UH21ok[o0<3@P?P0jX00@>D0UH28o`0aPOl1oh3j0020dOon087o
POnKo`20nP00P=7ooP21oh7oVol0P?X0083Aooh0POnLo`0/POonoo/0083Aooh0
POn1oiWon`00P=7ooP21oh7oVOok0020dOon087oW?l0?X7oo?l1P43n0020dol3
`000P87oPOnGo`60@?h0083Co`?00020POn1oiOo0H10oP00P=?o0l000821oico
02n1ooWoo@3Do`>00020POn1oiCoo@3Do`>00020POn1oiCoo@3Do`>00020POnL
o`0_POogo`400=Co0X00087oPOnAo`400=Co0X00087oPOnAo`400=Co0X00087o
Vol07X7ob?on087oPOn1on;ooP21oh7oPOoRooh0POnKo`0QPOo8o`40087oPOn1
on7o0@00POn1oh7ohOl10021oi[o01j1olWooP21oh7oPOoRooh0POn1oh7oh_on
087oV_l08H7obOl10021oh7oPOoQo`40087oPOn1on7o0@00POnIo`0NPOo:ooh0
POn1oh7oh_on087oPOn1on;ooP21oiWo02B1ol[o0P00@87oPOn1on;o0P00@87o
POn1on;o0P00@87oVOl09h7obol3P000P87oPOn1on?o0h000821oh7oPOoSo`>0
0020POnIo`0WPOo;o`>00020POn1oh7ohol3P000P87oPOn1on?o0h000821oiWo
02B1ol_o0T00087oPOn1on;o0T00087oPOn1on;o0T00087oV?l07X7oboon087o
POn1on;ooP21oh7oPOoRooh0POnHo`0QPOo;o`40087oPOn1on7o0@00POn1oh7o
hOl10021oiOo04:1olcooP2No`S<GQT001URi_on087oPOoAooh0W_l8c5hI000I
H^KooP21oh7odOon09ko2<aN6@006F;Vooh0Q_l0>H7oc?l1002No`2Hn@00k_h0
POn1om7o0@00W_l0V?T00>kn087oPOoAo`4009ko09Si003^oP26o`15POo=ooh0
Wol0i_d01J[okS`0<_h0POn1om;ooP2Oo`3Vo@05Z_o^?00boP21oh7od_on09oo
0>Km00FZonhl03;n08Ko04^1olgo0P00@9oo18@002oVo_l1legm087oPOoBo`80
042Oo`B4000_i_ko0O=Mo@21oh7od_l20010Wol4Q000;nKno`7cGOd0Q_l0B87o
c_l3P000P9oo0d@00:;ko`1EoP21oh7odol3P000P9oo0d@00:;ko`1EoP21oh7o
dol3P000P9oo0d@00:;ko`1EoP26o`18POo>o`>00030Wol35@00fO_o0<?n087o
POoCo`>00030Wol35@00fO_o0<?n087oPOoCo`>00030Wol35@00fO_o0<?n08Ko
0321olkooP2Nooh0nOon087oPOoCooh0W_on0?WooP21oh7odoon09kooP3iooh0
Q_l0<87oc_on09kooP3iooh0POn1om?ooP2Nooh0nOon087oPOoCooh0W_on0?Wo
oP26o`1APOo?o`:0002Mo`<4003gnol0gOh0POn1omCo0X0009go0`@00?Oko`3M
oP3no`9k:h21oh7of_l2P000WOl31000mo_o0=gn0?ko0W/[P8co04V1oloooP2M
o`<I003Dnol0Qoh0POn1omCooP2Mo`<I003Dnol0Qoh0oOl10821oh7of_on09go
0aT00=Cko`27oP3mo`40P8co04b1oloo0@00W?l3?000Z__o027n087oPOoDo`40
09co0c`00:[ko`0QoP3mo`40P87oPOoJo`4009co0c`00:[ko`0QoP3mo`40P8co
05F1om3o0X0009co18@0043go_l1ldcm087oPOoEo`:0002Lo`B40010moko0O=<
o@3mo`40P87oPOoKo`:0002Lo`B40010moko0O=<o@3mo`40P8co05R1om3o0X00
P9co0>kn00H@^ooM?01VoP21oh7oeOl2P020W?l0k_h01Q2komdl06Kn0?go0@20
POn1om_o0X00P9co0>kn00H@^ooM?01VoP3mo`40P8co04V1om3o0P00P9_o09Sj
004Qk_h0POn1omGo0P00P9_o09Sj004Qk_h0oOl10821oh7ofol20020Vol0V?X0
0B7^oP3mo`40P8co0661omKo0<3lo`800<2Jo`_DGQT0029cmol001V1oh7ofol0
`?co0P00`9[o2mAN6@008W?go`006Ogo0@20POn1on7o0<3lo`800<2Jo`_DGQT0
029cmol001Wmo`40P8co04J1omKo0H00o_on097o0l`003:1oh7ofol1P03nooh0
TOl3c000<_go0@20POn1on7o0H00o_on097o0l`003;mo`40P8co04R1omKo0H00
o_on097o0iP007N1oh7ofol1P03nooh0TOl3V000Moko0]d0P87oPOoQo`600?ko
oP2Ao`>H001go_l2g@20S?l0Jh7oe_l6P000oh000?go0<2Oo`<9003Qo?l4ZQT0
2=B1oh7ofol6P000oh000?go0<2Oo`<9003Qo?l4ZQT02=Cnoof0POn1on;o1X00
0?n0003mo`30Wol32@00hOco1:XI00SDo_omP8go06J1omKo0h00083n00?oo`00
W_l8E@006JW^ome^oP00^X7oPOoJo`>00020oP03ool009ko25D001VYk_oMK_h0
0;Z1oh7of_l3P000P?h00ooo002No`QE000IZNkogFkn002jQOl0AH7oe_l0P?`0
0h3oP02Mo`2Zm`00C87oPOoIo`20o003P?n009go0:[g001<POn1omWo083l00>0
oh00WOl0Z_L004b4o`1DPOoFo`20o002@010Vol3e8Q46Oh00bIMT?>1oh7ofOl0
P?`00T00@9_o0mB8A1Wn00<VGI3cPOn1omWo083l0090042Ko`?DR4@IoP039Uf@
lhCo02Z1omKo083j0020POn1oh7oj?l0P?X00821oh7oPOoXo`20nP00P87oTol0
987oeOok0020POn1oh7oi_ok0020POn1oh7oi_ok0020POnBo`0TPOoEoo`00821
oh7oPOoUoo`00821oh7oPOoUoo`00821oi7o01j1omGoo021oh7oPOoToo`0POn1
oh7oi?ol087oT?l07X7oeOom087oPOn1on?oo@21oh7oPOoSood0POn?o`0NPOoE
ooh0POn1oh7oh_on087oPOn1on;ooP21ohko02B1omGo0P00P87oPOn1on;o0P00
P87oPOn1on;o0P00P87oS_l08H7oeOl10821oh7oPOoQo`40P87oPOn1on7o0@20
POn=o`0NPOoEo`00POn1oh7oh?l0087oPOn1on3o0021ohco01B1oh7oPOn1oh7o
POn1oh7oPOnKo`0DPOn1oh7oPOn1oh7oPOn1oh7oVol0587oPOn1oh7oPOn1oh7o
POn1oi_o01B1oh7oPOn1oh7oPOn1oh7oPOnKo`0DPOn1oh7oPOn1oh7oPOn1oh7o
Vol0587oPOn1oh7oPOn1oh7oPOn1oi_o01B1oh7oPOn1oh7oPOn1oh7oPOnKo`0D
POn1oh7oPOn1oh7oPOn1oh7oVol0587oPOn1oh7oPOn1oh7oPOn1oi_o01B1oh7o
POn1oh7oPOn1oh7oPOnKo`0DPOn1oh7oPOn1oh7oPOn1oh7oVol0587oPOn1oh7o
POn1oh7oPOn1oi_o01B1oh7oPOn1oh7oPOn1oh7oPOnKo`0DPOn1oh7oPOn1oh7o
POn1oh7oVol0587oPOn1oh7oPOn1oh7oPOn1oi_o01B1oh7oPOn1oh7oPOn1oh7o
POnKo`0DPOn1oh7oPOn1oh7oPOn1oh7oVol0587oPOn1oh7oPOn1oh7oPOn1oi_o
01B1oh7oPOn1oh7oPOn1oh7oPOnKo`3o\>"], "Graphics",
  Editable->False,
  ImageSize->{190, 127.563},
  ImageMargins->{{239, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@00040P0@0005P0000I0000;0000<T2003=0@00
00000000002NC000fC800215CDH00040840000P100050000000000000000000000@00003000>0@00
b`0004H0003L4000d10004M4BD<1002000<004gT?Rd00000^10000402@000e`8000601`0000000D0
000;0_ooool50000309b0Bd2100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@040000104700@000040@d03P0002D31@2Q07D0J00N0H<17P6n0G@0
X@1d00@0000]0@<010000?0100080000nP850000003oool2100002d100040000;@4400@0003`0@40
1`000?`20000000000040000;@4100h0000T0`D05@;800<2c`090/P00`;101D2b0040000;@4300@0
003`0@0020000?X20001004000000P@0000]0@003P0002D31@0E0/P00`;?00T2b0030/405@;800@0
000]0@<010000?0100080000nP8000<00`000002100002d1000800009@<20:01b00:0/P0100002d1
0`040000l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D04P3402@0_@0N0<@0903;0180
a0040000;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@0B0<@0902m01h0
a00T0</04P3400@0000]0@<010000?0100080000nP8000<00`000002100002d1000800009@<201d0
a0270<@0100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0?P4g03l1
BP0j0D80<P5603h1=`040000;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D3
1@0n0CL0?`5:03X1@P0b0DH0?P4g00@0000]0@<010000?0100080000nP8000<00`000002100002d1
000800009@<202X1LP0j0D40100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000h0
000T0`D0hP1J0N40A`7V04l1kP1;0N80FP440000;@4300@0003`0@0020000?X20001004000000P@0
000]0@003P0002D31@3R05X1h@170NH0C`7^04/1hP1J0@@0000]0@<010000?0100080000nP8000<0
0`000002100002d1000800009@<20>H0D07f01l1100002d10`040000l04000P0003j0PD000000?oo
o`840000;@4000h0000T0`D0^`5k0;`1SP2g0HH0[`6:0;/1N`040000;@4300@0003`0@0020000?X2
0001004000000P@0000]0@003P0002D31@2k0G/0_06>0;L1QP2_0HX0^`5k00@0000]0@<010000?01
00080000nP8000<00`000002100002d1000800009@<20:41aP2g0HD0100002d10`040000l04000P0
003j0PD000000?ooo`840000;@4000h0000T0`D0N`5d06T1N`1_0G@0J@5]07/1M0040000;@4300@0
003`0@0020000?X20001004000000P@0000]0@003P0002D31@1k0G@0J@5k06l1M01Y0Fd0N`5d00@0
000]0@<010000?0100080000nP8000<00`000002100002d1000800009@<202/1L`1`0G@0100002d1
0`040000l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0Y@0M0KL05P6a01d1]`0T0JD0
7@440000;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@2U01d1]`0F0K40
7@6g02@1Y@0M0@@0000]0@<010000?0100080000nP8000<00`000002100002d1000800009@<20;00
7@7e01h1100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0K`0:0Fh0
m`1c0?l0N`3k06l02P440000;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D3
1@1_00X1KP3g07<0o`1k0?/0K`0:0@@0000]0@<010000?0100080000nP8000<00`000002100002d1
000800009@<207<000660<L01@0000T200000P@0000^0@00100002d11@040000l04201`0003k0]co
00000000T04000000000<U=iKF9_K00000000000000000000000000000000000100002d10P070000
8@D107?oc03P0@D000090_l000840000;P4000@0000]0@D010000?010P0L0000n`;bo`0000000901
00000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`0002450P0a<M<0
m@4500002@800002100002h100040000;@4500@0003`0@8070000?/2m_l00000002@0@000000000b
DgU]HVm/0000000000000000000000000000000000040000;@4200L0000Q1@408?oJ00<21@0000T2
00000P@0000^0@00100002d11@040000l04201`0003k0]co00000000T04000000000<U=iKF9_K000
00000000000000000000000000000000100002d10P0700008@D107?oP`320@D000090P0000840000
;P4000@0000]0@D010000?010P0L0000n`;fo`000000090100000000039CNFeRKf`0000000000000
0000000000000000000000@0000]0@801`0002450@0Poi40e`4500002@;o0002100002h100040000
;@4500@0003`0@8070000?/2l_l00000002@0@000000000bE6U]IG<PCVEg859_KF5^000000000000
0000000000040000;@4200L0000Q1@80<C::0=X11@0000T200000P@0000^0@00100002d11@040000
l04201`0003k0]co00000000T04000000000<U=iKF9_K00000000000000000000000000000000000
100002d10P0700008@D107?oA`1f0@D000090P0000840000;P4000@0000]0@D010000?010P0L0000
n`;fo`000000090100000000039CNFeRKf`00000000000000000000000000000000000@0000]0@80
1`0002450@0PoeL0R`4500002@;o0002100002h100040000;@4500@0003`0@8070000?/2l_l00000
002@0@000000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40
<_m>08h11@0000T2o`000P@0000^0@00100002d11@040000l04201`0003k0_;o00000000T0400000
0000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d10P0700008@D1037oCP2E0@D0
00090P0000840000;P4000@0000]0@D010000?010P0L0000n`;Lo`000000090100000000039CNFeR
Kf`00000000000000000000000000000000000@0000]0@801`0002450@1cob00B@4500002@800002
100002h100040000;@4500@0003`0@8070000?/2m_l00000002@0@000000000bDgU]HVm/00000000
00000000000000000000000000040000;@4200L0000Q1@408?l^05h11@0000T2o`000P@0000^0@00
100002d11@040000l04201`0003k0_;o00000000T04000000000<UAYKFEc84iUMb1BKfeQKP000000
0000000000000000100002d10P0700008@D103;o9`1Q0@D000090_l000840000;P4000@0000]0@D0
10000?010P0L0000n`;bo`000000090100000000039DJFeULb1>IGLPDVm]HFh00000000000000000
000000@0000]0@801`0002450@0bobL0J04500002@800002100002h100040000;@4500@0003`0@80
70000?/2g?l00000002l0P000000000bCF5dJ6E]HGAYHf4gCFm^K`00000000000000000000040000
;@4200L0000Q1@40IOlG0F/11@0000T2o`000P@0000^0@00100002d11@040000l04201`0003k0^ko
00000000T04000000000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d10P070000
8@D1037o:`610@D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;Lo`0000000;`2
00000000039=HGAXIFeQM6USHCM=Kfi_0000000000000000000000@0000]0@801`0002450@1Uoe@0
N`0500002@;o0002100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@000000000b
E6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40<_mX0940100002d1
0`040000l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0X01f0:40Q02M07l0U`210:00
MP040000;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@2P07H0X@2409d0
O`2G0840X01f00P0000U0`80W@1o09d0OP040000;@4300@0003`0@0020000?X21@000000oooo0P@0
000]0@003P0002@31@220Ad1M@4S0GT17P5e0AT1PP4M0@@0000]0@<010000?0100080000nP800040
0@000002100002d1000>00009@<508817@5e0B<1N@4N0GD16@620Ad1200002D30P1j0Ad1NP4N0@@0
000W0Ooo10000?0100040000l04100@0003`0@8010000?010`040000l04400@0003`0@D00`000000
4@0000`0000800002`000100003X0P00k04000T0000@0000j0800>`1000:000040000?oooooooooo
2@000100000]0P00LP400180000<00000@00024000080000500000`000070000500000`0000=0000
9P0001`000010000000000400001000000000RD0000<00000@0002D0000<00000000P5L0000`0000
S00009`0001E0P00OP4000D0002Q07D0J00N0H<17P6n0G@0X@1d02H0000L00000P0000D000000000
00000?ooo`8U000030000080000U0000300000@0081F0000<0000;4200020@00b@8001D100050000
5@;800<2c`090/P00`;101D2b00U000030000040000X000030000080000V00007000008000000000
0@000040000000029@0000`000020000E`000300002a0P000P400<T2000E0@001@0001D2b0030/l0
2@;800<2`@0E0/P09@0000`000010000:00000`0000200009P0001`000020000000000<000030000
00000RD0000<00000P0005L0000T0000:`8000T1002m0P003@400080002P0LP02P;802D0000<0000
0@0002P0000<00000P0002H0000L00000P0000D00000000000000?ooo`8U000030000080001F0000
<00001T0003m0000<@0000l1000500004P3402@0_@0N0<@0903;0180a00U000030000040000X0000
30000080000V000070000080000000000@000040000000029@0000`000020000E`000300000I0000
o@000340000?0@001@000180a00T0;d07P3402@0b`0B0<@09@0000`000010000:00000`000020000
9P0001`000020000000000<00003000000000RD0000<00000P0005L0000T00009P0000@1002h0000
20400080000M0<@0Q`3402D0000<00000@0002P0000<00000P0002H0000L00000P0000D000000000
00000?ooo`8U000030000080001F0000<00009X1001:0000Z`4006@000050000?P4g03l1BP0j0D80
<P5603h1=`0U000030000040000X000030000080000V000070000080000000000@00004000000002
9@0000`000020000E`000300002J0@00BP000:/1001T00001@0003h1=`0o0DX0>P520381AP0n0CL0
9@0000`000010000:00000`0000200009P0001`000020000000000<00003000000000RD0000<0000
0P0005L0000T0000S@4005H0002W0@00V`000080000Z0G80>P5102D0000<00000@0002P0000<0000
0P0002H0000L00000P0000D00000000000000?ooo`8U000030000080001F0000<00002h1002d0@00
?`400<d100050000hP1J0N40A`7V04l1kP1;0N80FP4U000030000040000X000030000080000V0000
70000080000000000@000040000000029@0000`000020000E`000300000^0@00]04003l1003=0@00
1@000>80FP7Q04L1iP1?0Nh0B`7R05X19@0000`000010000:00000`0000200009P0001`000020000
000000<00003000000000RD0000<00000P0005L0000T0000<`4007d1001<0@00`P400080003V0501
mP0O0BD0000<00000@0002P0000<00000P0002H0000L00000P0000D00000000000000?ooo`8U0000
30000080001F0000<0000442002U0000DP800;h000050000^`5k0;`1SP2g0HH0[`6:0;/1N`0U0000
30000040000X000030000080000V000070000080000000000@000040000000029@0000`000020000
E`00030000110P00Y@000582002n00001@000;/1N`2l0Hh0]`660:l1RP2k0G/09@0000`000010000
:00000`0000200009P0001`000020000000000<00003000000000RD0000<00000P0005L0000T0000
;0800;00001>0P002`400080002Q0LH0]`6502D0000<00000@0002P0000<00000P0002H0000L0000
0P0000D00000000000000?ooo`8U000030000080001F0000<0000>@1002B0000o0400:D000050000
N`5d06T1N`1_0G@0J@5]07/1M00U000030000040000X000030000080000V00007000008000000000
0@000040000000029@0000`000020000E`000300003T0@00TP000?`1002U00001@0007/1M01Y0G/0
K`5d06T1K@1k0G@09@0000`000010000:00000`0000200009P0001`000020000000000<000030000
00000RD0000<00000P0005L0000T0000S`4009P0003_0@00WP000080000[0G<0L05d02D0000<0000
0@0002P0000<00000P0002H0000L00000P0000D00000000000000?ooo`8U000030000080001F0000
<0000=h0001c0@00mP0008H100050000Y@0M0KL05P6a01d1]`0T0JD07@4U000030000040000X0000
30000080000V000070000080000000000@000040000000029@0000`000020000E`000300003N0000
L`400?H000260@001@000:D07@6g01H1/@0M0KL0906U01d19@0000`000010000:00000`000020000
9P0001`000020000000000<00003000000000RD0000<00000P0005L0000T0000jP0007X1001;0@00
P0400080002`01d1m@0N0BD0000<00000@0002P0000<00000P0002H0000L00000P0000D000000000
00000?ooo`8U000030000080001F0000<00009@0001:0@00YP0006<100050000K`0:0Fh0m`1c0?l0
N`3k06l02P4U000030000040000X000030000080000V000070000080000000000@00004000000002
9@0000`000020000E`000300002D0000BP400:H0001S0@001@0006l02P5^0?L0L`3o07/0n`1_00X1
9@0000`000010000:00000`0000200009P0001`000020000000000<00003000000000RD0000<0000
0P0005L0000T0000V@0000P1002f0000F0400080001c0001QP3701P0000<000000000U80001<0@00
0`000=coool0000000000000002@0@0000000P00039C07T0K@1R06l0K0000<TngCkS?_`n2clI?bPo
=SmQ?fToL3mh?h0oQcn??iLoWSnV?jho]Cnm?lLoecoS?`0000000030003D0P00230H<2@`<30o<4L`
D31H<64`JC1b<7X`Pc2;<9@`Vc2]<;<`_C33<?H`334P<BDa>c5?<E@aJS5n<H<aVC6]<KDa`c7@<N4a
jC7a<OTa6c8S<RXb<S8j<T4bBC9A<UPbH39X<VlbMc9o<XPbT3:I<Z4bZS800;/b`c;9<]8bhc;/<_Pb
oC85<`dc5C<M<dHcG3=`<gDcRc>O<j@c^S?><m<cjC?m<`@d4c@Q=30d?SA^=7Hd0000000000000000
00000000000000000@410@410@410@De9@0000`000030000D`0005@000220P004@4009d2001;0@00
0@000:;P349JU`a2h0400<`000010000C0000000000000000000000000000000D00007<gHSLE0000
600000`0003o0002DP0004`1000400000000000000000000000005h10000000000018000RSRK>:0h
ZSRg>;`haSSG>=`hiSSg>?dh5STU>C<i@SU@>F4iM3Ui>H`iTCVT>JTi_3W1>LTidCWI>O/i0000018j
6SXQ>RTj<CXh>T0jB3Y?>ULjGcYX>W0jNCZ1>XXjTSZK>Z<jZCZb>/<jc3[K>^<jjc[c>_PjoCXR>c4k
?c]>>e`kKS]j>h4kTc^I>j<kZC^d>l@kd3_L>n/klc_l>`@l3C`G?2Ll<c`o?4hlESaO?6LlL3bG?9ll
YSb^?000_Cc5?<dle3cL?>@ljccc??dl3CdI?BDm=3dn?DhmFSeV?GDmOCf6?HhmUcfO?JPm/3fi?L4m
bSgA?N<mjCd0000000000000000000000000000000010@410@410@41cShU0000300000@0000X0000
300000<0001B0000C04000<0003boooo0000000000000000T04000000000000bE01Y06d0I@1c0200
CP1U07L0801B06l0K@1Q06h00037<<``gc3T<?L`o30?<AHa9C4c<D8aD35k<H0aQC400000W36T<J/a
/c6k<L8abS7B<MTahC7Y<O8anS43<P/b538L<RDb;c8f<THbCc9H<UlbLC9g<X4bQc:`<[Xbbc;@<]Xb
ic;/<_Hb1c<<<aHc9c<]<d@cEc=L<flcM3>7<h`cWc>W<kDcaS?><mHcgS<0=0Dd2S@B=1Td8C@Y=30d
0010=4LdCcAG=5hdISA^=7LdOcB8=90dVCBQ=:Xd]3Bk=</de3CJ=><dm3Cm=0`e53DL=B@eD3EJ=F/e
L3Ej=@00000000000000000000000000000000410@410@410@5E=RD0000<00000`0005@0001H0000
W`8001X1002`0P00;P400040002Rh0a2FYL<@_D1003C00000P0004`0000000000000000000000000
00000500000a03401P0000L0000H000030000000008U0000300000@0000X0000300000<0001B0000
C04000<0003foooo0000000000000000T04000000080000bD`1i06d0HP1_06`0000`>STj?cY7>W8j
PCZ?>Yhj[3Zn>/Xjd3[I>PTk4C/H>b0k:3/_>cLk?c]6>dhkES/00000KC]f>ghkQc^?>iPkX3^Y>k<k
^S_:>m<kfC_R>o<ko3/b?44lCcaN?6`lOSb:?90lVCc9?=4lf3cP?>Plkccg??ll1Sd>?AHm7CdU?Bdm
=Sdn?DLmCceH?F0mJCec?GXmRSfC?ITmXSfc?K`ml3gj?@/n43hJ?RLn;3hf?TLn001F?VLnKCj4?YLn
W3j_?[@nack<?]lniSke?P<o4SlP?d/oD3mE?edoI3m/?g@oNcn3?h/oTSnJ?j8oZCna?`0000000000
0000000000000000000000410@410@410@5E<2D0000<00000`0005<0001D0000/@8002<1002c0P00
<P400040002Rh0a2FYL<@P<2003J00000@0004`000000000000000000000000000000500000P<Ulb
0P0002D0000<0000100002P0000<00000`000580001<0@000`000=coool0000000000000002@0@00
00000P00039C07T0K@1R06l0K000050dNcB0=8DdSCBD=9`dY3B[=;<d^cC2=<XddSCI=>4djCCb=?Xd
0cD;=A@e73DU=@00000l=DdeESF2=I4eWcF^=K`ecSGJ=N4elcGi=@<f2CHa=STf@3I8=U0fEcIO=VLf
KSIf=WhfQCJ==YDfWSJV=Zlf]cK0=/PfdCKI=^8fjCKk=P4g2cLA=aXg83LW=c@g>SM1=dhgEcMM=fDg
TSNQ=jlg_SO<=mhgjSO`=oTg:CP003Ph@3Q8>4lhEcQO>6HhKSQf>7dhQCR=>9HhWSRW>:lh^3S0><Th
dCSG>>0hlCSj>38i@CU?>EhiK3Un>HXi000000000000000000000000000000000@410@410@410Chj
9@0000`000030000D`0005@0001J0P00/00007D2003Z00000@000:;P349JU`a2`P4008<000010000
C0000000000000000000000000000000D00007<lZC`E00009@0000`000040000:00000`000030000
DP0004`100030000m_ooo`000000000000000901000000020000<U<0N@1]0680K`1/0000]Sk<?^0n
iCkk?Plo53lZ?cho@cmI?fdoLSml?hToSSnH?jDoZco3?m8of3oW?ndo00000000T08000X`=C0m<4@`
C31D<5/`Hc1[<78`NS22<8T`TC2I<:8`ZS2c<;/`a33<<=D`gC3S<>``oC06<A8a6c4]<CHaB35><FHa
K364<I@a[C6h<KlahC7^<O/a1C8C<Q`b:C8c<T4bL39j<XLbS3:F<Z<bZC;1<]0beS;U<P00nc89<aPc
9S=A<eTcHS=Y<g/cPC>;<i4cVS>Q<jTc/C>h<l0cb3??<mLcgc?V<nhcmS?o<`Ld43@H=24d:C@00000
00000000000000000000000000010@410@410@41hC@U0000300000<0001C0000E00007H200320000
N0800=4000010000X^0<@UZG34;G0@00T@000040001<0000000000000000000000000000001@0000
83Ko=P80000H000030000?l0008U0000300000@0000X0000300000<0001B0000C04000<0003boooo
0000000000000000T04000000000000bE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0003/H@@0
mV4400AR100>HP@06V8402YR100lHP@016<00000101`HP@0M64408iR102VHP@0^6840<IR103DHP@0
i6840:YS100@H`@076<402aS100jH`@0C6<405QS101^H`@0Q6<409IS10000000F684000000118?Vo
Zk_h_kadm[n_KOJoS4Sf_kbkn;nBM?Jo?Qoi_`@OnKlW3_Vo003f_od=nKo@L_Jo_dSf_id>nKom<oRo
/1Ch_mcUmkn>EONolfgf_cf`mkmNb_NoOMWg_b15mknA0ONocgKf_`00000000000000000000000000
000000410@410@410@7f_bD0000<00000`0005@0001H0000NP800;T0002;0P00c@000040002Rh0a2
FYL<@]X1002:00000P0004`000000000000000000000000000000500000a03801P0000L0000H0000
30000000008U0000300000@0000X0000300000<0001B0000C04000<0003Loooo0000000000000000
T04000000080000bD`1i06d0HP1_06`00013Kfe`HF=d00P1AfEdD79_IVU/IDU^M4400381AfEdEVEb
LfU_KP00BdEBCTE<<c80000000180WMcL79YKWAV@@1EDdEB<c8^I6a/003S04MUM4aQLgA5LW9_LP00
A`14IFaUM6E6JFaU@@3B04MUM4E^MVUbKfi]IFidDgAbJFiWL`2Q04MUM4=_KFeQKVA<JFiU@@1T04Eh
JGA@LVmSIG=c02H2EVUbM7EQK4IbIFD0001FJG9dMF5/@Fa/Kf<00>/0AfEdCFmTMFaUAVU/IDiQKFE1
002D04MUM453D000n017IGA?ADe3D000VP17I@00000000000000000000000000000000410@410@41
0@5iL2D0000<00000`0005<0001D0000m@400600000@0P00VP000040002Rh0a2FYL<@WH100170000
0@0004`000000000000000000000000000000500001cIG=c5@0002D0000<0000100002P0000<0000
0`000580001<0@000`000?Koool0000000000000002@0@0000000P00039C07T0K@1R06l0K0000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000@410@410@410@009@0000`000030000D`0005@0000A0P00
M@0001<2002400000@000:;P349JU`a2R`4005L000010000C0000000000000000000000000000000
D000020000020000600000`0003o00029@0000`000040000:00000`000030000DP0004`100030000
l_ooo`000000000000000901000000000000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000010@410@410@41000U0000300000<0001D0000E00001D2001Y00007@8007d000010000
X^0<@UZG34:>0@00CP000040001<0000000000000000000000000000001@0000<P0000L0000U0000
300000@0000X0000300000<0001B0000C04000<0003boooo0000000000000000T04000000000000b
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000410@410@410@4002D0000<0000
0`0005@0001D00007P8006T0000V0P00O@000040002Rh0a2FYL<@YD1001>00000@0004`000000000
000000000000000000000500000a00001`0001P0000<000000000RD0000<0000100002P0000<0000
0`000580001<0@000`000=coool0000000000000002@0@0000000P00039C07T0K@1R06l0K0000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000@410@410@410@009@0000`000030000D`0005@0002i0@00
;0000=@1001V00000@000:;P349JU`a2B@40020000010000C0000000000000000000000000000000
D00007<0000E00009@0000`000040000:00000`000030000DP0004`100030000m_ooo`0000000000
00000901000000020000<U<0N@1]0680K`1/00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000010@41
0@410@41000U0000300000<0001C0000E0000=D1000n0000e`4004d000010000X^0<@UZG349N0@00
;P000040001<0000000000000000000000000000001@000080000080000H000030000?l0008U0000
300000@0000X0000300000<0001B0000C04000<0003boooo0000000000000000T04000000000000b
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000410@410@410@4002D0000<0000
0`0005@0001D0000f@4003D0003Q0@00B@000040002Rh0a2FYL<@V41000W00000@0004`000000000
000000000000000000000500000b00001`0002D0000<0000100002P0000<00000`000580001<0@00
0`000?;oool0000000000000002@0@0000000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000@410@410@410@009@0000`000030000E00005@0003R0@00=@000>X100190000
0@000:;P349JU`a2J04002L000010000C0000000000000000000000000000000D0000380l3470000
600000`0000000029@0000`000040000:00000`000030000DP0004`100030000g?ooo`0000000000
00000;`2000000000000<Td0H@1d06P0I@1]0640M01Y06<0H@0g04d0K`1^06l00003>0Lh2cP?>1<h
5cPK>1lh8cPW>54mGSe[?Jln00000><nlchZ?d`oFSmO?gToYCo5?lXofcoQ?o4omSon?`3`0P140@00
0c09<0l`5C0K<24`>c18<6D`KC2E<</`f33N<?D`1C4:<AXa7c4_<C@aA35L<FDaKS5h<H<aR36><I<a
Yc6m<Llaj37i<@8b3c8F<RXb<c8k<U0bJ39n<P00Sc:D<YXbWc;Q<Q4c7S<S<c0cEC=V<f`cXC?A<mhc
hc?`<aDd9S@/=;HdaCA2=DPeHCEW=F`eMcF2=HLeSCD0000000000000000000000000000000010@41
0@410@41hSLU0000300000<0001D0000E0000>H1001d0@000P800:T100010000X^0<@UZG349[0@00
5`400040001<0000000000000000000000000000001@0000I@13?QH0000H000030000?l0008U0000
300000@0000X0000300000<0001B0000C04000<0003^oooo0000000000000000T04000000000000b
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0003C<]PbgS;Y<T<cBC>L<n@caSCO=1he<CDk=DPe
DSD00000[3Fa=M8ek3Go=@`f6SI==VXfNSJ<=ZdfbCK?=^dflSKo=P/g5cLL=b4g;SMR=h@g]cO4=lXg
fSOa=ohg4SPP>2Th=3QG>7ThR3RC>9/h]CRn>0@i73Ta>EDiTST3>Q0jWCZW>Zlj_cX^>ddkES]S>glk
Qc/4?1HlFcaW?8Hl002I?;dlbCcB?=XlW3fR?N0mj3gb?OXm03hk?T<nBCiA?W`nWCjn?^/noch8?b8o
=clm?d<oNSn0?hPoUSoB?`00000000000000000000000000000000410@410@410@6G<2D0000<0000
0`0005@0001D0000108008l1000?0P00Z@400040002Rh0a2FYL<@X41000[0@000@0004`000000000
000000000000000000000500000a06Xl2@0001P0000<000000000RD0000<0000100002P0000<0000
0`000580001<0@000`000=coool0000000000000002l0P0000000000039=0640M01X06D0K@1Q07@0
J@1S0640=`1=06l0KP1_0000`cc9?=Ll2cdB?B<m=Cdn?E0mJ3f9?I4mZ3fj?@00001D?V8nUCkl?Z@o
03030900000H<1`aKC5f<J4a[c7f<Ola2c8I<T4bBS:`<[`b`S;/<_8bCS>6<i<cVC>[<k4c^C?9<m/c
kS<5=0ld5c@W=4@dFcAR=7Hdac@J=c<gXSLK>5DhKSRO>1Xi<SV/>LDi^S[C>P<k73_5?<TlcC`00=Dl
fCcM?>4liCcY?>dllCb_?NDm5Chf?P00040301P0000]<34`@31I<6``n383<`00050304P0000V<1dg
000000000000000000000000000000000@410@410@410Bhj9@0000`000030000E00005@0002V0000
L@000<80002V00000@000:;P349JU`a2N`0005@000010000C0000000000000000000000000000000
D00006D0Mc8F0000600000`0003o00029@0000`000040000:00000`000030000DP0004`100030000
k_ooo`000000000000000901000000000000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
?CI<=UPfISIf=XDf]3Jh=[`f`3K4=^LfjcK_=_<f00000>@hlSPM>C/iCcUY>I@i_cWZ>ADj>cYQ>XLj
YcZe>^0joSXB>b`kEc^2>jdkf3_n>b@lBSaZ?7llSSbP?:ll^cc:?=/ljScf?0Dm4CdP?B`m>ce<?E/m
Icef?J0mY3fX?J`m/3fl?LTmf3gT?O<m2ChH?R@n<ci4?U<nGci^?P00RCjE?Z@ncSkB?]HnfSkN?^Xn
mch6?a8o8Cl]?c`oB3mG?fPoMcn3?i8oZ3ng?l<odSol?`00080306P1000000000000000000000000
0000000000010@410@410@41dC0U0000300000<0001D0000E0000<<0002<0000cP000:H000010000
X^0<@UZG34:A0000J0000040001<0000000000000000000000000000001@0000<P1W>0T0000U0000
30000040000X000030000080000V0000700000800005000000000000003oool29@0000`000020000
EP000300003;0000WP000=P0002a00001@000:00MP2Q08@0W@1o09L0P@2P07H09@0000`000010000
:00000`0000200009P0001`000020000000000400001000000000RD0000<00000P0005L0000`0000
b`0009h0003H0000/@0000D0002P07H0X@2409d0O`2G0840X01f05L0000T0000d`000:T0003C0000
ZP000080002M07l0W@1n02D0000<00000@0002P0000<00000P0002H0000L00000P0000D000000000
00000?ooo`8U000030000080001F0000<0000?@1001g0@001@8008@100050000PP4M0GD18`5i0Ah1
M@4I0H817@4U000030000040000X000030000080000V000070000080000000000@00004000000002
9@0000`000020000E`000300003d0@00M`4000D200240@001@0008817@5e0B<1N@4N0GD16@620Ad1
E`0002@0003j0@00O0400?X1001n0@000P0007X17@5j0Ah18P0000`0003ooooo:00000`000020000
:00000`000030000:00000`000010000:00000`000040000B`000100000000001@0000h0000D0000
00000100000D0000
\>"], "Graphics",
  Editable->False,
  ImageSize->{315, 190.875},
  ImageMargins->{{348, 0}, {0, 16.125}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Constitutive Equations", "Section",
  CellTags->"Constitutive equations"],

Cell[TextData[{
  "Relation between the stress and the strain. The ",
  StyleBox["Hooke's law",
    FontColor->RGBColor[1, 0, 0]],
  " gives the linear relation between their components."
}], "Text"],

Cell[BoxData[
    RowBox[{\(\(ConstitutiveLaw[\[Sigma]_]\)[expr_]\), ":=", 
      RowBox[{"expr", "/.", 
        RowBox[{"{", 
          
          RowBox[{\(Tensor[\[Sigma], {i_, j_}, {Void, Void}] :> \((If[
                  Length[i] > 0\ , 
                  If[Head[i] === 
                      Head[j], \[DoubleStruckCapitalE]uuuu[i, 
                        j, \(Head[i]\)[l], \(Head[i]\)[
                          m]] \[ScriptCapitalE]dd[\(Head[i]\)[l], \(Head[i]\)[
                          m]], Print["\<Error: not in the same frame\>"]], \
\[DoubleStruckCapitalE]uuuu[i, j, l, m] \[ScriptCapitalE]dd[l, m]])\)\), ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              
              StyleBox[\(Tensor[\[Sigma], {i_, j_, Void}, {Void, Void, 
                    Dif[x_]}]\),
                FontColor->RGBColor[0, 0, 1]], 
              ":>", \((If[Length[i] > 0\ , 
                  If[Head[i] === Head[j], 
                    PartialD[\[DoubleStruckCapitalE]uuuu[i, 
                          j, \(Head[i]\)[l], \(Head[i]\)[
                            m]] \[ScriptCapitalE]dd[\(Head[i]\)[
                            l], \(Head[i]\)[m]], x], 
                    Print["\<Error: not in the same frame\>"]], 
                  PartialD[\[DoubleStruckCapitalE]uuuu[i, j, l, 
                        m] \[ScriptCapitalE]dd[l, m], x]])\)}]}], 
          "}"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ResultFrame", "[", 
      RowBox[{"HookesLaw", "=", 
        RowBox[{
          RowBox[{"SequenceForm", "[", 
            RowBox[{"\"\<\!\(\*
StyleBox[\"Constitutive\",\nFontVariations->{\"Underline\"->True}]\)\!\(\*
StyleBox[\" \",\nFontVariations->{\"Underline\"->True}]\)\!\(\*
StyleBox[\"equations\",\nFontVariations->{\"Underline\"->True}]\)     \>\"", 
              ",", \(\[Sigma]uu[i, j]\), ",", "\"\< = \>\"", 
              ",", \(\[Sigma]\[Section]uu[i_, j_] = \[Sigma]uu[i, j] // 
                  ConstitutiveLaw[\[Sigma]]\)}], "]"}], 
          "//", \(ToFlavor[red]\)}]}], "]"}]], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  InterpretationBox[
                    
                    RowBox[{"\<\"\\!\\(\\* \
StyleBox[\\\"Constitutive\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\
\\!\\(\\* StyleBox[\\\" \\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\
\\!\\(\\* \
StyleBox[\\\"equations\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)   \
  \"\>", "\[InvisibleSpace]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Sigma]", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                red[ i], 
                                red[ j]],
                              Editable->False]],
                          Subsuperscript[ \[Sigma], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              StyleForm[ 
                                red[ j], ShowContents -> False]], 
                            SequenceForm[ 
                              red[ i], 
                              red[ j]]],
                          Editable->False],
                        "TraditionalForm"], 
                      "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]",
                       
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[ScriptCapitalE]", 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  red[ l], 
                                  red[ m]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ l], ShowContents -> False], 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[ScriptCapitalE], 
                              SequenceForm[ 
                                red[ l], 
                                red[ m]], 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ l], ShowContents -> False], 
                                StyleForm[ 
                                  red[ m], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"], " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False], 
                                  StyleForm[ 
                                    red[ l], ShowContents -> False], 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  red[ i], 
                                  red[ j], 
                                  red[ l], 
                                  red[ m]],
                                Editable->False]],
                            Subsuperscript[ \[DoubleStruckCapitalE], 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False], 
                                StyleForm[ 
                                  red[ l], ShowContents -> False], 
                                StyleForm[ 
                                  red[ m], ShowContents -> False]], 
                              SequenceForm[ 
                                red[ i], 
                                red[ j], 
                                red[ l], 
                                red[ m]]],
                            Editable->False],
                          "TraditionalForm"]}]}],
                    SequenceForm[ 
                    "\!\(\* StyleBox[\"Constitutive\",\n\
FontVariations->{\"Underline\"->True}]\)\!\(\* StyleBox[\" \",\n\
FontVariations->{\"Underline\"->True}]\)\!\(\* StyleBox[\"equations\",\n\
FontVariations->{\"Underline\"->True}]\)     ", 
                      Tensor[ \[Sigma], {
                        red[ i], 
                        red[ j]}, {Void, Void}], " = ", 
                      Times[ 
                        Tensor[ \[ScriptCapitalE], {Void, Void}, {
                          red[ l], 
                          red[ m]}], 
                        Tensor[ \[DoubleStruckCapitalE], {
                          red[ i], 
                          red[ j], 
                          red[ l], 
                          red[ m]}, {Void, Void, Void, Void}]]],
                    Editable->False], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "3", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  SequenceForm[ 
                  "\!\(\* StyleBox[\"Constitutive\",\n\
FontVariations->{\"Underline\"->True}]\)\!\(\* StyleBox[\" \",\n\
FontVariations->{\"Underline\"->True}]\)\!\(\* StyleBox[\"equations\",\n\
FontVariations->{\"Underline\"->True}]\)     ", 
                    Tensor[ \[Sigma], {
                      red[ i], 
                      red[ j]}, {Void, Void}], " = ", 
                    Times[ 
                      Tensor[ \[ScriptCapitalE], {Void, Void}, {
                        red[ l], 
                        red[ m]}], 
                      Tensor[ \[DoubleStruckCapitalE], {
                        red[ i], 
                        red[ j], 
                        red[ l], 
                        red[ m]}, {Void, Void, Void, Void}]]], "      (4.", 3,
                   ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["The above relation is called the \"Constitutive equation\"", "Text"],

Cell[BoxData[
    \(PartialD[\[Sigma]uu[i_, j_], \[ScriptCapitalE]dd[l_, 
          m_]] := \[DoubleStruckCapitalE]uuuu[i, j, l, m]\)], "Input"],

Cell[TextData[{
  StyleBox["The tensor \[DoubleStruckCapitalE], is symmetrical in ",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["{i,j}",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox[" and in ",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["{l,m}",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  ", because on one hand  ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["l",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ l], 
              red[ m]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["l",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ l], ShowContents -> False], 
              StyleForm[ 
                red[ m], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " is symmetrical in ",
  StyleBox["{l,m}",
    FontWeight->"Bold"],
  " :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptCapitalE]\[Section]dd[red@i, red@j]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["u", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ",", 
                                red[ 
                                  red[ j]]],
                              Editable->False],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ 
                            red[ i]], 
                          Dif[ 
                            red[ 
                              red[ j]]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ",", 
                                    red[ 
                                      red[ j]]],
                                  Editable->False],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 
                              red[ i]], ShowContents -> False], 
                          StyleForm[ 
                            Dif[ 
                              red[ 
                                red[ j]]], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ u, 
                      SequenceForm[ 
                        red[ 
                          red[ i]], 
                        Dif[ 
                          red[ 
                            red[ j]]]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 
                            red[ i]], ShowContents -> False], 
                        StyleForm[ 
                          Dif[ 
                            red[ 
                              red[ j]]], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "+", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["u", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ",", 
                                red[ 
                                  red[ i]]],
                              Editable->False],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ 
                            red[ j]], 
                          Dif[ 
                            red[ 
                              red[ i]]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ",", 
                                    red[ 
                                      red[ i]]],
                                  Editable->False],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 
                              red[ j]], ShowContents -> False], 
                          StyleForm[ 
                            Dif[ 
                              red[ 
                                red[ i]]], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ u, 
                      SequenceForm[ 
                        red[ 
                          red[ j]], 
                        Dif[ 
                          red[ 
                            red[ i]]]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 
                            red[ j]], ShowContents -> False], 
                        StyleForm[ 
                          Dif[ 
                            red[ 
                              red[ i]]], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "while the symmetry of the stress tensor was proven in Section 4.\nSo there \
is only 36 different elements in \[DoubleStruckCapitalE]. But there is in \
addition a ",
  StyleBox["further reduction in number",
    FontVariations->{"Underline"->True}],
  " due to the existence of a strain energy :\n\nThe strain energy density is \
given by :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]SequenceForm["\<Strain energy density =  \
 \>", \[ScriptA] = \(1\/2\) \[Sigma]uu[i, j] \[ScriptCapitalE]dd[i, j] // 
            ToFlavor[red]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  InterpretationBox[
                    
                    RowBox[{"\<\"Strain energy density =   \"\>", 
                      "\[InvisibleSpace]", 
                      RowBox[{\(1\/2\), " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[ScriptCapitalE]", 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  red[ i], 
                                  red[ j]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[ScriptCapitalE], 
                              SequenceForm[ 
                                red[ i], 
                                red[ j]], 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"], " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Sigma]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  red[ i], 
                                  red[ j]],
                                Editable->False]],
                            Subsuperscript[ \[Sigma], 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]], 
                              SequenceForm[ 
                                red[ i], 
                                red[ j]]],
                            Editable->False],
                          "TraditionalForm"]}]}],
                    SequenceForm[ "Strain energy density =   ", 
                      Times[ 
                        Rational[ 1, 2], 
                        Tensor[ \[ScriptCapitalE], {Void, Void}, {
                          red[ i], 
                          red[ j]}], 
                        Tensor[ \[Sigma], {
                          red[ i], 
                          red[ j]}, {Void, Void}]]],
                    Editable->False], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "4", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  SequenceForm[ "Strain energy density =   ", 
                    Times[ 
                      Rational[ 1, 2], 
                      Tensor[ \[ScriptCapitalE], {Void, Void}, {
                        red[ i], 
                        red[ j]}], 
                      Tensor[ \[Sigma], {
                        red[ i], 
                        red[ j]}, {Void, Void}]]], "      (4.", 4, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\[ScriptCapitalE] (explicitely \[ScriptCapitalE]\[Section]) and ",
  StyleBox["\[Sigma]",
    FontWeight->"Bold"],
  " are symmetrical with respect to their indices. ",
  "\n",
  "So, ",
  StyleBox["\[ScriptA]",
    FontWeight->"Bold"],
  " is explicitely,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ScriptA]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["which can be put into a standard order :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\((\[ScriptA] // EinsteinSum[])\) // 
          SymmetricStandardOrder[\[ScriptCapitalE]]\) // 
        SymmetricStandardOrder[\[Sigma]]\) // Simplify\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 1], 
                            red[ 1]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False], 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ 1], 
                          red[ 1]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False], 
                            StyleForm[ 
                              red[ 1], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 1], 
                            red[ 1]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 1], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1], 
                          red[ 1]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{"2", " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 1], 
                            red[ 2]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False], 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ 1], 
                          red[ 2]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False], 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 1], 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1], 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{"2", " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 1], 
                            red[ 3]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False], 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ 1], 
                          red[ 3]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["1",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 1], ShowContents -> False], 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["1",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 1], 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 1], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 1], 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 2], 
                            red[ 2]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False], 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ 2], 
                          red[ 2]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False], 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False], 
                            StyleForm[ 
                              red[ 2], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 2], 
                            red[ 2]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False], 
                          StyleForm[ 
                            red[ 2], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2], 
                          red[ 2]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{"2", " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 2], 
                            red[ 3]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False], 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ 2], 
                          red[ 3]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["2",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 2], ShowContents -> False], 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["2",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 2], 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 2], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 2], 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 3], 
                            red[ 3]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False], 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ 3], 
                          red[ 3]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["3",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ 3], ShowContents -> False], 
                            StyleForm[ 
                              red[ 3], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["3",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ 3], 
                            red[ 3]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ 3], ShowContents -> False], 
                          StyleForm[ 
                            red[ 3], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ 3], 
                          red[ 3]]],
                      Editable->False],
                    "TraditionalForm"]}]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "or ",
  StyleBox["in Cartesian coordinates",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ", using conventional notations :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {\[ScriptCapitalE]dd[red@1, red@1] -> \[ScriptCapitalE]d[
            x], \[ScriptCapitalE]dd[red@2, red@2] -> \[ScriptCapitalE]d[
            y], \[ScriptCapitalE]dd[red@3, red@3] -> \[ScriptCapitalE]d[
            z], \[ScriptCapitalE]dd[red@1, red@2] -> \[Gamma]dd[x, y]/
            2, \[ScriptCapitalE]dd[red@1, red@3] -> \[Gamma]dd[z, x]/
            2, \[ScriptCapitalE]dd[red@2, red@3] -> \[Gamma]dd[y, z]/
            2, \[Sigma]uu[red@1, red@1] -> \[Sigma]d[x], \[Sigma]uu[red@2, 
            red@2] -> \[Sigma]d[y], \[Sigma]uu[red@3, red@3] -> \[Sigma]d[
            z], \[Sigma]uu[red@1, red@2] -> \[Tau]dd[x, y], \[Sigma]uu[red@1, 
            red@3] -> \[Tau]dd[z, x], \[Sigma]uu[red@2, red@3] -> \[Tau]dd[y, 
            z]}\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox["x",
                          SequenceForm[ x],
                          Editable->False], 
                        InterpretationBox[
                          TagBox[
                            StyleBox["x",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ x], 
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox["x",
                          SequenceForm[ x],
                          Editable->False], 
                        InterpretationBox[
                          TagBox[
                            StyleBox["x",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ x], 
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False], 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ y], 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False], 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ y], 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox["z",
                          SequenceForm[ z],
                          Editable->False], 
                        InterpretationBox[
                          TagBox[
                            StyleBox["z",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ z], 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox["z",
                          SequenceForm[ z],
                          Editable->False], 
                        InterpretationBox[
                          TagBox[
                            StyleBox["z",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ z], 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Gamma]", 
                        InterpretationBox[\(x\[InvisibleSpace]y\),
                          SequenceForm[ x, y],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["x",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["y",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False], 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Gamma], 
                        SequenceForm[ x, y], 
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False], 
                          StyleForm[ y, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Tau]", 
                        InterpretationBox[\(x\[InvisibleSpace]y\),
                          SequenceForm[ x, y],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["x",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["y",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False], 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Tau], 
                        SequenceForm[ x, y], 
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False], 
                          StyleForm[ y, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Gamma]", 
                        InterpretationBox[\(y\[InvisibleSpace]z\),
                          SequenceForm[ y, z],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["y",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["z",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False], 
                            StyleForm[ z, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Gamma], 
                        SequenceForm[ y, z], 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False], 
                          StyleForm[ z, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Tau]", 
                        InterpretationBox[\(y\[InvisibleSpace]z\),
                          SequenceForm[ y, z],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["y",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["z",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False], 
                            StyleForm[ z, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Tau], 
                        SequenceForm[ y, z], 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False], 
                          StyleForm[ z, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Gamma]", 
                        InterpretationBox[\(z\[InvisibleSpace]x\),
                          SequenceForm[ z, x],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["z",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["x",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False], 
                            StyleForm[ x, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Gamma], 
                        SequenceForm[ z, x], 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False], 
                          StyleForm[ x, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Tau]", 
                        InterpretationBox[\(z\[InvisibleSpace]x\),
                          SequenceForm[ z, x],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["z",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["x",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False], 
                            StyleForm[ x, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Tau], 
                        SequenceForm[ z, x], 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False], 
                          StyleForm[ x, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\[ScriptA]",
    FontWeight->"Bold"],
  " =",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)]}],
                    SequenceForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], 
                      StyleForm[ 
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[ScriptCapitalE], 
                  SequenceForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]], 
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], 
                      StyleForm[ 
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)]}],
                    SequenceForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]], 
                  SequenceForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16], TraditionalForm]]],
  " is the total energy issued from the progressive application of a \
\"force\" from 0 to ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Sigma]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  FontColor -> RGBColor[ 1.0, 0.0, 0.0]], ShowContents -> 
                False], 
              StyleForm[ 
                StyleForm[ 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  FontColor -> RGBColor[ 1.0, 0.0, 0.0]], ShowContents -> 
                False]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
            Editable->False]], TraditionalForm]]],
  " (which can be written ",
  StyleBox["t",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[ScriptCapitalE]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox["l",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1.0, 0.0, 0.0]]&)]}],
                  SequenceForm[ 
                    StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ \[ScriptCapitalE], 
                SequenceForm[ 
                  StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]], 
                SequenceForm[ 
                  StyleForm[ 
                    StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[CapitalEpsilon]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["l",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1.0, 0.0, 0.0]]&)]}],
                  SequenceForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                  Editable->False]],
              Subsuperscript[ \[CapitalEpsilon], 
                SequenceForm[ 
                  StyleForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False]], 
                SequenceForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  ", 0 \[LessEqual] ",
  StyleBox["t",
    FontWeight->"Bold"],
  " \[LessEqual]1) during a \"displacement\" ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[ScriptCapitalE]", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
                
                SequenceForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                Editable->False], 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False]],
                Editable->False]],
            Subsuperscript[ \[ScriptCapitalE], 
              SequenceForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]], 
              SequenceForm[ 
                StyleForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False], 
                StyleForm[ 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["\[ScriptA]",
    FontWeight->"Bold"],
  " is the sum ",
  Cell[BoxData[
      RowBox[{"\[Integral]", 
        RowBox[{"\[DifferentialD]", 
          StyleBox["\[ScriptA]",
            FontWeight->"Bold"]}]}]]],
  ". So that if we write "
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{"d", 
          StyleBox["\[ScriptA]",
            FontWeight->"Bold"], "\[Section]"}]], ":=", 
      RowBox[{
        StyleBox["(*",
          FontColor->RGBColor[1, 0.878431, 0.623529]], 
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Sigma]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False], 
                        StyleForm[ 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)]}],
                      SequenceForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                      
                      Editable->False]],
                  Subsuperscript[ \[Sigma], 
                    SequenceForm[ 
                      StyleForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], 
                      StyleForm[ 
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False]], 
                    SequenceForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
                  Editable->False],
                "TraditionalForm"], "[", "t", "]"}], " ", 
            RowBox[{"\[DifferentialD]", 
              RowBox[{"(", 
                RowBox[{"t", " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                            i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            StyleForm[ 
                            j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              StyleForm[ 
                              i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                              ShowContents -> False], 
                            StyleForm[ 
                              StyleForm[ 
                              j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                              ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]], 
                        SequenceForm[ 
                          StyleForm[ 
                            StyleForm[ 
                            i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False], 
                          StyleForm[ 
                            StyleForm[ 
                            j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], ")"}]}]}], " ", "="}], 
        StyleBox["*)",
          FontColor->RGBColor[1, 0.878431, 0.623529]]}], 
      "  ", \(t\ \[Sigma]uu[i, j] \[ScriptCapitalE]dd[i, 
            j] \[DifferentialD]t // ToFlavor[red]\)}]], "Input"],

Cell[TextData[{
  "we verify that ",
  StyleBox["\[ScriptA]",
    FontWeight->"Bold"],
  " is recovered ( ",
  StyleBox["\[ScriptA]",
    FontWeight->"Bold"],
  "\[Section] \[Congruent] ",
  StyleBox["\[ScriptA]",
    FontWeight->"Bold"],
  " ):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{
          StyleBox["\[ScriptA]",
            FontWeight->"Bold"], "\[Section]"}]], "=", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{\(\[Integral]\_0\%1\), 
            RowBox[{
              FractionBox[
                StyleBox[
                  RowBox[{"d", 
                    StyleBox["\[ScriptA]",
                      FontWeight->"Bold"], 
                    "\[Section]"}]], \(\[DifferentialD]t\)], \(\
\[DifferentialD]t\)}]}], ")"}], 
        "/.", \({\[DoubleStruckCapitalE]uuuu[i, j, l, m]\ \[ScriptCapitalE]dd[
                l, m] -> \[Sigma]uu[i, j]}\)}]}]], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The factor 1/2 comes from the progressive application of the stress. For an \
infinitesimal increment of stress and strain, we will have,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{"d", 
          StyleBox["\[ScriptA]",
            FontWeight->"Bold"], "$"}]], 
      "=", \(\[Sigma]uu[i, j] d\[ScriptCapitalE]dd[i, j] // 
        ToFlavor[red]\)}]], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["d\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ d\[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "On the other hand, we can also differentiate ",
  StyleBox["\[ScriptA]\[Section]",
    FontWeight->"Bold"],
  ". For this we need to simplify the derivation of a tensor component by \
another component of the same tensor (which must of course be independent).",
  "\n",
  "I propose the following ",
  StyleBox["simplification of  partial derivatives",
    FontVariations->{"Underline"->True}],
  " (It must be checked on various cases) :"
}], "Text"],

Cell["So that after differentiation :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(d\[ScriptCapitalE]dd[red@p, red@q]\), 
          RowBox[{"PartialD", "[", 
            RowBox[{
              StyleBox["\[ScriptA]",
                FontWeight->"Bold"], 
              ",", \(\[ScriptCapitalE]dd[red@p, red@q]\)}], "]"}]}], 
        "//", \(PartialDSimplification[g]\)}], "//", 
      "Expand"}], "\[IndentingNewLine]", \(\(%[\([1]\)] + \((\(%[\([2]\)] // 
                ConstitutiveLaw[\[Sigma]]\) // PartialDSimplification[g])\) // 
        Factor\) // MetricSimplify[g]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["d\[ScriptCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["p",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["q",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ p], 
                        red[ q]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["p",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["q",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ p], ShowContents -> False], 
                        StyleForm[ 
                          red[ q], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ d\[ScriptCapitalE], 
                    SequenceForm[ 
                      red[ p], 
                      red[ q]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ p], ShowContents -> False], 
                      StyleForm[ 
                        red[ q], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["g", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["p",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ p], ShowContents -> False], 
                        red[ i]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["p",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ p], 
                        StyleForm[ 
                          red[ i], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ g, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ p], ShowContents -> False], 
                      red[ i]], 
                    SequenceForm[ 
                      red[ p], 
                      StyleForm[ 
                        red[ i], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["g", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["q",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ q], ShowContents -> False], 
                        red[ j]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["q",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ q], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ g, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ q], ShowContents -> False], 
                      red[ j]], 
                    SequenceForm[ 
                      red[ q], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Sigma]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ i], 
                        red[ j]],
                      Editable->False]],
                  Subsuperscript[ \[Sigma], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ i], 
                      red[ j]]],
                  Editable->False],
                "TraditionalForm"]}], "+", 
            RowBox[{\(1\/2\), " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["d\[ScriptCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["p",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["q",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ p], 
                        red[ q]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["p",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["q",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ p], ShowContents -> False], 
                        StyleForm[ 
                          red[ q], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ d\[ScriptCapitalE], 
                    SequenceForm[ 
                      red[ p], 
                      red[ q]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ p], ShowContents -> False], 
                      StyleForm[ 
                        red[ q], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ i], 
                        red[ j]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ 
                      red[ i], 
                      red[ j]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Sigma]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                InterpretationBox[
                                  SubsuperscriptBox["\[ScriptCapitalE]", 
                                    InterpretationBox[
                                      RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["q",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                      SequenceForm[ 
                                        red[ p], 
                                        red[ q]],
                                      Editable->False], 
                                    InterpretationBox[
                                      RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["q",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ p], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ q], ShowContents -> False]],
                                      Editable->False]],
                                  Subsuperscript[ \[ScriptCapitalE], 
                                    SequenceForm[ 
                                      red[ p], 
                                      red[ q]], 
                                    SequenceForm[ 
                                      StyleForm[ 
                                        red[ p], ShowContents -> False], 
                                      StyleForm[ 
                                        red[ q], ShowContents -> False]]],
                                  Editable->False],
                                "TraditionalForm"]}],
                            SequenceForm[ ",", 
                              Tensor[ \[ScriptCapitalE], {Void, Void}, {
                                red[ p], 
                                red[ q]}]],
                            Editable->False],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        Dif[ 
                          Tensor[ \[ScriptCapitalE], {Void, Void}, {
                            red[ p], 
                            red[ q]}]]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              InterpretationBox[
                                RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                  FormBox[
                                    InterpretationBox[
                                      SubsuperscriptBox["\[ScriptCapitalE]", 
                                        InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["q",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ p], 
                                        red[ q]],
                                        Editable->False], 
                                        InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["q",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ p], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ q], ShowContents -> False]],
                                        Editable->False]],
                                      Subsuperscript[ \[ScriptCapitalE], 
                                        SequenceForm[ 
                                        red[ p], 
                                        red[ q]], 
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ p], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ q], ShowContents -> False]]],
                                      Editable->False],
                                    "TraditionalForm"]}],
                                SequenceForm[ ",", 
                                  Tensor[ \[ScriptCapitalE], {Void, Void}, {
                                    red[ p], 
                                    red[ q]}]],
                                Editable->False],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ i], 
                        red[ j], 
                        StyleForm[ 
                          Dif[ 
                            Tensor[ \[ScriptCapitalE], {Void, Void}, {
                              red[ p], 
                              red[ q]}]], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[Sigma], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      Dif[ 
                        Tensor[ \[ScriptCapitalE], {Void, Void}, {
                          red[ p], 
                          red[ q]}]]], 
                    SequenceForm[ 
                      red[ i], 
                      red[ j], 
                      StyleForm[ 
                        Dif[ 
                          Tensor[ \[ScriptCapitalE], {Void, Void}, {
                            red[ p], 
                            red[ q]}]], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["d\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["p",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["q",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ p], 
                      red[ q]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["q",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ p], ShowContents -> False], 
                      StyleForm[ 
                        red[ q], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ d\[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ p], 
                    red[ q]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ p], ShowContents -> False], 
                    StyleForm[ 
                      red[ q], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ i], 
                            red[ j]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              red[ j], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ i], 
                          red[ j]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["p",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["q",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              red[ j], ShowContents -> False], 
                            StyleForm[ 
                              red[ p], ShowContents -> False], 
                            StyleForm[ 
                              red[ q], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["p",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["q",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ i], 
                            red[ j], 
                            red[ p], 
                            red[ q]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckCapitalE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            red[ p], ShowContents -> False], 
                          StyleForm[ 
                            red[ q], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ i], 
                          red[ j], 
                          red[ p], 
                          red[ q]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ i], 
                            red[ j]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              red[ j], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ i], 
                          red[ j]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["l",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ l], 
                            red[ m]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ l], 
                          red[ m]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            FormBox[
                              InterpretationBox[
                                RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                  FormBox[
                                    InterpretationBox[
                                      SubsuperscriptBox["\[ScriptCapitalE]", 
                                        InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["q",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ p], 
                                        red[ q]],
                                        Editable->False], 
                                        InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["q",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ p], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ q], ShowContents -> False]],
                                        Editable->False]],
                                      Subsuperscript[ \[ScriptCapitalE], 
                                        SequenceForm[ 
                                        red[ p], 
                                        red[ q]], 
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ p], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ q], ShowContents -> False]]],
                                      Editable->False],
                                    "TraditionalForm"]}],
                                SequenceForm[ ",", 
                                  Tensor[ \[ScriptCapitalE], {Void, Void}, {
                                    red[ p], 
                                    red[ q]}]],
                                Editable->False],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              red[ j], ShowContents -> False], 
                            StyleForm[ 
                              red[ l], ShowContents -> False], 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            Dif[ 
                              Tensor[ \[ScriptCapitalE], {Void, Void}, {
                                red[ p], 
                                red[ q]}]]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["l",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  InterpretationBox[
                                    
                                    RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                      
                                      FormBox[
                                        InterpretationBox[
                                        
                                        SubsuperscriptBox["\[ScriptCapitalE]",
                                         
                                        InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["q",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ p], 
                                        red[ q]],
                                        Editable->False], 
                                        InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["q",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ p], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ q], ShowContents -> False]],
                                        Editable->False]],
                                        Subsuperscript[ \[ScriptCapitalE], 
                                        SequenceForm[ 
                                        red[ p], 
                                        red[ q]], 
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ p], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ q], ShowContents -> False]]],
                                        Editable->False],
                                        "TraditionalForm"]}],
                                    SequenceForm[ ",", 
                                      
                                      Tensor[ \[ScriptCapitalE], {Void, 
                                        Void}, {
                                        red[ p], 
                                        red[ q]}]],
                                    Editable->False],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            red[ i], 
                            red[ j], 
                            red[ l], 
                            red[ m], 
                            StyleForm[ 
                              Dif[ 
                                Tensor[ \[ScriptCapitalE], {Void, Void}, {
                                  red[ p], 
                                  red[ q]}]], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckCapitalE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          Dif[ 
                            Tensor[ \[ScriptCapitalE], {Void, Void}, {
                              red[ p], 
                              red[ q]}]]], 
                        SequenceForm[ 
                          red[ i], 
                          red[ j], 
                          red[ l], 
                          red[ m], 
                          StyleForm[ 
                            Dif[ 
                              Tensor[ \[ScriptCapitalE], {Void, Void}, {
                                red[ p], 
                                red[ q]}]], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["q",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ p], ShowContents -> False], 
                          StyleForm[ 
                            red[ q], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["q",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ p], 
                          red[ q]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ p], ShowContents -> False], 
                        StyleForm[ 
                          red[ q], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ p], 
                        red[ q]]],
                    Editable->False],
                  "TraditionalForm"]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The second term in the parenthesis is zero, because \[DoubleStruckCapitalE] \
and \[ScriptCapitalE] are independent. The increment of strain energy is \
then,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{"d", 
          StyleBox["\[ScriptA]",
            FontWeight->"Bold"]}]], 
      "=", \(% /. \((Tensor[\[DoubleStruckCapitalE], {red@i, red@j, red@l, 
                red@m, Void}, {Void, Void, Void, Void, 
                Dif[Tensor[\[ScriptCapitalE], {Void, Void}, {red@p, 
                      red@q}]]}])\) -> 0\)}]], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["d\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["p",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["q",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ p], 
                      red[ q]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["q",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ p], ShowContents -> False], 
                      StyleForm[ 
                        red[ q], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ d\[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ p], 
                    red[ q]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ p], ShowContents -> False], 
                    StyleForm[ 
                      red[ q], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ i], 
                            red[ j]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              red[ j], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ i], 
                          red[ j]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["p",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["q",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              red[ j], ShowContents -> False], 
                            StyleForm[ 
                              red[ p], ShowContents -> False], 
                            StyleForm[ 
                              red[ q], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["p",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["q",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ i], 
                            red[ j], 
                            red[ p], 
                            red[ q]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckCapitalE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            red[ p], ShowContents -> False], 
                          StyleForm[ 
                            red[ q], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ i], 
                          red[ j], 
                          red[ p], 
                          red[ q]]],
                      Editable->False],
                    "TraditionalForm"]}], "+", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["q",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ p], ShowContents -> False], 
                          StyleForm[ 
                            red[ q], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["q",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ p], 
                          red[ q]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ p], ShowContents -> False], 
                        StyleForm[ 
                          red[ q], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ p], 
                        red[ q]]],
                    Editable->False],
                  "TraditionalForm"]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["and,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"zero", "=", 
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"d", 
              StyleBox["\[ScriptA]",
                FontWeight->"Bold"], "$"}]], "-", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[
                RowBox[{"d", 
                  StyleBox["\[ScriptA]",
                    FontWeight->"Bold"]}]], 
              StyleBox["/.",
                FontWeight->"Bold"], 
              StyleBox[\({p -> i, q -> j, i -> p, j -> q}\),
                FontWeight->"Bold"]}], 
            StyleBox[")",
              FontWeight->"Bold"]}]}], "//", "Simplify"}]}]], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{\(1\/2\), " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["d\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ d\[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ i], 
                          red[ j]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ i], 
                        red[ j]]],
                    Editable->False],
                  "TraditionalForm"], "-", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["p",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["q",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ p], 
                            red[ q]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["p",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["q",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ p], ShowContents -> False], 
                            StyleForm[ 
                              red[ q], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          red[ p], 
                          red[ q]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ p], ShowContents -> False], 
                          StyleForm[ 
                            red[ q], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["p",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["q",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ p], ShowContents -> False], 
                            StyleForm[ 
                              red[ q], ShowContents -> False], 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              red[ j], ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["p",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["q",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ p], 
                            red[ q], 
                            red[ i], 
                            red[ j]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckCapitalE], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ p], ShowContents -> False], 
                          StyleForm[ 
                            red[ q], ShowContents -> False], 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]], 
                        SequenceForm[ 
                          red[ p], 
                          red[ q], 
                          red[ i], 
                          red[ j]]],
                      Editable->False],
                    "TraditionalForm"]}]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This shows that we have also   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j]],
                  Editable->False]],
              Subsuperscript[ \[Sigma], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i], 
                  red[ j]]],
              Editable->False],
            "TraditionalForm"], 
          FormBox[
            RowBox[{"=", " ", 
              InterpretationBox[
                SubsuperscriptBox["\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["p",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["q",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ p], 
                      red[ q]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["q",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ p], ShowContents -> False], 
                      StyleForm[ 
                        red[ q], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ p], 
                    red[ q]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ p], ShowContents -> False], 
                    StyleForm[ 
                      red[ q], ShowContents -> False]]],
                Editable->False]}],
            "TraditionalForm"], " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["p",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["q",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ p], ShowContents -> False], 
                    StyleForm[ 
                      red[ q], ShowContents -> False], 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["p",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["q",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ p], 
                    red[ q], 
                    red[ i], 
                    red[ j]],
                  Editable->False]],
              Subsuperscript[ \[DoubleStruckCapitalE], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ p], ShowContents -> False], 
                  StyleForm[ 
                    red[ q], ShowContents -> False], 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]], 
                SequenceForm[ 
                  red[ p], 
                  red[ q], 
                  red[ i], 
                  red[ j]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  ", and that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["p",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["q",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ p, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ q, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["p",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["q",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1.0, 0.0, 0.0]]&)]}],
                  SequenceForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ p, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ q, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                  Editable->False]],
              Subsuperscript[ \[DoubleStruckCapitalE], 
                SequenceForm[ 
                  StyleForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ p, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ q, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False]], 
                SequenceForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ p, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ q, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
              Editable->False],
            "TraditionalForm"], "\[Congruent]", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["p",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["q",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ p, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ q, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox["p",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["q",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1.0, 0.0, 0.0]]&)]}],
                  SequenceForm[ 
                    StyleForm[ p, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ q, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                  Editable->False]],
              Subsuperscript[ \[DoubleStruckCapitalE], 
                SequenceForm[ 
                  StyleForm[ 
                    StyleForm[ p, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ q, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False]], 
                SequenceForm[ 
                  StyleForm[ p, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ q, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  ". A symmetry between the pairs {",
  StyleBox["i,j",
    FontColor->RGBColor[1, 0, 0]],
  "} and {",
  StyleBox["p,q",
    FontColor->RGBColor[1, 0, 0]],
  "} has to be included. \nThis is summarized in the rule :"
}], "Text"],

Cell[BoxData[
    \(\[DoubleStruckCapitalE]SymRule := \[DoubleStruckCapitalE]uuuu[i_, j_, 
          k_, l_] :> \[DoubleStruckCapitalE]uuuu @@ \((Sort[{Sort[{i, j}], 
                  Sort[{k, l}]}] // Flatten)\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[DoubleStruckCapitalE]uuuu[red@n, red@k, red@j, 
      red@l]\), "\[IndentingNewLine]", 
    \(% /. \[DoubleStruckCapitalE]SymRule\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["n",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["l",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ n], ShowContents -> False], 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    StyleForm[ 
                      red[ l], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["n",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["l",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ n], 
                    red[ k], 
                    red[ j], 
                    red[ l]],
                  Editable->False]],
              Subsuperscript[ \[DoubleStruckCapitalE], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ n], ShowContents -> False], 
                  StyleForm[ 
                    red[ k], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False], 
                  StyleForm[ 
                    red[ l], ShowContents -> False]], 
                SequenceForm[ 
                  red[ n], 
                  red[ k], 
                  red[ j], 
                  red[ l]]],
              Editable->False],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["l",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["n",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    StyleForm[ 
                      red[ l], ShowContents -> False], 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    StyleForm[ 
                      red[ n], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["l",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["n",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ j], 
                    red[ l], 
                    red[ k], 
                    red[ n]],
                  Editable->False]],
              Subsuperscript[ \[DoubleStruckCapitalE], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ j], ShowContents -> False], 
                  StyleForm[ 
                    red[ l], ShowContents -> False], 
                  StyleForm[ 
                    red[ k], ShowContents -> False], 
                  StyleForm[ 
                    red[ n], ShowContents -> False]], 
                SequenceForm[ 
                  red[ j], 
                  red[ l], 
                  red[ k], 
                  red[ n]]],
              Editable->False],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here is the list of the ",
  StyleBox["21",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" distinct elements of  ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\[DoubleStruckCapitalE]",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " (and similar lists in other basis) :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\((\[DoubleStruckCapitalE]uuuu[i, j, k, l] // 
            ArrayExpansion[{i, j, k, 
                l}])\) /. \[DoubleStruckCapitalE]SymRule;\)\), "\
\[IndentingNewLine]", 
    \(Distinct\[DoubleStruckCapitalE] = \(% // Flatten\) // 
        Union\), "\[IndentingNewLine]", 
    \(Length[%]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]1\
\[InvisibleSpace]1\),
                      SequenceForm[ 1, 1, 1, 1],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False]], 
                    SequenceForm[ 1, 1, 1, 1]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]1\
\[InvisibleSpace]2\),
                      SequenceForm[ 1, 1, 1, 2],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]], 
                    SequenceForm[ 1, 1, 1, 2]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]1\
\[InvisibleSpace]3\),
                      SequenceForm[ 1, 1, 1, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 1, 1, 1, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]2\
\[InvisibleSpace]2\),
                      SequenceForm[ 1, 1, 2, 2],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]], 
                    SequenceForm[ 1, 1, 2, 2]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]2\
\[InvisibleSpace]3\),
                      SequenceForm[ 1, 1, 2, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 1, 1, 2, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]3\
\[InvisibleSpace]3\),
                      SequenceForm[ 1, 1, 3, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 1, 1, 3, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]1\
\[InvisibleSpace]2\),
                      SequenceForm[ 1, 2, 1, 2],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]], 
                    SequenceForm[ 1, 2, 1, 2]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]1\
\[InvisibleSpace]3\),
                      SequenceForm[ 1, 2, 1, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 1, 2, 1, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]2\
\[InvisibleSpace]2\),
                      SequenceForm[ 1, 2, 2, 2],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]], 
                    SequenceForm[ 1, 2, 2, 2]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]2\
\[InvisibleSpace]3\),
                      SequenceForm[ 1, 2, 2, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 1, 2, 2, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]3\
\[InvisibleSpace]3\),
                      SequenceForm[ 1, 2, 3, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 1, 2, 3, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]1\
\[InvisibleSpace]3\),
                      SequenceForm[ 1, 3, 1, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 1, 3, 1, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]2\
\[InvisibleSpace]2\),
                      SequenceForm[ 1, 3, 2, 2],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]], 
                    SequenceForm[ 1, 3, 2, 2]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]2\
\[InvisibleSpace]3\),
                      SequenceForm[ 1, 3, 2, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 1, 3, 2, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]3\
\[InvisibleSpace]3\),
                      SequenceForm[ 1, 3, 3, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 1, 3, 3, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]2\
\[InvisibleSpace]2\),
                      SequenceForm[ 2, 2, 2, 2],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]], 
                    SequenceForm[ 2, 2, 2, 2]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]2\
\[InvisibleSpace]3\),
                      SequenceForm[ 2, 2, 2, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 2, 2, 2, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]3\
\[InvisibleSpace]3\),
                      SequenceForm[ 2, 2, 3, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 2, 2, 3, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(2\[InvisibleSpace]3\[InvisibleSpace]2\
\[InvisibleSpace]3\),
                      SequenceForm[ 2, 3, 2, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 2, 3, 2, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(2\[InvisibleSpace]3\[InvisibleSpace]3\
\[InvisibleSpace]3\),
                      SequenceForm[ 2, 3, 3, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 2, 3, 3, 3]],
                  Editable->False],
                "TraditionalForm"], ",", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["3",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(3\[InvisibleSpace]3\[InvisibleSpace]3\
\[InvisibleSpace]3\),
                      SequenceForm[ 3, 3, 3, 3],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]], 
                    SequenceForm[ 3, 3, 3, 3]],
                  Editable->False],
                "TraditionalForm"]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox["21",
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Hooke's law", "Subsection"],

Cell[TextData[{
  "For an",
  StyleBox[" isotropic",
    FontColor->RGBColor[0, 0, 1]],
  " body we have the well known relations using the Young's modulus ",
  StyleBox["\[CapitalEpsilon]",
    FontWeight->"Bold"],
  ", and the Poisson's ratio ",
  StyleBox["\[Nu]",
    FontWeight->"Bold"],
  " (we use here the notation ",
  StyleBox["\[Sigma]$",
    FontWeight->"Bold"],
  " for these particular values of the stress."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ResultFrame[
      SequenceForm[\*"\"\<\!\(\[Sigma]\^11\) = \>\"", \[Sigma]$uu[1, 
            1] = \(\[CapitalEpsilon]\/\(\((1 + \[Nu])\) \((1 - 
                      2  \[Nu])\)\)\) \((\((1 - \[Nu])\) \[ScriptCapitalE]dd[
                    1, 1] + \[Nu]\ \[ScriptCapitalE]dd[2, 
                    2] + \[Nu]\ \[ScriptCapitalE]dd[3, 
                    3])\)]]\), "\[IndentingNewLine]", 
    \(ResultFrame[\[IndentingNewLine]SequenceForm[\*"\"\<\!\(\[Sigma]\^12\) = \
\>\"", \[Sigma]$uu[1, 
            2] = \(\[CapitalEpsilon]\/\(2 \((1 + \[Nu])\)\)\) \((\
\[ScriptCapitalE]dd[1, 2] + \ \[ScriptCapitalE]dd[2, 1])\)]]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  InterpretationBox[
                    
                    RowBox[{"\<\"\\!\\(\[Sigma]\\^11\\) = \"\>", 
                      "\[InvisibleSpace]", 
                      FractionBox[
                        RowBox[{"\[CapitalEpsilon]", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{\((1 - \[Nu])\), " ", 
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["\[ScriptCapitalE]", 
                                      
                                      InterpretationBox[\(1\[InvisibleSpace]1\
\),
                                        SequenceForm[ 1, 1],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox["1",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox["1",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 1, ShowContents -> False], 
                                        
                                        StyleForm[ 1, ShowContents -> False]],
                                        
                                        Editable->False]],
                                    Subsuperscript[ \[ScriptCapitalE], 
                                      SequenceForm[ 1, 1], 
                                      SequenceForm[ 
                                        StyleForm[ 1, ShowContents -> False], 
                                        
                                        StyleForm[ 
                                        1, ShowContents -> False]]],
                                    Editable->False],
                                  "TraditionalForm"]}], "+", 
                              RowBox[{"\[Nu]", " ", 
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["\[ScriptCapitalE]", 
                                      
                                      InterpretationBox[\(2\[InvisibleSpace]2\
\),
                                        SequenceForm[ 2, 2],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox["2",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox["2",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 2, ShowContents -> False], 
                                        
                                        StyleForm[ 2, ShowContents -> False]],
                                        
                                        Editable->False]],
                                    Subsuperscript[ \[ScriptCapitalE], 
                                      SequenceForm[ 2, 2], 
                                      SequenceForm[ 
                                        StyleForm[ 2, ShowContents -> False], 
                                        
                                        StyleForm[ 
                                        2, ShowContents -> False]]],
                                    Editable->False],
                                  "TraditionalForm"]}], "+", 
                              RowBox[{"\[Nu]", " ", 
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["\[ScriptCapitalE]", 
                                      
                                      InterpretationBox[\(3\[InvisibleSpace]3\
\),
                                        SequenceForm[ 3, 3],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox["3",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox["3",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 3, ShowContents -> False], 
                                        
                                        StyleForm[ 3, ShowContents -> False]],
                                        
                                        Editable->False]],
                                    Subsuperscript[ \[ScriptCapitalE], 
                                      SequenceForm[ 3, 3], 
                                      SequenceForm[ 
                                        StyleForm[ 3, ShowContents -> False], 
                                        
                                        StyleForm[ 
                                        3, ShowContents -> False]]],
                                    Editable->False],
                                  "TraditionalForm"]}]}], 
                            ")"}]}], \(\((1 - 2\ \[Nu])\)\ \((\[Nu] + 
                              1)\)\)]}],
                    SequenceForm[ "\!\(\[Sigma]\^11\) = ", 
                      Times[ \[CapitalEpsilon], 
                        Power[ 
                          Plus[ 1, 
                            Times[ -2, \[Nu]]], -1], 
                        Power[ 
                          Plus[ 1, \[Nu]], -1], 
                        Plus[ 
                          Times[ 
                            Plus[ 1, 
                              Times[ -1, \[Nu]]], 
                            Tensor[ \[ScriptCapitalE], {Void, Void}, {1, 1}]],
                           
                          Times[ \[Nu], 
                            Tensor[ \[ScriptCapitalE], {Void, Void}, {2, 2}]],
                           
                          Times[ \[Nu], 
                            
                            Tensor[ \[ScriptCapitalE], {Void, Void}, {3, 
                              3}]]]]],
                    Editable->False], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "5", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  SequenceForm[ "\!\(\[Sigma]\^11\) = ", 
                    Times[ \[CapitalEpsilon], 
                      Power[ 
                        Plus[ 1, 
                          Times[ -2, \[Nu]]], -1], 
                      Power[ 
                        Plus[ 1, \[Nu]], -1], 
                      Plus[ 
                        Times[ 
                          Plus[ 1, 
                            Times[ -1, \[Nu]]], 
                          Tensor[ \[ScriptCapitalE], {Void, Void}, {1, 1}]], 
                        Times[ \[Nu], 
                          Tensor[ \[ScriptCapitalE], {Void, Void}, {2, 2}]], 
                        Times[ \[Nu], 
                          
                          Tensor[ \[ScriptCapitalE], {Void, Void}, {3, 
                            3}]]]]], "      (4.", 5, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  InterpretationBox[
                    
                    RowBox[{"\<\"\\!\\(\[Sigma]\\^12\\) = \"\>", 
                      "\[InvisibleSpace]", 
                      FractionBox[
                        RowBox[{"\[CapitalEpsilon]", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              FormBox[
                                InterpretationBox[
                                  SubsuperscriptBox["\[ScriptCapitalE]", 
                                    
                                    InterpretationBox[\(1\[InvisibleSpace]2\),
                                      
                                      SequenceForm[ 1, 2],
                                      Editable->False], 
                                    InterpretationBox[
                                      RowBox[{
                                        TagBox[
                                        StyleBox["1",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox["2",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                      SequenceForm[ 
                                        StyleForm[ 1, ShowContents -> False], 
                                        
                                        StyleForm[ 2, ShowContents -> False]],
                                      
                                      Editable->False]],
                                  Subsuperscript[ \[ScriptCapitalE], 
                                    SequenceForm[ 1, 2], 
                                    SequenceForm[ 
                                      StyleForm[ 1, ShowContents -> False], 
                                      StyleForm[ 2, ShowContents -> False]]],
                                  Editable->False],
                                "TraditionalForm"], "+", 
                              FormBox[
                                InterpretationBox[
                                  SubsuperscriptBox["\[ScriptCapitalE]", 
                                    
                                    InterpretationBox[\(2\[InvisibleSpace]1\),
                                      
                                      SequenceForm[ 2, 1],
                                      Editable->False], 
                                    InterpretationBox[
                                      RowBox[{
                                        TagBox[
                                        StyleBox["2",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox["1",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                      SequenceForm[ 
                                        StyleForm[ 2, ShowContents -> False], 
                                        
                                        StyleForm[ 1, ShowContents -> False]],
                                      
                                      Editable->False]],
                                  Subsuperscript[ \[ScriptCapitalE], 
                                    SequenceForm[ 2, 1], 
                                    SequenceForm[ 
                                      StyleForm[ 2, ShowContents -> False], 
                                      StyleForm[ 1, ShowContents -> False]]],
                                  Editable->False],
                                "TraditionalForm"]}], 
                            ")"}]}], \(2\ \((\[Nu] + 1)\)\)]}],
                    SequenceForm[ "\!\(\[Sigma]\^12\) = ", 
                      Times[ 
                        Rational[ 1, 2], \[CapitalEpsilon], 
                        Power[ 
                          Plus[ 1, \[Nu]], -1], 
                        Plus[ 
                          Tensor[ \[ScriptCapitalE], {Void, Void}, {1, 2}], 
                          Tensor[ \[ScriptCapitalE], {Void, Void}, {2, 1}]]]],
                    
                    Editable->False], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "6", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  SequenceForm[ "\!\(\[Sigma]\^12\) = ", 
                    Times[ 
                      Rational[ 1, 2], \[CapitalEpsilon], 
                      Power[ 
                        Plus[ 1, \[Nu]], -1], 
                      Plus[ 
                        Tensor[ \[ScriptCapitalE], {Void, Void}, {1, 2}], 
                        Tensor[ \[ScriptCapitalE], {Void, Void}, {2, 1}]]]], 
                  "      (4.", 6, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "From which, using the constitutive equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], 
                      StyleForm[ 
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)]}],
                    SequenceForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]], 
                  SequenceForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
                Editable->False],
              "TraditionalForm"], "\[InvisibleSpace]", "\<\" = \"\>", 
            "\[InvisibleSpace]", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)]}],
                      SequenceForm[ 
                        StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        
                        StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                      
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          StyleForm[ 
                          l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False], 
                        StyleForm[ 
                          StyleForm[ 
                          m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ 
                      StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]], 
                    SequenceForm[ 
                      StyleForm[ 
                        StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], 
                      StyleForm[ 
                        StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False], 
                        StyleForm[ 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False], 
                        StyleForm[ 
                          StyleForm[ 
                          l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False], 
                        StyleForm[ 
                          StyleForm[ 
                          m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)]}],
                      SequenceForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        
                        StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        
                        StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                      
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], 
                      StyleForm[ 
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], 
                      StyleForm[ 
                        StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], 
                      StyleForm[ 
                        StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False]], 
                    SequenceForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
                  Editable->False],
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  " and the symmetry relations, we extract the ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["l",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["m",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox["j",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox["l",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox["m",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
            SequenceForm[ 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ l, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
            Editable->False]], TraditionalForm]]],
  ". In the \"",
  StyleBox["black",
    FontWeight->"Bold"],
  "\" cartesian basis :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(CoefficientList[\((\[Sigma]\[Section]uu[1, 1] - \[Sigma]$uu[1, 1] // 
                    EinsteinSum[])\) /. \[DoubleStruckCapitalE]SymRule // 
              SymmetricStandardOrder[\[ScriptCapitalE]], {\[ScriptCapitalE]dd[
                1, 1], \[ScriptCapitalE]dd[2, 2], \[ScriptCapitalE]dd[3, 
                3], \[ScriptCapitalE]dd[1, 2], \[ScriptCapitalE]dd[1, 
                3], \[ScriptCapitalE]dd[2, 3]}] // Flatten\) // 
        Union;\)\), "\[IndentingNewLine]", 
    \(res11 = \(Solve[% == 
              0, {\[DoubleStruckCapitalE]uuuu[1, 1, 1, 
                1], \[DoubleStruckCapitalE]uuuu[1, 1, 1, 
                2], \[DoubleStruckCapitalE]uuuu[1, 1, 1, 
                3], \[DoubleStruckCapitalE]uuuu[1, 1, 2, 
                2], \[DoubleStruckCapitalE]uuuu[1, 1, 2, 
                3], \[DoubleStruckCapitalE]uuuu[1, 1, 3, 3]}]\)[\([1]\)] // 
        Simplify\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
1\[InvisibleSpace]1\),
                        SequenceForm[ 1, 1, 1, 1],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 1, 1]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(\(\[CapitalEpsilon]\ \((\[Nu] - 
                          1)\)\)\/\(2\ \[Nu]\^2 + \[Nu] - 1\)\)}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
1\[InvisibleSpace]2\),
                        SequenceForm[ 1, 1, 1, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 1, 2]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
1\[InvisibleSpace]3\),
                        SequenceForm[ 1, 1, 1, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 1, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
2\[InvisibleSpace]2\),
                        SequenceForm[ 1, 1, 2, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 2, 2]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(2\ \[Nu]\^2 + \
\[Nu] - 1\)\)\)}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
2\[InvisibleSpace]3\),
                        SequenceForm[ 1, 1, 2, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 2, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 1, 1, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(2\ \[Nu]\^2 + \
\[Nu] - 1\)\)\)}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(CoefficientList[\((\[Sigma]\[Section]uu[1, 2] - \[Sigma]$uu[1, 2] // 
                    EinsteinSum[])\) /. \[DoubleStruckCapitalE]SymRule // 
              SymmetricStandardOrder[\[ScriptCapitalE]], {\[ScriptCapitalE]dd[
                1, 1], \[ScriptCapitalE]dd[2, 2], \[ScriptCapitalE]dd[3, 
                3], \[ScriptCapitalE]dd[1, 2], \[ScriptCapitalE]dd[1, 
                3], \[ScriptCapitalE]dd[2, 3]}] // Flatten\) // 
        Union;\)\), "\[IndentingNewLine]", 
    \(res12 = \(Solve[% == 
              0, {\[DoubleStruckCapitalE]uuuu[1, 2, 1, 
                2], \[DoubleStruckCapitalE]uuuu[1, 1, 1, 
                2], \[DoubleStruckCapitalE]uuuu[1, 2, 1, 
                3], \[DoubleStruckCapitalE]uuuu[1, 2, 2, 
                2], \[DoubleStruckCapitalE]uuuu[1, 2, 2, 
                3], \[DoubleStruckCapitalE]uuuu[1, 2, 3, 3]}]\)[\([1]\)] // 
        Simplify\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
1\[InvisibleSpace]2\),
                        SequenceForm[ 1, 1, 1, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 1, 2]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]\
1\[InvisibleSpace]2\),
                        SequenceForm[ 1, 2, 1, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 1, 2, 1, 2]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(\[CapitalEpsilon]\/\(2\ \[Nu] + 2\)\)}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]\
1\[InvisibleSpace]3\),
                        SequenceForm[ 1, 2, 1, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 2, 1, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]\
2\[InvisibleSpace]2\),
                        SequenceForm[ 1, 2, 2, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 1, 2, 2, 2]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]\
2\[InvisibleSpace]3\),
                        SequenceForm[ 1, 2, 2, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 2, 2, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 1, 2, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 2, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["and all the cyclic permutations",
    FontVariations->{"Underline"->True}],
  " of {1,2,3}. In fact there is only 4 distinct and non-zero values :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m3[i_] := Mod[i, 3] + 1;\)\), "\[IndentingNewLine]", 
    \(res22 = \(res11 /. {\[DoubleStruckCapitalE]uuuu[i_, j_, k_, 
                l_] -> \[DoubleStruckCapitalE]uuuu[i // m3, j // m3, k // m3, 
                l // m3]}\) /. \[DoubleStruckCapitalE]SymRule\), "\
\[IndentingNewLine]", 
    \(res33 = \(res22 /. {\[DoubleStruckCapitalE]uuuu[i_, j_, k_, 
                l_] -> \[DoubleStruckCapitalE]uuuu[i // m3, j // m3, k // m3, 
                l // m3]}\) /. \[DoubleStruckCapitalE]SymRule\), "\
\[IndentingNewLine]", 
    \(res23 = \(res12 /. {\[DoubleStruckCapitalE]uuuu[i_, j_, k_, 
                l_] -> \[DoubleStruckCapitalE]uuuu[i // m3, j // m3, k // m3, 
                l // m3]}\) /. \[DoubleStruckCapitalE]SymRule\), "\
\[IndentingNewLine]", 
    \(res31 = \(res23 /. {\[DoubleStruckCapitalE]uuuu[i_, j_, k_, 
                l_] -> \[DoubleStruckCapitalE]uuuu[i // m3, j // m3, k // m3, 
                l // m3]}\) /. \[DoubleStruckCapitalE]SymRule\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]\
2\[InvisibleSpace]2\),
                        SequenceForm[ 2, 2, 2, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 2, 2, 2, 2]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(\(\[CapitalEpsilon]\ \((\[Nu] - 
                          1)\)\)\/\(2\ \[Nu]\^2 + \[Nu] - 1\)\)}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]\
2\[InvisibleSpace]3\),
                        SequenceForm[ 2, 2, 2, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 2, 2, 2, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]\
2\[InvisibleSpace]2\),
                        SequenceForm[ 1, 2, 2, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 1, 2, 2, 2]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 2, 2, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 2, 2, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(2\ \[Nu]\^2 + \
\[Nu] - 1\)\)\)}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]\
2\[InvisibleSpace]2\),
                        SequenceForm[ 1, 3, 2, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 1, 3, 2, 2]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
2\[InvisibleSpace]2\),
                        SequenceForm[ 1, 1, 2, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 2, 2]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(2\ \[Nu]\^2 + \
\[Nu] - 1\)\)\)}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(3\[InvisibleSpace]3\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 3, 3, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 3, 3, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(\(\[CapitalEpsilon]\ \((\[Nu] - 
                          1)\)\)\/\(2\ \[Nu]\^2 + \[Nu] - 1\)\)}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 1, 3, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 3, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(2\[InvisibleSpace]3\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 2, 3, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 2, 3, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 1, 1, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(2\ \[Nu]\^2 + \
\[Nu] - 1\)\)\)}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 1, 2, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 2, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 2, 2, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 2, 2, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(2\ \[Nu]\^2 + \
\[Nu] - 1\)\)\)}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]\
2\[InvisibleSpace]3\),
                        SequenceForm[ 2, 2, 2, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 2, 2, 2, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(2\[InvisibleSpace]3\[InvisibleSpace]\
2\[InvisibleSpace]3\),
                        SequenceForm[ 2, 3, 2, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 2, 3, 2, 3]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(\[CapitalEpsilon]\/\(2\ \[Nu] + 2\)\)}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]\
2\[InvisibleSpace]3\),
                        SequenceForm[ 1, 2, 2, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 2, 2, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(2\[InvisibleSpace]3\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 2, 3, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 2, 3, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]\
2\[InvisibleSpace]3\),
                        SequenceForm[ 1, 3, 2, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 3, 2, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
2\[InvisibleSpace]3\),
                        SequenceForm[ 1, 1, 2, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 2, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]\
3\[InvisibleSpace]3\),
                        SequenceForm[ 1, 3, 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 3, 3, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]\
1\[InvisibleSpace]3\),
                        SequenceForm[ 1, 3, 1, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 3, 1, 3]],
                    Editable->False],
                  "TraditionalForm"], 
                "\[Rule]", \(\[CapitalEpsilon]\/\(2\ \[Nu] + 2\)\)}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]\
2\[InvisibleSpace]3\),
                        SequenceForm[ 1, 3, 2, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 3, 2, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]\
1\[InvisibleSpace]3\),
                        SequenceForm[ 1, 1, 1, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 1, 1, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]\
1\[InvisibleSpace]3\),
                        SequenceForm[ 1, 2, 1, 3],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 1, 2, 1, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      
                      InterpretationBox[\(1\[InvisibleSpace]3\[InvisibleSpace]\
2\[InvisibleSpace]2\),
                        SequenceForm[ 1, 3, 2, 2],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 1, 3, 2, 2]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", "0"}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ElasticModuli = \(\(\(\(\(Distinct\[DoubleStruckCapitalE] /. res11\) /. 
                res22\) /. res33\) /. res12\) /. res23\) /. res31\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\({\(\[CapitalEpsilon]\ \((\[Nu] - 1)\)\)\/\(2\ \[Nu]\^2 + \
\[Nu] - 1\), 0, 
            0, \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(2\ \[Nu]\^2 + \[Nu] - 
                    1\)\)\), 
            0, \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(2\ \[Nu]\^2 + \[Nu] - 
                    1\)\)\), \[CapitalEpsilon]\/\(2\ \[Nu] + 2\), 0, 0, 0, 
            0, \[CapitalEpsilon]\/\(2\ \[Nu] + 2\), 0, 0, 
            0, \(\[CapitalEpsilon]\ \((\[Nu] - 1)\)\)\/\(2\ \[Nu]\^2 + \[Nu] \
- 1\), 0, \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(2\ \[Nu]\^2 + \[Nu] - 
                    1\)\)\), \[CapitalEpsilon]\/\(2\ \[Nu] + 2\), 
            0, \(\[CapitalEpsilon]\ \((\[Nu] - 1)\)\)\/\(2\ \[Nu]\^2 + \[Nu] \
- 1\)}\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We can also introduce the Lame's coefficients \[Lambda] and \[Mu] :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]LameRule = \(Solve[{\(-\(\(\
\[CapitalEpsilon]\ \[Nu]\)\/\(\((\[Nu] + 1)\)\ \((2\ \[Nu] - 
                              1)\)\)\)\) == \[Lambda], \[CapitalEpsilon]\/\(2\
\ \((\[Nu] + 1)\)\) == \[Mu]}, {\[CapitalEpsilon]\ , \[Nu]}]\)[\([1]\)] // 
          Simplify]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              
              InterpretationBox[\("      "\[InvisibleSpace]{\[CapitalEpsilon] \
\[Rule] \(\[Mu]\ \((3\ \[Lambda] + 2\ \[Mu])\)\)\/\(\[Lambda] + \[Mu]\), \
\[Nu] \[Rule] \[Lambda]\/\(2\ \((\[Lambda] + \[Mu])\)\)}\[InvisibleSpace]"    \
  (4."\[InvisibleSpace]7\[InvisibleSpace]")"\),
                SequenceForm[ "      ", {\[CapitalEpsilon] -> Times[ \[Mu], 
                    Power[ 
                      Plus[ \[Lambda], \[Mu]], -1], 
                    Plus[ 
                      Times[ 3, \[Lambda]], 
                      Times[ 2, \[Mu]]]], \[Nu] -> Times[ 
                    Rational[ 1, 2], \[Lambda], 
                    Power[ 
                      Plus[ \[Lambda], \[Mu]], -1]]}, "      (4.", 7, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        RowBox[{
          StyleBox["In",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[" ",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["two",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[" ",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["dimensions",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[" ",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["we",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox[" ",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["have",
            FontColor->RGBColor[0, 0, 1]], " ", \((see\ below)\)}], "  ", 
        "*)"}], " ", 
      "\[IndentingNewLine]", \(ResultFrame[\[IndentingNewLine]{\
\[CapitalEpsilon] -> 
            2  \[Mu] \((2  \[Mu] + 
                    2  \[Lambda])\)/\((2  \[Mu] + \[Lambda])\), \[Nu] -> \
\[Lambda]/\((\[Lambda] + 2  \[Mu])\)}]\)}]], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              
              InterpretationBox[\("      "\[InvisibleSpace]{\[CapitalEpsilon] \
\[Rule] \(2\ \[Mu]\ \((2\ \[Lambda] + 2\ \[Mu])\)\)\/\(\[Lambda] + 2\ \
\[Mu]\), \[Nu] \[Rule] \[Lambda]\/\(\[Lambda] + 2\ \[Mu]\)}\[InvisibleSpace]" \
     (4."\[InvisibleSpace]8\[InvisibleSpace]")"\),
                SequenceForm[ 
                "      ", {\[CapitalEpsilon] -> Times[ 2, \[Mu], 
                    Power[ 
                      Plus[ \[Lambda], 
                        Times[ 2, \[Mu]]], -1], 
                    Plus[ 
                      Times[ 2, \[Lambda]], 
                      Times[ 2, \[Mu]]]], \[Nu] -> Times[ \[Lambda], 
                    Power[ 
                      Plus[ \[Lambda], 
                        Times[ 2, \[Mu]]], -1]]}, "      (4.", 8, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["TABLE OF ELASTIC MODULI :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Thread[
        Distinct\[DoubleStruckCapitalE] == \((ElasticModuli /. LameRule // 
              FullSimplify)\)] // TableForm\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          InterpretationBox[GridBox[{
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]1\
\[InvisibleSpace]1\[InvisibleSpace]1\),
                            SequenceForm[ 1, 1, 1, 1],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False]], 
                          SequenceForm[ 1, 1, 1, 1]],
                        Editable->False],
                      "TraditionalForm"], "==", \(\[Lambda] + 2\ \[Mu]\)}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]1\
\[InvisibleSpace]1\[InvisibleSpace]2\),
                            SequenceForm[ 1, 1, 1, 2],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False]], 
                          SequenceForm[ 1, 1, 1, 2]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]1\
\[InvisibleSpace]1\[InvisibleSpace]3\),
                            SequenceForm[ 1, 1, 1, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 1, 1, 1, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]1\
\[InvisibleSpace]2\[InvisibleSpace]2\),
                            SequenceForm[ 1, 1, 2, 2],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False]], 
                          SequenceForm[ 1, 1, 2, 2]],
                        Editable->False],
                      "TraditionalForm"], "==", "\[Lambda]"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]1\
\[InvisibleSpace]2\[InvisibleSpace]3\),
                            SequenceForm[ 1, 1, 2, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 1, 1, 2, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]1\
\[InvisibleSpace]3\[InvisibleSpace]3\),
                            SequenceForm[ 1, 1, 3, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 1, 1, 3, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "\[Lambda]"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]2\
\[InvisibleSpace]1\[InvisibleSpace]2\),
                            SequenceForm[ 1, 2, 1, 2],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False]], 
                          SequenceForm[ 1, 2, 1, 2]],
                        Editable->False],
                      "TraditionalForm"], "==", "\[Mu]"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]2\
\[InvisibleSpace]1\[InvisibleSpace]3\),
                            SequenceForm[ 1, 2, 1, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 1, 2, 1, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]2\
\[InvisibleSpace]2\[InvisibleSpace]2\),
                            SequenceForm[ 1, 2, 2, 2],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False]], 
                          SequenceForm[ 1, 2, 2, 2]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]2\
\[InvisibleSpace]2\[InvisibleSpace]3\),
                            SequenceForm[ 1, 2, 2, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 1, 2, 2, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]2\
\[InvisibleSpace]3\[InvisibleSpace]3\),
                            SequenceForm[ 1, 2, 3, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 1, 2, 3, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]3\
\[InvisibleSpace]1\[InvisibleSpace]3\),
                            SequenceForm[ 1, 3, 1, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 1, 3, 1, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "\[Mu]"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]3\
\[InvisibleSpace]2\[InvisibleSpace]2\),
                            SequenceForm[ 1, 3, 2, 2],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False]], 
                          SequenceForm[ 1, 3, 2, 2]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]3\
\[InvisibleSpace]2\[InvisibleSpace]3\),
                            SequenceForm[ 1, 3, 2, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 1, 3, 2, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(1\[InvisibleSpace]3\
\[InvisibleSpace]3\[InvisibleSpace]3\),
                            SequenceForm[ 1, 3, 3, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 1, 3, 3, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(2\[InvisibleSpace]2\
\[InvisibleSpace]2\[InvisibleSpace]2\),
                            SequenceForm[ 2, 2, 2, 2],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False]], 
                          SequenceForm[ 2, 2, 2, 2]],
                        Editable->False],
                      "TraditionalForm"], "==", \(\[Lambda] + 2\ \[Mu]\)}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(2\[InvisibleSpace]2\
\[InvisibleSpace]2\[InvisibleSpace]3\),
                            SequenceForm[ 2, 2, 2, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 2, 2, 2, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(2\[InvisibleSpace]2\
\[InvisibleSpace]3\[InvisibleSpace]3\),
                            SequenceForm[ 2, 2, 3, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 2, 2, 3, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "\[Lambda]"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(2\[InvisibleSpace]3\
\[InvisibleSpace]2\[InvisibleSpace]3\),
                            SequenceForm[ 2, 3, 2, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 2, 3, 2, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "\[Mu]"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(2\[InvisibleSpace]3\
\[InvisibleSpace]3\[InvisibleSpace]3\),
                            SequenceForm[ 2, 3, 3, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 2, 3, 3, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", "0"}]},
                {
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["3",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False], 
                              StyleForm[ 3, ShowContents -> False]],
                            Editable->False], 
                          
                          InterpretationBox[\(3\[InvisibleSpace]3\
\[InvisibleSpace]3\[InvisibleSpace]3\),
                            SequenceForm[ 3, 3, 3, 3],
                            Editable->False]],
                        Subsuperscript[ \[DoubleStruckCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False], 
                            StyleForm[ 3, ShowContents -> False]], 
                          SequenceForm[ 3, 3, 3, 3]],
                        Editable->False],
                      "TraditionalForm"], "==", \(\[Lambda] + 2\ \[Mu]\)}]}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            TableForm[ {
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 1, 1, 1}, {Void, Void, 
                  Void, Void}], 
                Plus[ \[Lambda], 
                  Times[ 2, \[Mu]]]], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 1, 1, 2}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 1, 1, 3}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 1, 2, 2}, {Void, Void, 
                  Void, Void}], \[Lambda]], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 1, 2, 3}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 1, 3, 3}, {Void, Void, 
                  Void, Void}], \[Lambda]], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 2, 1, 2}, {Void, Void, 
                  Void, Void}], \[Mu]], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 2, 1, 3}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 2, 2, 2}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 2, 2, 3}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 2, 3, 3}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 3, 1, 3}, {Void, Void, 
                  Void, Void}], \[Mu]], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 3, 2, 2}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 3, 2, 3}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {1, 3, 3, 3}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {2, 2, 2, 2}, {Void, Void, 
                  Void, Void}], 
                Plus[ \[Lambda], 
                  Times[ 2, \[Mu]]]], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {2, 2, 2, 3}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {2, 2, 3, 3}, {Void, Void, 
                  Void, Void}], \[Lambda]], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {2, 3, 2, 3}, {Void, Void, 
                  Void, Void}], \[Mu]], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {2, 3, 3, 3}, {Void, Void, 
                  Void, Void}], 0], 
              Equal[ 
                
                Tensor[ \[DoubleStruckCapitalE], {3, 3, 3, 3}, {Void, Void, 
                  Void, Void}], 
                Plus[ \[Lambda], 
                  Times[ 2, \[Mu]]]]}]],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
In the \"black\" canonical Euclidean basis the above relation can be \
summarized in the form :\
\>", "Text"],

Cell[BoxData[
    \(\[DoubleStruckCapitalE]\[Section]uuuu[i_, j_, k_, 
        l_] := \[Lambda]\ Tensor[\[Delta], {i, j}, {Void, Void}] 
          Tensor[\[Delta], {k, l}, {Void, 
              Void}] + \[Mu]\ \((Tensor[\[Delta], {i, k}, {Void, Void}] 
                Tensor[\[Delta], {j, l}, {Void, Void}] + 
              Tensor[\[Delta], {i, l}, {Void, Void}] 
                Tensor[\[Delta], {j, k}, {Void, Void}])\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SequenceForm["\<                 \>", \[DoubleStruckCapitalE]uuuu[i, j, 
        l, m], "\< = \>", \[DoubleStruckCapitalE]\[Section]uuuu[i, j, l, 
        m]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          InterpretationBox[
            RowBox[{"\<\"                 \"\>", "\[InvisibleSpace]", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["i",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["j",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["l",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["m",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ i, ShowContents -> False], 
                        StyleForm[ j, ShowContents -> False], 
                        StyleForm[ l, ShowContents -> False], 
                        StyleForm[ m, ShowContents -> False]],
                      Editable->False], 
                    
                    InterpretationBox[\(i\[InvisibleSpace]j\[InvisibleSpace]l\
\[InvisibleSpace]m\),
                      SequenceForm[ i, j, l, m],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckCapitalE], 
                    SequenceForm[ 
                      StyleForm[ i, ShowContents -> False], 
                      StyleForm[ j, ShowContents -> False], 
                      StyleForm[ l, ShowContents -> False], 
                      StyleForm[ m, ShowContents -> False]], 
                    SequenceForm[ i, j, l, m]],
                  Editable->False],
                "TraditionalForm"], "\[InvisibleSpace]", "\<\" = \"\>", 
              "\[InvisibleSpace]", 
              RowBox[{
                RowBox[{"\[Mu]", " ", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Delta]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox["i",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox["m",
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  StyleForm[ i, ShowContents -> False], 
                                  StyleForm[ m, ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox[\(i\[InvisibleSpace]m\),
                                SequenceForm[ i, m],
                                Editable->False]],
                            Subsuperscript[ \[Delta], 
                              SequenceForm[ 
                                StyleForm[ i, ShowContents -> False], 
                                StyleForm[ m, ShowContents -> False]], 
                              SequenceForm[ i, m]],
                            Editable->False],
                          "TraditionalForm"], " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Delta]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox["j",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox["l",
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  StyleForm[ j, ShowContents -> False], 
                                  StyleForm[ l, ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox[\(j\[InvisibleSpace]l\),
                                SequenceForm[ j, l],
                                Editable->False]],
                            Subsuperscript[ \[Delta], 
                              SequenceForm[ 
                                StyleForm[ j, ShowContents -> False], 
                                StyleForm[ l, ShowContents -> False]], 
                              SequenceForm[ j, l]],
                            Editable->False],
                          "TraditionalForm"]}], "+", 
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Delta]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox["i",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox["l",
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  StyleForm[ i, ShowContents -> False], 
                                  StyleForm[ l, ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox[\(i\[InvisibleSpace]l\),
                                SequenceForm[ i, l],
                                Editable->False]],
                            Subsuperscript[ \[Delta], 
                              SequenceForm[ 
                                StyleForm[ i, ShowContents -> False], 
                                StyleForm[ l, ShowContents -> False]], 
                              SequenceForm[ i, l]],
                            Editable->False],
                          "TraditionalForm"], " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Delta]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox["j",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox["m",
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  StyleForm[ j, ShowContents -> False], 
                                  StyleForm[ m, ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox[\(j\[InvisibleSpace]m\),
                                SequenceForm[ j, m],
                                Editable->False]],
                            Subsuperscript[ \[Delta], 
                              SequenceForm[ 
                                StyleForm[ j, ShowContents -> False], 
                                StyleForm[ m, ShowContents -> False]], 
                              SequenceForm[ j, m]],
                            Editable->False],
                          "TraditionalForm"]}]}], ")"}]}], "+", 
                RowBox[{"\[Lambda]", " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Delta]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["i",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["j",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ i, ShowContents -> False], 
                            StyleForm[ j, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[\(i\[InvisibleSpace]j\),
                          SequenceForm[ i, j],
                          Editable->False]],
                      Subsuperscript[ \[Delta], 
                        SequenceForm[ 
                          StyleForm[ i, ShowContents -> False], 
                          StyleForm[ j, ShowContents -> False]], 
                        SequenceForm[ i, j]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Delta]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["l",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["m",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ l, ShowContents -> False], 
                            StyleForm[ m, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[\(l\[InvisibleSpace]m\),
                          SequenceForm[ l, m],
                          Editable->False]],
                      Subsuperscript[ \[Delta], 
                        SequenceForm[ 
                          StyleForm[ l, ShowContents -> False], 
                          StyleForm[ m, ShowContents -> False]], 
                        SequenceForm[ l, m]],
                      Editable->False],
                    "TraditionalForm"]}]}]}],
            SequenceForm[ "                 ", 
              
              Tensor[ \[DoubleStruckCapitalE], {i, j, l, m}, {Void, Void, 
                Void, Void}], " = ", 
              Plus[ 
                Times[ \[Mu], 
                  Plus[ 
                    Times[ 
                      Tensor[ \[Delta], {i, m}, {Void, Void}], 
                      Tensor[ \[Delta], {j, l}, {Void, Void}]], 
                    Times[ 
                      Tensor[ \[Delta], {i, l}, {Void, Void}], 
                      Tensor[ \[Delta], {j, m}, {Void, Void}]]]], 
                Times[ \[Lambda], 
                  Tensor[ \[Delta], {i, j}, {Void, Void}], 
                  Tensor[ \[Delta], {l, m}, {Void, Void}]]]],
            Editable->False],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Due to the tensorial character of the elastic moduli, we have in an \
arbitrary (",
  StyleBox["red",
    FontColor->RGBColor[1, 0, 0]],
  " for instance) basis"
}], "Text"],

Cell[BoxData[
    \(\[DoubleStruckCapitalE]\[Section]uuuu[i_, j_, k_, 
        l_] := \[Lambda]\ guu[i, j] 
          guu[k, l] + \[Mu]\ \((guu[i, k] guu[j, l] + 
              guu[i, l] guu[j, k])\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]SequenceForm[\[DoubleStruckCapitalE]uuuu[
            i, j, l, m], "\< =   \>", \[DoubleStruckCapitalE]\[Section]uuuu[
            i, j, l, m]] // ToFlavor[red]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False], 
                                StyleForm[ 
                                  red[ l], ShowContents -> False], 
                                StyleForm[ 
                                  red[ m], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                red[ i], 
                                red[ j], 
                                red[ l], 
                                red[ m]],
                              Editable->False]],
                          Subsuperscript[ \[DoubleStruckCapitalE], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              StyleForm[ 
                                red[ j], ShowContents -> False], 
                              StyleForm[ 
                                red[ l], ShowContents -> False], 
                              StyleForm[ 
                                red[ m], ShowContents -> False]], 
                            SequenceForm[ 
                              red[ i], 
                              red[ j], 
                              red[ l], 
                              red[ m]]],
                          Editable->False],
                        "TraditionalForm"], 
                      "\[InvisibleSpace]", "\<\" =   \"\>", 
                      "\[InvisibleSpace]", 
                      RowBox[{
                        RowBox[{"\[Mu]", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["g", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ i], 
                                        red[ m]],
                                        Editable->False]],
                                    Subsuperscript[ g, 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]], 
                                      SequenceForm[ 
                                        red[ i], 
                                        red[ m]]],
                                    Editable->False],
                                  "TraditionalForm"], " ", 
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["g", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ j], 
                                        red[ l]],
                                        Editable->False]],
                                    Subsuperscript[ g, 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False]], 
                                      SequenceForm[ 
                                        red[ j], 
                                        red[ l]]],
                                    Editable->False],
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["g", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ i], 
                                        red[ l]],
                                        Editable->False]],
                                    Subsuperscript[ g, 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False]], 
                                      SequenceForm[ 
                                        red[ i], 
                                        red[ l]]],
                                    Editable->False],
                                  "TraditionalForm"], " ", 
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["g", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ j], 
                                        red[ m]],
                                        Editable->False]],
                                    Subsuperscript[ g, 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]], 
                                      SequenceForm[ 
                                        red[ j], 
                                        red[ m]]],
                                    Editable->False],
                                  "TraditionalForm"]}]}], ")"}]}], "+", 
                        RowBox[{"\[Lambda]", " ", 
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["g", 
                                InterpretationBox[
                                  RowBox[{
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                     "\[InvisibleSpace]", 
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                  SequenceForm[ 
                                    StyleForm[ 
                                      red[ i], ShowContents -> False], 
                                    StyleForm[ 
                                      red[ j], ShowContents -> False]],
                                  Editable->False], 
                                InterpretationBox[
                                  RowBox[{
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"], "\[InvisibleSpace]",
                                     
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ 
                                    red[ i], 
                                    red[ j]],
                                  Editable->False]],
                              Subsuperscript[ g, 
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False]], 
                                SequenceForm[ 
                                  red[ i], 
                                  red[ j]]],
                              Editable->False],
                            "TraditionalForm"], " ", 
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["g", 
                                InterpretationBox[
                                  RowBox[{
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                     "\[InvisibleSpace]", 
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                  SequenceForm[ 
                                    StyleForm[ 
                                      red[ l], ShowContents -> False], 
                                    StyleForm[ 
                                      red[ m], ShowContents -> False]],
                                  Editable->False], 
                                InterpretationBox[
                                  RowBox[{
                                    FormBox[
                                      TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"], "\[InvisibleSpace]",
                                     
                                    FormBox[
                                      TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ 
                                    red[ l], 
                                    red[ m]],
                                  Editable->False]],
                              Subsuperscript[ g, 
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ l], ShowContents -> False], 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False]], 
                                SequenceForm[ 
                                  red[ l], 
                                  red[ m]]],
                              Editable->False],
                            "TraditionalForm"]}]}]}],
                    SequenceForm[ 
                      Tensor[ \[DoubleStruckCapitalE], {
                        red[ i], 
                        red[ j], 
                        red[ l], 
                        red[ m]}, {Void, Void, Void, Void}], " =   ", 
                      Plus[ 
                        Times[ \[Mu], 
                          Plus[ 
                            Times[ 
                              Tensor[ g, {
                                red[ i], 
                                red[ m]}, {Void, Void}], 
                              Tensor[ g, {
                                red[ j], 
                                red[ l]}, {Void, Void}]], 
                            Times[ 
                              Tensor[ g, {
                                red[ i], 
                                red[ l]}, {Void, Void}], 
                              Tensor[ g, {
                                red[ j], 
                                red[ m]}, {Void, Void}]]]], 
                        Times[ \[Lambda], 
                          Tensor[ g, {
                            red[ i], 
                            red[ j]}, {Void, Void}], 
                          Tensor[ g, {
                            red[ l], 
                            red[ m]}, {Void, Void}]]]],
                    Editable->False], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "9", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  SequenceForm[ 
                    Tensor[ \[DoubleStruckCapitalE], {
                      red[ i], 
                      red[ j], 
                      red[ l], 
                      red[ m]}, {Void, Void, Void, Void}], " =   ", 
                    Plus[ 
                      Times[ \[Mu], 
                        Plus[ 
                          Times[ 
                            Tensor[ g, {
                              red[ i], 
                              red[ m]}, {Void, Void}], 
                            Tensor[ g, {
                              red[ j], 
                              red[ l]}, {Void, Void}]], 
                          Times[ 
                            Tensor[ g, {
                              red[ i], 
                              red[ l]}, {Void, Void}], 
                            Tensor[ g, {
                              red[ j], 
                              red[ m]}, {Void, Void}]]]], 
                      Times[ \[Lambda], 
                        Tensor[ g, {
                          red[ i], 
                          red[ j]}, {Void, Void}], 
                        Tensor[ g, {
                          red[ l], 
                          red[ m]}, {Void, Void}]]]], "      (4.", 9, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "or ",
  StyleBox["using the Young's modulus ",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["\[CapitalEpsilon]",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox[", and the Poisson's ratio \[Nu]",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " (see ",
  "Lame",
  "Rule above)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]LameForm = \(SequenceForm[\
\[DoubleStruckCapitalE]uuuu[i, j, l, 
                  m], "\< = \>", \[DoubleStruckCapitalE]\[Section]uuuu[i, j, 
                  l, m]] /. {\[Lambda] -> \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\
\(\((\[Nu] + 1)\)\ \((2\ \[Nu] - 
                              1)\)\)\)\), \[Mu] -> \[CapitalEpsilon]\/\(2\ \
\((\[Nu] + 1)\)\)} // FullSimplify\) // ToFlavor[red]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False], 
                                StyleForm[ 
                                  red[ l], ShowContents -> False], 
                                StyleForm[ 
                                  red[ m], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                red[ i], 
                                red[ j], 
                                red[ l], 
                                red[ m]],
                              Editable->False]],
                          Subsuperscript[ \[DoubleStruckCapitalE], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              StyleForm[ 
                                red[ j], ShowContents -> False], 
                              StyleForm[ 
                                red[ l], ShowContents -> False], 
                              StyleForm[ 
                                red[ m], ShowContents -> False]], 
                            SequenceForm[ 
                              red[ i], 
                              red[ j], 
                              red[ l], 
                              red[ m]]],
                          Editable->False],
                        "TraditionalForm"], 
                      "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]",
                       
                      FractionBox[
                        RowBox[{"\[CapitalEpsilon]", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["g", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ i], 
                                        red[ m]],
                                        Editable->False]],
                                    Subsuperscript[ g, 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]], 
                                      SequenceForm[ 
                                        red[ i], 
                                        red[ m]]],
                                    Editable->False],
                                  "TraditionalForm"], " ", 
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["g", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ j], 
                                        red[ l]],
                                        Editable->False]],
                                    Subsuperscript[ g, 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False]], 
                                      SequenceForm[ 
                                        red[ j], 
                                        red[ l]]],
                                    Editable->False],
                                  "TraditionalForm"]}], "+", 
                              RowBox[{
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["g", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ i], 
                                        red[ l]],
                                        Editable->False]],
                                    Subsuperscript[ g, 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False]], 
                                      SequenceForm[ 
                                        red[ i], 
                                        red[ l]]],
                                    Editable->False],
                                  "TraditionalForm"], " ", 
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["g", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ j], 
                                        red[ m]],
                                        Editable->False]],
                                    Subsuperscript[ g, 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]], 
                                      SequenceForm[ 
                                        red[ j], 
                                        red[ m]]],
                                    Editable->False],
                                  "TraditionalForm"]}], "+", 
                              FractionBox[
                                RowBox[{"2", " ", "\[Nu]", " ", 
                                  FormBox[
                                    InterpretationBox[
                                      SubsuperscriptBox["g", 
                                        InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False]],
                                        Editable->False], 
                                        InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ i], 
                                        red[ j]],
                                        Editable->False]],
                                      Subsuperscript[ g, 
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ j], ShowContents -> False]], 
                                        SequenceForm[ 
                                        red[ i], 
                                        red[ j]]],
                                      Editable->False],
                                    "TraditionalForm"], " ", 
                                  FormBox[
                                    InterpretationBox[
                                      SubsuperscriptBox["g", 
                                        InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]],
                                        Editable->False], 
                                        InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        red[ l], 
                                        red[ m]],
                                        Editable->False]],
                                      Subsuperscript[ g, 
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ l], ShowContents -> False], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]], 
                                        SequenceForm[ 
                                        red[ l], 
                                        red[ m]]],
                                      Editable->False],
                                    "TraditionalForm"]}], \(1 - 2\ \[Nu]\)]}],
                             ")"}]}], \(2\ \((\[Nu] + 1)\)\)]}],
                    SequenceForm[ 
                      Tensor[ \[DoubleStruckCapitalE], {
                        red[ i], 
                        red[ j], 
                        red[ l], 
                        red[ m]}, {Void, Void, Void, Void}], " = ", 
                      Times[ 
                        Rational[ 1, 2], \[CapitalEpsilon], 
                        Power[ 
                          Plus[ 1, \[Nu]], -1], 
                        Plus[ 
                          Times[ 
                            Tensor[ g, {
                              red[ i], 
                              red[ m]}, {Void, Void}], 
                            Tensor[ g, {
                              red[ j], 
                              red[ l]}, {Void, Void}]], 
                          Times[ 
                            Tensor[ g, {
                              red[ i], 
                              red[ l]}, {Void, Void}], 
                            Tensor[ g, {
                              red[ j], 
                              red[ m]}, {Void, Void}]], 
                          Times[ 2, 
                            Power[ 
                              Plus[ 1, 
                                Times[ -2, \[Nu]]], -1], \[Nu], 
                            Tensor[ g, {
                              red[ i], 
                              red[ j]}, {Void, Void}], 
                            Tensor[ g, {
                              red[ l], 
                              red[ m]}, {Void, Void}]]]]],
                    Editable->False], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "10", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  SequenceForm[ 
                    Tensor[ \[DoubleStruckCapitalE], {
                      red[ i], 
                      red[ j], 
                      red[ l], 
                      red[ m]}, {Void, Void, Void, Void}], " = ", 
                    Times[ 
                      Rational[ 1, 2], \[CapitalEpsilon], 
                      Power[ 
                        Plus[ 1, \[Nu]], -1], 
                      Plus[ 
                        Times[ 
                          Tensor[ g, {
                            red[ i], 
                            red[ m]}, {Void, Void}], 
                          Tensor[ g, {
                            red[ j], 
                            red[ l]}, {Void, Void}]], 
                        Times[ 
                          Tensor[ g, {
                            red[ i], 
                            red[ l]}, {Void, Void}], 
                          Tensor[ g, {
                            red[ j], 
                            red[ m]}, {Void, Void}]], 
                        Times[ 2, 
                          Power[ 
                            Plus[ 1, 
                              Times[ -2, \[Nu]]], -1], \[Nu], 
                          Tensor[ g, {
                            red[ i], 
                            red[ j]}, {Void, Void}], 
                          Tensor[ g, {
                            red[ l], 
                            red[ m]}, {Void, Void}]]]]], "      (4.", 10, 
                  ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["We recover the well known Lame rules defined above,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Solve[
        Eliminate[{\[Lambda] == \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(\((\[Nu] \
+ 1)\)\ \((2\ \[Nu] - 
                          1)\)\)\)\), \[Mu] == \[CapitalEpsilon]\/\(2\ \((\
\[Nu] + 1)\)\)}, \[Nu]], \[CapitalEpsilon]]\)[\([1]\)]\), \
"\[IndentingNewLine]", 
    \(\(Solve[
        Eliminate[{\[Lambda] == \(-\(\(\[CapitalEpsilon]\ \[Nu]\)\/\(\((\[Nu] \
+ 1)\)\ \((2\ \[Nu] - 
                          1)\)\)\)\), \[Mu] == \[CapitalEpsilon]\/\(2\ \((\
\[Nu] + 1)\)\)}, \[CapitalEpsilon]], \[Nu]]\)[\([1]\)]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\({\[CapitalEpsilon] \[Rule] \(-\(\(\[Mu]\ \((3\ \[Lambda] + 
                          2\ \[Mu])\)\)\/\(\(-\[Lambda]\) - \[Mu]\)\)\)}\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\({\[Nu] \[Rule] \[Lambda]\/\(2\ \((\[Lambda] + \
\[Mu])\)\)}\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example of an idealized porous material ( Fl\[UDoubleDot]gge page 53 \
).", "Subsubsection"],

Cell[TextData[{
  "It consists of thin walls of thickness t << a, parallel to the coordinate \
planes x, y, z. There are ",
  StyleBox["n",
    FontWeight->"Bold"],
  " walls in each directions."
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PICT", "\<\
:oH0U02a0T<2FP0A0_l<0?ooool0/@0009@0009J0002@`000000000N00402P2D
0;42@`9J09X0003oQZ@0U02a0T<2FP0000@0000004P000180000400P00<02000
0005o9k81ObNf02D0;42@`9J09@0/@930UX0000DPOn1oh7oPOn1oh7oPOn1oh7o
Q_l0587oPOn1oh7oPOn1oh7oPOn1ohKo01B1oh7oPOn1oh7oPOn1oh7oPOn6o`0D
POn1oh7oPOn1oh7oPOn1oh7oQ_l0587oPOn1oh7oPOn1oh7oPOn1ohKo01B1oh7o
POn1oh7oPOn1oh7oPOn6o`0DPOn1oh7oPOn1oh7oPOn1oh7oQ_l0587oPOn1oh7o
POn1oh7oPOn1ohKo01B1oh7oPOn1oh7oPOn1oh7oPOn6o`0DPOn1oh7oPOn1oh7o
POn1oh7oQ_l0587oPOn1oh7oPOn1oh7oPOn1ohKo01B1oh7oPOn1oh7oPOn1oh7o
POn6o`0DPOn1oh7oPOn1oh7oPOn1oh7oQ_l0587oPOn1oh7oPOn1oh7oPOn1ohKo
01B1oh7oPOn1oh7oPOn1oh7oPOn6o`0DPOn1oh7oPOn1oh7oPOn1oh7oQ_l0587o
POn1oh7oPOn1oh7oPOn1ohKo01B1oh7oPOn1oh7oPOn1oh7oPOn6o`0DPOn1oh7o
POn1oh7oPOn1oh7oQ_l0587oPOn1oh7oPOn1oh7oPOn1ohKo01B1oh7oPOn1oh7o
POn1oh7oPOn6o`0DPOn1oh7oPOn1oh7oPOn1oh7oQ_l0587oPOn1oh7oPOn1oh7o
POn1ohKo01B1oh7oPOn1oh7oPOn1oh7oPOn6o`0DPOn1oh7oPOn1oh7oPOn1oh7o
Q_l0687oPOn3087oPOoFoh<0POn1omKoP`3Fo`14POomohD0oEWL000]oUWL0?eI
g03mFH7odon50?eIg000;OiIg03mFM`0oEV1om?oQ@3mFM`002gnFM`0oEWL0?eI
eol0J87ooOl00?iI02gL0?eIf`3nFMd0o5WL0?eIg@3lFM`0oEV1om?o003nF@0]
g03mFM/0oUWM0?aIg03mFMd0o5WL0?eIPOoCo`00oUT0;M`0oEWK0?iIg@3lFM`0
oEWM0?aIg03mFMOo06:1oogooET0;Md0o5WL0?eIg@3lFM`0oEWM0?aIg03mFH7o
doomF@0]g@3lFM`0oEWM0?aIg03mFMd0o5WL0?eIPOoCooeI02gM0?aIg03mFMd0
o5WL0?eIg@3lFM`0oEWGo`1RPOomooeI02gM0?aIg03mFMh0neWM0?aIgP3kFM`0
oEV1om?ooET0;Md0o5WL0?eIgP3kFMd0o5WN0?]Ig03mFH7odoomF@0]g@3lFM`0
oEWN0?]Ig@3lFMh0neWL0?eIeol0KX7oo_olF@0]gP00;OaIg@3lFMh0o5T00=ko
o5WMooaIfoomFH7oe?olF@0]gP00;OaIg@3lFMh0o5T00=koo5WMooaIfoomFH7o
e?olF@0]gP00;OaIg@3lFMh0o5T00=koo5WMooaIfoomFMOo06R1ookoo5WMo`2/
oEWMooaIg_l0[?aIgOolFMkoneWKooeIPOoDooaIgOl0[?eIgOolFMko0:clFMgo
o5WNoo]IfoomFH7oe?olFMgo0:cmFMgoo5WNo`2/o5WMooaIg_okFM_ooEWGo`2A
POl1ojclF@2/g_l0[?eI0:cNo`2/oET0[=koo5WMooeI02gNo`2/o5T00=_ooEV1
omKo0:clF@2/g_l0[?eI0:cNo`2/oET0[=koo5WMooeI02gNo`2/o5T00=_ooEV1
omKo0:clF@2/g_l0[?eI0:cNo`2/oET0[=koo5WMooeI02gNo`2/o5T00=_ooEWG
o`1gPOl0oo]IgOolFMgooET0;Mkoo5T00=koo5T00=koo5T1o`3KooeIPOoFoo]I
gOolFMgooET0;Mkoo5T00=koo5T00=koo5T1o`3KooeIPOoFoo]IgOolFMgooET0
;Mkoo5T00=koo5T00=koo5T1o`3KooeIeol0T87o0:clF@00g_olF@00g_olF@0]
g_omF@7o0=ooo5T1[03NooeI0_oo0=_ooEV1omOo0:clF@00g_olF@00g_olF@0]
g_omF@7o0=ooo5T1[03NooeI0_oo0=_ooEV1omOo0:clF@00g_olF@00g_olF@0]
g_omF@7o0=ooo5T1[03NooeI0_oo0=_ooEWGo`2FPOl0[?eI0Ol0g_omF@7o0=ko
o5T0P=ooo5T1o`3OooaI0J`0goolF@;oo`3KooeIPOoGo`2/oET1o`3NooeI0Ol0
g_olF@20goolF@7o0=ooo5T1[03OooaI0_oo0=_ooEV1omOo0:cmF@7o0=kooET1
o`3NooaI083OooaI0Ol0goolF@6/0=ooo5T2ool0foomFMOo09>1ooaI0Ol0gool
F@7o0=ooneT0P=oooET2ool0h?okF@7o0=oooEWno`00foomIX7oeoolF@7o0=oo
o5T1o`3Ooo]I083OooeI0_oo0>3oneT1o`3OooeIo_l00=_ooFJ1omOoo5T1o`3O
ooaI0Ol0gookF@20goomF@;oo`3Poo]I0Ol0goomFOko003KooeVeol0Zh7ooET2
ool0goomF@;oo`3Po`2/o5T1oh3PooaI0_oo0>3oo5T2ool0h?olFOko003Lo`2c
oFJ1omOooET2ool0goomF@;oo`3Po`2/o5T1oh3PooaI0_oo0>3oo5T2ool0h?ol
FOko003Lo`2coFJ1omOooET2ool0goomF@;oo`3Po`2/o5T1oh3PooaI0_oo0>3o
o5T2ool0h?olFOko003Lo`2coFKGo`2aP_olF@;oo`3PooaI0_oo0>3o0:clF@7o
P>3ooEWno`00hOl0[?aI0_oo0>3ooEWmo`00g?l0/oeVPOoHooaI0_oo0>3oo5T2
ool0h?l0[?aI0On0h?omFOko003Qo`2/o5T2ool0h?omFOgo003Lo`2coFJ1omSo
o5T2ool0h?olF@;oo`3Po`2/o5T1oh3PooeIo_l00>7o0:clF@;oo`3PooeIoOl0
0=co0;?mI]Oo0<J3o`2/oEWno`00hH00[?eI0ff0P03PP?eI0bf0P43RP02/oET0
@oj0003QP?aIgX00;OeI0:cnP000fh3mIP1PPOoIo`2/oEWno`00hH00[?eI0ff0
P03PP?eI0bf0P43RP02/oET0@oj0003QP?aIgX00;OeI0:cnP000fh3mIP1PPOoI
o`2/oEWno`00hH00[?eI0ff0P03PP?eI0bf0P43RP02/oET0@oj0003QP?aIgX00
;OeI0:cnP000fh3mIP1Peol0ZhCoo5Wno`00hOokF@;oo`3PooaIo_l0P>;oo5T3
[?oo0>7oo5Wno`20hOolFOgo003LooaV05V1om[oo5Wno`00hOokF@;oo`3PooaI
o_l0P>;oo5T3[?oo0>7oo5Wno`20hOolFOgo003LooaV05V1om[oo5Wno`00hOok
F@;oo`3PooaIo_l0P>;oo5T3[?oo0>7oo5Wno`20hOolFOgo003LooaV05WGo`2a
Q?olFOko003Qoo]I0_oo0>7oo5Wmo`20hookFOko003QooeIoOl0P>;oo5T0[?ko
003LooaV0EUIPOoJooaIo_l00>7oneT2ool0hOolFOgo083Soo]Io_l00>7ooEWm
o`20h_olF@2/o_l00=coo6H1FEV1om[oo5Wno`00hOokF@;oo`3QooaIoOl0P>?o
neWno`00hOomFOgo083RooaI0:cno`00g?olIP5IFMOo0;65ooaIo_l00>7o0:cl
F@;oo`3PooaIo_l00>;oo5Wno`00hOolFOgo083RooaIoOl00=coo6H1FEV1om_o
o5Wno`00hOl0[?aI0_oo0>3oo5Wno`00h_olFOko003QooaIoOl0P>;oo5Wmo`00
g?olIP5IFH7ofoolFOko003Qo`2/o5T2ool0h?olFOko003RooaIo_l00>7oo5Wm
o`20h_olFOgo003LooaV0EUIeol0^XGooET0[?ko003Qo`2/oET2oon0h?olFOko
003Ro`2/o5T2ool0hOolFOgo003Roo]Io_l00=coo6KnFH7ofoomF@2/o_l00>7o
0:cmF@;ooh3PooaIo_l00>;o0:clF@;oo`3QooaIoOl00>;oneWno`00g?olI_iI
POoKooeI0:cno`00hOl0[?eI0_ooP>3oo5Wno`00h_l0[?aI0_oo0>7oo5Wmo`00
h_okFOko003LooaVoUWGo`2aQ_olF@>/ool0h?olF@;ooh3PooeIoOl00>;o0:cm
FOko003QooaIo_l00>7oo5Wno`00foomI_eIPOoLooaI0jcoo`3PooaI0_ooP>3o
oEWmo`00h_l0[?eIo_l00>7oo5Wno`00hOolFOko003KooeVoEV1omcoo5T3[?oo
0>3oo5T2oon0h?omFOgo003Ro`2/oEWno`00hOolFOko003QooaIo_l00=_ooFKm
FMOo0:j6ooaI0_oo0=oooEWno`20hOolFOko003QooaI0_ooP>7oo5Wmo`00h_l0
[?aIo_l00=coo6KmFH7og?olF@;oo`3OooeIo_l0P>7oo5Wno`00hOolF@;ooh3Q
ooaIoOl00>;o0:clFOko003LooaVoEV1omcoo5T2ool0goomFOko083QooaIo_l0
0>7oo5T2oon0hOolFOgo003Ro`2/o5Wno`00g?olI_eIeol0hHOoo5T3[?n0P>3o
oET4[?ooP<3Ro`2/oET4[?ooP83Ro`2/oEWno`20h_l0[?eI0:cno`00hOl0PoeI
o_l00=co0;?mIP2coEV1omgoo5T3[?n0P>3ooET4[?ooP<3Ro`2/oET4[?ooP83R
o`2/oEWno`20h_l0[?eI0:cno`00hOl0PoeIo_l00=co0;?mIP2coEV1omgoo5T3
[?n0P>3ooET4[?ooP<3Ro`2/oET4[?ooP83Ro`2/oEWno`20h_l0[?eI0:cno`00
hOl0PoeIo_l00=co0;?mIP2coEWGo`2dR?l0[?aI0_oo0>3oo5Wno`00h_okFOko
003RooaIoOl0P>?oneWno`00hOolFOko083KooaV0?omFH7og_l0[?aI0_oo0>3o
o5Wno`00h_okFOko003RooaIoOl0P>?oneWno`00hOolFOko083KooaV0?omFH7o
g_l0[?aI0_oo0>3oo5Wno`00h_okFOko003RooaIoOl0P>?oneWno`00hOolFOko
083KooaV0?omFMOo0:j8ooaI0_ooP>3oo5Wno`00hOokF@;oo`3QooaIo_l00>;o
neWno`00hOolFOko083Loo]V0?omFH7og_olF@;ooh3PooaIo_l00>7oneT2ool0
hOolFOko003Roo]Io_l00>7oo5Wno`20g?okIP3ooEV1omkoo5T2oon0h?olFOko
003Qoo]I0_oo0>7oo5Wno`00h_okFOko003QooaIo_l0P=confH0ooeIeol0`hSo
o5T2oon0h?olF@;oo`3Qo`2/o5T2ool0hOolFOko003Ro`2/o5Wno`00hOolFOgo
083Mo`2co6H1ooomFH7og_olF@;ooh3PooaI0_oo0>7o0:clF@;oo`3QooaIo_l0
0>;o0:clFOko003QooaIoOl0P=go0;?lIP7oooeIPOoNooaI0_ooP>3oo5T2ool0
hOl0[?aI0_oo0>7oo5Wno`00h_l0[?aIo_l00>7oo5Wmo`20gOl0/oaV0OoooEWG
o`2LROolFOko083QooaIo_l00>;o0@0]oEWM0?eIg@00;OeIg03mFMX0o_l0/oaV
0OoooEV1omooo5Wno`20hOolFOko003Ro`40;OeIg@3mFMd002gmFM`0oEWJ0?ko
0;?lIP7oooeIPOoOooaIo_l0P>7oo5Wno`00h_l102gmFMd0oEWM000]oEWL0?eI
fP3no`2co6H1ooomFMOo08B;o`400?eIg03mF@0]g@3lFMd0oEWM0?aIg@3lFMd0
oET1ooolI_kooEV1on7o0@00oEWL0?eI02gM0?aIg@3mFMd0o5WM0?aIg@3mF@7o
ooaVo_omFH7ohOl1003mFM`0oET0;Md0o5WM0?eIg@3lFMd0o5WM0?eI0Oooo6Kn
ooeIeol0Qh_o003lFMd0o5T0;Mh0o5WM0?eI02gN0?aIg@3lFM`0oET1ooomI_go
oEV1on7o003lFMd0o5T0;Mh0o5WM0?eI02gN0?aIg@3lFM`0oET1ooomI_gooEV1
on7o003lFMd0o5T0;Mh0o5WM0?eI02gN0?aIg@3lFM`0oET1ooomI_gooEWGo`1h
RoolFMd0neWM0?aIg@3mF@0]gP3lFMd0o5WL0?eI0?olI_gooEV1on7oo5WM0?]I
g@3lFMd0oET0;Mh0o5WM0?aIg03mF@3oo6KmooeIPOoQooaIg@3kFMd0o5WM0?eI
02gN0?aIg@3lFM`0oET0ooaVoOomFMOo0=:<o`2/oET0;Mh001OlF@0]gP3mF@2/
oX000>:002glF@:FP03QP?eI0:cmP010hX3lF@2FoX000>20oET0/oeVo?omFH7o
h_l0[?eI02gN000Go5T0;Mh0oET0[?j0003RP00]o5T2UX00hH3mF@2/oH00@>:0
o5T0U_j0003PP?eI0;?mI_cooEV1on;o0:cmF@0]gP005oaI02gN0?eI0:cnP000
hX00;OaI0YJ00>60oET0[?f0043RP?aI09KnP000h83mF@2coFKlooeIeol0]hco
oET0[?ko003QooaI0_ooP>3oo5Wno`00hOokF@7o0>7oo5Wmo`00h_okFOko003O
ooeIoFKkooeIPOoRooeI0:cno`00hOolF@;ooh3PooaIo_l00>7oneT1o`3QooaI
oOl00>;oneWno`00goomFOeVnoomFH7oh_omF@2/o_l00>7oo5T2oon0h?olFOko
003Qoo]I0Ol0hOolFOgo003Roo]Io_l00=oooEWmI__ooEWGo`33SOolF@>/ool0
h?olF@;ooh3QooaIoOl00>;o0:clF@;oo`3RooaI003mo`00hookFOgo003OooiI
o6KkooeIPOoSooaI0jcoo`3PooaI0_ooP>7oo5Wmo`00h_l0[?aI0_oo0>;oo5T0
0?go003Soo]IoOl00=oooUWlI__ooEV1on?oo5T3[?oo0>3oo5T2oon0hOolFOgo
003Ro`2/o5T2ool0h_olF@00oOl00>?oneWmo`00goonFOaVnoomFMOo0<>>oo]I
o_l00>7oo5Wno`20hOolFOko003Qo`2/oET2oon0hOolF@00o_l00>;oneWno`00
g_l1FEWlI_[ooEV1onConeWno`00hOolFOko083QooaIo_l00>7o0:cmF@;ooh3Q
ooaI003no`00h_okFOko003No`5IFOaVn_omFH7oi?okFOko003QooaIo_l0P>7o
o5Wno`00hOl0[?eI0_ooP>7oo5T00?ko003Roo]Io_l00=ko0EUIo6KjooeIeol0
f8koneT2ool0h?omF@00o_l0P>;oo5T0;Oko003QooaI0_ooP>;oo5T1[03no`00
hol0[?aI003no`00g_l1FEWlI_[ooEV1onConeT2ool0h?omF@00o_l0P>;oo5T0
;Oko003QooaI0_ooP>;oo5T1[03no`00hol0[?aI003no`00g_l1FEWlI_[ooEV1
onConeT2ool0h?omF@00o_l0P>;oo5T0;Oko003QooaI0_ooP>;oo5T1[03no`00
hol0[?aI003no`00g_l1FEWlI_[ooEWGo`3NSol0[?aI0`3oo`3QooaI0`3oo`3Q
ooaI0h3oo`3QooaI0`3ooh3RooaI1?l0ool0h_l0[?eI1?l0ool0gOl0FOaV0;?j
ooeIPOoUo`2/o5T30?oo0>7oo5T30?oo0>7oo5T3P?oo0>7oo5T30?ooP>;oo5T4
o`3oo`3Ro`2/oET4o`3oo`3Mo`1Io6H0/o[ooEV1onGo0:clF@<0ool0hOolF@<0
ool0hOolF@>0ool0hOolF@<0oon0h_olF@Co0?oo0>;o0:cmF@Co0?oo0=go05Wl
IP2cn_omFMOo0<n?o`2/oET3o`3o0>3ooET4o`3oo`3Roo]I0h3oo`3QooaI0`3o
oh3Soo]I0ol0o`3QooaI0ol0oh3Lo`1Io6KiooeIPOoUo`2/oET3o`3o0>3ooET4
o`3oo`3Roo]I0h3oo`3QooaI0`3ooh3Soo]I0ol0o`3QooaI0ol0oh3Lo`1Io6Ki
ooeIPOoUo`2/oET3o`3o0>3ooET4o`3oo`3Roo]I0h3oo`3QooaI0`3ooh3Soo]I
0ol0o`3QooaI0ol0oh3Lo`1Io6KiooeIeol0ihoooET3[?l0P>7o0:cmF@B/o`20
P>;o0:clF@3ooX3QooeI1:co0820hol0[?aI1?oo0820h_l0[?eI1?oo0?n0g?ol
IP2cnOomFH7oiOomF@>/o`20hOl0[?eI1:co0820h_l0[?aI0?onP>7ooET4[?l0
P83So`2/o5T4ool0P83Ro`2/oET4ool0oh3LooaV0;?iooeIPOoUooeI0jco083Q
o`2/oET4[?l0P83Ro`2/o5T0ooj0hOomF@B/o`20P>?o0:clF@Coo`20P>;o0:cm
F@Coo`3oP=coo6H0/oWooEWGo`39T?olF@?oo`20hOolF@?oo`00hOolF@?ooh00
hOolF@?oo`00h_olFOko0@00hOomFOko0P3oP=go0;?lI_SooEV1onKoo5T3ool0
P>7oo5T3ool00>7oo5T3oon00>7oo5T3ool00>;oo5Wno`400>7ooEWno`80oh3M
o`2co6KhooeIPOoVooaI0ooo083QooaI0ooo003QooaI0oooP03QooaI0ooo003R
ooaIo_l1003QooeIo_l20?n0gOl0/oaVn?omFMOo0:R@ooeIo_l1083RooaI0jco
o`3Qo`2/o5T2oon0hOolFOkoh@00;OaIg@3lFML003?mI_OooEV1onKooEWno`40
P>;oo5T3[?oo0>7o0:clF@;ooh3QooaIo_oQ000]o5WM0?aIe`00<oeVmoomFH7o
i_omFOko0@20h_olF@>/ool0hOl0[?aI0_ooP>7oo5Wnon4002glFMd0o5WG000c
oFKgooeIeol0RY7oo5Wnon00o5WM0?aIg@3lFOh0hOolFOko083QooaIo_l00=[o
o6KgooeIPOoWooaIo_oP0?aIg@3lFMd0o5Wn0>7oo5Wno`20hOolFOko003JooaV
moomFH7oioolFOkoh03lFMd0o5WM0?aIoP3QooaIo_l0P>7oo5Wno`00f_olI_Oo
oEWGo`2gT_olFOko003Qoo]I0_oo0>3oo5Wno`20h_olF@>/ool0hOolFOko083Q
ooaIo_l00=_oo6H0FOOooEV1onSoo5Wno`00hOokF@;oo`3PooaIo_l0P>;oo5T3
[?oo0>7oo5Wno`20hOolFOko003KooaV05WgooeIPOoXooaIo_l00>7oneT2ool0
h?olFOko083RooaI0jcoo`3QooaIo_l0P>7oo5Wno`00foolIP1ImoomFMOo0;BB
ooaIo_l00>;oneWno`00hOolFOgo083RooaI0_oo0>7oo5Wmo`20h_olFOko003J
ooaV05WgooeIPOoXooaIo_l00>;oneWno`00hOolFOgo083RooaI0_oo0>7oo5Wm
o`20h_olFOko003JooaV05WgooeIPOoXooaIo_l00>;oneWno`00hOolFOgo083R
ooaI0_oo0>7oo5Wmo`20h_olFOko003JooaV05WgooeIeol0_I?oo5Wno`00hOok
F@;oo`3PooeIoOl00>;oneT2ool0hOomFOco083RooeI0:cno`00foolIP5IFOOo
oEV1onWoo5Wno`00hOokF@;oo`3PooeIoOl00>;oneT2ool0hOomFOco083RooeI
0:cno`00foolIP5IFOOooEV1onWoo5Wno`00hOokF@;oo`3PooeIoOl00>;oneT2
ool0hOomFOco083RooeI0:cno`00foolIP5IFOOooEWGo`3NU?l0[?eI0jcoo`3Q
o`2/oET3[?ooP>3ooET0[?ko003Roo]I0_oo0>7ooET0[?ko0H20h_olF@?Foh20
fol0/oeVoUWgooeIPOoZo`2/oET3[?oo0>7o0:cmF@>/oon0h?omF@2/o_l00>;o
neT2ool0hOomF@2/o_l1P83RooaI0mKoP83Ko`2coFKnFOOooEV1on[o0:cmF@>/
ool0hOl0[?eI0jcooh3PooeI0:cno`00h_okF@;oo`3QooeI0:cno`60P>;oo5T3
e_n0P=_o0;?mI_iImoomFMOo0;ZDooaI0_oo0>3oo5Wno`20hOolFOko003Ro`2/
o5T2oon0hOolFOgo003Roo]I0_oo0=[ooFKmFOOooEV1on[oo5T2ool0h?olFOko
083QooaIo_l00>;o0:clF@;ooh3QooaIoOl00>;oneT2ool0f_omI_eImoomFH7o
j_olF@;oo`3PooaIo_l0P>7oo5Wno`00h_l0[?aI0_ooP>7oo5Wmo`00h_okF@;o
o`3JooeVoEWgooeIeol0^YGoneT2ool0h?omFOgo083QooeIoOl00>;o0:cmFOko
083QooeIoOl00>7oo5T2ool0f_olI_eImoomFH7ojookF@;oo`3PooeIoOl0P>7o
oEWmo`00h_l0[?eIo_l0P>7ooEWmo`00hOolF@;oo`3JooaVoEWgooeIPOo[oo]I
0_oo0>3ooEWmo`20hOomFOgo003Ro`2/oEWno`20hOomFOgo003QooaI0_oo0=[o
o6KmFOOooEWGo`30UOolF@;oo`3PooaIo_l00>7oo5Wno`00hOolFOko083RooaI
oOl00>;o0:clF@;oo`3JooeV0;?mFOOooEV1on_oo5T2ool0h?olFOko003QooaI
o_l00>7oo5Wno`20h_olFOgo003Ro`2/o5T2ool0f_omIP2coEWgooeIPOo[ooaI
0_oo0>3oo5Wno`00hOolFOko003QooaIo_l0P>;oo5Wmo`00h_l0[?aI0_oo0=[o
oFH0/oeImoomFMOo0<JFoo]I0_oo0>7oo5Wmo`00h_olF@2/o_l00>;oo5Wmo`20
hoolF@2/o_l00>7oo5T2oon0f_olIP2coEWgooeIPOo/oo]I0_oo0>7oo5Wmo`00
h_olF@2/o_l00>;oo5Wmo`20hoolF@2/o_l00>7oo5T2oon0f_olIP2coEWgooeI
POo/oo]I0_oo0>7oo5Wmo`00h_olF@2/o_l00>;oo5Wmo`20hoolF@2/o_l00>7o
o5T2oon0f_olIP2coEWgooeIeol0ciOo0:clF@;ooh3PooaIo_l00>7oo5T3[?oo
0>7oo5Wno`00h_olF@2/o_l00>7oo5T2oon0f_olIP3ooEWgo`1IoFJ1onko0:cl
F@;ooh3PooaIo_l00>7oo5T3[?oo0>7oo5Wno`00h_olF@2/o_l00>7oo5T2oon0
f_olIP3ooEWgo`1IoFJ1onko0:clF@;ooh3PooaIo_l00>7oo5T3[?oo0>7oo5Wn
o`00h_olF@2/o_l00>7oo5T2oon0f_olIP3ooEWgo`1IoFKHo`30Uol0[?aI0_oo
P>7oo5Wno`00hOokF@;oo`3QooaIoOl00>?oneWno`00hOolFOko083Koo]V0?om
FOOoo6J1onko0:clF@;ooh3QooaIo_l00>7oneT2ool0hOolFOgo003Soo]Io_l0
0>7oo5Wno`20fookIP3ooEWgooaVPOo^o`2/o5T2oon0hOolFOko003Qoo]I0_oo
0>7oo5Wmo`00hookFOko003QooaIo_l0P=_onfH0ooeImoolI]So09>GooaIo_l0
P>?o0@00oEWL0?aIg@3mFMd0o5WL0?eIfP3noo]V0oooFEWb005VIX7ok_olFOko
083So`400?eIg03lFMd0oEWM0?aIg03mFMX0o_okIP?ooeUIlP01IVJ1onkoo5Wn
o`20hol1003mFM`0o5WM0?eIg@3lFM`0oEWJ0?konfH3oomIFO800FIVf?l0f9Wo
0@0]oEWN000]oET0@md004?mF@0]g`00;OeI02gN000GoET0;Mh002gmF@0]g@3m
F@7ofOaV0[?oooeIn?l0/oeV0;>1oo3o0@0]oEWN000]oET0@md004?mF@0]g`00
;OeI02gN000GoET0;Mh002gmF@0]g@3mF@7ofOaV0[?oooeIn?l0/oeV0;>1oo3o
0@0]oEWN000]oET0@md004?mF@0]g`00;OeI02gN000GoET0;Mh002gmF@0]g@3m
F@7ofOaV0[?oooeIn?l0/oeV0;?Ho`2=VOolFMd0o5T0;Md0o5WN0?aIg@00;OeI
g@3lFM`0oET1ok?mI_gooEWhooaVPOo_ooaIg@3lF@0]g@3lFMh0o5WM000]oEWM
0?aIg03mF@7o/oeVoOomFOSoo6J1onooo5WM0?aI02gM0?aIgP3lFMd002gmFMd0
o5WL0?eI0OncoFKmooeIn?olI]Oo08ZIooaIgP3kFMd0o5WN0?aI02gM0?aIgP3l
FM/0oET0ooaVoOomFOWoo6H0FH7okoolFMh0neWM0?aIgP3lF@0]g@3lFMh0o5WK
0?eI0?olI_gooEWiooaV05V1onooo5WN0?]Ig@3lFMh0o5T0;Md0o5WN0?aIf`3m
F@3oo6KmooeInOolIP1Ieol0aY[oo5WM0?aIo_l00>7oo5Wmo`20h_olFOko003P
ooeIo_l0P>7ooET0[?ko003OooeI0?omI_cooEWiooaV05V1oo3oo5WM0?aIo_l0
0>7oo5Wmo`20h_olFOko003PooeIo_l0P>7ooET0[?ko003OooeI0?omI_cooEWi
ooaV05V1oo3oo5WM0?aIo_l00>7oo5Wmo`20h_olFOko003PooeIo_l0P>7ooET0
[?ko003OooeI0?omI_cooEWiooaV05WGo`3BVoolFOko003Qo`2/o5T2ool0h?ol
FOko003Roo]Io_l00>7oo5Wno`20h_olF@>/ool0g_omFOaVo?omFO[oo6H1FEV1
oo7oo5Wno`00hOl0[?aI0_oo0>3oo5Wno`00h_okFOko003QooaIo_l0P>;oo5T3
[?oo0=kooEWlI_cooEWjooaV0EUIPOoaooaIo_l00>7o0:clF@;oo`3PooaIo_l0
0>;oneWno`00hOolFOko083RooaI0jcoo`3NooeIo6KlooeIn_olIP5IFMOo0<nK
ooaIo_l00>7oo5Wno`00hOolFOgo003So`2/o5T30?oo0>7oo5Wmo`20hookFOko
003NooeIoFKkooeIn_omI_iIPOoaooaIo_l00>7oo5Wno`00hOolFOgo003So`2/
o5T30?oo0>7oo5Wmo`20hookFOko003NooeIoFKkooeIn_omI_iIPOoaooaIo_l0
0>7oo5Wno`00hOolFOgo003So`2/o5T30?oo0>7oo5Wmo`20hookFOko003NooeI
oFKkooeIn_omI_iIeol0f9coo5T3[?oo0>3oo5T2oon0h?omF@00o_l00>;o0:cl
F@<0ool0hOolFOko003Roo]I0_oo0=gooUWlI__ooEWkooaVoUV1oo;oo5T3[?oo
0>3oo5T2oon0h?omF@00o_l00>;o0:clF@<0ool0hOolFOko003Roo]I0_oo0=go
oUWlI__ooEWkooaVoUV1oo;oo5T3[?oo0>3oo5T2oon0h?omF@00o_l00>;o0:cl
F@<0ool0hOolFOko003Roo]I0_oo0=gooUWlI__ooEWkooaVoUWGo`48WOl0[?aI
0h3oP83QooeI1:`0oon0h_l0[?eI1H<0oon0P>;ooET4[?l0o`3QooeI02gno`60
P>?o0:cmF@B/0?n0P=go0EUIo6KjooeIo?l0/oeVoEV1oo?o0:clF@>0oh20hOom
F@B/0?ooP>;o0:cmF@F30?ooP83RooeI1:co0?l0hOomF@0]o_l1P83So`2/oET4
[03oP83Mo`5IFOaVn_omFOco0;?mI_eIPOoco`2/o5T3P?n0P>7ooET4[03ooh3R
o`2/oET5P`3ooh20h_omF@B/o`3o0>7ooET0;Oko0H20hol0[?eI1:`0oh20gOl1
FEWlI_[ooEWlo`2coFKmFMOo0>6MooaI0on0o`3QooaI1?l0oon0h_olF@B/0?oo
0>;oo5T3ool0P>7oo5T30?oo0>7oo5T2o`20fol0FOaVnOomFOcooFH0/oeIPOoc
ooaI0on0o`3QooaI1?l0oon0h_olF@B/0?oo0>;oo5T3ool0P>7oo5T30?oo0>7o
o5T2o`20fol0FOaVnOomFOcooFH0/oeIPOocooaI0on0o`3QooaI1?l0oon0h_ol
F@B/0?oo0>;oo5T3ool0P>7oo5T30?oo0>7oo5T2o`20fol0FOaVnOomFOcooFH0
/oeIeol0kIko0:clF@;oP03PooeI1?oo0?l0h_okF@?o0?l0hOomFOko0@20hOom
F@B/0?oo0>7ooET3ool0P=_o05WmIP2cnOomFOgoo6H0/oeIPOodo`2/o5T2oh00
h?omF@Coo`3o0>;oneT3o`3o0>7ooEWno`40P>7ooET4[03oo`3QooeI0ooo083K
o`1IoFH0/oWooEWmooaV0;?mFH7om?l0[?aI0_n00>3ooET4ool0o`3Roo]I0ol0
o`3QooeIo_l1083QooeI1:`0ool0hOomF@?oo`20fol0FOeV0;?iooeIoOolIP2c
oEWGo`3KW_olF@;oo`3PooaI0ooo003QooaI0ooo003QooaIo_l1083RooaI0j`0
o`3QooaI0ooo083KooaV0;?iooeIo_okIP3ooEV1ooCoo5T2ool0h?olF@?oo`00
hOolF@?oo`00hOolFOko0@20h_olF@>/0?l0hOolF@?oo`20foolIP2cnOomFOko
nfH0ooeIPOodooaI0_oo0>3oo5T3ool00>7oo5T3ool00>7oo5Wno`40P>;oo5T3
[03o0>7oo5T3ool0P=_oo6H0/oWooEWnoo]V0?omFMOo0=^NooaI0_oo0>3ooEWn
o`400>;o0:clF@?oo`00hOomFOgo0@20h_olF@?o0?l0hOomFOko0@20foolI_So
oEWnoo]V0?omFH7om?olF@;oo`3PooeIo_l1003Ro`2/o5T3ool00>7ooEWmo`40
P>;oo5T3o`3o0>7ooEWno`40P=_oo6KhooeIo_okIP3ooEV1ooCoo5T2ool0h?om
FOko0@00h_l0[?aI0ooo003QooeIoOl1083RooaI0ol0o`3QooeIo_l1083KooaV
n?omFOkonfH0ooeIeol0YIooo5Wno`20hOolFOko003QooaIo_oP0?aIg@3kFMh0
o5WG0?]Vn?omF@;ook?lIP7oooeIPOoeooaIo_l0P>7oo5Wno`00hOolFOkoh03l
FMd0neWN0?aIe`3kI_SooET2oonco6H1ooomFH7omOolFOko083QooaIo_l00>7o
o5Wnon00o5WM0?]IgP3lFML0nfKhooeI0_oo/oaV0OoooEWGo`2mWoomFOgoh@3l
F@0]g@3lFOh0hOolFOgo003Ro`2/o5T1oh3PooaIo_l00=[oo6KgooeI0_oo/oeV
o_omFH7omOomFOgoh@3lF@0]g@3lFOh0hOolFOgo003Ro`2/o5T1oh3PooaIo_l0
0=[oo6KgooeI0_oo/oeVo_omFH7omOomFOgoh@3lF@0]g@3lFOh0hOolFOgo003R
o`2/o5T1oh3PooaIo_l00=[oo6KgooeI0_oo/oeVo_omFMOo0ANQo`2/oET0[?ko
003Ro`2/o5T3e_oo0>7ooET0[?ko083Ro`2/oET0Poko0H20h_l0PoeI0ZcoP>7o
0:cmF@B/oon0P=_o08gmIP1PmoomF@7oooeV0;?nooeIPOogo`2/oET0[?ko003R
o`2/o5T3e_oo0>7ooET0[?ko083Ro`2/oET0Poko0H20h_l0PoeI0ZcoP>7o0:cm
F@B/oon0P=_o08gmIP1PmoomF@7oooeV0;?nooeIPOogo`2/oET0[?ko003Ro`2/
o5T3e_oo0>7ooET0[?ko083Ro`2/oET0Poko0H20h_l0PoeI0ZcoP>7o0:cmF@B/
oon0P=_o08gmIP1PmoomF@7oooeV0;?nooeIeol0cj7oo5Wno`00hOolFOko003Q
ooaIoOl0P>;oo5Wmo`00hOomFOko083QooeI0jcoo`3IooaV05WgooeI0?olI_go
oEV1ooOoo5Wno`00hOolFOko003QooaIoOl0P>;oo5Wmo`00hOomFOko083QooeI
0jcoo`3IooaV05WgooeI0?olI_gooEV1ooOoo5Wno`00hOolFOko003QooaIoOl0
P>;oo5Wmo`00hOomFOko083QooeI0jcoo`3IooaV05WgooeI0?olI_gooEWGo`3H
X_olFOko003Qo`2/o5T2ool0hOolFOgo003Roo]Io_l00>7oo5T2ool0hOolF@>/
ool0f_olIP5IFOOooET0ooeVo?omFH7on?olFOko003Qo`2/o5T2ool0hOolFOgo
003Roo]Io_l00>7oo5T2ool0hOolF@>/ool0f_olIP5IFOOooET0ooeVo?omFH7o
n?olFOko003Qo`2/o5T2ool0hOolFOgo003Roo]Io_l00>7oo5T2ool0hOolF@>/
ool0f_olIP5IFOOooET0ooeVo?omFMOo0=:RooeI0:cno`00hOl0[?eIo_l00>7o
o5Wno`00hOolFOko003PooeIo_l00>7oo5T2ool0fOomI_iImoomFOaVo?omFH7o
n?omF@2/o_l00>7o0:cmFOko003QooaIo_l00>7oo5Wno`00h?omFOko003QooaI
0_oo0=WooFKnFOOooEWlI_cooEV1ooSooET0[?ko003Qo`2/oEWno`00hOolFOko
003QooaIo_l00>3ooEWno`00hOolF@;oo`3IooeVoUWgooeIo6KlooeIeol0bJ?o
o5T3[?oo0>3oo5T2oon0hOolFOgo003Roo]Io_l00>7oo5T2ool0hOokF@;oo`3J
ooaVoUWgooiIo6KkooeIPOoiooaI0jcoo`3PooaI0_ooP>7oo5Wmo`00h_okFOko
003QooaI0_oo0>7oneT2ool0f_olI_iImoonFOaVnoomFH7onOolF@>/ool0h?ol
F@;ooh3QooaIoOl00>;oneWno`00hOolF@;oo`3Qoo]I0_oo0=[oo6KnFOOooUWl
I__ooEWGo`3<XoolFOko003PooeIo_l0P>7ooET0[?ko003QooaIo_l00>3ooEWn
o`00hOolF@;oo`3IooeVoEWgooiIo6KkooeIPOoiooaIo_l00>3ooEWno`20hOom
F@2/o_l00>7oo5Wno`00h?omFOko003QooaI0_oo0=WooFKmFOOooUWlI__ooEV1
ooWoo5Wno`00h?omFOko083QooeI0:cno`00hOolFOko003PooeIo_l00>7oo5T2
ool0fOomI_eImoonFOaVnoomFMOo0=FToo]I0_oo0>3oo5Wno`20h_olF@2/o_l0
0>;o0:clFOko003QooaI0_oo0>7oneT2ool0f_olI_eImol1FEWlI_[ooEV1oo[o
neT2ool0h?olFOko083RooaI0:cno`00h_l0[?aIo_l00>7oo5T2ool0hOokF@;o
o`3JooaVoEWgo`5IFOaVn_omFH7on_okF@;oo`3PooaIo_l0P>;oo5T0[?ko003R
o`2/o5Wno`00hOolF@;oo`3Qoo]I0_oo0=[oo6KmFOOo0EUIo6KjooeIeol0fjGo
neWno`00hOolFOgo083Soo]Io_l00>7oo5Wno`20hOolFOko003Ro`2/o5T2oon0
fOomIP3ooEWgo`5IFOeV0;?jooeIPOokoo]Io_l00>7oo5Wmo`20hookFOko003Q
ooaIo_l0P>7oo5Wno`00h_l0[?aI0_ooP=WooFH0ooeImol1FEWmIP2cn_omFH7o
nookFOko003QooaIoOl0P>?oneWno`00hOolFOko083QooaIo_l00>;o0:clF@;o
oh3IooeV0?omFOOo0EUIoFH0/o[ooEWGo`4DY_l0e_aI0jco`83Qo`2/oET4[?oo
P83So`2/o5T4[?ooP83Ro`2/oET0[?ko083Ro`2/oET3Pooo0>7o08?mF@>/oon0
f_omIP6=ooeImol0FOaV0=WjooeIPOolo`3Fo5T3[?o0P>7o0:cmF@B/oon0P>?o
0:clF@B/oon0P>;o0:cmF@2/o_l0P>;o0:cmF@>3ool0hOl0PoeI0jcooh3JooeV
0HgooEWgo`1Io6H0fO[ooEV1ooco0=KlF@>/ol20hOl0[?eI1:cooh20hol0[?aI
1:cooh20h_l0[?eI0:cno`20h_l0[?eI0h?oo`3Qo`23oET3[?ooP=[ooFH1SOom
FOOo05WlIP3In_omFMOo092Vo`0]oEWL0?eIg@3lFM`0oEWL0?aIg@3mFMd0oEWn
ooaV0[?oFO80oFKiooeIPOolo`0]oEWL0?eIg@3lFM`0oEWL0?aIg@3mFMd0oEWn
ooaV0[?oFO80oFKiooeIPOolo`0]oEWL0?eIg@3lFM`0oEWL0?aIg@3mFMd0oEWn
ooaV0[?oFO80oFKiooeIeol0UZKoo5WM0?aIgP00;OaIg@3lFMd0neWN0?aIg@3m
F@7ooo]V0OoooEWgooaVn?omFH7oo?olFMd0o5WN000]o5WM0?aIg@3kFMh0o5WM
0?eI0OoonfH1ooomFOOoo6KhooeIPOolooaIg@3lFMh002glFMd0o5WM0?]IgP3l
FMd0oET1oookIP7oooeImoolI_SooEWGo`2LYoolFMd0o5T0;Mh0o5WM0?aIg@3k
FMh0o5WL0?eI0OoonfH1ooomFOSo0;?lI_SooEV1oogoo5WM0?aI02gN0?aIg@3l
FMd0neWN0?aIg03mF@7ooo]V0OoooEWho`2co6KhooeIPOomooaIg@3lF@0]gP3l
FMd0o5WM0?]IgP3lFM`0oET1oookIP7oooeIn?l0/oaVn?omFMOo09VWooaIg@3l
F@0]gP3lFMd0o5WM0?]IgP3lFM`0oET1ok?lI_kooEWho`2coFKgooeIPOomooaI
g@3lF@0]gP3lFMd0o5WM0?]IgP3lFM`0oET1ok?lI_kooEWho`2coFKgooeIPOom
ooaIg@3lF@0]gP3lFMd0o5WM0?]IgP3lFM`0oET1ok?lI_kooEWho`2coFKgooeI
eol0TjSoo5WM0?]IgP3lFMd0o5WM000]o5WN0?aIf`3mF@7o/oeVoOomFOSoo6Kg
ooeIPOonooaIg@3kFMh0o5WM0?aIg@00;OaIgP3lFM/0oET1ok?mI_gooEWhooaV
moomFH7oo_olFMd0neWN0?aIg@3lFMd002glFMh0o5WK0?eI0OncoFKmooeIn?ol
I_OooEWGo`3TZ?omFOgo003Roo]Io_l00>7ooEWlo`20h_omF@2/oOl00>;o0:cm
FOko083QooeIo_l00=kooET0ooaVoOomFOWoo6H0FOOooEV1ookooEWmo`00h_ok
FOko003QooeIo?l0P>;ooET0[?go003Ro`2/oEWno`20hOomFOko003NooeI0?ol
I_gooEWiooaV05WgooeIPOonooeIoOl00>;oneWno`00hOomFOco083RooeI0:cm
o`00h_l0[?eIo_l0P>7ooEWno`00g_omF@3oo6KmooeInOolIP1ImoomFMOo0A2Y
ooeI0:cno`00h_l0e_aI0jcoo`3QooeI02gmo`00h_olF@3Fo_l00>7ooET4[?oo
P<3So`2/oET4PoooP83NooeI0;?mI_cooEWjo`2coFH1H5WgooeIPOl1ooomF@2/
o_l00>;o0=KlF@>/ool0hOomF@0]oOl00>;oo5T0e_ko003QooeI1:cooh30hol0
[?eI18?ooh20g_omF@2coFKlooeIn_l0/oeV0F1ImoomFH7o0OoooET0[?ko003R
o`3Fo5T3[?oo0>7ooET0;Ogo003RooaI0=Kno`00hOomF@B/oon0`>?o0:cmF@B3
oon0P=kooET0/oeVo?omFO[o0;?mIP5PFOOooEWGo`3TZ_olFOko003Qo`2/oET3
0?ooP>7oo5T00?ko003Roo]Io_l00>7oo5Wno`00h_olF@>/ool0gOomFOeVnoom
FO[ooFKnFOOooEV1o`3oo5Wno`00hOl0[?eI0`3ooh3QooaI003no`00h_okFOko
003QooaIo_l00>;oo5T3[?oo0=gooEWmI__ooEWjooeVoUWgooeIPOl0ooaIo_l0
0>7o0:cmF@<0oon0hOolF@00o_l00>;oneWno`00hOolFOko003RooaI0jcoo`3M
ooeIoFKkooeIn_omI_iImoomFMOo0>n[ooaI02gno`00hOolF@<0oon0h_olF@7o
0?ko003So`2/o5T00?ko003RooaI0`3oo`3Roo]I0X3o0=cooUWlI__ooEWkooaV
oUWgooeIPOolF@0]o_l00>7oo5T30?ooP>;oo5T1o`3no`00hol0[?aI003no`00
h_olF@<0ool0h_okF@:0o`3LooiIo6KkooeInoolI_iImoomFH7oo5T0;Oko003Q
ooaI0`3ooh3RooaI0Ol0o_l00>?o0:clF@00o_l00>;oo5T30?oo0>;oneT2P?l0
g?onFOaVnoomFO_oo6KnFOOooEWGo`3_ZoolF@<]ool0h?omF@Co0?ooP>;oo5T4
o`3oo`3Ro`2/o5T30?oo0>7oo5T30?oo0>;oo5T3oh3o0=co0EUIo6KjooeInoom
I_eImoomFH7oo5T3;Ooo0>3ooET4o`3ooh3RooaI1?l0ool0h_l0[?aI0`3oo`3Q
ooaI0`3oo`3RooaI0on0o`3Lo`5IFOaVn_omFO_ooFKmFOOooEV1ooaI0bgoo`3P
ooeI1?l0oon0h_olF@Co0?oo0>;o0:clF@<0ool0hOolF@<0ool0h_olF@?oP?l0
g?l1FEWlI_[ooEWkooeVoEWgooeIeol0k:coneT3P?oo0>7oo5T4o`3ooh3SooaI
1:co0?l0hOolF@?o0?l0hOolF@?o0?l0h_l0[?aI0_n00=_o0EUIo6KjooeIo?ol
I_eImoomFH;oneT3P?oo0>7oo5T4o`3ooh3SooaI1:co0?l0hOolF@?o0?l0hOol
F@?o0?l0h_l0[?aI0_n00=_o0EUIo6KjooeIo?olI_eImoomFH;oneT3P?oo0>7o
o5T4o`3ooh3SooaI1:co0?l0hOolF@?o0?l0hOolF@?o0?l0h_l0[?aI0_n00=_o
0EUIo6KjooeIo?olI_eImoomFMOo0?F/ooaI0on0o`3QooaI1?oo0?l0h_olF@Co
o`3o0>7ooET4ool0o`3QooeI1?oo0?l0h_l0[?eI0_oo0=[o05WlI_WooEWlooeV
0;?mFOOooEV2ooaI0on0o`3QooaI1?oo0?l0h_olF@Coo`3o0>7ooET4ool0o`3Q
ooeI1?oo0?l0h_l0[?eI0_oo0=[o05WlI_WooEWlooeV0;?mFOOooEV2ooaI0on0
o`3QooaI1?oo0?l0h_olF@Coo`3o0>7ooET4ool0o`3QooeI1?oo0?l0h_l0[?eI
0_oo0=[o05WlI_WooEWlooeV0;?mFOOooEWGo`3/[Ol0[?aI0_n00>3oo5T3ool0
0>;oneT3ool00>7oo5T3ool0P>7oo5T3ool00>7oo5T2ool0f_l0FOeV0;?iooeI
oOolIP2coEWgooeIPol0[?aI0_n00>3oo5T3ool00>;oneT3ool00>7oo5T3ool0
P>7oo5T3ool00>7oo5T2ool0f_l0FOeV0;?iooeIoOolIP2coEWgooeIPol0[?aI
0_n00>3oo5T3ool00>;oneT3ool00>7oo5T3ool0P>7oo5T3ool00>7oo5T2ool0
f_l0FOeV0;?iooeIoOolIP2coEWgooeIeol0k:go0:cmF@?ooh00hOolFOko0@00
h_olFOko0@00hOomFOko0@20hOomF@B/ool00>7ooEWno`20f_olIP2cnOomFOko
nfH0ooeImoomFH?o0:cmF@?ooh00hOolFOko0@00h_olFOko0@00hOomFOko0@20
hOomF@B/ool00>7ooEWno`20f_olIP2cnOomFOkonfH0ooeImoomFH?o0:cmF@?o
oh00hOolFOko0@00h_olFOko0@00hOomFOko0@20hOomF@B/ool00>7ooEWno`20
f_olIP2cnOomFOkonfH0ooeImoomFMOo0>b]ooeI0Zcoon200:cmFMf006gmF@>/
P800h83mF@>/P800h83lF@:FP03QP00]oET3[8200=Z003?lI_SooET2oonco6H1
/oomFOOooEV3ooeI0Zcoon200:cmFMf006gmF@>/P800h83mF@>/P800h83lF@:F
P03QP00]oET3[8200=Z003?lI_SooET2oonco6H1/oomFOOooEV3ooeI0Zcoon20
0:cmFMf006gmF@>/P800h83mF@>/P800h83lF@:FP03QP00]oET3[8200=Z003?l
I_SooET2oonco6H1/oomFOOooEWGo`3G[_olFOko083QooeI0:cno`00hOolFOko
003QooaIo_l00>7oneT2ool0hOolFOko003JooaVmoomF@7oooaVo_omFOOooEV4
ooaIo_l0P>7ooET0[?ko003QooaIo_l00>7oo5Wno`00hOokF@;oo`3QooaIo_l0
0=[oo6KgooeI0Oooo6KnooeImoomFHCoo5Wno`20hOomF@2/o_l00>7oo5Wno`00
hOolFOko003Qoo]I0_oo0>7oo5Wno`00f_olI_OooET1ooolI_kooEWgooeIeol0
ejkooEWmo`20h_olF@>/ool0h?omFOko083PooeIo_l00>3oo5T2ool0hOolFOko
003Joo]VmoomF@7o/oaVo_l1FEWb001IQ?omFOgo083RooaI0jcoo`3PooeIo_l0
P>3ooEWno`00h?olF@;oo`3QooaIo_l00=[onfKgooeI0Onco6Kno`5IFO8005V4
ooeIoOl0P>;oo5T3[?oo0>3ooEWno`20h?omFOko003PooaI0_oo0>7oo5Wno`00
f_okI_OooET1ok?lI_ko0EUIlP00FMOo0>V_ooaIo_l00>;oneWno`00hOolFOko
083QooaIo_l00>7o0:clF@;oo`3QooeIoOl00=_o0;?lIP1ImoomF@7o/oeVoOom
FOSooFH0FHGoo5Wno`00h_okFOko003QooaIo_l0P>7oo5Wno`00hOl0[?aI0_oo
0>7ooEWmo`00fol0/oaV05WgooeI0OncoFKmooeIn?omIP1IQOolFOko003Roo]I
o_l00>7oo5Wno`20hOolFOko003Qo`2/o5T2ool0hOomFOgo003Ko`2co6H0FOOo
oET1ok?mI_gooEWhooeV05WGo`3Y[oomFOgo003Roo]I0_oo0>3ooEWmo`20hOom
F@>/ool0h?l0[?eI0_ooP>7oo5Wno`00f_l0/oaV05WgooeI0?olI_gooEWhooeV
05V5ooeIoOl00>;oneT2ool0h?omFOgo083QooeI0jcoo`3Po`2/oET2oon0hOol
FOko003Jo`2co6H0FOOooET0ooaVoOomFOSooFH0FHGooEWmo`00h_okF@;oo`3P
ooeIoOl0P>7ooET3[?oo0>3o0:cmF@;ooh3QooaIo_l00=[o0;?lIP1ImoomF@3o
o6KmooeIn?omIP1Ieol0jK3oo5Wno`00h_l0[?aIo_l00>7oo5Wmo`20h_olF@>/
ool0h?olF@;ooh3QooeI0jcoo`3IooaV0EUImoomF@3ooFKlooeInOolIP1IQ_ol
FOko003Ro`2/o5Wno`00hOolFOgo083RooaI0jcoo`3PooaI0_ooP>7ooET3[?oo
0=Woo6H1FEWgooeI0?omI_cooEWiooaV05V6ooaIo_l00>;o0:clFOko003QooaI
oOl0P>;oo5T3[?oo0>3oo5T2oon0hOomF@>/ool0fOolIP5IFOOooET0ooeVo?om
FOWoo6H0FMOo0>2aooaIo_l00>7o0:cmFOko003QooaIoOl00>;oneT2ool0h?ol
FOko083RooaI0jcoo`3IooeVoUWgooeIo6KlooeInOomIP5IFHOoo5Wno`00hOl0
[?eIo_l00>7oo5Wmo`00h_okF@;oo`3PooaIo_l0P>;oo5T3[?oo0=WooFKnFOOo
oEWlI_cooEWiooeV0EUIQoolFOko003Qo`2/oEWno`00hOolFOgo003Roo]I0_oo
0>3oo5Wno`20h_olF@>/ool0fOomI_iImoomFOaVo?omFOWooFH1FEWGo`4F/_l0
[?eI18?ooh20hOomF@>/oon0hOl0[?eI0:cno`00h_l0e_aI0Zco0>3o0:cmF@>/
ool0h_l0[?aI0_oo0=WooFH0H?iImoonFOaVnoomFO_o0;?mIP9PFEV8o`2/oET4
PoooP83QooeI0jcooh3Qo`2/oET0[?ko003Ro`3Fo5T2[?l0h?l0[?eI0jcoo`3R
o`2/o5T2ool0fOomIP1PoUWgooiIo6KkooeInol0/oeV0V1IFHSo0:cmF@B3oon0
P>7ooET3[?ooP>7o0:cmF@2/o_l00>;o0=KlF@:/o`3Po`2/oET3[?oo0>;o0:cl
F@;oo`3IooeV063nFOOooUWlI__ooEWko`2coFH2H5UIeol0jK;oo5Wno`00hOol
FOko083QooeI0:cno`00hOl0[?eI0_ooP=oooEWno`00h_l0[?aI0_oo0=Woo6Km
FOOo0EUIo6KjooeInoolI_iIR?olFOko003QooaIo_l0P>7ooET0[?ko003Qo`2/
oET2oon0goomFOko003Ro`2/o5T2ool0fOolI_eImol1FEWlI_[ooEWkooaVoUV8
ooaIo_l00>7oo5Wno`20hOomF@2/o_l00>7o0:cmF@;ooh3OooeIo_l00>;o0:cl
F@;oo`3IooaVoEWgo`5IFOaVn_omFO_oo6KnFMOo0>Vcoo]I0_oo0>7oo5Wmo`20
h_olF@2/o_l00>7oo5T2oon0h?olFOko003Ro`2/o5T2ool0fOomIP3ooEWgo`5I
FOeVnOomFOcoo6KmFHWoneT2ool0hOolFOgo083RooaI0:cno`00hOolF@;ooh3P
ooaIo_l00>;o0:clF@;oo`3IooeV0?omFOOo0EUIoFKiooeIo?olI_eIROokF@;o
o`3QooaIoOl0P>;oo5T0[?ko003QooaI0_ooP>3oo5Wno`00h_l0[?aI0_oo0=Wo
oFH0ooeImol1FEWmI_WooEWlooaVoEWGo`3P/oolFOko003QooaIo_l00>7oo5Wn
o`00h?omFOko083PooeIo_l00>7oo5T2oon0fOolIP3ooEWgo`1Io6KiooeIo?om
IP2coEV9ooaIo_l00>7oo5Wno`00hOolFOko003PooeIo_l0P>3ooEWno`00hOol
F@;ooh3IooaV0?omFOOo05WlI_WooEWlooeV0;?mFHWoo5Wno`00hOolFOko003Q
ooaIo_l00>3ooEWno`20h?omFOko003QooaI0_ooP=Woo6H0ooeImol0FOaVnOom
FOcooFH0/oeIeol0i[Co0:clF@;oo`3QooaIoOl00>;oneWno`00hOolFOko083S
o`400?aIg@3mFMT0o_olIP7oooeImol0FOeV0;?iooeIoOolIP2coEV:o`2/o5T2
ool0hOolFOgo003Roo]Io_l00>7oo5Wno`20hol1003lFMd0oEWI0?koo6H1ooom
FOOo05WmIP2cnOomFOgoo6H0/oeIR_l0[?aI0_oo0>7oo5Wmo`00h_okFOko003Q
ooaIo_l0P>?o0@00o5WM0?eIf@3nooaV0OoooEWgo`1IoFH0/oWooEWmooaV0;?m
FMOo0;>do`0]oEWM0?eIg03lFM`0oEWL0?eI02gM0?eIg@3mFOkoo6H1ooomFOOo
o6H0/oWooEWmooaV0?omFH[o02gmFMd0oEWL0?aIg03mFM`0oET0;Md0oEWM0?eI
o_olIP7oooeImoolIP2cnOomFOgoo6H0ooeIR_l0;OeIg@3mFM`0o5WL0?eIg03m
F@0]g@3mFMd0oEWnooaV0OoooEWgooaV0;?iooeIoOolIP3ooEWGo`2f]?l0;OeI
gP3lFMd002glFMd0o5WM0?aI02gN0?eIg03mF@7oooaV0k?ooeWb0?iVn?omFOko
nfH0ooeIR_l0;OeIgP3lFMd002glFMd0o5WM0?aI02gN0?eIg03mF@7oooaV0k?o
oeWb0?iVn?omFOkonfH0ooeIR_l0;OeIgP3lFMd002glFMd0o5WM0?aI02gN0?eI
g03mF@7oooaV0k?ooeWb0?iVn?omFOkonfH0ooeIeol0_;CooEWN0?aI02gM0?aI
g@3lFMd0neWN000]oEWL0?eI0Onco6KnooeIn?olIP2cn?omF@;oomWlIP7oooeI
R_omFMh0o5T0;Md0o5WM0?aIg@3kFMh002gmFM`0oET1ok?lI_kooEWhooaV0;?h
ooeI0_oofOaV0OoooEV:ooeIgP3lF@0]g@3lFMd0o5WM0?]IgP00;OeIg03mF@7o
/oaVo_omFOSoo6H0/oSooET2oooIo6H1ooomFMOo0<ReooaIg`3kFMd0o5WM0?aI
g@00;OaI0_oo0>3ooEWno`00goomF@3oo6KmooeInOl0/oaVmoomF@;ook?mI_ko
oEV;ooaIg`3kFMd0o5WM0?aIg@00;OaI0_oo0>3ooEWno`00goomF@3oo6KmooeI
nOl0/oaVmoomF@;ook?mI_kooEV;ooaIg`3kFMd0o5WM0?aIg@00;OaI0_oo0>3o
oEWno`00goomF@3oo6KmooeInOl0/oaVmoomF@;ook?mI_kooEWGo`3e]_olFOko
003RooaIoOl00>7ooEWmo`20hOomF@2/o_l00>7oo5T2oon0h?olF@;oo`3NooeI
0;?lI_gooEWiooaV05WgooeI0Oooo6KnooeIS?olFOko003RooaIoOl00>7ooEWm
o`20hOomF@2/o_l00>7oo5T2oon0h?olF@;oo`3NooeI0;?lI_gooEWiooaV05Wg
ooeI0Oooo6KnooeIS?olFOko003RooaIoOl00>7ooEWmo`20hOomF@2/o_l00>7o
o5T2oon0h?olF@;oo`3NooeI0;?lI_gooEWiooaV05WgooeI0Oooo6KnooeIeol0
mKKoo5T2ool0h_l0[?aIo_l00>7oo5Wmo`20h_olF@>/ool0h?olF@;ooh3QooaI
o_l00=kooET0/oeVo?omFOWoo6H0FOOooET0ooaVoOomFHcoo5T2ool0h_l0[?aI
o_l00>7oo5Wmo`20h_olF@>/ool0h?olF@;ooh3QooaIo_l00=kooET0/oeVo?om
FOWoo6H0FOOooET0ooaVoOomFHcoo5T2ool0h_l0[?aIo_l00>7oo5Wmo`20h_ol
F@>/ool0h?olF@;ooh3QooaIo_l00=kooET0/oeVo?omFOWoo6H0FOOooET0ooaV
oOomFMOo0>ngooaIo_l00>;oo5T00?ko003RooaIo?l0P>?oneWno`00hOolFOko
083QooaI0_oo0=gooEWlI_cooEWjooaV0EUImoomF@3oo6KmooaIS_olFOko003R
ooaI003no`00h_olFOco083Soo]Io_l00>7oo5Wno`20hOolF@;oo`3MooeIo6Kl
ooeIn_olIP5IFOOooET0ooaVoOolFHkoo5Wno`00h_olF@00o_l00>;oo5Wlo`20
hookFOko003QooaIo_l0P>7oo5T2ool0gOomFOaVo?omFO[oo6H1FEWgooeI0?ol
I_goo5WHo`3_]oomF@<0ool0hOolF@<0ool0hOolFOgo003Roo]I0_oo0>3ooET0
0?ko083RooaI0jcoo`3MooeIoFKkooeIn_omI_iImoomFOaVo?olFHkooET30?oo
0>7oo5T30?oo0>7oo5Wmo`00h_okF@;oo`3PooeI003no`20h_olF@>/ool0gOom
FOeVnoomFO[ooFKnFOOooEWlI_coo5V>ooeI0`3oo`3QooaI0`3oo`3QooaIoOl0
0>;oneT2ool0h?omF@00o_l0P>;oo5T3[?oo0=gooEWmI__ooEWjooeVoUWgooeI
o6KlooaIf?l0kkSoo5T30?oo0>;oo5T3o`3oP>7oo5T00?ko003Roo]I0P3o0>3o
o5T30?oo0>7oo5T2P?l0g?onFOaVnoomFO_oo6KnFOOooEWmI__oo5V?ooaI0`3o
o`3RooaI0ol0oh3QooaI003no`00h_okF@80o`3PooaI0`3oo`3QooaI0X3o0=co
oUWlI__ooEWkooaVoUWgooeIoFKkooaISoolF@<0ool0h_olF@?o0?n0hOolF@00
o_l00>;oneT20?l0h?olF@<0ool0hOolF@:0o`3LooiIo6KkooeInoolI_iImoom
FOeVnoolFMSo0?RiooaI0j`0o`3QooeI1?oo0?n0hOomF@6/0?ko003RooaI0ol0
o`3PooeI0ol0o`3Qoo]I0H00fol1FEWlI_[ooEWkooeVoEWgooiIo6KjooeIT?ol
F@>/0?l0hOomF@Coo`3oP>7ooET1[03no`00h_olF@?o0?l0h?omF@?o0?l0hOok
F@600=_o0EUIo6KjooeInoomI_eImoonFOaVn_omFI3oo5T3[03o0>7ooET4ool0
oh3QooeI0J`0o_l00>;oo5T3o`3o0>3ooET3o`3o0>7oneT1P03Ko`5IFOaVn_om
FO_ooFKmFOOooUWlI_[ooEWHo`4U^_l0[?aI0]H00>7ooET5[?oo0?n0h_olF@CF
0?oo0>;o0:cmF@>/o`20hOl0[?eI1:co0820h_l0[?aI0_m0P=_o0EUPoFH0/o[o
oEWlooeV0;?mFOOo0UUIH?eVnOomFI7o0:clF@;F003QooeI1Jcoo`3oP>;oo5T4
eP3oo`3Ro`2/oET3[?l0P>7o0:cmF@B/o`20P>;o0:clF@;o@83Ko`5IH?eV0;?j
ooeIo?omIP2coEWgo`9IFF3mI_WooEVAo`2/o5T2eP00hOomF@F/ool0oh3RooaI
1=H0ool0h_l0[?eI0jco083Qo`2/oET4[?l0P83Ro`2/o5T2od20fol1FF3mIP2c
n_omFOcooFH0/oeImol2FEUPoFKiooeIf?l0nk[oo5T2ool0hOolFOko0@00h_ok
F@?o0?l0hOolF@?oo`20hOolF@?oo`00hOolF@;oo`3Jo`1IoFKhooeIoOolIP3o
oEWgo`5IFOeV0;?iooeITOolF@;oo`3QooaIo_l1003Roo]I0ol0o`3QooaI0ooo
083QooaI0ooo003QooaI0_oo0=[o05WmI_SooEWmooaV0?omFOOo0EUIoFH0/oWo
oEVAooaI0_oo0>7oo5Wno`400>;oneT3o`3o0>7oo5T3ool0P>7oo5T3ool00>7o
o5T2ool0f_l0FOeVn?omFOgoo6H0ooeImol1FEWmIP2cnOomFMSo0?jkoo]I0_oo
0>7ooEWmo`400>;oo5T4ool0o`3QooeIo_l1083RooaI0jcoo`3Qo`2/o5T2oon0
f_olI_SooEWnooaV0K?ooEWgo`1Io6H0/oWooEVBoo]I0_oo0>7ooEWmo`400>;o
o5T4ool0o`3QooeIo_l1083RooaI0jcoo`3Qo`2/o5T2oon0f_olI_SooEWnooaV
0K?ooEWgo`1Io6H0/oWooEVBoo]I0_oo0>7ooEWmo`400>;oo5T4ool0o`3QooeI
o_l1083RooaI0jcoo`3Qo`2/o5T2oon0f_olI_SooEWnooaV0K?ooEWgo`1Io6H0
/oWooEWHo`2c_?l0[?aI0_ooP>40o5WM0?]Ig@3lFMd0o5WM0?aIeP3mIP2cn?om
FOkoo6H1/oomFOOo05WlI_SooEVCo`2/o5T2oon0h@3lFMd0neWM0?aIg@3lFMd0
o5WF0?eV0;?hooeIo_olIP6cooeImol0FOaVn?omFI?o0:clF@;ooh3Q0?aIg@3k
FMd0o5WM0?aIg@3lFMH0oFH0/oSooEWnooaV0K?ooEWgo`1Io6KhooeIf?l0n;co
0:clF@;ooh3RooaI0:cno`00h_l0[?aI0_ooP>3oo5Wno`00hOokF@;oo`3PooaI
0_oo0=[oo6H0/oSooET1oookIP7oooeImookI_SooEVCo`2/o5T2oon0h_olF@2/
o_l00>;o0:clF@;ooh3PooaIo_l00>7oneT2ool0h?olF@;oo`3JooaV0;?hooeI
0OoonfH1ooomFOOonfKhooeITol0[?aI0_ooP>;oo5T0[?ko003Ro`2/o5T2oon0
h?olFOko003Qoo]I0_oo0>3oo5T2ool0f_olIP2cn?omF@7ooo]V0OoooEWgoo]V
n?omFMSo0>VlooaIo_l0P>;oo5T0[?ko003Ro`2/o5T2oon0h?olFOko003Roo]I
o_l00>7oo5Wno`00f_olI_OooET1ooolI_ko05Wb0?iVmoomFI?oo5Wno`20h_ol
F@2/o_l00>;o0:clF@;ooh3PooaIo_l00>;oneWno`00hOolFOko003JooaVmoom
F@7oooaVo_l0FO80oVKgooeIToolFOko083RooaI0:cno`00h_l0[?aI0_ooP>3o
o5Wno`00h_okFOko003QooaIo_l00=[oo6KgooeI0Oooo6Kno`1IlP3nI_OooEWH
o`3S_?omFOko003Roo]Io_l00>7oo5Wno`20hOolFOko003Qoo]I0_oo0>3ooEWn
o`00f_okI_OooET1ok?lI_kooEWho`2co6KgooeIToomFOko003Roo]Io_l00>7o
o5Wno`20hOolFOko003Qoo]I0_oo0>3ooEWno`00f_okI_OooET1ok?lI_kooEWh
o`2co6KgooeIToomFOko003Roo]Io_l00>7oo5Wno`20hOolFOko003Qoo]I0_oo
0>3ooEWno`00f_okI_OooET1ok?lI_kooEWho`2co6KgooeIf?l17;ko0:cmF@B/
oon0P>?o0:clFOko0H20h_l0[?eIo_l1P<3Ro`2/oEWno`00hOl0[?eI0jcooh3P
ooeI1:cooh20fookIP1ImoomF@7oSOeVoOomFOSooFH0H?KooEVEo`2/oET4[?oo
P83So`2/o5Wno`60P>;o0:cmFOko0H30h_l0[?eIo_l00>7o0:cmF@>/oon0h?om
F@B/oon0P=_onfH0FOOooET1ohgmI_gooEWhooeV063fooeIUOl0[?eI1:cooh20
hol0[?aIo_l1P83Ro`2/oEWno`60`>;o0:cmFOko003Qo`2/oET3[?ooP>3ooET4
[?ooP83Koo]V05WgooeI0On=oFKmooeIn?omIP1Pm_omFMSo0?:nooaIo_l00>;o
o5Wno`00h?omFOko003PooeI0jcoo`3PooaIo_l0P>7oo5Wno`00fol0/oaV0EUI
moomF@3ooFKlooeInOolIP1Im_omFIGoo5Wno`00h_olFOko003PooeIo_l00>3o
oET3[?oo0>3oo5Wno`20hOolFOko003Ko`2co6H1FEWgooeI0?omI_cooEWiooaV
05WfooeIUOolFOko003RooaIo_l00>3ooEWno`00h?omF@>/ool0h?olFOko083Q
ooaIo_l00=_o0;?lIP5IFOOooET0ooeVo?omFOWoo6H0FOKooEWHo`3b_oolFOko
003Ro`2/o5Wno`00hOolFOko003QooaI0jcoo`3PooeIoOl0P>7ooEWno`00f_l0
/oeVoUWgooeIo6KlooeInOomIP5IFOKooEVFooaIo_l00>;o0:clFOko003QooaI
o_l00>7oo5T3[?oo0>3ooEWmo`20hOomFOko003Jo`2coFKnFOOooEWlI_cooEWi
ooeV0EUIm_omFIKoo5Wno`00h_l0[?aIo_l00>7oo5Wno`00hOolF@>/ool0h?om
FOgo083QooeIo_l00=[o0;?mI_iImoomFOaVo?omFOWooFH1FEWfooeIf?l0jKoo
oEWmo`00h_l0[?eIo_l0P>3ooEWno`00h?olF@;oo`3PooaIo_l00>7oo5T2ool0
fOolI_iImoonFOaVnoomFO[oo6H1FEWfooeIU_omFOgo003Ro`2/oEWno`20h?om
FOko003PooaI0_oo0>3oo5Wno`00hOolF@;oo`3IooaVoUWgooiIo6KkooeIn_ol
IP5IFOKooEVFooeIoOl00>;o0:cmFOko083PooeIo_l00>3oo5T2ool0h?olFOko
003QooaI0_oo0=Woo6KnFOOooUWlI__ooEWjooaV0EUIm_omFMSo0>?0ooaIo_l0
0>7oo5Wno`20hOolFOko003Qoo]I0_oo0>7oo5Wmo`00h_olF@>/ool0fOomI_eI
moonFOaVnoomFO[ooFKnFOKooEVGooaIo_l00>7oo5Wno`20hOolFOko003Qoo]I
0_oo0>7oo5Wmo`00h_olF@>/ool0fOomI_eImoonFOaVnoomFO[ooFKnFOKooEVG
ooaIo_l00>7oo5Wno`20hOolFOko003Qoo]I0_oo0>7oo5Wmo`00h_olF@>/ool0
fOomI_eImoonFOaVnoomFO[ooFKnFOKooEWHo`3_`OolF@2/o_l00>;oo5Wmo`20
h_olFOko003Qo`2/o5T2ool0h?olFOko003QooaI0Zco0=Woo6KmFOOo0EUIo6Kj
ooeInoolI_iIm_omFISoo5T0[?ko003RooaIoOl0P>;oo5Wno`00hOl0[?aI0_oo
0>3oo5Wno`00hOolF@:/o`3IooaVoEWgo`5IFOaVn_omFO_oo6KnFOKooEVHooaI
0:cno`00h_olFOgo083RooaIo_l00>7o0:clF@;oo`3PooaIo_l00>7oo5T2[?l0
fOolI_eImol1FEWlI_[ooEWkooaVoUWfooeIf?l0kl7oo5T3[?oo0>7oo5Wmo`20
h_olFOko003Qo`2/o5T1oh3PooaIo_l00>7oneT2ool0fOomIP3ooEWgo`5IFOeV
nOomFO_ooFKmFOKooEVHooaI0jcoo`3QooaIoOl0P>;oo5Wno`00hOl0[?aI0On0
h?olFOko003Qoo]I0_oo0=WooFH0ooeImol1FEWmI_WooEWkooeVoEWfooeIV?ol
F@>/ool0hOolFOgo083RooaIo_l00>7o0:clF@7oP>3oo5Wno`00hOokF@;oo`3I
ooeV0?omFOOo0EUIoFKiooeInoomI_eIm_omFMSo0Ao3o`30o5T0;Oj0003RP?eI
02gmP000hX3lF@=GP800hX01003mF@0]gP00;OeIg@005oaIgP3n;@3Fo_l0/oeV
0K?ooEWgo`1IoFH0SOWooEWmo`2coFH0SOeIm_omFI[o0<3lF@0]oX000>:0oET0
;Of0003RP?aI0eN0P03RP0400?eI02gN000]oEWM000Go5WN0?h]0=Kno`2coFH1
/oomFOOo05WmIP2=nOomFOgo0;?mIP2=oEWfooeIV_l0`?aI02gnP000hX3mF@0]
oH000>:0o5T3Eh200>:00@00oET0;Mh002gmFMd001OlFMh0oRd0e_ko0;?mIP6c
ooeImol0FOeV08giooeIoOl0/oeV08gmFOKooEWHo`2o`ol0[?aIg@3mFMd0neWM
0?aIgP3lF@0]g@3lFMd0oUT0[?koo6H1ooob0?eV0;?iooeIoOolIP2coEWfooeI
V_l0[?aIg@3mFMd0neWM0?aIgP3lF@0]g@3lFMd0oUT0[?koo6H1ooob0?eV0;?i
ooeIoOolIP2coEWfooeIV_l0[?aIg@3mFMd0neWM0?aIgP3lF@0]g@3lFMd0oUT0
[?koo6H1ooob0?eV0;?iooeIoOolIP2coEWfooeIf?l0_<?oo5WM0?eIg@00;OaI
g@3lFMd0o5T0;Md0o5WM0?iI0ZcoooaVo_omFOOoo6KhooeIo_okIP3ooEWfooeI
V_olFMd0oEWM000]o5WM0?aIg@3lF@0]g@3lFMd0oUT2[?ooo6KnooeImoolI_So
oEWnoo]V0?omFOKooEVJooaIg@3mFMd002glFMd0o5WM0?aI02gM0?aIg@3nF@:/
ooolI_kooEWgooaVn?omFOkonfH0ooeIm_omFMSo0;o3ooaIg@3mFMd002glFMd0
o5WN0?]Ig@3lFM`0oUT2[?oooFH0/okooEWhoo]Vn?omFOkoo6H1ooomFOKooEVJ
ooaIg@3mFMd002glFMd0o5WN0?]Ig@3lFM`0oUT2[?oooFH0/okooEWhoo]Vn?om
FOkoo6H1ooomFOKooEVJooaIg@3mFMd002glFMd0o5WN0?]Ig@3lFM`0oUT2[?oo
oFH0/okooEWhoo]Vn?omFOkoo6H1ooomFOKooEWHo`3Ma?olFMd0o5WM0?aIg@3l
FOko003QooaIo_l00>7oo5Wmo`20h?onF@6/ooaV0;?nooeIn?olI_OooET1oook
IP7oooeIm_omFI_oo5WM0?aIg@3lFMd0o5Wno`00hOolFOko003QooaIoOl0P>3o
oUT1[?olIP2co_omFOSoo6KgooeI0OoonfH1ooomFOKooEVKooaIg@3lFMd0o5WM
0?aIo_l00>7oo5Wno`00hOolFOgo083PooiI0Jcoo6H0/okooEWhooaVmoomF@7o
oo]V0OoooEWfooeIf?l11<CooEWmo`20hOomF@2/o_l00>7ooEWno`20hOolFOko
003Qo`2/o5T2ool0h?olFOko003OooiI0Jcoo6KmooeInOokI_OooET1ooolI_ko
oEWfooeIVoomFOgo083QooeI0:cno`00hOomFOko083QooaIo_l00>7o0:clF@;o
o`3PooaIo_l00=oooUT1[?olI_gooEWioo]VmoomF@7oooaVo_omFOKooEVKooeI
oOl0P>7ooET0[?ko003QooeIo_l0P>7oo5Wno`00hOl0[?aI0_oo0>3oo5Wno`00
goonF@6/ooaVoOomFOWonfKgooeI0Oooo6KnooeIm_omFMSo0@C5ooaIoOl0P>;o
o5T3[?oo0>7oo5Wno`20hOolFOko003QooaIo_l00>7oo5Wmo`00goonF@2/nfKm
ooeIn_l0/oaV05WgooeI0Onco6KnooeIm_omFIcoo5Wmo`20h_olF@>/ool0hOol
FOko083QooaIo_l00>7oo5Wno`00hOolFOgo003OooiI0:ckI_gooEWjo`2co6H0
FOOooET1ok?lI_kooEWfooeIW?olFOgo083RooaI0jcoo`3QooaIo_l0P>7oo5Wn
o`00hOolFOko003QooaIoOl00=oooUT0[?]VoOomFO[o0;?lIP1ImoomF@7o/oaV
o_omFOKooEWHo`4Fa_olF@00o_l00>;oneWno`00h_olFOgo083RooaI0jcoo`3P
ooaI0_ooP>3ooET00?ko003NooiI0:clI_cooEWjo`2co6H0FOOooET1ok?mI_go
05Wb009VFEVMooaI003no`00h_okFOko003RooaIoOl0P>;oo5T3[?oo0>3oo5T2
oon0h?omF@00o_l00=kooUT0[?aVo?omFO[o0;?lIP1ImoomF@7o/oeVoOl0FO80
0VIIFIgoo5T00?ko003Roo]Io_l00>;oo5Wmo`20h_olF@>/ool0h?olF@;ooh3P
ooeI003no`00g_onF@2/o6KlooeIn_l0/oaV05WgooeI0OncoFKmo`1IlP02IUUI
f?l1D/Oo0:cmF@F/0?ooP83So`3Fo5T3[?oo0>;o0:cmF@0]o_l00>;o0:clF@>0
oh20hOomF@B/0?ooP>;o0:cmF@B30?oo0=gooUT0H?eV0;?looeIn_omIP9PFEWg
ooeI0;?mIP2coOolFOWooFH1FEVNo`2/oET5[03ooh20hol0e_aI0jcoo`3Ro`2/
oET0;Oko003Ro`2/o5T3P?n0P>7ooET4[03ooh3Ro`2/oET4P`3oo`3MooiI063m
IP2co?omFO[ooFH2H5UImoomF@2coFH0/ogoo5WiooeV0EUIW_l0[?eI1J`0oon0
P>?o0=KlF@>/ool0h_l0[?eI02gno`00h_l0[?aI0h3oP83QooeI1:`0oon0h_l0
[?eI18<0ool0gOonF@1PoFH0/ocooEWjooeV0V1IFOOooET0/oeV0;?mooaInOom
IP5IFMSo0AW7ooeI1Jco0?oo0>;o0:cmF@<0ool0hOomF@Co0?oo0>7oo5T3oh3o
0>7oo5T4o`3ooh3RooaI0j`0o`3LooiIo6KkooeInoolI_iImoomFOaVnoomFO[o
o6H1FEVNooeI1Jco0?oo0>;o0:cmF@<0ool0hOomF@Co0?oo0>7oo5T3oh3o0>7o
o5T4o`3ooh3RooaI0j`0o`3LooiIo6KkooeInoolI_iImoomFOaVnoomFO[oo6H1
FEVNooeI1Jco0?oo0>;o0:cmF@<0ool0hOomF@Co0?oo0>7oo5T3oh3o0>7oo5T4
o`3ooh3RooaI0j`0o`3LooiIo6KkooeInoolI_iImoomFOaVnoomFO[oo6H1FEWH
o`4=b?olF@B/o`3o0>7oo5T20?n0hOolF@?o0?l0hOl0[?aI0_n00>3ooET4ool0
o`3Roo]I0ol0o`3Lo`5IFOaVn_omFO_ooFKmFOOooUWlI_[ooEWjooeVoUVOooaI
1:co0?l0hOolF@80oh3QooaI0ol0o`3Qo`2/o5T2oh00h?omF@Coo`3o0>;oneT3
o`3o0=co0EUIo6KjooeInoomI_eImoonFOaVn_omFO[ooFKnFIooo5T4[?l0o`3Q
ooaI0P3oP>7oo5T3o`3o0>7o0:clF@;oP03PooeI1?oo0?l0h_okF@?o0?l0g?l1
FEWlI_[ooEWkooeVoEWgooiIo6KjooeIn_omI_iIf?l12/Soo5T4ool0o`3QooeI
0ol0oh3QooeI1:co0?l0hOolF@;oo`3PooaI0ooo003QooaI0ooo003Ko`5IFOaV
n_omFOcoo6KmFOOooUWmI_WooEWkooaVoUVOooaI1?oo0?l0hOomF@?o0?n0hOom
F@B/o`3o0>7oo5T2ool0h?olF@?oo`00hOolF@?oo`00fol1FEWlI_[ooEWlooaV
oEWgooiIoFKiooeInoolI_iIWoolF@Coo`3o0>7ooET3o`3oP>7ooET4[?l0o`3Q
ooaI0_oo0>3oo5T3ool00>7oo5T3ool00=_o0EUIo6KjooeIo?olI_eImoonFOeV
nOomFO_oo6KnFMSo0A39oo]I0ooo003QooaI0ol0oh3RooaI0jco003PooaI0_oo
0>3ooEWno`400>;o0:clF@?oo`00fol0FOaVnOomFOcooFH0ooeImol1FEWlI_Wo
oEWlooaVoEVPoo]I0ooo003QooaI0ol0oh3RooaI0jco003PooaI0_oo0>3ooEWn
o`400>;o0:clF@?oo`00fol0FOaVnOomFOcooFH0ooeImol1FEWlI_WooEWlooaV
oEVPoo]I0ooo003QooaI0ol0oh3RooaI0jco003PooaI0_oo0>3ooEWno`400>;o
0:clF@?oo`00fol0FOaVnOomFOcooFH0ooeImol1FEWlI_WooEWlooaVoEWHo`41
bOolFOko0@00hOomF@Coo`3oP>;oo5T3ool00>7oo5Wno`20hOolFOko003QooaI
o_oI001IoFKhooeIoOolIP3ooEWgo`5IFOeVn?omFOcoo6KmFJ3oo5Wno`400>7o
oET4ool0oh3RooaI0ooo003QooaIo_l0P>7oo5Wno`00hOolFOkof@00FOeVn?om
FOgoo6H0ooeImol1FEWmI_SooEWlooaVoEVPooaIo_l1003QooeI1?oo0?n0h_ol
F@?oo`00hOolFOko083QooaIo_l00>7oo5WnomT005WmI_SooEWmooaV0?omFOOo
0EUIoFKhooeIo?olI_eIf?l0c/[o0:clF@7ooml0o5WN0?]Ig@3mFMd0o5T0;Md0
o5Wn0=Woo6KhooeIo_olIP7oooeImol0FOaVn?omFOgoo6H0ooeIXOl0[?aI0Ooo
g`3lFMh0neWM0?eIg@3lF@0]g@3lFOh0fOolI_SooEWnooaV0OoooEWgo`1Io6Kh
ooeIoOolIP3ooEVQo`2/o5T1oooO0?aIgP3kFMd0oEWM0?aI02gM0?aIoP3IooaV
n?omFOkoo6H1ooomFOOo05WlI_SooEWmooaV0?omFMSo0D?:ooaI0ooo`03QooaI
0_oo0>7o0:clF@;oo`3Qo`2/oET0[?ko003Ro`2/o5T3e_oo0>7ooET0[?ko083J
o`2coFKgooeI0_oo/oeV0hgooeWn;ON00BdcoVH0/oSooEWno`2coFH1/oomFJ7o
o5T3ooo00>7oo5T2ool0hOl0[?aI0_oo0>7o0:cmF@2/o_l00>;o0:clF@?Fool0
hOomF@2/o_l0P=[o0;?mI_OooET2ooncoFH3SOooFOh]mh01;C?nIP2cn?omFOko
0;?mIP6cooeIXOolF@?ool00hOolF@;oo`3Qo`2/o5T2ool0hOl0[?eI0:cno`00
h_l0[?aI0mKoo`3QooeI0:cno`20f_l0/oeVmoomF@;ook?mIP>=oomIoRggP04]
<oiV0;?hooeIo_l0/oeV0K?ooEWHo`3nboolFOko083QooaI0_oo0>3oo5T2oon0
h?olFOko003QooaIo_l00>7oo5Wmo`20f_omIP2cmoomF@7oooaVo_omFOOoo6Kg
ooeIo_olIP7oooeIX_olFOko083QooaI0_oo0>3oo5T2oon0h?olFOko003QooaI
o_l00>7oo5Wmo`20f_omIP2cmoomF@7oooaVo_omFOOoo6KgooeIo_olIP7oooeI
X_olFOko083QooaI0_oo0>3oo5T2oon0h?olFOko003QooaIo_l00>7oo5Wmo`20
f_omIP2cmoomF@7oooaVo_omFOOoo6KgooeIo_olIP7oooeIf?l10L_ooEWmo`20
hOomF@>/ool0h?omFOko083QooaIo_l00>7oneT2ool0hOolFOgo003JooaV0;?g
ooeI0?okI_kooEWhoo]VmoomF@7ooo]V0OoooEVRooeIoOl0P>7ooET3[?oo0>3o
oEWno`20hOolFOko003Qoo]I0_oo0>7oo5Wmo`00f_olIP2cmoomF@3onfKnooeI
n?okI_OooET1oookIP7oooeIX_omFOgo083QooeI0jcoo`3PooeIo_l0P>7oo5Wn
o`00hOokF@;oo`3QooaIoOl00=[oo6H0/oOooET0oo]Vo_omFOSonfKgooeI0Ooo
nfH1ooomFMSo0@O<ooaIoOl0P>;oo5T2[?l0h?olFOko083QooeI0:cno`00hOol
FOko003QooaIo_l00=[onfH0[?OooET0ooaVoOomFOWo0;?lI_KooET1ooolI_ko
oEVSooaIoOl0P>;oo5T2[?l0h?olFOko083QooeI0:cno`00hOolFOko003QooaI
o_l00=[onfH0[?OooET0ooaVoOomFOWo0;?lI_KooET1ooolI_kooEVSooaIoOl0
P>;oo5T2[?l0h?olFOko083QooeI0:cno`00hOolFOko003QooaIo_l00=[onfH0
[?OooET0ooaVoOomFOWo0;?lI_KooET1ooolI_kooEWHo`4:c?omFOgo003QooaI
0_oo0>3ooEWno`00hOolF@>/ool0hOl0[?aI0_ooP>7oo5Wmo`00f_okIP2/moom
F@2co6KmooeInOl0/oaVm_omF@7o/oaVo_omFJ?ooEWmo`00hOolF@;oo`3PooeI
o_l00>7oo5T3[?oo0>7o0:clF@;ooh3QooaIoOl00=[onfH0[?OooET0/oaVoOom
FOWo0;?lI_KooET1ok?lI_kooEVSooeIoOl00>7oo5T2ool0h?omFOko003QooaI
0jcoo`3Qo`2/o5T2oon0hOolFOgo003Joo]V0:cgooeI0;?lI_gooEWio`2co6Kf
ooeI0Onco6KnooeIf?l14lgoo5Wmo`00h_okF@7o0>3oo5Wno`00hOolFOko003Q
o`2/oEWno`20hOomF@2/o_l00=[o0;?lIP5I[?OooET0/oeVo?omFOWoo6H0FOKo
oET1ok?mI_gooEVTooaIoOl00>;oneT1o`3PooaIo_l00>7oo5Wno`00hOl0[?eI
o_l0P>7ooET0[?ko003Jo`2co6H1FJcgooeI0;?mI_cooEWiooaV05WfooeI0Onc
oFKmooeIY?olFOgo003Roo]I0Ol0h?olFOko003QooaIo_l00>7o0:cmFOko083Q
ooeI0:cno`00f_l0/oaV0EV/moomF@2coFKlooeInOolIP1Im_omF@7o/oeVoOom
FMSo0@g=ooeIoOl00>7oo5T2ool0h?omFOko003Qoo]I0_oo0>3oo5Wno`20h_ol
F@2/o_l00=[o0;?mIP9IFJcgooeIo6KlooeInOomIP5IFOKooET0ooaVoOomFJCo
oEWmo`00hOolF@;oo`3PooeIo_l00>7oneT2ool0h?olFOko083RooaI0:cno`00
f_l0/oeV0UUI[?OooEWlI_cooEWiooeV0EUIm_omF@3oo6KmooeIY?omFOgo003Q
ooaI0_oo0>3ooEWno`00hOokF@;oo`3PooaIo_l0P>;oo5T0[?ko003Jo`2coFH2
FEV/moomFOaVo?omFOWooFH1FEWfooeI0?olI_gooEWHo`4Xcol0[?eI08?no`60
P>?o0=KlF@:/oh3Qo`2/oET4[?ooP83Roo]I0oooP83QooaIo_l1P<3Soo]Io_l0
0=WooFH3H5UI[?OooUWlI__ooEWjooeV0V1IFOKooEWlI_cooEVVo`2/oET0Poko
0H20hol0e_aI0ZcoP>7o0:cmF@B/oon0P>;oneT3oon0P>7oo5Wno`60`>?oneWn
o`00fOomIP=PFEV/moonFOaVnoomFO[ooFH2H5UIm_omFOaVo?omFJKo0:cmF@23
o_l1P83So`3Fo5T2[?n0hOl0[?eI1:cooh20h_okF@?ooh20hOolFOko0H30hook
FOko003IooeV0f1IFJcgooiIo6KkooeIn_omIP9PFEWfooeIo6KlooeIf?l13Loo
o5T0[?ko003Ro`2/o5T2oon0hOolF@;oo`3Qo`2/o5T2oon0h?olFOko003Roo]I
o_l00=Woo6KnF@2/mol1FEWlI_[ooEWkooaVoUWfooiIo6KkooeIY_olF@2/o_l0
0>;o0:clF@;ooh3QooaI0_oo0>7o0:clF@;ooh3PooaIo_l00>;oneWno`00fOol
I_iI0:cgo`5IFOaVn_omFO_oo6KnFOKooUWlI__ooEVVooaI0:cno`00h_l0[?aI
0_ooP>7oo5T2ool0hOl0[?aI0_ooP>3oo5Wno`00h_okFOko003IooaVoUT0[?Oo
0EUIo6KjooeInoolI_iIm_onFOaVnoomFMSo0@[@oo]Io_l00>7oo5Wno`20h_ol
F@>/ool0hOl0[?eIo_l0P>3ooEWmo`00h_olFOgo003IooeV0?onF@2/mol1FEWm
I_WooEWkooeVoEWfooiIoFKjooeIYookFOko003QooaIo_l0P>;oo5T3[?oo0>7o
0:cmFOko083PooeIoOl00>;oo5Wmo`00fOomIP3ooUT0[?Oo0EUIoFKiooeInoom
I_eIm_onFOeVn_omFJOoneWno`00hOolFOko083RooaI0jcoo`3Qo`2/oEWno`20
h?omFOgo003RooaIoOl00=WooFH0ooiI0:cgo`5IFOeVnOomFO_ooFKmFOKooUWm
I_[ooEWHo`47dOokFOgo003RooaIo_l00>;oneT2ool0h?l0[?eIo_l0P>3ooEWn
o`00hOolFOko003IooaV0?onF@2/mol0FOaVnOomFOcoo6KmFOKo0EUIo6KjooeI
Z?okFOgo003RooaIo_l00>;oneT2ool0h?l0[?eIo_l0P>3ooEWno`00hOolFOko
003IooaV0?onF@2/mol0FOaVnOomFOcoo6KmFOKo0EUIo6KjooeIZ?okFOgo003R
ooaIo_l00>;oneT2ool0h?l0[?eIo_l0P>3ooEWno`00hOolFOko003IooaV0?on
F@2/mol0FOaVnOomFOcoo6KmFOKo0EUIo6KjooeIf?l0n=7oneWno`00hOolFOko
003Roo]I0_oo0>;oneWmo`20hookFOgo003Soo]Io_l0P=Woo6H1ooob0?eVn?om
FOcooFH0ooeIm_l1FEWmI_WooEVXoo]Io_l00>7oo5Wno`00h_okF@;oo`3Roo]I
oOl0P>?oneWmo`00hookFOko083IooaV0OoolP3mI_SooEWlooeV0?omFOKo0EUI
oFKiooeIZ?okFOko003QooaIo_l00>;oneT2ool0h_okFOgo083Soo]IoOl00>?o
neWno`20fOolIP7ooo80oFKhooeIo?omIP3ooEWfo`5IFOeVnOomFMSo0@7AooaI
o_l00>3ooEWno`00hOolF@;oo`3Qoo]Io_l00>;oneWno`00h_okFOko083IooaV
0OoooUT0[?Ooo6KhooeIoOolIP3ooEWfo`1Io6KiooeIZ?olFOko003PooeIo_l0
0>7oo5T2ool0hOokFOko003Roo]Io_l00>;oneWno`20fOolIP7oooiI0:cgooaV
n?omFOgoo6H0ooeIm_l0FOaVnOomFJSoo5Wno`00h?omFOko003QooaI0_oo0>7o
neWno`00h_okFOko003Roo]Io_l0P=Woo6H1ooonF@2/moolI_SooEWmooaV0?om
FOKo05WlI_WooEWHo`4=dOolFOko003PooeI0_oo0>3oo5T2ool0hOomFOco003R
ooaIoOl00>;ooEWlo`20f_olI_kooUT0[?OooFH0/oSooEWnooaV0K?ooEWfo`1I
oFH0/oWooEVXooaIo_l00>3ooET2ool0h?olF@;oo`3QooeIo?l00>;oo5Wmo`00
h_omFOco083JooaVo_onF@2/moomIP2cn?omFOkoo6H1/oomFOKo05WmIP2cnOom
FJSoo5Wno`00h?omF@;oo`3PooaI0_oo0>7ooEWlo`00h_olFOgo003RooeIo?l0
P=[oo6KnooiI0:cgooeV0;?hooeIo_olIP6cooeIm_l0FOeV0;?iooeIf?l12]7o
o5T2oon0goomF@;oo`3PooaI0On0h?omFOgo003QooaIo_l00>7ooEWlo`20f_om
IP2co_onF@2/n?olIP2cn?omFOkoo6H1/oomFOKoo6H0/oWooEVXooaI0_ooP=oo
oET2ool0h?olF@7oP>3ooEWmo`00hOolFOko003QooeIo?l0P=[ooFH0/okooUT0
[?Soo6H0/oSooEWnooaV0K?ooEWfooaV0;?iooeIZ?olF@;ooh3OooeI0_oo0>3o
o5T1oh3PooeIoOl00>7oo5Wno`00hOomFOco083JooeV0;?nooiI0:chooaV0;?h
ooeIo_olIP6cooeIm_olIP2cnOomFMSo0A?AooaI0_ooP=oooET1o`3OooaI0On0
h?omFOko003PooaI0_oo0>3ooEWmo`00f_olIP3Io_onF@2/nOl0/oaVmoomF@7o
ooaV0[?oooeI0:cho`2co6KhooeIZ?olF@;ooh3OooeI0Ol0goolF@7oP>3ooEWn
o`00h?olF@;oo`3PooeIoOl00=[oo6H0fOkooUT0[?Wo0;?lI_OooET1ooolIP:c
ooomF@2/n?l0/oaVn?omFJSoo5T2oon0goomF@7o0=ooo5T1oh3PooeIo_l00>3o
o5T2ool0h?omFOgo003JooaV0=WnooiI0:cio`2co6KgooeI0Oooo6H2/ooooET0
[?So0;?lI_SooEWHo`3bdOolF@;ooh3OooeI003NooaI003OooeI0_oo0=ooo5T1
o`3OooeIo_l00=[onfKmooiI0:cjoo]V05WgooeI0Onco6Kno`1IlP3nI_OooEVX
ooaI0_ooP=oooET00=koo5T00=oooET2ool0goolF@7o0=oooEWno`00f_okI_go
oUT0[?[onfH0FOOooET1ok?lI_ko05Wb0?iVmoomFJSoo5T2oon0goomF@00g_ol
F@00goomF@;oo`3OooaI0Ol0goomFOko003Joo]VoOonF@2/n_okIP1ImoomF@7o
/oaVo_l0FO80oVKgooeIf?l0mM7oo5T1o`3NooeI003NooaI003OooeI0_oo0=oo
o5T1o`3OooeIo_l00=[oo6KlooiI0:cjoo]V05WgooeI0OncoFKmooaInOl0/oaV
moomFJSoo5T1o`3NooeI003NooaI003OooeI0_oo0=ooo5T1o`3OooeIo_l00=[o
o6KlooiI0:cjoo]V05WgooeI0OncoFKmooaInOl0/oaVmoomFJSoo5T1o`3NooeI
003NooaI003OooeI0_oo0=ooo5T1o`3OooeIo_l00=[oo6KlooiI0:cjoo]V05Wg
ooeI0OncoFKmooaInOl0/oaVmoomFMSo0>WAooaI0Ol0g_omFMgoo5WNooeI0Ol0
g_olF@20g_omF@;oo`3Joo]Vo?onF@2/nol0/oaV0EUImoomF@3oo6KlooeInOol
IP1ImoomFJSoo5T1o`3NooeIgOolFMkooET1o`3NooaI083NooeI0_oo0=[onfKl
ooiI0:cko`2co6H1FEWgooeI0?olI_cooEWiooaV05WgooeIZ?olF@7o0=kooEWM
ooaIg_omF@7o0=koo5T0P=kooET2ool0f_okI_cooUT0[?_o0;?lIP5IFOOooET0
ooaVo?omFOWoo6H0FOOooEWHo`3YdOolF@00gOomFMgoo5WNooeI0Ol0g_olF@20
g_omF@7o0=[o0;?lI__ooUT0[?_o0;?mI_iImoomF@3ooFKkooeInOomIP5IFOOo
oEVXooaI003MooeIgOolFMkooET1o`3NooaI083NooeI0Ol0f_l0/oaVnoonF@2/
nol0/oeVoUWgooeI0?omI__ooEWiooeV0EUImoomFJSoo5T00=gooEWMooaIg_om
F@7o0=koo5T0P=kooET1o`3Jo`2co6KkooiI0:cko`2coFKnFOOooET0ooeVnoom
FOWooFH1FEWgooeIf?l0e=7oo5WLooeIgOolFMkooET00=goo5T0P=kooET1o`3J
o`2co6KkooiI0:ckooaVoUWgooeIo6KkooeIn_olIP5IFOOooEVXooaIg?omFMgo
o5WNooeI003MooaI083NooeI0Ol0f_l0/oaVnoonF@2/noolI_iImoomFOaVnoom
FO[oo6H1FEWgooeIZ?olFMcooEWMooaIg_omF@00gOolF@20g_omF@7o0=[o0;?l
I__ooUT0[?_oo6KnFOOooEWlI__ooEWjooaV0EUImoomFMSo0;cAooaIg?omFMgo
o5WNooeIg?olFMgooET00=Woo6KjooiI0:ckooeVoEWgooeIoFKjooeIn_omI_iI
moomFJSoo5WLooeIgOolFMkooEWLooaIgOomF@00fOolI_[ooUT0[?_ooFKmFOOo
oEWmI_[ooEWjooeVoUWgooeIZ?olFMcooEWMooaIg_omFMcoo5WMooeI003IooaV
n_onF@2/noomI_eImoomFOeVn_omFO[ooFKnFOOooEWHo`3JdOol@=bCoD3MToa0
gY?m@=bCo43MToe001?IT`1FoVKiooiI0:clooeV0;?mFOOo0UUIH?eV0;?jooeI
noomIP1PoUWgooeIZ?ol@=bCoD3MToa0gY?m@=bCo43MToe001?IT`1FoVKiooiI
0:clooeV0;?mFOOo0UUIH?eV0;?jooeInoomIP1PoUWgooeIZ?ol@=bCoD3MToa0
gY?m@=bCo43MToe001?IT`1FoVKiooiI0:clooeV0;?mFOOo0UUIH?eV0;?jooeI
noomIP1PoUWgooeIf?l0RM7oPBJ89P96IVKhooiI0:cmooaV0?omFOOo0EUIo6Ki
ooeIo?olI_eImoomFJSoPBJ89P96IVKhooiI0:cmooaV0?omFOOo0EUIo6KiooeI
o?olI_eImoomFJSoPBJ89P96IVKhooiI0:cmooaV0?omFOOo0EUIo6KiooeIo?ol
I_eImoomFMSo08oAoh4VR2H2AVIVn?onF@2/o_olIP7oooeImol0FOaVn?omFOco
oFH0ooeImoomFJSoPBJ89P96IVKhooiI0:cnooaV0OoooEWgo`1Io6KhooeIo?om
IP3ooEWgooeIZ?n19XPV0TIVI_SooUT0[?koo6H1ooomFOOo05WlI_SooEWlooeV
0?omFOOooEWHo`2BdOn19XPV0DIVmoonF@2/o_olIP7oooeImol0FOeV0;?hooeI
oOolIP3ooEWgooeIZ?n19XPV0DIVmoonF@2/o_olIP7oooeImol0FOeV0;?hooeI
oOolIP3ooEWgooeIZ?n19XPV0DIVmoonF@2/o_olIP7oooeImol0FOeV0;?hooeI
oOolIP3ooEWgooeIf?l0S=7oPBJ89P56I_OooUT2[?ooo6KnooeImoolIP2cn?om
FOkoo6H1/oomFOOooEVXoh4VR2H1AVKgooiI0ZcoooaVo_omFOOoo6H0/oSooEWn
ooaV0K?ooEWgooeIZ?n19XPV0DIVmoonF@:/ooolI_kooEWgooaV0;?hooeIo_ol
IP6cooeImoomFMSo0?_AooaIm?l00>[ooEWdo`00joolFOCo003/ooeIlol00>_o
o5Wco`00k?omFO7o003MooiI0ZcoooeV0;?noo80oFKgooeIo_olIP6cooeImoom
FJSoo5Wdo`00j_omFOCo003[ooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl0
0=gooUT2[?oooFH0/okolP3mI_OooEWnooaV0K?ooEWgooeIZ?olFOCo003ZooeI
m?l00>_oo5Wdo`00k?omFO?o003[ooaIlol00>cooEWao`00gOonF@:/ooomIP2c
o_ob0?eVmoomFOkoo6H1/oomFOOooEWHo`41dOolFOCo003ZooeIm?l00>_oo5Wd
o`00k?omFO?o003[ooaIlol00>cooEWao`00gOonF@6/ooaV0;?nooeIn?okI_Oo
oET1oookIP7oooeImoomFJSoo5Wdo`00j_omFOCo003[ooaIm?l00>cooEWco`00
joolFO?o003/ooeIlOl00=gooUT1[?olIP2co_omFOSonfKgooeI0OoonfH1ooom
FOOooEVXooaIm?l00>[ooEWdo`00joolFOCo003/ooeIlol00>_oo5Wco`00k?om
FO7o003MooiI0Jcoo6H0/okooEWhoo]VmoomF@7ooo]V0OoooEWgooeIf?l0o]7o
o5Wdo`00j_omFOCo003[ooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl00=go
oUT1[;?lI_gooEWio`2co6KfooeI0Onco6KnooeImoomFJSoo5Wdo`00j_omFOCo
003[ooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl00=gooUT1[;?lI_gooEWi
o`2co6KfooeI0Onco6KnooeImoomFJSoo5Wdo`00j_omFOCo003[ooaIm?l00>co
oEWco`00joolFO?o003/ooeIlOl00=gooUT1[;?lI_gooEWio`2co6KfooeI0Onc
o6KnooeImoomFMSo0?SAooaIm?l00>[ooEWdo`00joolFOCo003/ooeIlol00>_o
o5Wco`00k?omFO7o003MooiI0:clI_cooEWiooaV05WfooeI0?olI_gooEWgooeI
Z?olFOCo003ZooeIm?l00>_oo5Wdo`00k?omFO?o003[ooaIlol00>cooEWao`00
gOonF@2/o6KlooeInOolIP1Im_omF@3oo6KmooeImoomFJSoo5Wdo`00j_omFOCo
003[ooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl00=gooUT0[?aVo?omFOWo
o6H0FOKooET0ooaVoOomFOOooEWHo`3hdOolFOCo003ZooeIm?l00>_oo5Wdo`00
k?omFO?o003[ooaIlol00>cooEWao`00gOonF@1Po6KlooeIn_l0/oaV05WfooeI
0;?lI_golP3nFJSoo5Wdo`00j_omFOCo003[ooaIm?l00>cooEWco`00joolFO?o
003/ooeIlOl00=gooUT0H?aVo?omFO[o0;?lIP1Im_omF@2co6Kmoo80oUVXooaI
m?l00>[ooEWdo`00joolFOCo003/ooeIlol00>_oo5Wco`00k?omFO7o003MooiI
063lI_cooEWjo`2co6H0FOKooET0/oaVoOob0?iIf?l0mM7oo5Wdo`00j_omFOCo
003[ooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl00=gooUWlI__ooEWjooaV
0EUIm_omF@2coFKlooeImoomFJSoo5Wdo`00j_omFOCo003[ooaIm?l00>cooEWc
o`00joolFO?o003/ooeIlOl00=gooUWlI__ooEWjooaV0EUIm_omF@2coFKlooeI
moomFJSoo5Wdo`00j_omFOCo003[ooaIm?l00>cooEWco`00joolFO?o003/ooeI
lOl00=gooUWlI__ooEWjooaV0EUIm_omF@2coFKlooeImoomFMSo0?GAooaIm?l0
0>[ooEWdo`00joolFOCo003/ooeIlol00>_oo5Wco`00k?omFO7o003MooiIo6Kk
ooeIn_olIP5IFOKooEWlI_cooEWiooiVoUVXooaIm?l00>[ooEWdo`00joolFOCo
003/ooeIlol00>_oo5Wco`00k?omFO7o003MooiIo6KkooeIn_olIP5IFOKooEWl
I_cooEWiooiVoUVXooaIm?l00>[ooEWdo`00joolFOCo003/ooeIlol00>_oo5Wc
o`00k?omFO7o003MooiIo6KkooeIn_olIP5IFOKooEWlI_cooEWiooiVoUWHo`3e
dOolFOCo003ZooeIm?l00>_oo5Wdo`00k?omFO?o003[ooaIlol00>cooEWao`00
gOl1FEWlI_[ooEWkooaVoUWfooiIo6KkooeIn_omI_iIZ?olFOCo003ZooeIm?l0
0>_oo5Wdo`00k?omFO?o003[ooaIlol00>cooEWao`00gOl1FEWlI_[ooEWkooaV
oUWfooiIo6KkooeIn_omI_iIZ?olFOCo003ZooeIm?l00>_oo5Wdo`00k?omFO?o
003[ooaIlol00>cooEWao`00gOl1FEWlI_[ooEWkooaVoUWfooiIo6KkooeIn_om
I_iIf?l0mM7oo5Wdo`00j_omFOCo003[ooaIm?l00>cooEWco`00joolFO?o003/
ooeIlOl00=go0EUIoFKiooeInoomI_eIm_onFOaVnoomFO[ooFKnFJSoo5Wdo`00
j_omFOCo003[ooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl00=go0EUIoFKi
ooeInoomI_eIm_onFOaVnoomFO[ooFKnFJSoo5Wdo`00j_omFOCo003[ooaIm?l0
0>cooEWco`00joolFO?o003/ooeIlOl00=go0EUIoFKiooeInoomI_eIm_onFOaV
noomFO[ooFKnFMSo0>cAooaImOoW008]FEWeo`20j@3mFOGoj001FEWdo`20j03n
FO?oj000FO7o003Mo`1Io6KiooeIo?olI_eIm_l1FEWlI_[ooEWkooaVoUVXooaI
mOoW008]FEWeo`20j@3mFOGoj001FEWdo`20j03nFO?oj000FO7o003Mo`1Io6Ki
ooeIo?olI_eIm_l1FEWlI_[ooEWkooaVoUVXooaImOoW008]FEWeo`20j@3mFOGo
j001FEWdo`20j03nFO?oj000FO7o003Mo`1Io6KiooeIo?olI_eIm_l1FEWlI_[o
oEWkooaVoUWHo`47dOolFOKo003XooeImOl0P>[oo5Wfo`60P>_ooEWdo`20j_ol
FOCo003[ooeIlOoLP04]<oiVn?omFOgo0;?mIP3ooEWfo`5IH?eVnOomFOco0;?m
I_eIZ?olFOKo003XooeImOl0P>[oo5Wfo`60P>_ooEWdo`20j_olFOCo003[ooeI
lOoLP04]<oiVn?omFOgo0;?mIP3ooEWfo`5IH?eVnOomFOco0;?mI_eIZ?olFOKo
003XooeImOl0P>[oo5Wfo`60P>_ooEWdo`20j_olFOCo003[ooeIlOoLP04]<oiV
n?omFOgo0;?mIP3ooEWfo`5IH?eVnOomFOco0;?mI_eIf?l0nm7oo5Wgo`00ioom
FOGo083ZooaImol00>WooEWeo`00jOolFOGo003ZooeIl_l00=cooFKgooeIoOom
IP7oooeIm_l0FOeVn?omFOgoo6H0ooeIZ?olFOOo003WooeImOl0P>[oo5Wgo`00
jOomFOGo003YooaImOl00>[ooEWbo`00g?omI_OooEWmooeV0OoooEWfo`1IoFKh
ooeIoOolIP3ooEVXooaImol00>OooEWeo`20j_olFOOo003YooeImOl00>Woo5We
o`00j_omFO;o003LooeVmoomFOgooFH1ooomFOKo05WmI_SooEWmooaV0?omFMSo
0?GAooaImol00>OooEWfo`00jOolFOOo003YooeImOl00>Woo5Wfo`00jOomFO?o
003LooaVmoomFOkoo6H1ooomFOKoo6KhooeIoOolIP3ooEVXooaImol00>OooEWf
o`00jOolFOOo003YooeImOl00>Woo5Wfo`00jOomFO?o003LooaVmoomFOkoo6H1
ooomFOKoo6KhooeIoOolIP3ooEVXooaImol00>OooEWfo`00jOolFOOo003YooeI
mOl00>Woo5Wfo`00jOomFO?o003LooaVmoomFOkoo6H1ooomFOKoo6KhooeIoOol
IP3ooEWHo`47dOolFOSo083VooeImol00>Soo5Who`00j?omFOKo003XooaIm_l0
0>WooEWco`00g?omIP2cmoomFOkooFH2/ooooEWfooeV0;?hooeIo_olIP6cooeI
Z?olFOSo083VooeImol00>Soo5Who`00j?omFOKo003XooaIm_l00>WooEWco`00
g?omIP2cmoomFOkooFH2/ooooEWfooeV0;?hooeIo_olIP6cooeIZ?olFOSo083V
ooeImol00>Soo5Who`00j?omFOKo003XooaIm_l00>WooEWco`00g?omIP2cmoom
FOkooFH2/ooooEWfooeV0;?hooeIo_olIP6cooeIf?l11=7oo5Who`20i_omFOOo
003XooaIn?l00>SooEWfo`00j?olFOOo003XooeIm?l00=coo6H0/oOooET1oool
IP:cooob0?eV0;?hooeIo_olIP7oooeIZ?olFOSo083VooeImol00>Soo5Who`00
j?omFOKo003XooaImol00>SooEWdo`00g?olIP2cmoomF@7oooaV0[?ooo80oFH0
/oSooEWnooaV0OoooEVXooaIn?l0P>KooEWgo`00j?olFOSo003XooeIm_l00>So
o5Wgo`00j?omFOCo003LooaV0;?gooeI0Oooo6H2/ooolP3mIP2cn?omFOkoo6H1
ooomFMSo0?kAooaIn?l0P>KooEWho`00ioolFOWo083WooeImol00>Ooo5Wgo`00
j?omFOCo003Moo]V0:cgooeI0?okI_kooEWgooaVmoomF@7ooo]V0OoooEVXooaI
n?l0P>KooEWho`00ioolFOWo083WooeImol00>Ooo5Wgo`00j?omFOCo003Moo]V
0:cgooeI0?okI_kooEWgooaVmoomF@7ooo]V0OoooEVXooaIn?l0P>KooEWho`00
ioolFOWo083WooeImol00>Ooo5Wgo`00j?omFOCo003Moo]V0:cgooeI0?okI_ko
oEWgooaVmoomF@7ooo]V0OoooEWHo`3kdOolFOWo003UooeIn?l00>Ooo5Wio`20
ioomFOSo003VooaIn?l00>OooEWeo`20g?okIP2/moomF@3onfKnooeIn?okI_Oo
oET1ooolI_kooEVXooaInOl00>GooEWho`00ioolFOWo083WooeIn?l00>Koo5Wh
o`00ioomFOGo083Loo]V0:cgooeI0?okI_kooEWhoo]VmoomF@7oooaVo_omFJSo
o5Wio`00iOomFOSo003WooaInOl0P>OooEWho`00i_olFOSo003WooeImOl0P=co
nfH0[?OooET0oo]Vo_omFOSonfKgooeI0Oooo6KnooeIf?l1;]7oo5Wjo`60P>Go
oEWjo`60P>Koo5Wjo`60`>OooEWio`60P>Koo5Wio`70P>OooEWeo`20gOl0/oeV
0V1I[?OooET0/oeV0;?mooeInOl0/oaV05WgooeI0OncoFH0/okooEVXooaIn_l1
P83UooeIn_l1P83VooaIn_l1P<3WooeInOl1P83VooaInOl1`83WooeImOl0P=go
0;?mIP9PFJcgooeI0;?mIP2coOomFOWo0;?lIP1ImoomF@7o/oeV0;?nooeIZ?ol
FO[o0H20iOomFO[o0H20i_olFO[o0H30ioomFOWo0H20i_olFOWo0L20ioomFOGo
083Mo`2coFH2H5V/moomF@2coFH0/ogooEWio`2co6H0FOOooET1ok?mIP2co_om
FMSo0@7AooaIn_l00>CooEWjo`00iOolFO[o003VooeInOl00>Goo5Wio`20i_om
FOKo003LooaV0UUI[?OooEWlI_cooEWiooaV0EUImoomF@3oo6KmooeIZ?olFO[o
003TooeIn_l00>Goo5Wjo`00i_omFOWo003UooaInOl0P>KooEWfo`00g?olIP9I
FJcgooeIo6KlooeInOolIP5IFOOooET0ooaVoOomFJSoo5Wjo`00i?omFO[o003U
ooaIn_l00>KooEWio`00iOolFOWo083VooeIm_l00=coo6H2FEV/moomFOaVo?om
FOWoo6H1FEWgooeI0?olI_gooEWHo`3ndOolFO_o003SooeInol00>Coo5Wko`00
iOomFO[o003TooaInOl0P>KooEWfo`00g?omI_iI0:cgooeIoFKkooeInOomI_iI
moomF@3ooFKlooeIZ?olFO_o003SooeInol00>Coo5Wko`00iOomFO[o003TooaI
nOl0P>KooEWfo`00g?omI_iI0:cgooeIoFKkooeInOomI_iImoomF@3ooFKlooeI
Z?olFO_o003SooeInol00>Coo5Wko`00iOomFO[o003TooaInOl0P>KooEWfo`00
g?omI_iI0:cgooeIoFKkooeInOomI_iImoomF@3ooFKlooeIf?l0n=7oo5Wko`00
hoomFO_o003TooaIo?l00>CooEWko`20hoolFO[o003UooeImol00=coo6KnF@2/
moonFOaVnoomFO[oo6KnFOOooEWlI_cooEVXooaInol00>?ooEWko`00i?olFOco
003TooeInol0P>?oo5Wjo`00iOomFOOo003LooaVoUT0[?OooUWlI__ooEWjooaV
oUWgooeIo6KlooeIZ?olFO_o003SooeInol00>Coo5Wlo`00i?omFO_o083SooaI
n_l00>GooEWgo`00g?olI_iI0:cgooiIo6KkooeIn_olI_iImoomFOaVo?omFMSo
0?kAooaIo?l00>;ooEWlo`20hoolFOco003TooeInol0P>?oo5Wjo`00iOomFOOo
003LooeV0?onF@2/moonFOeVn_omFO[ooFKmFOOooUWlI__ooEVXooaIo?l00>;o
oEWlo`20hoolFOco003TooeInol0P>?oo5Wjo`00iOomFOOo003LooeV0?onF@2/
moonFOeVn_omFO[ooFKmFOOooUWlI__ooEVXooaIo?l00>;ooEWlo`20hoolFOco
003TooeInol0P>?oo5Wjo`00iOomFOOo003LooeV0?onF@2/moonFOeVn_omFO[o
oFKmFOOooUWlI__ooEWHo`41dOolFOco003RooeIo?l0P>?oo5Wmo`00hoomFO_o
083SooaInol00>CooEWho`00g?olIP3ooUT0[?Oo0EUIo6KjooeInoolI_eImoon
FOaVnoomFJSoo5Wlo`00h_omFOco083SooaIoOl00>?ooEWko`20hoolFO_o003T
ooeIn?l00=coo6H0ooiI0:cgo`5IFOaVn_omFO_oo6KmFOOooUWlI__ooEVXooaI
o?l00>;ooEWlo`20hoolFOgo003SooeInol0P>?oo5Wko`00i?omFOSo003LooaV
0?onF@2/mol1FEWlI_[ooEWkooaVoEWgooiIo6KkooeIf?l13M7oo5Wmo`00hOom
FOco083SooaIoOl00>?ooEWko`20hoolFO_o003TooeIn?l00=goo6H1ooonF@2/
mol1FEWmI_WooEWkooeV0?omFOOo0EUIo6KjooeIZ?olFOgo003QooeIo?l0P>?o
o5Wmo`00hoomFO_o083SooaInol00>CooEWho`00gOolIP7oooiI0:cgo`5IFOeV
nOomFO_ooFH0ooeImol1FEWlI_[ooEVXooaIoOl00>7ooEWlo`20hoolFOgo003S
ooeInol0P>?oo5Wko`00i?omFOSo003MooaV0OoooUT0[?Oo0EUIoFKiooeInoom
IP3ooEWgo`5IFOaVn_omFMSo0BGAooaIo_l1P83QooeIoOl00>;oo5T3oon0P>;o
oEWmo`60P>;oo5Wlo`00hoomFOWo003Mo`2coFH2/ooooRd0EoN002gmIP2cnOom
FOcooFH1/oomFOOo0EUPoFKiooeIZ?olFOko0H20hOomFOgo003RooaI0oooP83R
ooeIoOl1P83RooaIo?l00>?ooEWio`00gOl0/oeV0[?oooh]05OgP00]oFH0/oWo
oEWlooeV0K?ooEWgo`5IH?eVnOomFJSoo5Wno`60P>7ooEWmo`00h_olF@?ooh20
h_omFOgo0H20h_olFOco003SooeInOl00=go0;?mIP:cooon;@1Gmh00;OeV0;?i
ooeIo?omIP6cooeImol1FF3mI_WooEWHo`4=dOolFOko003PooeIo_l00>7oo5T2
ool0hOomFOgo003QooaIoOl00>;ooEWjo`00g?omIP2co_onF@2/moolI_SooEWm
ooaV0OoooEWgo`1IoFH0/oWooEVXooaIo_l00>3ooEWno`00hOolF@;oo`3QooeI
oOl00>7oo5Wmo`00h_omFO[o003LooeV0;?nooiI0:cgooaVn?omFOgoo6H1ooom
FOOo05WmIP2cnOomFJSoo5Wno`00h?omFOko003QooaI0_oo0>7ooEWmo`00hOol
FOgo003RooeIn_l00=cooFH0/okooUT0[?Ooo6KhooeIoOolIP7oooeImol0FOeV
0;?iooeIf?l13M7oo5T2oon0goomFOko003QooaI0On0h?omFOko003PooaIo_l0
0>7ooEWko`00g?olIP2co_onF@2/n?olIP2cn?omFOkoo6H2/ooooEWgooaV0;?i
ooeIZ?olF@;ooh3OooeIo_l00>7oo5T1oh3PooeIo_l00>3oo5Wno`00hOomFO_o
003LooaV0;?nooiI0:chooaV0;?hooeIo_olIP:cooomFOOoo6H0/oWooEVXooaI
0_ooP=oooEWno`00hOolF@7oP>3ooEWno`00h?olFOko003QooeInol00=coo6H0
/okooUT0[?Soo6H0/oSooEWnooaV0[?oooeImoolIP2cnOomFMSo0?_AooaI0_oo
P=oooET2ool0h?olF@7oP>3ooET2ool0goolFOko003QooeInol00=coo6KmooiI
0:chooaVmoomFOkoo6H2/ooooEWgooaVn?omFJSoo5T2oon0goomF@;oo`3PooaI
0On0h?omF@;oo`3OooaIo_l00>7ooEWko`00g?olI_gooUT0[?Soo6KgooeIo_ol
IP:cooomFOOoo6KhooeIZ?olF@;ooh3OooeI0_oo0>3oo5T1oh3PooeI0_oo0=oo
o5Wno`00hOomFO_o003LooaVoOonF@2/n?olI_OooEWnooaV0[?oooeImoolI_So
oEWHo`3hdOolF@;ooh3OooeI0_oo0>3oo5T1oh3PooeI0_oo0=ooo5T2ool0h?om
FOco083Loo]VoOonF@2/nOokI_OooET1oookI_kooEWhoo]Vn?omFJSoo5T2oon0
goomF@;oo`3PooaI0On0h?omF@;oo`3OooaI0_oo0>3ooEWlo`20g?okI_gooUT0
[?WonfKgooeI0OoonfKnooeIn?okI_SooEVXooaI0_ooP=oooET2ool0h?olF@7o
P>3ooET2ool0goolF@;oo`3PooeIo?l0P=confKmooiI0:cioo]VmoomF@7ooo]V
o_omFOSonfKhooeIf?l0mM7oo5T2oon0goomF@7o0=ooo5T00=oooET1o`3NooaI
0_oo0>3ooEWlo`20g?olI_cooUT0[?Woo6H0FOOooET1ooolI_gooEWhooaVmoom
FJSoo5T2oon0goomF@7o0=ooo5T00=oooET1o`3NooaI0_oo0>3ooEWlo`20g?ol
I_cooUT0[?Woo6H0FOOooET1ooolI_gooEWhooaVmoomFJSoo5T2oon0goomF@7o
0=ooo5T00=oooET1o`3NooaI0_oo0>3ooEWlo`20g?olI_cooUT0[?Woo6H0FOOo
oET1ooolI_gooEWhooaVmoomFMSo0>KAooaI0Ol0g_omF@00g_olF@00goomF@7o
0=koo5T1o`3OooeIo?l0P=gonfKlooiI0:cjoo]V05WgooeI0Onco6Kmoo80oVKg
ooeIZ?olF@7o0=kooET00=koo5T00=oooET1o`3NooaI0Ol0goomFOco083Moo]V
o?onF@2/n_okIP1ImoomF@7o/oaVoOob0?iVmoomFJSoo5T1o`3NooeI003NooaI
003OooeI0Ol0g_olF@7o0=oooEWlo`20gOokI_cooUT0[?[onfH0FOOooET1ok?l
I_golP3nI_OooEWHo`3edOolF@00gOomF@00g_omF@00g_omF@00gOolF@7o0=oo
oEWlo`20g_l0/oaVnoonF@2/n_olIP5IFOOooET1ok?mI_cooEWiooaV05WgooeI
Z?olF@00gOomF@00g_omF@00g_omF@00gOolF@7o0=oooEWlo`20g_l0/oaVnoon
F@2/n_olIP5IFOOooET1ok?mI_cooEWiooaV05WgooeIZ?olF@00gOomF@00g_om
F@00g_omF@00gOolF@7o0=oooEWlo`20g_l0/oaVnoonF@2/n_olIP5IFOOooET1
ok?mI_cooEWiooaV05WgooeIf?l14m7ooET1;H3MooiI003MooiI0@1Ig_onF@00
g?olF@20g_omFOgo003Mo`2=oFH0/o_ooUT0[?_o0;?mIP9PFEWgooeI0?omIP2c
o?omFO[o0;?mIP5PFOOooEVXooeI0Bf0gOonF@00gOonF@40FMkooUT00=coo5T0
P=kooEWmo`00gOl0SOeV0;?kooiI0:cko`2coFH2H5UImoomF@3ooFH0/ocooEWj
o`2coFH1H5WgooeIZ?omF@4]P=gooUT00=gooUT105WNooiI003LooaI083NooeI
oOl00=go08gmIP2cnoonF@2/nol0/oeV0V1IFOOooET0ooeV0;?looeIn_l0/oeV
0F1ImoomFMSo0>cAooeI003Lo`=IF@1IgOl4FET0FEWNo`=IFBeIg?olF@20g_om
FOko003LooeVnOonF@2/noolI_iImoomFOaVnoomFO[ooFKnFOOooEVXooeI003L
o`=IF@1IgOl4FET0FEWNo`=IFBeIg?olF@20g_omFOko003LooeVnOonF@2/nool
I_iImoomFOaVnoomFO[ooFKnFOOooEVXooeI003Lo`=IF@1IgOl4FET0FEWNo`=I
FBeIg?olF@20g_omFOko003LooeVnOonF@2/noolI_iImoomFOaVnoomFO[ooFKn
FOOooEWHo`20dOn19XPV04KnI_WooUT0[?coo6KmFOOooEWmI_[ooEWkooaVoUWg
ooeIZ?n19XPV04KnI_WooUT0[?coo6KmFOOooEWmI_[ooEWkooaVoUWgooeIZ?n1
9XPV04KnI_WooUT0[?coo6KmFOOooEWmI_[ooEWkooaVoUWgooeIf?l0P=7oPBJ8
9P96IVKhooiI0:clooaVoEWgooiIo6KjooeInoomI_eImoomFJSoPBJ89P96IVKh
ooiI0:clooaVoEWgooiIo6KjooeInoomI_eImoomFJSoPBJ89P96IVKhooiI0:cl
ooaVoEWgooiIo6KjooeInoomI_eImoomFMSo08WAoh4VR2H2AVIVn?onF@2/oOol
IP3ooEWgo`5IFOaVnOomFOcoo6KmFOOooEVXoh4VR2H2AVIVn?onF@2/oOolIP3o
oEWgo`5IFOaVnOomFOcoo6KmFOOooEVXoh4VR2H2AVIVn?onF@2/oOolIP3ooEWg
o`5IFOaVnOomFOcoo6KmFOOooEWHo`2?dOn19XPV0DIVmoonF@2/oOomIP7oooeI
mol1FEWlI_WooEWlooeV0?omFOOooEVXoh4VR2H1AVKgooiI0:cmooeV0OoooEWg
o`5IFOaVnOomFOcooFH0ooeImoomFJSoPBJ89P56I_OooUT0[?gooFH1ooomFOOo
0EUIo6KiooeIo?omIP3ooEWgooeIf?l0S=7oPBJ89P56I_OooUT0[?koo6H1ooom
FOOo05WlI_SooEWmooaV0?omFOOooEVXoh4VR2H1AVKgooiI0:cnooaV0OoooEWg
o`1Io6KhooeIoOolIP3ooEWgooeIZ?n19XPV0DIVmoonF@2/o_olIP7oooeImol0
FOaVn?omFOgoo6H0ooeImoomFMSo0A3AooaIm?l00>[ooEWeo`20j_olFOCo003/
ooeIlol00>_oo5Wco`00k?omF@20l_l00=gooUT3[?oo/oeVo_om;ON002gmIP2c
n?omFOkoo6H1/oomFOOooEVXooaIm?l00>[ooEWeo`20j_olFOCo003/ooeIlol0
0>_oo5Wco`00k?omF@20l_l00=gooUT3[?oo/oeVo_om;ON002gmIP2cn?omFOko
o6H1/oomFOOooEVXooaIm?l00>[ooEWeo`20j_olFOCo003/ooeIlol00>_oo5Wc
o`00k?omF@20l_l00=gooUT3[?oo/oeVo_om;ON002gmIP2cn?omFOkoo6H1/oom
FOOooEWHo`44dOolFOCo003ZooeImOl0P>[oo5Wdo`00k?omFO?o003[ooaIlol0
0>cooEWao`00gOonF@:/ooomIP2co_omFOOoo6KgooeI0OoonfH1ooomFOOooEVX
ooaIm?l00>[ooEWeo`20j_olFOCo003/ooeIlol00>_oo5Wco`00k?omFO7o003M
ooiI0ZcoooeV0;?nooeImoolI_OooET1oookIP7oooeImoomFJSoo5Wdo`00j_om
FOGo083ZooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl00=gooUT2[?oooFH0
/okooEWgooaVmoomF@7ooo]V0OoooEWgooeIf?l0o]7oo5Wdo`00j_omFOGo083Z
ooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl00=gooUT1[?olIP2co_omFOSo
nfKgooeI0Oooo6KnooeImoomFJSoo5Wdo`00j_omFOGo083ZooaIm?l00>cooEWc
o`00joolFO?o003/ooeIlOl00=gooUT1[?olIP2co_omFOSonfKgooeI0Oooo6Kn
ooeImoomFJSoo5Wdo`00j_omFOGo083ZooaIm?l00>cooEWco`00joolFO?o003/
ooeIlOl00=gooUT1[?olIP2co_omFOSonfKgooeI0Oooo6KnooeImoomFMSo0?;A
ooaIm?l00>[ooEWeo`20j_olFOCo003/ooeIlol00>_oo5Wco`00k?omFO7o003M
ooiI0:ckI_gooEWhooaVm_omF@3onfKnooeImoomFJSoo5Wdo`00j_omFOGo083Z
ooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl00=gooUT0[?]VoOomFOSoo6Kf
ooeI0?okI_kooEWgooeIZ?olFOCo003ZooeImOl0P>[oo5Wdo`00k?omFO?o003[
ooaIlol00>cooEWao`00gOonF@2/nfKmooeIn?olI_KooET0oo]Vo_omFOOooEWH
o`3bdOolFOCo003ZooeImOl0P>[oo5Wdo`00k?omFO?o003[ooaIlol00>cooEWa
o`00gOonF@2/nfKmooeInOokI_KooET0ooaVoOomFOOooEVXooaIm?l00>[ooEWe
o`20j_olFOCo003/ooeIlol00>_oo5Wco`00k?omFO7o003MooiI0:ckI_gooEWi
oo]Vm_omF@3oo6KmooeImoomFJSoo5Wdo`00j_omFOGo083ZooaIm?l00>cooEWc
o`00joolFO?o003/ooeIlOl00=gooUT0[?]VoOomFOWonfKfooeI0?olI_gooEWg
ooeIf?l0n=7oo5Wdo`00j_omFOGo083ZooaIm?l00>cooEWco`00joolFO?o003/
ooeIlOl00=gooUT0H?aVo?omFOWoo6H0FOKooET0/oaVoOomFOOooEVXooaIm?l0
0>[ooEWeo`20j_olFOCo003/ooeIlol00>_oo5Wco`00k?omFO7o003MooiI063l
I_cooEWiooaV05WfooeI0;?lI_gooEWgooeIZ?olFOCo003ZooeImOl0P>[oo5Wd
o`00k?omFO?o003[ooaIlol00>cooEWao`00gOonF@1Po6KlooeInOolIP1Im_om
F@2co6KmooeImoomFMSo0?SAooaIm?l00>[ooEWeo`20j_olFOCo003/ooeIlol0
0>_oo5Wco`00k?omFO7o003MooiI063mI__ooEWjo`2co6H0FOKooET0/oeVo?ob
0?iIZ?olFOCo003ZooeImOl0P>[oo5Wdo`00k?omFO?o003[ooaIlol00>cooEWa
o`00gOonF@1PoFKkooeIn_l0/oaV05WfooeI0;?mI_colP3nFJSoo5Wdo`00j_om
FOGo083ZooaIm?l00>cooEWco`00joolFO?o003/ooeIlOl00=gooUT0H?eVnoom
FO[o0;?lIP1Im_omF@2coFKloo80oUWHo`3_dOolFOCo003ZooeImOl0P>[oo5Wd
o`00k?omFO?o003[ooaIlol00>cooEWao`00gOonFOaVnoomFO[oo6H1FEWfooeI
o6KlooeImoomFJSoo5Wdo`00j_omFOGo083ZooaIm?l00>cooEWco`00joolFO?o
003/ooeIlOl00=gooUWlI__ooEWjooaV0EUIm_omFOaVo?omFOOooEVXooaIm?l0
0>[ooEWeo`20j_olFOCo003/ooeIlol00>_oo5Wco`00k?omFO7o003MooiIo6Kk
ooeIn_olIP5IFOKooEWlI_cooEWgooeIf?l11=7oo5Wdo`00j_omFOGo083ZooaI
m?l00>cooEWco`00joolFO?o003/ooeIlOl00=go0UUIH?eVn_omFO_o0;?mIP9P
FEWfooiI063mI__ooEWgoof/Z?olFOCo003ZooeImOl0P>[oo5Wdo`00k?omFO?o
003[ooaIlol00>cooEWao`00gOl2FEUPoFKjooeInol0/oeV0V1IFOKooUT0H?eV
noomFOOooJbXooaIm?l00>[ooEWeo`20j_olFOCo003/ooeIlol00>_oo5Wco`00
k?omFO7o003Mo`9IFF3mI_[ooEWko`2coFH2H5UIm_onF@1PoFKkooeImoom[=So
0=OAooaImOoW008]FEWeonP0oEWeonP00EUIm?l0P>T0oEWconP005Wao`00gOl1
FEWmI_WooEWkooeVoEWfo`5IFOaVn_omFI[oo5WeonL00ReIFOGoj03mFOGoj001
FEWdo`20j@3mFO?oj000FO7o003Mo`5IFOeVnOomFO_ooFKmFOKo0EUIo6KjooeI
V_olFOGoi`02;EUImOoX0?eImOoX005IFOCo083Y0?eIlooX001IlOl00=go0EUI
oFKiooeInoomI_eIm_l1FEWlI_[ooEW:o`3GdOolFOGo003YooeImOl0P>[oo5We
o`00joomFOCo083ZooaIlol00>cooEW<o`1Io6KiooeIo?olI_eIm_l1FEWlI_[o
oEVJooaImOl00>WooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFLco
05WlI_WooEWlooaVoEWfo`5IFOaVn_omFI[oo5Weo`00jOomFOGo083ZooaImOl0
0>_ooEWdo`20j_olFO?o003/ooeIc?l0FOaVnOomFOcoo6KmFOKo0EUIo6KjooeI
b_l0f]7oo5Wfo`00j?omFOKo003YooaIm_l00>[ooEWdo`20j_olFOCo003[ooeI
lOoJ0?iVn?omFOcooFH0ooeIm_l0FOaVnOomFI[oo5Wfo`00j?omFOKo003YooaI
m_l00>[ooEWdo`20j_olFOCo003[ooeIlOoJ0?iVn?omFOcooFH0ooeIm_l0FOaV
nOomFI[oo5Wfo`00j?omFOKo003YooaIm_l00>[ooEWdo`20j_olFOCo003[ooeI
lOoJ0?iVn?omFOcooFH0ooeIm_l0FOaVnOomFL[o0>3AooaIm_l00>SooEWfo`00
jOolFOOo003YooeImOl00>Woo5Wdo`00joomFO;o003LooaVn?omFOgoo6H0ooeI
m_l0FOeVn?omFI[oo5Wfo`00j?omFOKo003YooaImol00>WooEWeo`00jOolFOCo
003[ooeIl_l00=coo6KhooeIoOolIP3ooEWfo`1IoFKhooeIV_olFOKo003XooeI
m_l00>Woo5Wgo`00jOomFOGo003YooaIm?l00>_ooEWbo`00g?olI_SooEWmooaV
0?omFOKo05WmI_SooEW:o`3MdOolFOOo003WooeImol00>Soo5Wgo`00jOomFOGo
003YooaImOl00>[ooEWco`00g?olI_OooEWmooeV0OoooEWfooaVn?omFI[oo5Wg
o`00ioomFOOo003XooaImol00>WooEWeo`00jOolFOGo003ZooeIlol00=coo6Kg
ooeIoOomIP7oooeIm_olI_SooEVJooaImol00>OooEWgo`00j?olFOOo003YooeI
mOl00>Woo5Weo`00j_omFO?o003LooaVmoomFOgooFH1ooomFOKoo6KhooeIb_l0
hm7oo5Wgo`00ioomFOOo003XooaIn?l00>SooEWfo`00j?olFOKo003YooeIlol0
0=coo6KgooeIo_olIP7oooeIm_omIP2cn?omFI[oo5Wgo`00ioomFOOo003XooaI
n?l00>SooEWfo`00j?olFOKo003YooeIlol00=coo6KgooeIo_olIP7oooeIm_om
IP2cn?omFI[oo5Wgo`00ioomFOOo003XooaIn?l00>SooEWfo`00j?olFOKo003Y
ooeIlol00=coo6KgooeIo_olIP7oooeIm_omIP2cn?omFL[o0@CAooaIn?l0P>Ko
oEWio`60P>Ooo5Wio`70P>SooEWgo`60P>Soo5Wgo`60P>WooEWdo`00g?olIP2`
moomF@;ook?mIP:cooom;ON003?mIP3In?omFI[oo5Who`20i_omFOWo0H20iool
FOWo0L20j?omFOOo0H20j?olFOOo0H20jOomFOCo003LooaV0;3gooeI0_oo/oeV
0[?oood]mh00<oeV0=WhooeIV_olFOSo083VooeInOl1P83WooaInOl1`83XooeI
mol1P83XooaImol1P83YooeIm?l00=coo6H0/?OooET2ooncoFH2/ooooBggP00c
oFH0fOSooEW:o`3PdOolFOSo083VooeInOl00>Koo5Wio`20ioomFOSo003VooaI
mol00>SooEWeo`20g?okIP2/moomF@3onfKnooeIn?okI_OooEVJooaIn?l0P>Ko
oEWio`00i_olFOWo083WooeIn?l00>Koo5Wgo`00j?omFOGo083Loo]V0:cgooeI
0?okI_kooEWhoo]VmoomFI[oo5Who`20i_omFOWo003VooaInOl0P>OooEWho`00
i_olFOOo003XooeImOl0P=confH0[?OooET0oo]Vo_omFOSonfKgooeIb_l0jM7o
o5Wio`00iOomFO[o003UooaInOl0P>OooEWho`00i_olFOSo003WooeImOl0P=co
o6H1FJcgooeI0?okI_kooEWhooaV05WgooeIV_olFOWo003UooeIn_l00>Goo5Wi
o`20ioomFOSo003VooaIn?l00>OooEWeo`20g?olIP5I[?OooET0oo]Vo_omFOSo
o6H0FOOooEVJooaInOl00>GooEWjo`00iOolFOWo083WooeIn?l00>Koo5Who`00
ioomFOGo083LooaV0EV/moomF@3onfKnooeIn?olIP1ImoomFL[o0?GAooaInOl0
0>GooEWjo`00iOolFO[o003VooeInOl00>Goo5Wio`20i_omFOGo083Mo`2co6H1
FJcgooeI0;?lI_gooEWio`2co6H0FOOooEVJooaInOl00>GooEWjo`00iOolFO[o
003VooeInOl00>Goo5Wio`20i_omFOGo083Mo`2co6H1FJcgooeI0;?lI_gooEWi
o`2co6H0FOOooEVJooaInOl00>GooEWjo`00iOolFO[o003VooeInOl00>Goo5Wi
o`20i_omFOGo083Mo`2co6H1FJcgooeI0;?lI_gooEWio`2co6H0FOOooEW:o`3e
dOolFO[o003TooeInol00>Coo5Wjo`00i_omFOWo003UooaInOl0P>KooEWfo`00
g?l0/oeV0UUI[?OooET0/oeVo?omFOWoo6H1FEWgooeIV_olFO[o003TooeInol0
0>Coo5Wjo`00i_omFOWo003UooaInOl0P>KooEWfo`00g?l0/oeV0UUI[?OooET0
/oeVo?omFOWoo6H1FEWgooeIV_olFO[o003TooeInol00>Coo5Wjo`00i_omFOWo
003UooaInOl0P>KooEWfo`00g?l0/oeV0UUI[?OooET0/oeVo?omFOWoo6H1FEWg
ooeIb_l0jM7oo5Wjo`00i?omFO_o003TooaInol00>GooEWjo`00i?olFOWo083V
ooeIm_l00=coo6H2FEV/moomFOaVo?omFOWoo6H1FEWgooeIV_olFO[o003TooeI
nol00>Coo5Wko`00iOomFO[o003TooaInOl0P>KooEWfo`00g?olIP9IFJcgooeI
o6KlooeInOolIP5IFOOooEVJooaIn_l00>CooEWko`00i?olFO_o003UooeIn_l0
0>Coo5Wio`20i_omFOKo003LooaV0UUI[?OooEWlI_cooEWiooaV0EUImoomFL[o
0>KAooaInol00>?ooEWlo`20hoolFOco003TooeInol0P>?oo5Wio`20i_omFOOo
003KooeVoUT0[?OooEWmI__ooEWjooaVoUWgooeIV_olFO_o003SooeIo?l0P>?o
o5Wlo`00i?omFO_o083SooaInOl0P>KooEWgo`00foomI_iI0:cgooeIoFKkooeI
n_olI_iImoomFI[oo5Wko`00hoomFOco083SooaIo?l00>CooEWko`20hoolFOWo
083VooeImol00=_ooFKnF@2/moomFOeVnoomFO[oo6KnFOOooEW:o`47dOolFOco
0H20hoomFOco083SooaIoOl1P83TooeInol0P>?oo5Wjo`00iOomFOSo0H20gOl0
/oeV0;?nF@2/moonFOeV0;?kooeInol0/oeVoEWgooeIV_olFOco0H20hoomFOco
083SooaIoOl1P83TooeInol0P>?oo5Wjo`00iOomFOSo0H20gOl0/oeV0;?nF@2/
moonFOeV0;?kooeInol0/oeVoEWgooeIV_olFOco0H20hoomFOco083SooaIoOl1
P83TooeInol0P>?oo5Wjo`00iOomFOSo0H20gOl0/oeV0;?nF@2/moonFOeV0;?k
ooeInol0/oeVoEWgooeIb_l0mM7oo5Wlo`00h_omFOco083SooaIoOl00>?ooEWk
o`20hoolFO_o003TooeIn?l00=coo6H0ooiI0:cgo`5IFOaVn_omFO_ooFH0ooeI
moomFI[oo5Wlo`00h_omFOco083SooaIoOl00>?ooEWko`20hoolFO_o003TooeI
n?l00=coo6H0ooiI0:cgo`5IFOaVn_omFO_ooFH0ooeImoomFI[oo5Wlo`00h_om
FOco083SooaIoOl00>?ooEWko`20hoolFO_o003TooeIn?l00=coo6H0ooiI0:cg
o`5IFOaVn_omFO_ooFH0ooeImoomFL[o0?SAooaIoOl00>7ooEWmo`00h_olFOko
003RooeIo?l00>;oo5Wlo`00hoomFOWo003LooaV0OoooUT0[?Oo0EUIoFKiooeI
o?olIP3ooEWgooeIV_olFOgo003QooeIoOl00>;oo5Wno`00h_omFOco003RooaI
o?l00>?ooEWio`00g?olIP7oooiI0:cgo`5IFOeVnOomFOcoo6H0ooeImoomFI[o
o5Wmo`00hOomFOgo003RooaIo_l00>;ooEWlo`00h_olFOco003SooeInOl00=co
o6H1ooonF@2/mol1FEWmI_WooEWlooaV0?omFOOooEW:o`3edOolFOko003PooeI
o_l00>7oo5T2ool0hOomFOgo003QooaIo?l00>?ooEWio`00g?omI_kooUT0[?Oo
05WlI_WooEWlooeV0OoooEWgooeIV_olFOko003PooeIo_l00>7oo5T2ool0hOom
FOgo003QooaIo?l00>?ooEWio`00g?omI_kooUT0[?Oo05WlI_WooEWlooeV0Ooo
oEWgooeIV_olFOko003PooeIo_l00>7oo5T2ool0hOomFOgo003QooaIo?l00>?o
oEWio`00g?omI_kooUT0[?Oo05WlI_WooEWlooeV0OoooEWgooeIb_l0hm7oo5Wn
o`00h?omFOko003QooaI0_oo0>7ooEWmo`00hOolFOgo003RooeIn_l00=coo6Kn
oo80oFKhooeIoOolIP7oooeImoomFI[oo5Wno`00h?omFOko003QooaI0_oo0>7o
oEWmo`00hOolFOgo003RooeIn_l00=coo6Knoo80oFKhooeIoOolIP7oooeImoom
FI[oo5Wno`00h?omFOko003QooaI0_oo0>7ooEWmo`00hOolFOgo003RooeIn_l0
0=coo6Knoo80oFKhooeIoOolIP7oooeImoomFL[o0?GAooaI0_ooP=oooET2ool0
h?olF@7oP>3ooEWno`00h?olFOgo003RooeInol00=_ooFH0/okooUT0[?Ooo6Kh
ooeIoOomIP:cooomFOOooEVJooaI0_ooP=oooET2ool0h?olF@7oP>3ooEWno`00
h?olFOgo003RooeInol00=_ooFH0/okooUT0[?Ooo6KhooeIoOomIP:cooomFOOo
oEVJooaI0_ooP=oooET2ool0h?olF@7oP>3ooEWno`00h?olFOgo003RooeInol0
0=_ooFH0/okooUT0[?Ooo6KhooeIoOomIP:cooomFOOooEW:o`3kdOolF@;ooh3O
ooeI0_oo0>3oo5T1oh3PooeI0_oo0=ooo5Wno`00hOomFO_o003LooaV0;?nooiI
0:chooaV0;?hooeIo_olIP:cooomFOOooEVJooaI0_ooP=oooET2ool0h?olF@7o
P>3ooET2ool0goolFOko003QooeInol00=coo6H0/okooUT0[?Soo6H0/oSooEWn
ooaV0[?oooeImoomFI[oo5T2oon0goomF@;oo`3PooaI0On0h?omF@;oo`3OooaI
o_l00>7ooEWko`00g?olIP2co_onF@2/n?olIP2cn?omFOkoo6H2/ooooEWgooeI
b_l0jM7oo5T2oon0goomF@7o0=ooo5T1oh3PooeI0_oo0=ooo5Wno`00hOomFOco
083KooaVoOonF@2/n?olI_OooET1oookI_kooEWgooeIV_olF@;ooh3OooeI0Ol0
goolF@7oP>3ooET2ool0goolFOko003QooeIo?l0P=_oo6KmooiI0:chooaVmoom
F@7ooo]Vo_omFOOooEVJooaI0_ooP=oooET1o`3OooaI0On0h?omF@;oo`3OooaI
o_l00>7ooEWlo`20foolI_gooUT0[?Soo6KgooeI0OoonfKnooeImoomFL[o0?GA
ooaI0_n0`=oooET1P83OooaI003OooeI0Ol0g_olF@;oP83PooeIo?l0P=coo6H0
/ogooUT0[?Woo6H0H?OooET1omWlIP2co_omFOOooEVJooaI0_n0`=oooET1P83O
ooaI003OooeI0Ol0g_olF@;oP83PooeIo?l0P=coo6H0/ogooUT0[?Woo6H0H?Oo
oET1omWlIP2co_omFOOooEVJooaI0_n0`=oooET1P83OooaI003OooeI0Ol0g_ol
F@;oP83PooeIo?l0P=coo6H0/ogooUT0[?Woo6H0H?OooET1omWlIP2co_omFOOo
oEW:o`3GdOolF@7o0=kooET00=kooET00=kooET00=goo5T1o`3OooeIo?l0P=go
nfKlooiI0:cjoo]V05WgooeI0OncoFKloo80oUVJooaI0Ol0g_omF@00g_omF@00
g_omF@00gOolF@7o0=oooEWlo`20gOokI_cooUT0[?[onfH0FOOooET1ok?mI_co
lP3nFI[oo5T1o`3NooeI003NooeI003NooeI003MooaI0Ol0goomFOco083Moo]V
o?onF@2/n_okIP1ImoomF@7o/oeVo?ob0?iIb_l0h=7oo5T00=gooUT00=gooUT1
05WNooiI003LooaI083NooeIoOl00=go0;?lI__ooUT0[?[oo6H1FEWgooeI0?ol
I_cooEWgooeIV_olF@00gOonF@00gOonF@40FMkooUT00=coo5T0P=kooEWmo`00
gOl0/oaVnoonF@2/n_olIP5IFOOooET0ooaVo?omFOOooEVJooaI003MooiI003M
ooiI0@1Ig_onF@00g?olF@20g_omFOgo003Mo`2co6KkooiI0:cjooaV0EUImoom
F@3oo6KlooeImoomFL[o0=gAooeI003Lo`=IF@1IgOonF@40FMkooUT00=coo5T0
P=kooEWmo`00gOl0/oaVnoonF@2/nol0/oaV0EUImoomF@3ooFKkooeIS?omF@00
g?l3FET0FMgooUT105WNooiI003LooaI083NooeIoOl00=go0;?lI__ooUT0[?_o
0;?lIP5IFOOooET0ooeVnoomFHcooET00=co0eUI05WMooiI0@1Ig_onF@00g?ol
F@20g_omFOgo003Mo`2co6KkooiI0:cko`2co6H1FEWgooeI0?omI__ooEVlo`3D
dOomF@00g?l3FET0FMgo15UI05UIg_l3FET]FMcoo5T0P=kooEWno`00g?olI_[o
oUT0[?_o0;?mI_iImoomFOaVnoomFHcooET00=co0eUI05WMo`AIF@1IFMko0eUI
;EWLooaI083NooeIo_l00=coo6KjooiI0:cko`2coFKnFOOooEWlI__ooEV<ooeI
003Lo`=IF@1IgOl4FET0FEWNo`=IFBeIg?olF@20g_omFOko003LooaVn_onF@2/
nol0/oeVoUWgooeIo6KkooeI_?l0dM7ooUT105WLo`=I;EUIgOl4FET0FEWNo`=I
FBeIg?omF@00gOomF@;oo`3KooeVnOonF@2/noolI_iImoomFOeVn_omFHcooUT1
05WLo`=I;EUIgOl4FET0FEWNo`=IFBeIg?omF@00gOomF@;oo`3KooeVnOonF@2/
noolI_iImoomFOeVn_omFHcooUT105WLo`=I;EUIgOl4FET0FEWNo`=IFBeIg?om
F@00gOomF@;oo`3KooeVnOonF@2/noolI_iImoomFOeVn_omFKco06;Aoh4VR2H0
A_iVnOonF@2/o?olI_eImoonFOaVn_omFHcoPBJ89P16oVKiooiI0:clooaVoEWg
ooiIo6KjooeIS?n19XPV04KnI_WooUT0[?coo6KmFOOooUWlI_[ooEVlo`1ddOn1
9XPV0TIVI_SooUT0[?go0;?mIP2coEWgo`9IFF3mI_WooEV<oh4VR2H2AVIVn?on
F@2/oOl0/oeV0;?mFOOo0UUIH?eVnOomFHcoPBJ89P96IVKhooiI0:cmo`2coFH0
/oeImol2FEUPoFKiooeI_?l0J=7oPBJ89P56I_OooUT0[?gooFH1ooomFOOo05Wl
I_SooEV<oh4VR2H1AVKgooiI0:cmooeV0OoooEWgo`1Io6KhooeIS?n19XPV0DIV
moonF@2/oOomIP7oooeImol0FOaVn?omFKco06SAoh4VR2H1AVKgooiI0:cnooaV
0OoooEWgo`1Io6KhooeIS?n19XPV0DIVmoonF@2/o_olIP7oooeImol0FOaVn?om
FHcoPBJ89P56I_OooUT0[?koo6H1ooomFOOo05WlI_SooEVlo`3DdOolFOCo003Z
ooeImOl0P>[oo5Weo`00joomFO?o003[ooaIlol00>cooEWao`00gOonF@2/o_om
I_kolP3mIP2cn?omFHcoo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWco`00jool
FO?o003/ooeIlOl00=gooUT0[?kooFKnoo80oFH0/oSooEV<ooaIm?l00>[ooEWe
o`20j_olFOGo003[ooeIlol00>_oo5Wco`00k?omFO7o003MooiI0:cnooeVo_ob
0?eV0;?hooeI_?l0e=7oo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWco`00jool
FO?o003/ooeIlOl00=gooUT2[?ooo6KnooeImoolI_OooEV<ooaIm?l00>[ooEWe
o`20j_olFOGo003[ooeIlol00>_oo5Wco`00k?omFO7o003MooiI0ZcoooaVo_om
FOOoo6KgooeIS?olFOCo003ZooeImOl0P>[oo5Weo`00joomFO?o003[ooaIlol0
0>cooEWao`00gOonF@:/ooolI_kooEWgooaVmoomFKco0=[AooaIm?l00>[ooEWe
o`20j_olFOGo003[ooeIlol00>_oo5Wco`00k?omFO7o003MooiI0ZcoooeV0;?n
ooeIn?okI_OooEV<ooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIlol00>_oo5Wc
o`00k?omFO7o003MooiI0ZcoooeV0;?nooeIn?okI_OooEV<ooaIm?l00>[ooEWe
o`20j_olFOGo003[ooeIlol00>_oo5Wco`00k?omFO7o003MooiI0ZcoooeV0;?n
ooeIn?okI_OooEVlo`3GdOolFOCo003ZooeImOl0P>[oo5Weo`00joomFO?o003[
ooaIlol00>cooEWao`00gOonF@6/ooaV0;?nooeIn?olI_KooEV<ooaIm?l00>[o
oEWeo`20j_olFOGo003[ooeIlol00>_oo5Wco`00k?omFO7o003MooiI0Jcoo6H0
/okooEWhooaVm_omFHcoo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWco`00jool
FO?o003/ooeIlOl00=gooUT1[?olIP2co_omFOSoo6KfooeI_?l0e=7oo5Wdo`00
j_omFOGo083ZooaImOl00>_ooEWco`00joolFO?o003/ooeIlOl00=gooUT0[?]V
oOomFOWoo6H0H?KooEV<ooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIlol00>_o
o5Wco`00k?omFO7o003MooiI0:ckI_gooEWiooaV063fooeIS?olFOCo003ZooeI
mOl0P>[oo5Weo`00joomFO?o003[ooaIlol00>cooEWao`00gOonF@2/nfKmooeI
nOolIP1Pm_omFKco0=[AooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIlol00>_o
o5Wco`00k?omFO7o003MooiI063lI_cooEWjo`2co6H0FOKooEV<ooaIm?l00>[o
oEWeo`20j_olFOGo003[ooeIlol00>_oo5Wco`00k?omFO7o003MooiI063lI_co
oEWjo`2co6H0FOKooEV<ooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIlol00>_o
o5Wco`00k?omFO7o003MooiI063lI_cooEWjo`2co6H0FOKooEVlo`3GdOolFOCo
003ZooeImOl0P>[oo5Weo`00joomFO?o003[ooaIlol00>cooEWao`00gOonF@1P
oFKkooeIn_olIP5IFOKooEV<ooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIlol0
0>_oo5Wco`00k?omFO7o003MooiI063mI__ooEWjooaV0EUIm_omFHcoo5Wdo`00
j_omFOGo083ZooaImOl00>_ooEWco`00joolFO?o003/ooeIlOl00=gooUT0H?eV
noomFO[oo6H1FEWfooeI_?l0dM7oo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWc
o`00joolFO?o003/ooeIlOl00=gooUWlI__ooEWjooaV0EUIm_omFHcoo5Wdo`00
j_omFOGo083ZooaImOl00>_ooEWco`00joolFO?o003/ooeIlOl00=gooUWlI__o
oEWjooaV0EUIm_omFHcoo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWco`00jool
FO?o003/ooeIlOl00=gooUWlI__ooEWjooaV0EUIm_omFKco0<kAooaIm?l00>[o
oEWeo`20j_olFOGo003[ooeIlol00>_oo5Wco`00k?omFO7o003MooiIoFKjooeI
noolI_iIm_omFHcoo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWco`00joolFO?o
003/ooeIlOl00=gooUWmI_[ooEWkooaVoUWfooeIS?olFOCo003ZooeImOl0P>[o
o5Weo`00joomFO?o003[ooaIlol00>cooEWao`00gOonFOeVn_omFO_oo6KnFOKo
oEVlo`3AdOolFOCo003ZooeImOl0P>[oo5Weo`00joomFO?o003[ooaIlol00>co
oEWao`00gOl1FEWlI_[ooEWkooeVoEWfooeIS?olFOCo003ZooeImOl0P>[oo5We
o`00joomFO?o003[ooaIlol00>cooEWao`00gOl1FEWlI_[ooEWkooeVoEWfooeI
S?olFOCo003ZooeImOl0P>[oo5Weo`00joomFO?o003[ooaIlol00>cooEWao`00
gOl1FEWlI_[ooEWkooeVoEWfooeI_?l0aM7oo5WeonL00ReIFOGoj03mFOGo003[
ooeIlol00>_oo5WconP005Wao`00gOl1FEWmI_WooEWlooaVoEWfooeIS?olFOGo
i`02;EUImOoX0?eImOl00>_ooEWco`00joolFO?oj000FO7o003Mo`5IFOeVnOom
FOcoo6KmFOKooEV<ooaImOoW008]FEWeonP0oEWeo`00joomFO?o003[ooaIlooX
001IlOl00=go0EUIoFKiooeIo?olI_eIm_omFKco0=7AooaImOl00>WooEWeo`20
j_olFOKoi`01FEWdo`20j@3mFO?o003/ooeIlOl00=go05WlI_WooEWlooeV0?om
FOKooEV<ooaImOl00>WooEWeo`20j_olFOKoi`01FEWdo`20j@3mFO?o003/ooeI
lOl00=go05WlI_WooEWlooeV0?omFOKooEV<ooaImOl00>WooEWeo`20j_olFOKo
i`01FEWdo`20j@3mFO?o003/ooeIlOl00=go05WlI_WooEWlooeV0?omFOKooEVl
o`3DdOolFOKo003XooeIm_l00>Woo5Wgo`00jOomFOCo083ZooaIm?l00>_ooEWb
om^00C<coVKhooeIoOomIP6cooeIm_omFHcoo5Wfo`00j?omFOKo003YooaImol0
0>WooEWdo`20j_olFOCo003[ooeIl_oKP04c<oiVn?omFOgooFH1/oomFOKooEV<
ooaIm_l00>SooEWfo`00jOolFOOo003YooeIm?l0P>[oo5Wdo`00joomFO;ofh01
<c?nI_SooEWmooeV0K?ooEWfooeI_?l0dM7oo5Wgo`00ioomFOOo003XooaIn?l0
0>SooEWeo`00jOolFOGo003ZooeIlol00=coo6KgooeIo_olIP7oooeIm_omFHco
o5Wgo`00ioomFOOo003XooaIn?l00>SooEWeo`00jOolFOGo003ZooeIlol00=co
o6KgooeIo_olIP7oooeIm_omFHcoo5Wgo`00ioomFOOo003XooaIn?l00>SooEWe
o`00jOolFOGo003ZooeIlol00=coo6KgooeIo_olIP7oooeIm_omFKco0=CAooaI
mol00>OooEWgo`00j?olFOWo083WooeImOl00>Woo5Wfo`00jOomFO?o003LooaV
moomFOkooFH2/ooooEWfooeIS?olFOOo003WooeImol00>Soo5Wio`20ioomFOGo
003YooaIm_l00>WooEWco`00g?olI_OooEWnooeV0[?oooeIm_omFHcoo5Wgo`00
ioomFOOo003XooaInOl0P>OooEWeo`00jOolFOKo003YooeIlol00=coo6KgooeI
o_omIP:cooomFOKooEVlo`3MdOolFOSo083VooeIn?l00>Ooo5Wio`20ioomFOKo
003XooaIm_l00>WooEWdo`00g?olIP2cmoomF@7oooaV0[?oooeIm_omFHcoo5Wh
o`20i_omFOSo003WooaInOl0P>OooEWfo`00j?olFOKo003YooeIm?l00=coo6H0
/oOooET1ooolIP:cooomFOKooEV<ooaIn?l0P>KooEWho`00ioolFOWo083WooeI
m_l00>Soo5Wfo`00jOomFOCo003LooaV0;?gooeI0Oooo6H2/ooooEWfooeI_?l0
c]7oo5Who`20i_omFOWo003VooaInOl0P>OooEWfo`00j?olFOOo003XooeImOl0
P=_oo6H0[?OooET0oo]Vo_ob0?eIS?olFOSo083VooeInOl00>Koo5Wio`20ioom
FOKo003XooaImol00>SooEWeo`20foolIP2/moomF@3onfKnoo80oEV<ooaIn?l0
P>KooEWio`00i_olFOWo083WooeIm_l00>Soo5Wgo`00j?omFOGo083KooaV0:cg
ooeI0?okI_kolP3mFKco0<cAooaIn?l0P>KooEWio`00i_olFOWo083WooeImol0
0>Ooo5Wgo`00j?omFOGo083Loo]V0:cgooeI0?okI_kooEV1oogoo5Who`20i_om
FOWo003VooaInOl0P>OooEWgo`00ioolFOOo003XooeImOl0P=confH0[?OooET0
oo]Vo_omFH7ooOolFOSo083VooeInOl00>Koo5Wio`20ioomFOOo003WooaImol0
0>SooEWeo`20g?okIP2/moomF@3onfKnooeI[Ol0cm7oo5Wio`00iOomFO[o003U
ooaIn_l00>KooEWho`00i_olFOSo003WooeImOl0P=coo6H1FJcgooeI0;?lI_go
oEV1oogoo5Wio`00iOomFO[o003UooaIn_l00>KooEWho`00i_olFOSo003WooeI
mOl0P=coo6H1FJcgooeI0;?lI_gooEV1oogoo5Wio`00iOomFO[o003UooaIn_l0
0>KooEWho`00i_olFOSo003WooeImOl0P=coo6H1FJcgooeI0;?lI_gooEV]o`3T
dOolFO[o0H20iOomFO_o0H20iOolFO_o003UooeInOl1P83VooaInOl0P>KooEWf
o`60`=go0;?mIP9PFJcgooeI08gmI_cooEV1oogoo5Wjo`60P>GooEWko`60P>Go
o5Wko`00iOomFOWo0H20i_olFOWo083VooeIm_l1P<3Mo`2coFH2H5V/moomF@2=
oFKlooeIPOomooaIn_l1P83UooeInol1P83UooaInol00>GooEWio`60P>Koo5Wi
o`20i_omFOKo0H30gOl0/oeV0V1I[?OooET0SOeVo?omFJgo0<cAooaIn_l00>Co
oEWko`00i?olFOco003TooeIn_l00>Coo5Wio`20i_omFOOo003KooaV0UUI[?Oo
oEWmI__ooEV1oogoo5Wjo`00i?omFO_o003TooaIo?l00>CooEWjo`00i?olFOWo
083VooeImol00=_oo6H2FEV/moomFOeVnoomFH7ooOolFO[o003TooeInol00>Co
o5Wlo`00i?omFO[o003TooaInOl0P>KooEWgo`00foolIP9IFJcgooeIoFKkooeI
[Ol0c=7oo5Wko`00hoomFOco083SooaIo?l00>CooEWjo`00i?olFOWo083VooeI
mol00=_ooFKnF@2/moonFOaVnoomFH7ooOolFO_o003SooeIo?l0P>?oo5Wlo`00
i?omFO[o003TooaInOl0P>KooEWgo`00foomI_iI0:cgooiIo6KkooeIPOomooaI
nol00>?ooEWlo`20hoolFOco003TooeIn_l00>Coo5Wio`20i_omFOOo003KooeV
oUT0[?OooUWlI__ooEV]o`3<dOolFO_o003SooeIo?l0P>?oo5Wmo`00hoomFO_o
083SooaIn_l00>GooEWho`00foolI_iI0:cgooiIoFKjooeIPOomooaInol00>?o
oEWlo`20hoolFOgo003SooeInol0P>?oo5Wjo`00iOomFOSo003KooaVoUT0[?Oo
oUWmI_[ooEV1oogoo5Wko`00hoomFOco083SooaIoOl00>?ooEWko`20hoolFO[o
003UooeIn?l00=_oo6KnF@2/moonFOeVn_omFJgo0=GAooaIo?l00>;ooEWlo`20
hoolFOgo003SooeInol0P>?oo5Wjo`00iOomFOSo003LooaV0?onF@2/mol1FEWl
I_[ooEV1oogoo5Wlo`00h_omFOco083SooaIoOl00>?ooEWko`20hoolFO[o003U
ooeIn?l00=coo6H0ooiI0:cgo`5IFOaVn_omFH7ooOolFOco003RooeIo?l0P>?o
o5Wmo`00hoomFO_o083SooaIn_l00>GooEWho`00g?olIP3ooUT0[?Oo0EUIo6Kj
ooeI[Ol0eM7oo5Wlo`00h_omFOco083SooaIo_l00>;ooEWko`20hoolFO_o003T
ooeInOl00=_oo6H0ooiI0:cgo`5IFOeVnOomFH7ooOolFOco003RooeIo?l0P>?o
o5Wno`00h_omFO_o083SooaInol00>CooEWio`00foolIP3ooUT0[?Oo0EUIoFKi
ooeIPOomooaIo?l00>;ooEWlo`20hoolFOko003RooeInol0P>?oo5Wko`00i?om
FOWo003KooaV0?onF@2/mol1FEWmI_WooEV]o`3EdOolFOgo003QooeIoOl00>;o
o5T2ool0hOomFOco003RooaIo?l00>?ooEWjo`00foolIP7oooiI0:cgo`1Io6Ki
ooeIPOomooaIoOl00>7ooEWmo`00h_olF@;oo`3QooeIo?l00>;oo5Wlo`00hoom
FO[o003KooaV0OoooUT0[?Oo05WlI_WooEV1oogoo5Wmo`00hOomFOgo003RooaI
0_oo0>7ooEWlo`00h_olFOco003SooeIn_l00=_oo6H1ooonF@2/mol0FOaVnOom
FJgo0=_AooaIo_l00>3ooEWno`00hOolF@;o`83QooeIoOl1P83RooaIoOl1P83S
ooeInol1P83Lo`2coFKnooh]05OgP?aVn?omFH7ooOolFOko003PooeIo_l00>7o
o5T2ol20hOomFOgo0H20h_olFOgo0H20hoomFO_o0H20g?l0/oeVo_on;@1Gmh3l
I_SooEV1oogoo5Wno`00h?omFOko003QooaI0_o0P>7ooEWmo`60P>;oo5Wmo`60
P>?ooEWko`60P=co0;?mI_kooRd0EoN0o6KhooeI[Ol0eM7oo5T2oon0goomF@;o
o`3PooaI0On0h?omFOko003PooaIoOl00>;ooEWko`00foomIP2co_onF@2/n?ol
IP2cn?omFH7ooOolF@;ooh3OooeI0_oo0>3oo5T1oh3PooeIo_l00>3oo5Wmo`00
h_omFO_o003KooeV0;?nooiI0:chooaV0;?hooeIPOomooaI0_ooP=oooET2ool0
h?olF@7oP>3ooEWno`00h?olFOgo003RooeInol00=_ooFH0/okooUT0[?Soo6H0
/oSooEV]o`3?dOolF@;ooh3OooeI0_oo0>3oo5T1oh3PooeIo_l00>3oo5Wno`00
hOomFOco083KooaV0;?nooiI0:chooaVmoomFH7ooOolF@;ooh3OooeI0_oo0>3o
o5T1oh3PooeIo_l00>3oo5Wno`00hOomFOco083KooaV0;?nooiI0:chooaVmoom
FH7ooOolF@;ooh3OooeI0_oo0>3oo5T1oh3PooeIo_l00>3oo5Wno`00hOomFOco
083KooaV0;?nooiI0:chooaVmoomFJgo0<KAooaI0_ooP=oooET1o`3OooaI0On0
h?omF@;oo`3OooaIo_l00>7ooEWlo`20foolI_gooUT0[?WonfKgooeIPOomooaI
0_ooP=oooET1o`3OooaI0On0h?omF@;oo`3OooaIo_l00>7ooEWlo`20foolI_go
oUT0[?WonfKgooeIPOomooaI0_ooP=oooET1o`3OooaI0On0h?omF@;oo`3OooaI
o_l00>7ooEWlo`20foolI_gooUT0[?WonfKgooeI[Ol0a]7oo5T2oon0goomF@7o
0=ooo5T00=oooET1o`3NooaI0_oo0>3ooEWlo`20g?okI_gooUT0[?Woo6H0FOOo
oEV1oogoo5T2oon0goomF@7o0=ooo5T00=oooET1o`3NooaI0_oo0>3ooEWlo`20
g?okI_gooUT0[?Woo6H0FOOooEV1oogoo5T2oon0goomF@7o0=ooo5T00=oooET1
o`3NooaI0_oo0>3ooEWlo`20g?okI_gooUT0[?Woo6H0FOOooEV]o`2mdOolF@7o
0=kooET00=kooET00=kooET1o`3NooaI0Ol0goomFOgo003KooaVo?onF@2/n_ok
IP1ImoomFH7ooOolF@7o0=kooET00=kooET00=kooET1o`3NooaI0Ol0goomFOgo
003KooaVo?onF@2/n_okIP1ImoomFH7ooOolF@7o0=kooET00=kooET00=kooET1
o`3NooaI0Ol0goomFOgo003KooaVo?onF@2/n_okIP1ImoomFJgo0;gAooaI0Ol0
g_omF@00g_omF@00g_omF@00gOolF@7o0=oooEWmo`00g?okI_cooUT0[?[oo6H1
FEWgooeIPOomooaI0Ol0g_omF@00g_omF@00g_omF@00gOolF@7o0=oooEWmo`00
g?okI_cooUT0[?[oo6H1FEWgooeIPOomooaI0Ol0g_omF@00g_omF@00g_omF@00
gOolF@7o0=oooEWmo`00g?okI_cooUT0[?[oo6H1FEWgooeI[Ol0a]7oo5T00=go
oUT00=gooUT105WNooiI003LooaI083NooeIo_l00=co0;?lI__ooUT0[?_o0;?l
IP5IFOOooEV1oogoo5T00=gooUT00=gooUT105WNooiI003LooaI083NooeIo_l0
0=co0;?lI__ooUT0[?_o0;?lIP5IFOOooEV1oogoo5T00=gooUT00=gooUT105WN
ooiI003LooaI083NooeIo_l00=co0;?lI__ooUT0[?_o0;?lIP5IFOOooEV]o`3B
dOomF@00g?l3FET0FMgo15UI;BeIg_l3FEU3;Mcoo5T0P=kooET2ool0fol0SOeV
0;?kooiI0:cko`2=oFKnFOOooEV1oogooET00=co0eUI05WMo`AIFBd]FMko0eUI
@bgLooaI083NooeI0_oo0=_o08gmIP2cnoonF@2/nol0SOeVoUWgooeIPOomooeI
003Lo`=IF@1IgOl4FET];EWNo`=IFD<]g?olF@20g_omF@;oo`3Ko`2=oFH0/o_o
oUT0[?_o08gmI_iImoomFJgo0;gAooiI0@1Ig?l3FBeIFMgo0ET0oUWNo`=IFBeI
g?omF@00gOomF@7o0=[ooFKiooiI0:clooaVoEWgooeIPOomooiI0@1Ig?l3FBeI
FMgo0ET0oUWNo`=IFBeIg?omF@00gOomF@7o0=[ooFKiooiI0:clooaVoEWgooeI
POomooiI0@1Ig?l3FBeIFMgo0ET0oUWNo`=IFBeIg?omF@00gOomF@7o0=[ooFKi
ooiI0:clooaVoEWgooeI[Ol0E=7oPBJ89P16oVKiooiI0:clooaVoEWgooeIPOom
oh4VR2H0A_iVnOonF@2/o?olI_eImoomFH7ooOn19XPV04KnI_WooUT0[?coo6Km
FOOooEV]o`1JdOn19XPV0TIVI_SooUT0[?goo6H0ooeImoomFH7ooOn19XPV0TIV
I_SooUT0[?goo6H0ooeImoomFH7ooOn19XPV0TIVI_SooUT0[?goo6H0ooeImoom
FJgo05gAoh4VR2H2AVIVn?onF@2/oOomIP7oooeImoomFH7ooOn19XPV0TIVI_So
oUT0[?gooFH1ooomFOOooEV1oogoPBJ89P96IVKhooiI0:cmooeV0OoooEWgooeI
[Ol0F]7oPBJ89P56I_OooUT0[?koo6H1ooomFOOooEV1oogoPBJ89P56I_OooUT0
[?koo6H1ooomFOOooEV1oogoPBJ89P56I_OooUT0[?koo6H1ooomFOOooEV]o`1G
dOn19XPV0DIVmoonF@2/o_omI_kooEWgooeIPOomoh4VR2H1AVKgooiI0:cnooeV
o_omFOOooEV1oogoPBJ89P56I_OooUT0[?kooFKnooeImoomFJgo0=;AooaIm?l0
0>[ooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFO7o003MooiI0Zco
ooeV08gnood]mX3n[87ooOolFOCo003ZooeImOl0P>[oo5Weo`00joomFOCo083Z
ooaIlol00>cooEWao`00gOonF@:/ooomIP2=o_om;OJ0oZb1oogoo5Wdo`00j_om
FOGo083ZooaImOl00>_ooEWdo`20j_olFO?o003/ooeIlOl00=gooUT2[?oooFH0
SOkooBgfP?j/[Ol0`m7oo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_ol
FO?o003/ooeIlOl00=gooUT1[?olIP2co_omFH7okoolFOCo003ZooeImOl0P>[o
o5Weo`00joomFOCo083ZooaIlol00>cooEWao`00gOonF@6/ooaV0;?nooeIPOo_
ooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFO7o003M
ooiI0Jcoo6H0/okooEVOo`2mdOolFOCo003ZooeImOl0P>[oo5Weo`00joomFOCo
083ZooaIlol00>cooEWao`00gOonF@6/ooaVoOomFH7okoolFOCo003ZooeImOl0
P>[oo5Weo`00joomFOCo083ZooaIlol00>cooEWao`00gOonF@6/ooaVoOomFH7o
koolFOCo003ZooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol00>cooEWao`00
gOonF@6/ooaVoOomFIoo0;[AooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0
P>[oo5Wco`00k?omFO7o003MooiI0:ckI_gooEV1onooo5Wdo`00j_omFOGo083Z
ooaImOl00>_ooEWdo`20j_olFO?o003/ooeIlOl00=gooUT0[?]VoOomFH7okool
FOCo003ZooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol00>cooEWao`00gOon
F@2/nfKmooeIWol0^]7oo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_ol
FO?o003/ooeIlOl00=gooUT0H?aVo?omFH7okoolFOCo003ZooeImOl0P>[oo5We
o`00joomFOCo083ZooaIlol00>cooEWao`00gOonF@1Po6KlooeIPOo_ooaIm?l0
0>[ooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFO7o003MooiI063l
I_cooEVOo`2jdOolFOCo003ZooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol0
0>cooEWao`00gOonF@1Po6KlooeIPOo_ooaIm?l00>[ooEWeo`20j_olFOGo003[
ooeIm?l0P>[oo5Wco`00k?omFO7o003MooiI063lI_cooEV1onooo5Wdo`00j_om
FOGo083ZooaImOl00>_ooEWdo`20j_olFO?o003/ooeIlOl00=gooUT0H?aVo?om
FIoo0;CAooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?om
FO7o003MooiIo6KkooeIPOo_ooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0
P>[oo5Wco`00k?omFO7o003MooiIo6KkooeIPOo_ooaIm?l00>[ooEWeo`20j_ol
FOGo003[ooeIm?l0P>[oo5Wco`00k?omFO7o003MooiIo6KkooeIWol0^]7oo5Wd
o`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_olFO?o003/ooeIlOl00=go0UUI
H?eVn_omFH7okoolFOCo003ZooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol0
0>cooEWao`00gOl2FEUPoFKjooeIPOo_ooaIm?l00>[ooEWeo`20j_olFOGo003[
ooeIm?l0P>[oo5Wco`00k?omFO7o003Mo`9IFF3mI_[ooEVOo`2gdOolFOCo003Z
ooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol00>cooEWao`00gOl1FEWmI_Wo
oEV1onooo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_olFO?o003/ooeI
lOl00=go0EUIoFKiooeIPOo_ooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0
P>[oo5Wco`00k?omFO7o003Mo`5IFOeVnOomFIoo0;CAooaIm?l00>[ooEWeo`20
j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFO7o003Mo`1Io6KiooeIPOo_ooaI
m?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFO7o003Mo`1I
o6KiooeIPOo_ooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00
k?omFO7o003Mo`1Io6KiooeIWol0Wm7oo5WeonL00ReIFOGoj03mFOKoi`01FEWd
onP0oEWconP005Wao`00gOl0FOeVn?omFH7okoolFOGoi`02;EUImOoX0?eIm_oW
005IFOCoj03mFO?oj000FO7o003Mo`1IoFKhooeIPOo_ooaImOoW008]FEWeonP0
oEWfonL00EUIm?oX0?eIlooX001IlOl00=go05WmI_SooEVOo`2XdOolFOKo003X
ooeIm_l00>Woo5Wgo`00jOomFOGo003YooaIm?l00>_ooEWaomX0oVKhooeIPOo_
ooaIm_l00>SooEWfo`00jOolFOOo003YooeImOl00>Woo5Wdo`00joomFO7ofP3n
I_SooEV1onooo5Wfo`00j?omFOKo003YooaImol00>WooEWeo`00jOolFOCo003[
ooeIlOoJ0?iVn?omFIoo0:kAooaIm_l00>SooEWfo`00jOolFOOo003YooeImOl0
0>Woo5Weo`00j_omFO;o003MooaVmoomFH7okoolFOKo003XooeIm_l00>Woo5Wg
o`00jOomFOGo003YooaImOl00>[ooEWbo`00gOolI_OooEV1onooo5Wfo`00j?om
FOKo003YooaImol00>WooEWeo`00jOolFOGo003ZooeIl_l00=goo6KgooeIWol0
[]7oo5Wgo`00ioomFOOo003XooaIn?l00>SooEWfo`00j?olFOGo003ZooeIlol0
0=coo6KgooeIPOo_ooaImol00>OooEWgo`00j?olFOSo003XooeIm_l00>Soo5We
o`00j_omFO?o003LooaVmoomFH7okoolFOOo003WooeImol00>Soo5Who`00j?om
FOKo003XooaImOl00>[ooEWco`00g?olI_OooEVOo`2ddOolFOSo083VooeImol0
0>Soo5Wio`20ioomFOOo003WooaIm_l00>WooEWco`00gOolIP2cmoomFH7okool
FOSo083VooeImol00>Soo5Wio`20ioomFOOo003WooaIm_l00>WooEWco`00gOol
IP2cmoomFH7okoolFOSo083VooeImol00>Soo5Wio`20ioomFOOo003WooaIm_l0
0>WooEWco`00gOolIP2cmoomFIoo0<KAooaIn?l0P>KooEWio`60P>Ooo5Wio`20
ioomFOSo0H20ioolFOOo0H20jOomFOGo0L20gOl0/oaV0:cgooeIPOo_ooaIn?l0
P>KooEWio`60P>Ooo5Wio`20ioomFOSo0H20ioolFOOo0H20jOomFOGo0L20gOl0
/oaV0:cgooeIPOo_ooaIn?l0P>KooEWio`60P>Ooo5Wio`20ioomFOSo0H20iool
FOOo0H20jOomFOGo0L20gOl0/oaV0:cgooeIWol0]m7oo5Who`20i_omFOWo003V
ooaInOl0P>OooEWho`00i_olFOSo003WooeImOl0P=coo6H1FJcgooeIPOo_ooaI
n?l0P>KooEWio`00i_olFOWo083WooeIn?l00>Koo5Who`00ioomFOGo083LooaV
0EV/moomFH7okoolFOSo083VooeInOl00>Koo5Wio`20ioomFOSo003VooaIn?l0
0>OooEWeo`20g?olIP5I[?OooEVOo`2mdOolFOWo003UooeIn_l00>Goo5Wjo`00
i_omFOWo003UooaIn?l00>OooEWeo`20gOl0/oaV0EV/moomFH7okoolFOWo003U
ooeIn_l00>Goo5Wjo`00i_omFOWo003UooaIn?l00>OooEWeo`20gOl0/oaV0EV/
moomFH7okoolFOWo003UooeIn_l00>Goo5Wjo`00i_omFOWo003UooaIn?l00>Oo
oEWeo`20gOl0/oaV0EV/moomFIoo0<3AooaIn_l00>CooEWjo`00iOolFO_o003U
ooeIn_l00>Coo5Wio`20i_omFOGo083Mo`2coFH2FEV/moomFH7okoolFO[o003T
ooeIn_l00>Goo5Wko`00iOomFO[o003TooaInOl0P>KooEWeo`20gOl0/oeV0UUI
[?OooEV1onooo5Wjo`00i?omFO[o003UooaInol00>GooEWjo`00i?olFOWo083V
ooeImOl0P=go0;?mIP9IFJcgooeIWol0^]7oo5Wjo`00i?omFO_o003TooaInol0
0>GooEWjo`00i?olFOWo083VooeIm_l00=coo6H2FEV/moomFH7okoolFO[o003T
ooeInol00>Coo5Wko`00iOomFO[o003TooaInOl0P>KooEWfo`00g?olIP9IFJcg
ooeIPOo_ooaIn_l00>CooEWko`00i?olFO_o003UooeIn_l00>Coo5Wio`20i_om
FOKo003LooaV0UUI[?OooEVOo`2jdOolFO_o003SooeInol00>Coo5Wlo`00i?om
FO_o083SooaInOl0P>KooEWgo`00foomI_iI0:cgooeIPOo_ooaInol00>?ooEWk
o`00i?olFOco003TooeInol0P>?oo5Wio`20i_omFOOo003KooeVoUT0[?OooEV1
onooo5Wko`00hoomFO_o003TooaIo?l00>CooEWko`20hoolFOWo083VooeImol0
0=_ooFKnF@2/moomFIoo0;[AooaInol00>?ooEWlo`20hoolFOco003TooeInol0
P>?oo5Wjo`00iOomFOOo003LooaVoUT0[?OooEV1onooo5Wko`00hoomFOco083S
ooaIo?l00>CooEWko`20hoolFO[o003UooeImol00=coo6KnF@2/moomFH7okool
FO_o003SooeIo?l0P>?oo5Wlo`00i?omFO_o083SooaIn_l00>GooEWgo`00g?ol
I_iI0:cgooeIWol0`m7oo5Wlo`00h_omFOco083SooaIoOl00>?ooEWko`20hool
FO_o0H20iOomFOSo003LooaV0?onF@2/moomFH7okoolFOco003RooeIo?l0P>?o
o5Wmo`00hoomFO_o083SooaInol1P83UooeIn?l00=coo6H0ooiI0:cgooeIPOo_
ooaIo?l00>;ooEWlo`20hoolFOgo003SooeInol0P>?oo5Wko`60P>GooEWho`00
g?olIP3ooUT0[?OooEVOo`33dOolFOgo003QooeIo?l0P>?oo5Wno`00h_omFOco
003RooaInol00>CooEWio`00g?olIP7oooiI0:cgooeIPOo_ooaIoOl00>7ooEWl
o`20hoolFOko003RooeIo?l00>;oo5Wko`00i?omFOWo003LooaV0OoooUT0[?Oo
oEV1onooo5Wmo`00hOomFOco083SooaIo_l00>;ooEWlo`00h_olFO_o003TooeI
nOl00=coo6H1ooonF@2/moomFIoo0;CAooaIo_l00>3ooEWmo`00h_olF@;oo`3Q
ooeIoOl00>7oo5Wlo`00hoomFOWo003LooeVo_oc0?eIPOo_ooaIo_l00>3ooEWm
o`00h_olF@;oo`3QooeIoOl00>7oo5Wlo`00hoomFOWo003LooeVo_oc0?eIPOo_
ooaIo_l00>3ooEWmo`00h_olF@;oo`3QooeIoOl00>7oo5Wlo`00hoomFOWo003L
ooeVo_oc0?eIWol0`=7oo5Wno`00h?omFOko003QooaI0_oo0>7ooEWmo`00hOol
FOgo003RooeIn_l00=coo6KnooiI0:cgooeIPOo_ooaIo_l00>3ooEWno`00hOol
F@;oo`3QooeIoOl00>7oo5Wmo`00h_omFO[o003LooaVo_onF@2/moomFH7okool
FOko003PooeIo_l00>7oo5T2ool0hOomFOgo003QooaIoOl00>;ooEWjo`00g?ol
I_kooUT0[?OooEVOo`2gdOolF@;ooh3OooeIo_l00>7oo5T1oh3PooeIo_l00>3o
o5Wmo`00h_omFO_o003KooeV0;?nooiI0:b1on7oo5T2oon0goomFOko003QooaI
0On0h?omFOko003PooaIoOl00>;ooEWko`00foomIP2co_onF@2/POoQooaI0_oo
P=oooEWno`00hOolF@7oP>3ooEWno`00h?olFOgo003RooeInol00=_ooFH0/oko
oUT0[97o0;OAooaI0_ooP=oooET2ool0h?olF@7oP>3ooEWno`00h?olFOko003Q
ooeInol00=coo6H0/okooUT0[87ohOolF@;ooh3OooeI0_oo0>3oo5T1oh3PooeI
o_l00>3oo5Wno`00hOomFO_o003LooaV0;?nooiI0:b1on7oo5T2oon0goomF@;o
o`3PooaI0On0h?omFOko003PooaIo_l00>7ooEWko`00g?olIP2co_onF@2/TOl0
/M7oo5T2oon0goomF@;oo`3PooaI0On0h?omF@;oo`3OooaI0_oo0>3ooEWlo`20
foolI_gooUT0[87ohOolF@;ooh3OooeI0_oo0>3oo5T1oh3PooeI0_oo0=ooo5T2
ool0h?omFOco083KooaVoOonF@2/POoQooaI0_ooP=oooET2ool0h?olF@7oP>3o
oET2ool0goolF@;oo`3PooeIo?l0P=_oo6KmooiI0:bAo`2^dOolF@;ooh3OooeI
0Ol0goolF@7oP>3ooET2ool0goolF@;oo`3PooeIo?l0P=confKmooiI0:b1on7o
o5T2oon0goomF@7o0=ooo5T1oh3PooeI0_oo0=ooo5T2ool0h?omFOco083Loo]V
oOonF@2/POoQooaI0_ooP=oooET1o`3OooaI0On0h?omF@;oo`3OooaI0_oo0>3o
oEWlo`20g?okI_gooUT0[97o0:_AooaI0H20g_omF@60P=oooET1;H3OooeI0H20
g_olF@7o0=oooEWlo`20gOl0/oaVo?onF@2/POoQooaI0H20g_omF@60P=oooET1
;H3OooeI0H20g_olF@7o0=oooEWlo`20gOl0/oaVo?onF@2/POoQooaI0H20g_om
F@60P=oooET1;H3OooeI0H20g_olF@7o0=oooEWlo`20gOl0/oaVo?onF@2/TOl0
W=7oo5T00=gooET00=kooET00=kooET00=goo5T0P=kooEWmo`00gOl0/oaVnoon
F@2/POoQooaI003MooeI003NooeI003NooeI003MooaI083NooeIoOl00=go0;?l
I__ooUT0[87ohOolF@00gOomF@00g_omF@00g_omF@00gOolF@20g_omFOgo003M
o`2co6KkooiI0:bAo`2OdOomF@00g?onF@00gOonF@40FMkooUT00=coo5T0P=ko
oEWno`00g?l0/oaVnoonF@2/POoQooeI003LooiI003MooiI0@1Ig_onF@00g?ol
F@20g_omFOko003Lo`2co6KkooiI0:b1on7ooET00=cooUT00=gooUT105WNooiI
003LooaI083NooeIo_l00=co0;?lI__ooUT0[97o09cAooeI003Lo`=IF@1IgOon
F@40FMkooUT00=coo5T0P=kooEWno`00g?olI_[ooUT0[87ohOomF@00g?l3FET0
FMgooUT105WNooiI003LooaI083NooeIo_l00=coo6KjooiI0:b1on7ooET00=co
0eUI05WMooiI0@1Ig_onF@00g?olF@20g_omFOko003LooaVn_onF@2/TOl0YM7o
oUT105WLo`=IF@1IgOl4FET0FEWNo`=IFBeIg?omF@00gOomF@;oo`3KooeVnOon
F@2/POoQooiI0@1Ig?l3FET0FMgo15UI05UIg_l3FET]FMcooET00=gooET2ool0
foomI_WooUT0[87ohOonF@40FMco0eUI05WMo`AIF@1IFMko0eUI;EWLooeI003M
ooeI0_oo0=_ooFKiooiI0:bAo`2UdOl4FET0FEWLo`=I;EUIgOl1F@3nFMko0eUI
;EWLooeI003MooeI0_oo0=coo6KiooiI0:b1on7o15UI05UIg?l3FBeIFMgo0ET0
oUWNo`=IFBeIg?omF@00gOomF@;oo`3LooaVnOonF@2/POoQo`AIF@1IFMco0eT]
FEWMo`5I0?iIg_l3FET]FMcooET00=gooET2ool0g?olI_WooUT0[97o03KAoh4V
R2H2AVIVn?onF@2/POoQoh4VR2H2AVIVn?onF@2/POoQoh4VR2H2AVIVn?onF@2/
TOl0=]7oPBJ89P96I[?hooiI0:b1on7oPBJ89P96I[?hooiI0:b1on7oPBJ89P96
I[?hooiI0:bAo`0cdOn19XPV0DIVmoonF@2/POoQoh4VR2H1AVKgooiI0:b1on7o
PBJ89P56I_OooUT0[97o033Aoh4VR2H0ToKooUT0[87ohOn19XPV09?fooiI0:b1
on7oPBJ89P2Cm_onF@2/TOl0Z=7oo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWd
o`20j_olFO?o003/ooeIl_l00=cooUT0[87ohOolFOCo003ZooeImOl0P>[oo5We
o`00joomFOCo083ZooaIlol00>cooEWbo`00g?onF@2/POoQooaIm?l00>[ooEWe
o`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFO;o003LooiI0:bAo`2XdOol
FOCo003ZooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol00>cooEWbo`00g?on
F@2/POoQooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?om
FO;o003LooiI0:b1on7oo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_ol
FO?o003/ooeIl_l00=cooUT0[97o0:SAooaIm?l00>[ooEWeo`20j_olFOGo003[
ooeIm?l0P>[oo5Wco`00k?omFO;o003LooiI0:b1on7oo5Wdo`00j_omFOGo083Z
ooaImOl00>_ooEWdo`20j_olFO?o003/ooeIl_l00=cooUT0[87ohOolFOCo003Z
ooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol00>cooEWbo`00g?onF@2/TOl0
Z=7oo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_olFO?o003/ooeIl_l0
0=cooUT0[87ohOolFOCo003ZooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol0
0>cooEWbo`00g?onF@2/POoQooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0
P>[oo5Wco`00k?omFO;o003LooiI0:bAo`2XdOolFOCo003ZooeImOl0P>[oo5We
o`00joomFOCo083ZooaIlol00>cooEWbo`00g?onF@2/POoQooaIm?l00>[ooEWe
o`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFO;o003LooiI0:b1on7oo5Wd
o`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_olFO?o003/ooeIl_l00=cooUT0
[97o0:SAooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?om
FO;o003LooiI0:b1on7oo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_ol
FO?o003/ooeIl_l00=cooUT0[87ohOolFOCo003ZooeImOl0P>[oo5Weo`00joom
FOCo083ZooaIlol00>cooEWbo`00g?onF@2/TOl0Z=7oo5Wdo`00j_omFOGo083Z
ooaImOl00>_ooEWdo`20j_olFO?o003/ooeIl_l00=cooUT0[87ohOolFOCo003Z
ooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol00>cooEWbo`00g?onF@2/POoQ
ooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFO;o003L
ooiI0:bAo`2XdOolFOCo003ZooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol0
0>cooEWbo`00g?onF@2/POoQooaIm?l00>[ooEWeo`20j_olFOGo003[ooeIm?l0
P>[oo5Wco`00k?omFO;o003LooiI0:b1on7oo5Wdo`00j_omFOGo083ZooaImOl0
0>_ooEWdo`20j_olFO?o003/ooeIl_l00=cooUT0[97o0:SAooaIm?l00>[ooEWe
o`20j_olFOGo003[ooeIm?l0P>[oo5Wco`00k?omFO;o003LooiI0:b1on7oo5Wd
o`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_olFO?o003/ooeIl_l00=cooUT0
[87ohOolFOCo003ZooeImOl0P>[oo5Weo`00joomFOCo083ZooaIlol00>cooEWb
o`00g?onF@2/TOl0Z=7oo5Wdo`00j_omFOGo083ZooaImOl00>_ooEWdo`20j_ol
FO?o003/ooeIl_l00=cooUT0[87ohOolFOCo003ZooeImOl0P>[oo5Weo`00joom
FOCo083ZooaIlol00>cooEWbo`00g?onF@2/POoQooaIm?l00>[ooEWeo`20j_ol
FOGo003[ooeIm?l0P>[oo5Wco`00k?omFO;o003LooiI0:bAo`2@dOolFOGoi`3n
FOGoj03mFOKoi`01FEWdonP0oEWconT00EUIl_l00=cooUT0[87ohOolFOGoi`3n
FOGoj03mFOKoi`01FEWdonP0oEWconT00EUIl_l00=cooUT0[87ohOolFOGoi`3n
FOGoj03mFOKoi`01FEWdonP0oEWconT00EUIl_l00=cooUT0[97o09cAooaImOl0
0>WooEWeo`20j_olFOKo003ZooeIm?l0P>[oo5Wco`00k?omFLcooUT0[87ohOol
FOGo003YooeImOl0P>[oo5Wfo`00j_omFOCo083ZooaIlol00>cooEW<ooiI0:b1
on7oo5Weo`00jOomFOGo083ZooaIm_l00>[ooEWdo`20j_olFO?o003/ooeIc?on
F@2/TOl0Z=7oo5Wfo`00j?omFOKo003YooaImol00>WooEWeo`00jOolFOGo0H20
joomFO;ofh03;EUI[87ohOolFOKo003XooeIm_l00>Woo5Wgo`00jOomFOGo003Y
ooaImOl1P83[ooeIl_oKP0<]FEV/POoQooaIm_l00>SooEWfo`00jOolFOOo003Y
ooeImOl00>Woo5Weo`60P>_ooEWbom^00beIFJbAo`2HdOolFOOo003WooeImol0
0>Soo5Who`00j?omFOKo003XooaImOl00>[ooEWco`00POngooaImol00>OooEWg
o`00j?olFOSo003XooeIm_l00>Soo5Weo`00j_omFO?o0021okOoo5Wgo`00ioom
FOOo003XooaIn?l00>SooEWfo`00j?olFOGo003ZooeIlol0087oiol0V=7oo5Wh
o`20i_omFOOo003XooaIn?l00>SooEWfo`00j?olFOKo003YooeIlol0087o]ool
FOSo083VooeImol00>Soo5Who`00j?omFOKo003XooaIm_l00>WooEWco`00POng
ooaIn?l0P>KooEWgo`00j?olFOSo003XooeIm_l00>Soo5Wfo`00jOomFO?o0021
onOo09SAooaIn?l0P>KooEWho`00ioolFOWo083WooeImol00>Ooo5Wgo`00j?om
FOCo0021okKoo5Who`20i_omFOSo003WooaInOl0P>OooEWgo`00ioolFOOo003X
ooeIm?l0087o]_olFOSo083VooeIn?l00>Ooo5Wio`20ioomFOOo003WooaImol0
0>SooEWdo`00POoVo`2HdOolFOSo083VooeIn?l00>Ooo5Wio`20ioomFOOo003W
ooaImol00>SooEWeo`20POneooaIn?l0P>KooEWho`00ioolFOWo083WooeImol0
0>Ooo5Wgo`00j?omFOGo0821okGoo5Who`20i_omFOSo003WooaInOl0P>OooEWg
o`00ioolFOOo003XooeImOl0P87oiOl0V=7oo5Who`20i_omFOWo003VooaInOl0
P>OooEWho`00i_olFOSo003WooeImOl0P87o]OolFOSo083VooeInOl00>Koo5Wi
o`20ioomFOSo003VooaIn?l00>OooEWeo`20POneooaIn?l0P>KooEWio`00i_ol
FOWo083WooeIn?l00>Koo5Who`00ioomFOGo0821onGo09SAooaInOl00>GooEWj
o`00iOolFO[o003VooeInOl00>Goo5Wio`20i_omFOGo0821okGoo5Wio`00iOom
FO[o003UooaIn_l00>KooEWio`00iOolFOWo083VooeImOl0P87o]OolFOWo003U
ooeIn_l00>Goo5Wjo`00i_omFOWo003UooaInOl0P>KooEWeo`20POoUo`2TdOol
FO[o003TooeInol1P83UooaInol1P83VooeIn_l1P83UooaInOl0P>KooEWfo`60
`87o]OolFO[o003TooeInol1P83UooaInol1P83VooeIn_l1P83UooaInOl0P>Ko
oEWfo`60`87o]OolFO[o003TooeInol1P83UooaInol1P83VooeIn_l1P83UooaI
nOl0P>KooEWfo`60`87oiOl0V=7oo5Wko`00hoomFO_o003TooaInol00>GooEWj
o`00i?olFO[o003UooeImol0087o/oolFO_o003SooeInol00>Coo5Wko`00iOom
FO[o003TooaIn_l00>GooEWgo`00POncooaInol00>?ooEWko`00i?olFO_o003U
ooeIn_l00>Coo5Wjo`00iOomFOOo0021on?o09SAooaInol00>?ooEWlo`20hool
FOco003TooeInol0P>?oo5Wjo`00iOomFOOo0021ok?oo5Wko`00hoomFOco083S
ooaIo?l00>CooEWko`20hoolFO[o003UooeImol0087o/oolFO_o003SooeIo?l0
P>?oo5Wlo`00i?omFO_o083SooaIn_l00>GooEWgo`00POoSo`20dOolFMcooEWl
o`20hoolFOco003TooeInol0P>?oo5WMooeIn?l0087o/_olFMcooEWlo`20hool
FOco003TooeInol0P>?oo5WMooeIn?l0087o/_olFMcooEWlo`20hoolFOco003T
ooeInol0P>?oo5WMooeIn?l0087oh_l0G=7oo5WLooeIgOolFMkooEWLooaIgOom
FOSo0021ok;oo5WLooeIgOolFMkooEWLooaIgOomFOSo0021ok;oo5WLooeIgOol
FMkooEWLooaIgOomFOSo0021on;o03:1omOooEWLooaIgOomFH7oPOn^ooeIg?ol
FMgooEV1oh7o[_omFMcoo5WMooeIPOoHo`0VPOn/o`00fOl0087oPOn2o`00fOl0
087oPOn2o`00fOl0087oeol0<X7onol0P;?o003Io`00POn1om7o082co`00fOl0
087oPOoAo`20/ol00=Wo0021omOo03j1o`;oo`3no`00/ol00=Wo0021oh7oeOl0
0?ko002co`00fOl0087oPOoEo`00o_l00;?o003Io`00POoGo`0nPOl2ool0o_l0
0;?o003Io`00POn1omGo003no`00/ol00=Wo0021oh7oeOl00?ko002co`00fOl0
087oeol0?X7o0_oo0?ko002co`00fOl0087oPOoEo`00o_l00;?o003Io`00POn1
omGo003no`00/ol00=Wo0021omOo03j1o`;oo`3no`00/ol00=Wo0021oh7oeOl0
0?ko002co`00fOl0087oPOoEo`00o_l00;?o003Io`00POoGo`0nPOl2ool0o_l0
0;?o003Io`00POn1omGo003no`00/ol00=Wo0021oh7oeOl00?ko002co`00fOl0
087oeol0;87o0_oo0?ko0021oh7oPOoMo`00o_l0087oPOn1omgo003no`00POn1
omoo02b1o`;oo`3no`00POn1oh7ogOl00?ko0021oh7oPOoMo`00o_l0087oPOoO
o`0PPOl2oon0POn1oh7ofOl0P87oPOn1omWo0821oh7ofol0587oPOn1oh7oPOn1
oh7oPOn1ohKo01B1oh7oPOn1oh7oPOn1oh7oPOn6o`0_POnco`9gA:W>o`6YGX7o
POn@o`9gA:W>o`6YGX7oPOn@o`9gA:W>o`6YGX7og_l0?X7o/ol4E@00A=gCo`CM
Ma00:h7oPOn@o`AE0014gM?o1=eg400[POn1oi3o15D004CMdol4gGL@02^1omko
05n1ooGo0ZU4Ml7o1]f72014Z@3Io`L0ZD@00127kX7oPOoBo`:YA7O1o`KMQ`P0
A:T0fOl70:U4000@Qnj1oh7od_l2ZDAg`Ol6gHL804BY0=Wo1`2YA00048O^POoN
o`1_R?l2^dBYm?l5gGL@001E_ol1gEGn001gfol0^oh00EG<POn1on;o0[]4ZOCo
1Meg4000EKoo0MeEoP00Mm_o0;_n005Ec87oPOoRo`:kA:Wdo`GMMa0005Foo`7M
EOh007OKo`2koP01ELb1om_o07:8o`WEKd@@?6nRj_n0o_l708Pl:fJ8`nkAonP0
fol0P>T0POn1ooGo2ME_A10lKj;Zoh3no`L0R3`[IXS3k]7oj03Ko`20j@21oh7o
mOl9eFm443a_X^[oP?ko1`28?2]VR<?^dOoX0=_o083Y087ok_l0KhCo1KYE00Qg
0?koj@00P<oo0MeEoP00Mm_o0;_n005Ec87oPOoNo`FjE@08M`3nonT0083?o`7M
EOh007OKo`2koP01ELb1oh7og_l5^UD027L0o_oY0020col1gEGn001gfol0^oh0
0EG<POoKo`1YUooX0?koj@00P=7o1]f72014Z@3Io`L0ZD@00127kX7oPOodonP0
o_oY0020dOl6gHL804BY0=Wo1`2YA00048O^POn1ooCoj03nonT0083Ao`KMQ`P0
A:T0fOl70:U4000@Qnj1omko07:GonP0o_l40100ELbno`ME0014gOoo0=Wo1`3o
omeg400[POn1ooCoj03no`@0401Ec;ko1eD004CMool0fOl70?oogGL@02^1oh7o
m?oX0?ko100@05G<__l7E@00A=goo`3Io`L0oooMMa00:h7og_l0PHCo1KYE00Qg
0?ko1`3oM`0048OM`Ol2MdBYoOl00=Wo003lo`6YGX7oPOoQo`FjE@08M`3no`L0
ogL00127gL7o0WM4ZOgo003Io`00o?l1ZEj1oh7ohOl5^UD027L0o_l70?mg000@
Qmg1o`9gA:Wmo`00fOl00?co0JUNPOoNo`1JQol8gHL@0014e?l0o_l80?oogGL@
001EPOn1oh7okOl8gHL@0014e?l0o_l80?oogGL@001EPOn1oh7okOl8gHL@0014
e?l0o_l80?oogGL@001EPOn1onOo05N8o`FZ000@Mmgno`00o_l00?co0ZU4Mh7o
POn1onko1JX0011ggOko003no`00o?l2ZDAgPOn1oh7ok_l5ZP0047OMo_l00?ko
003lo`:YA7N1oh7oiol0<8So0]fRe?_o0821oh7oPOoRo`;MX]Cko`20POn1oh7o
h_l2gJ;Dnol0P87oPOoKo`0DPOn1oh7oPOn1oh7oPOn1oh7oQ_l0=H7oPOoeo`5^
4?h00R5VkX7oPOn1on3o0Fh@oP028FK^POn1oh7oh?l1KQ3n008QI^j1onco04B1
oo3o0KX0R_l9c240I_oME@00C87oPOoKo`6j08[o2L`Q06KogED004b1oh7ofol1
^P2:o`W<8@1VomeE001<POo/o`17POo`o`4b08_o0md004Cmo`<b002jPOn1omco
0C80Rol3g@00A?go0c800;Z1oh7og?l1<P2;o`?M0014oOl3<P00^X7okOl0HX7o
lOl2^P00_ol00=Wo003go`=40020oOl3V000A87oPOoMo`:j002oo`00fOl00?Oo
0d@0083mo`>H0014POn1omgo0[X00;oo003Io`00mol3A000P?go0iP004B1ongo
05n1oo;o0?On0;oo003Io`00moon0020oOl3c000487oPOoNo`3goP2oo`00fOl0
0?OooP00P?go0l`00121oh7og_l0moh0_ol00=Wo003gooh0083mo`?<000@POo]
o`1RPOoko`00nOl0R?h0_ol00=Wo003gooh0083looh0POn1onOo003io`28oP2o
o`00fOl00?OooP00P?cooP21oh7oiol00?Wo08Sn0;oo003Io`00moon0020o?on
087okOl0Ph7o0_oo0?ko003ko`:ZG@Cn0?j009k3o`00fOl00?Oo0lb0P>Klooh0
POn1on_o003no`00nol2ZUd4oP3nP02N`ol00=Wo003go`?<P83Vo?on087oPOo[
o`00o_l00?_o0ZYM1?h0oX00W/?o003Io`00mol3c820i_cooP21ongo06R1o`;o
o`3no`00nOl0P?h0_ol00=Wo003ao`;MQb7n087oPOo[o`00o_l00?Wo083n0;oo
003Io`00lOl2gHLQoP21oh7ojol00?ko003io`20oP2oo`00fOl00?7o0]f78Oh0
POo]o`1^POl2ool0o_l00?Wo083n0;oo003Io`00lol4ZD@0EK[n087oPOo[o`00
o_l00?Wo083n0;oo003Io`00lol4ZD@0EK[n087oPOo[o`00o_l00?Wo083n0;oo
003Io`00lol4ZD@0EK[n087okOl0LH7o0_oo0?ko003io`20oP2oo`00fOl00?Co
1E@0EMgoooh0POn1on_o003no`00nOl0P?h0_ol00=Wo003do`ED05GMooon087o
POo[o`00o_l00?Wo083n0;oo003Io`00m?l5E01EgOoooP21ongo05V1o`;oo`3n
o`00nOl0P?h0R_l3c240^_gooP21oh7ojol00?ko003io`20oP2:o`?<8@2joOon
087oPOo[o`00o_l00?Wo083n08[o0l`Q0;[mooh0POo]o`1IPOl2ool0o_l00?Wo
083n08_o0iP006Klooh0POn1on_o003no`00nOl0P?h0Rol3V000I_cooP21oh7o
jol00?ko003io`20oP2;o`>H001Vo?on087okOl0D87o0_oo0?Go083n08co0;[n
003<o?on087oPOo[o`00mOl0P?h0S?l0^_h00<clooh0POn1on_o003eo`20oP2<
o`2joP00c?cooP21ongo04B1oo;o083n08co02;n003ko?on087oPOoNo`20oP2<
o`0RoP00nocooP21oh7og_l0P?h0S?l08_h00?_looh0POo]o`0nPOobo`20oP2<
ood0o?l0k_h0POn1omko083n08coo@3lo`3^oP21oh7og_l0P?h0S?om0?co0>kn
087okOl0CH7ol_l0P?h0S?l08Oh00<?no`7M8Oh0POn1omko083n08co027n0033
o_l1gB7n087oPOoNo`20oP2<o`0QoP00`oko0MdQoP21ongo05V1oo;o083n08co
07On00E4k^ig06Kn00:YgEF1oh7ohOl0P?h0S?l0Moh01DC^kWL0I_h00ZWMEH7o
POoQo`20oP2<o`1goP05A>k^M`1VoP02ZMeEPOo`o`1@POobo`20oP2;o`0Qo003
8Lco8Oh00A3<POn1on7o083n08_o027l00<Qc?lQoP014<b1oh7ohOl0P?h0Rol0
8O`00b7<ob7n004@c87ol?l0D87ol_l0P?h0R_l4Ma00<YSno`C<225gkX7oPOoP
o`20oP2:o`Ag400bV?ko1<`88GO^POn1on3o083n08[o17L@03:Ho_l4c0PQMnj1
onoo02J1oo;o083n087oPOn1omco083n087oPOn1omco083n087oPOo[o`0/POob
o`24oP00iX7oPOn1omgo08Cn003VPOn1oh7ogOl0Q?h00>J1oh7ok?l0=H7ol_l0
Z_h00dC^kUj1oh7oPOoPo`2ZoP03A>k^GX7oPOn1on3o0:[n00=4k^iNPOn1onoo
02b1oo;o0>Kk0028POn1oh7oh?l0i_/008R1oh7oPOoPo`3Vn`00R87oPOo_o`0_
POoao`G<A000<YR1oh7oPOoNo`G<A000<YR1oh7oPOoNo`G<A000<YR1oh7ok_l0
587oPOn1oh7oPOn1oh7oPOn1ohKo01B1oh7oPOn1oh7oPOn1oh7oPOn6o`0DPOn1
oh7oPOn1oh7oPOn1oh7oQ_l0587oPOn1oh7oPOn1oh7oPOn1ohKo01B1oh7oPOn1
oh7oPOn1oh7oPOn6o`0DPOn1oh7oPOn1oh7oPOn1oh7oQ_l00?l\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{251, 254.438},
  ImageMargins->{{284, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0009]l0@0005P0000?00003`0005H1001S0@00
00000000000e9@00g2H00215CDH00040O9/00=T300050000000000000000000000@00003000>0@00
b`0004H0001X=@00G3D004M4BD<1002000<006Z9H^d00000A3D000402@000j8J000601`0000000D0
000;0_ooool50000308K0@l1100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@040000104700@000040@d0100002d10`040000l04000P0003j0P00
0P02000000840000;@4000P0000U0`80eP1A0>00@@0800009@<20>00?`3P03P0200002D30P3F04l0
eP1700P0000U0`80eP170>00>@040000;@4300@0003`0@0020000?X20001004000000P@0000]0@00
200002D30P3O03H0g`0]00@0000]0@<010000?0100080000nP8000800P000002100002d100080000
9@<20=H0A@3F03h0200002D30P3F03h0h00`00@0000]0@<010000?0100080000nP8000400@000002
100002d1000800009@<20=l0;03O02@0100002d10`040000l04000P0003j0P000P02000000840000
;@4000P0000U0`80eP0l0=H0=P0800009@<20=H0=@3P02L0100002d10`040000l04000P0003j0P00
0@01000000840000;@4000P0000U0`80g`0T0=l06`040000;@4300@0003`0@0020000?X200020080
00000P@0000]0@00200002D30P3F03@0eP0^00P0000U0`80eP0]0>007@040000;@4300@0003`0@00
20000?X20001004000000P@0000]0@00200002D30P3O01/0g`0B00@0000]0@<010000?0100080000
nP8000800P000002100002d1000800009@<20=H0;03F02D0200002D30P3P01D0oP0E00P0000U0`80
eP0T0>005@0800009@<20<`0H03F0540200002D30P3F0500eP1700P0000U0`80c01N0<`0E`080000
9@<20<`0E`3F04P0100002d10`040000l04000P0003j0P000@01000000840000;@4000P0000U0`80
eP150=H0?@040000;@4300@0003`0@0020000?X20002008000000P@0000]0@00200002D30P3<05D0
c01?00P0000U0`80c01>0=H0?`040000;@4300@0003`0@0020000?X20001004000000P@0000]0@00
200002D30P3F03`0eP0d00@0000]0@<010000?0100080000nP8000800P000002100002d100080000
9@<20<`0C@3<04D0200002D30P3<04D0eP0f00@0000]0@<010000?0100080000nP8000400@000002
100002d1000800009@<20=@0<`3D02/0100002d10`040000l04000P0003j0P000P02000000840000
;@4000P0000U0`80c0130<`0?00800009@<20<`0?03F02h0100002d10`040000l04000P0003j0P00
0@01000000840000;@4000P0000U0`80e00Z0=@08`040000;@4300@0003`0@0020000?X200020080
00000P@0000]0@00200002D30P3;03/0b`0c00P0000U0`80eP0U0?@09@0800009@<20</0<`3F02D0
200002D30P3206l0c01P00P0000U0`80c01O0<`0E`0800009@<20<80K@3206H0200002D30P3206H0
c01G00@0000]0@<010000?0100080000nP8000400@000002100002d1000800009@<20<X0E03:04d0
100002d10`040000l04000P0003j0P000P02000000840000;@4000P0000U0`80`P1U0<80GP080000
9@<20<80G@3<04l0100002d10`040000l04000P0003j0P000@01000000840000;@4000P0000U0`80
bP1<0<X0@`040000;@4300@0003`0@0020000?X20002008000000P@0000]0@00200002D30P3205`0
`P1E00P0000U0`80`P1D0<`0A@040000;@4300@0003`0@0020000?X20001004000000P@0000]0@00
200002D30P3:04<0bP0j00@0000]0@<010000?0100080000nP8000800P000002100002d100080000
9@<20<80D`3204d0200002D30P3204`0b`0l00@0000]0@<010000?0100080000nP8000400@000002
100002d1000800009@<20<X0>@3:0380100002d10`040000l04000P0003j0P000P02000000840000
;@4000P0000U0`80`P1:0<80@`0800009@<20</0=03Z03@0200002D30P3204<0b`0d00@0000]0@<0
10000?0100080000nP8000400@000002100002d1000800009@<20<40K@3106D0200002D30P3006@0
`01L00@0000]0@<010000?0100080000nP8000800P000002100002d1000800009@<20;P0K@3205h0
100002d10`040000l04000P0003j0P000@01000000840000;@4000P0000U0`80`01K0<00D`040000
;@4300@0003`0@0020000?X20002008000000P@0000]0@00200002D30P2g06/0]`1U00P0000U0`80
]`1U0<80E@040000;@4300@0003`0@0020000?X20001004000000P@0000]0@00200002D30P300580
`01;00@0000]0@<010000?0100080000nP8000800P000002100002d1000800009@<20;L0H`2g05/0
200002D30P2g05/0`P1=00@0000]0@<010000?0100080000nP8000400@000002100002d100080000
9@<20<00B@300440100002d10`040000l04000P0003j0P000P02000000840000;@4000P0000U0`80
]`1I0;L0DP0800009@<20<80@`3P04<0200002D30P2g0580`P1300@0000]0@<010000?0100080000
nP8000400@000002100002d1000800009@<20;L0J`2g06<0200002D30P2f0680]P1J00@0000]0@<0
10000?0100080000nP8000800P000002100002d1000800009@<20:h0J`2g05`0100002d10`040000
l04000P0003j0P000@01000000840000;@4000P0000U0`80]P1I0;H0D@040000;@4300@0003`0@00
20000?X20002008000000P@0000]0@00200002D30P2]06T0[@1S00P0000U0`80]`1C0=H0D`080000
9@<20:d0HP2g05<0200002D30P0F06`0=01/00P0000U0`80=@1/0540K00800009@<20580K01_06`0
200002D30P1a06`0SP1/00P0000U0`80S`1/0:/0K0040000;@4300@0003`0@0020000?X200010040
00000P@0000]0@00200002D30P0D06T0501R00P0000U0`80<P1Y0380HP040000;@4300@0003`0@00
20000?X20002008000000P@0000]0@00200002D30P0F06@0=01T00@0000]0@<010000?0100080000
nP8000400@000002100002d1000800009@<20500J@1@0680100002d10`040000l04000P0003j0P00
0P02000000840000;@4000P0000U0`80=@1T0540I0040000;@4300@0003`0@0020000?X200010040
00000P@0000]0@00200002D30P1_06T0K`1R00@0000]0@<010000?0100080000nP8000800P000002
100002d1000800009@<20540I01_06@0100002d10`040000l04000P0003j0P000@01000000840000
;@4000P0000U0`80K`1Y06l0HP0800009@<208d0J@2=0680100002d10`040000l04000P0003j0P00
0P02000000840000;@4000P0000U0`80L@1T08h0I0040000;@4300@0003`0@0020000?X200010040
00000P@0000]0@00200002D30P2=06T0S@1Q00P0000U0`80Z`1Y0:/0HP040000;@4300@0003`0@00
20000?X20002008000000P@0000]0@00200002D30P2?06@0Z`1T00P0000U0`80[@1T0<X0I0040000
;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@180180?P0R05`08P1W0180
B00B00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<504P04P0n0280
G00R06L04P180180200002D30P190180B@0;00P0000U0`80I`0B06L02`040000;@4300@0003`0@00
20000?X21@000000oooo0P@0000]0@003P0002@31@1W0180G00R07/08P250180I`0B00@0000]0@<0
10000?0100080000nP8000400@000002100002d1000>00009@<506L04P1L0280N`0R08D04P1W0180
200002D30P1W0180I`0:00P0000U0`80Q@0B08D02`040000;@4300@0003`0@0020000?X21@000000
oooo0P@0000]0@003P0002@31@250180N`0R09T08P2S0180Q@0B00@0000]0@<010000?0100080000
nP8000400@000002100002d1000>00009@<508D04P1k0280V@0R0:<04P250180200002D30P250180
Q@0:00P0000U0`80X`0B0:<02P040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00
3P0002@31@2S0180V@0R0;L08P310180X`0B00@0000]0@<010000?0100080000nP8000400@000002
100002d1000>00009@<50:<04P2I0280]`0R0<404P2S0180200002D30P2S0180X`0:00P0000U0`80
`@0B0<402P040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@310140
]`0Q0=H08@3P0140`@0A00@0000]0@<010000?0100080000nP8000400@000002100002d1000>0000
9@<50<404@2g0240eP0Q0>004@310140200002D30P310140`@0:00P0000U0`80h00B0>002P040000
;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@3P0140eP0Q0?@08@3n0140
h00A00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<50>004@3F0240
m00Q0?h04@3P0140200002D30P3P0140h00:00@0000]0@<010000?0100080000nP850000003oool2
100002d1000>000090<503h08@0c0340D@0a05`08@0n0240100002d10`040000l04000P0003j0P00
0@01000000840000;@4000h0000U0`D0?P0Q03<0<@1A0340G00Q03h08@0800009@<203h08P0n01T0
200002D30P1M0280G@0J00@0000]0@<010000?0100080000nP850000003oool2100002d1000>0000
90<505`08@1A0340L@0a07/08@1L0240100002d10`040000l04000P0003j0P000@01000000840000
;@4000h0000U0`D0G00Q0540<@1a0340N`0Q05`08@0800009@<205d08P1M01T0200002D30P1k0280
N`0I00@0000]0@<010000?0100080000nP850000003oool2100002d1000>000090<507/08@1a0340
S`0a09T08@1k0240100002d10`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0
N`0Q0740<@2?0340V@0Q07/08@0800009@<207/08P1k01T0200002D30P2I0280V@0I00@0000]0@<0
10000?0100080000nP850000003oool2100002d1000>000090<509T08@2?0300[@0`0;L08@2I0240
100002d10`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0V@0Q08l0<02]0300
]`0Q09T08@0800009@<20;L08P2g01T0100002d10`040000l04000P0003j0PD000000?ooo`840000
;@4000h0000T0`D0]`0Q0:d0<03<0300eP0Q0;L08@040000;@4300@0003`0@0020000?X200010040
00000P@0000]0@003P0002D31@2g0240[@0`0<`0<03F0240]`0Q00P0000U0`80eP0R0=H06@040000
;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@3F0240bP0`0>X0<03d0240
eP0Q00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<50=H08@3:0300
jP0`0?@08@3F0240200002D30P3F0280eP0I00@0000]0@<010000?0100080000nP850000003oool2
100002d1000>000090<503<0<00Y0440A`110540<00c0300100002d10`040000l04000P0003j0P00
0@01000000840000;@4000h0000U0`D0<`0`02T0@@170440D@0`03<0<00800009@<203<0<@0c02T0
200002D30P1B0340DP0Y00@0000]0@<010000?0100080000nP850000003oool2100002d1000>0000
90<50540<0170440IP110740<01A0300100002d10`040000l04000P0003j0P000@01000000840000
;@4000h0000U0`D0D@0`04L0@@1V0440L@0`0540<00800009@<20580<@1B02T0200002D30P1a0340
L@0Y00@0000]0@<010000?0100080000nP850000003oool2100002d1000>000090<50740<01V0440
Q01108l0<01a0300100002d10`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0
L@0`06H0@@240440S`0`0740<00800009@<208l0<@2?02T0100002d10`040000l04000P0003j0PD0
00000?ooo`840000;@4000h0000T0`D0S`0`08@0@@2S0440[@0`08l0<0040000;@4300@0003`0@00
20000?X20001004000000P@0000]0@003P0002D31@2?0300Q0110:<0@@2]0300S`0`00P0000U0`80
[00a0:`0:@040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@2/0300
XP110<00@@3:0300[00`00@0000]0@<010000?0100080000nP8000400@000002100002d1000>0000
9@<50:`0<02R0440`0110<X0<02/0300200002D30P2/0340[00Y00P0000U0`80bP0a0<X0:@040000
;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@3:0300`0110=l0@@3Z0300
bP0`00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<50<X0<0300440
g`110>X0<03:0300100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0
:@1101l0D@0m0540A`1102T0@@040000;@4300@0003`0@0020000?X20001004000000P@0000]0@00
3P0002D31@0Y04407`1A03d0D@170440:@1100P0000U0`80:@1102T0>@0800009@<204L0@@1703T0
200002D30P0O04l07`1900@0000]0@<010000?0100080000nP850000003oool2100002d1000>0000
90<504L0@00m0500F`1@06H0@0170400100002d10`040000l04000P0003j0P000@01000000840000
;@4000h0000U0`D0A`1003d0D01K0500IP1004L0@00800009@<206H0@@1V03T0100002d10`040000
l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0IP1005/0D01j0500Q01006H0@0040000
;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@1V0400F`1@07X0D0240400
IP1000P0000U0`80IP1006H0>@0800009@<208@0@02403T0100002d10`040000l04000P0003j0PD0
00000?ooo`840000;@4000h0000T0`D0Q01007X0D02H0500XP1008@0@0040000;@4300@0003`0@00
20000?X20001004000000P@0000]0@003P0002D31@240400NP1@09P0D02R0400Q01000P0000U0`80
Q01008@0>@0800009@<20:80@02R03T0100002d10`040000l04000P0003j0PD000000?ooo`840000
;@4000h0000T0`D0XP1009P0D02f0500`0100:80@0040000;@4300@0003`0@0020000?X200010040
00000P@0000]0@003P0002D31@2R0400V01@0;H0D0300400XP1000P0000U0`80`0100<00>@040000
;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@300400]P1@0=@0D03O0400
`01000@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<50<00@02f0500
e01@0=l0@0300400200002D30P300400`00i00@0000]0@<010000?0100080000nP850000003oool2
100002d1000>000090<501l0D00E0640<`1Q03d0D00O0500100002d10`040000l04000P0003j0P00
0@01000000840000;@4000h0000U0`D07`1@01D0H@0c0640?@1@01l0D00800009@<203d0D00m04P0
100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0?@1@03<0H@1A0640
F`1@03d0D0040000;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@0m0500
<`1Q0540H@1K0500?@1@00P0000U0`80?@1@03d0B00800009@<205`0D01L04P0100002d10`040000
l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0F`1@0500H@1`0640NP1@05/0D0040000
;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@1K0500D01Q0700H@1j0500
F`1@00P0000U0`80NP1@07X0B0040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00
3P0002@31@1j0500L01Q08h0H@2H0500NP1@00@0000]0@<010000?0100080000nP8000400@000002
100002d1000>00009@<507X0D01`0640SP1Q09P0D01j0500200002D30P1j0500NP1800P0000U0`80
V01@09P0B0040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@2H0500
SP1Q0:`0H@2f0500V01@00@0000]0@<010000?0100080000nP8000400@000002100002d1000>0000
9@<509P0D02>0640[01Q0;H0D02H0500200002D30P2H0500V01800P0000U0`80]P1@0;H0B0040000
;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@2f0500[01Q0<X0H@3D0500
]P1@00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<50;H0D02/0640
bP1Q0=@0D02f0500200002D30P2f0500]P1800@0000]0@<010000?0100080000nP850000003oool2
100002d1000>000090<501D0H00:0700:@1`03<0H00E0600100002d10`040000l04000P0003j0P00
0@01000000840000;@4000h0000U0`D05@1P00X0L00Y0700<`1P01D0H00800009@<201D0H00E05P0
200002D30P0b0600<P1H00@0000]0@<010000?0100080000nP850000003oool2100002d1000>0000
90<50380H00X0700AP1`0500H00b0600100002d10`040000l04000P0003j0P000@01000000840000
;@4000h0000U0`D0<P1P02P0L0160700D01P0380H00800009@<20500H01@05P0100002d10`040000
l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0D01P04H0L01U0700L01P0500H0040000
;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@1@0600AP1`06D0L01`0600
D01P00P0000U0`80L01P0700F0040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00
3P0002@31@1`0600I@1`08<0L02>0600L01P00@0000]0@<010000?0100080000nP8000400@000002
100002d1000>00009@<50700H01U0700P`1`08h0H01`0600200002D30P1`0600L01G00P0000U0`80
SP1P08h0E`040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@2>0600
P`1`0:80L02/0600SP1P00@0000]0@<010000?0100080000nP8000400@000002100002d1000>0000
9@<508h0H0230700XP1`0:`0H02>0600200002D30P2>0600SP1G00P0000U0`80[01P0:`0E`040000
;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@2/0600XP1_0<00K`3:0600
[01P00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<50:`0H02R06l0
`01_0<X0H02/0600100002d10`040000l04000P0003j0P00100405UIF@840000;@4000P0000U0`80
3P3T00h0JP0800009@<202`0i00/06X0200002D30P190>@0B@1Z00P0000U0`80I`3U06L0JP080000
9@<208H0i@2606X0200002D30P2T0>D0Y01Z00@0000]0@<010000?0100080000nP8000@010000002
100002d1000800009@<204/03P1X00h0200002D30P1Y00h0Q@0>00P0000U0`80QP0>0:@03P080000
9@<20:@03P3200h0200002D30P3200h0g`0>00P0000U0`80h00>0?d03P0800009@<20440701M01`0
200002D30P1O01`0O00L00P0000U0`80O@0L09T0700800009@<209/0702g01`0200002D30P2h01`0
e@0L00P0000U0`80eP0L0?<0700800009@<203H0:`1D02/0200002D30P1D02/0LP0[00P0000U0`80
L`0[08l0:`0800009@<20900:`2]02/0200002D30P2]02/0b`0[00P0000U0`80b`0[0>T0:`080000
9@<202`0>`1:03/0200002D30P1:03/0IP0k00P0000U0`80J00k08@0>`0800009@<208D0>`2S03/0
200002D30P2S03/0`@0k00P0000U0`80`@0k0=l0>`0800009@<20280B@0o04T0200002D30P1004T0
G01900P0000U0`80G@1907/0B@0800009@<207`0B@2H04T0200002D30P2I04P0]P1800P0000U0`80
]`180=D0B00800009@<201P0F00e05P0200002D30P0e05P0D`1H00P0000U0`80D`1H0700F0080000
9@<20780F02>05P0200002D30P2?05P0[01H00P0000U0`80[@1H0<X0F0040000;@4300@0003`0@00
20000?X200020080FEUI0P@0000]0@00200002D30P3n00`0o`2?00P0000U0`80m00K0?D0WP080000
9@<20>X0;03[0:h0200002D30P3P03/0h02m00P0000U0`80eP1:0=H0c@0800009@<20</0gP3;05T0
200002D30P0=06L0B@0=00@0000]0@<010000?0100080000nP8000800P1VIVH2100002d100080000
9@<20<80L@3m01<0200002D30P3208T0o`0Z00P0000U0`80`P2S0?h0A00800009@<20<<0_03n05d0
200002D30P330=@0o@1h00@0000]0@<010000?0100080000nP8000400@000002100002d100080000
9@<208<0R@2?07P0200002D30P2?07P0X@1h00P0000U0`80S`1h08l0K`0800009@<206<0R@1`07P0
200002D30P1`07P0PP1h00P0000U0`80L@1h0740K`0800009@<204H0R@1B07P0200002D30P1B07P0
H`1h00P0000U0`80D`1h05<0K`0800009@<202P0R@0d07P0200002D30P0d07P0AP1h00P0000U0`80
=01h03@0K`0800009@<200/0R@0F07P0200002D30P0F07P0:01h00P0000U0`805P1h01H0K`080000
9@<20:80RP2^07T0200002D30P2^07P0[`1`00P0000U0`80[P1i0</0N@0800009@<208<0XP2?0900
200002D30P2?0900X@2@00P0000U0`80S`2@08l0R00800009@<206<0XP1`0900200002D30P1`0900
PP2@00P0000U0`80L@2@0740R@0800009@<204H0XP1B0900200002D30P1B0900H`2@00P0000U0`80
D`2@05<0R@0800009@<202P0XP0c0900200002D30P0c0900AP2@00P0000U0`80=02@03@0R0080000
9@<200/0XP0F0900200002D30P0F0900:02@00P0000U0`805P2@01H0R00800009@<20:80X`2^0940
200002D30P2^0900[`2900P0000U0`80[P2A0</0T@0800009@<208<0_02?0:X0200002D30P2?0:T0
X@2Y00P0000U0`80S`2Y08l0X`0800009@<206<0_01`0:X0200002D30P1`0:X0PP2Z00P0000U0`80
L@2Z0740X`0800009@<204H0_01B0:X0200002D30P1B0:X0H`2Z00P0000U0`80DP2Z0580X`080000
9@<202P0_00c0:X0200002D30P0c0:T0AP2Y00P0000U0`80=02Y03@0X`0800009@<200/0_00F0:X0
200002D30P0F0:T0:02Y00P0000U0`805P2Y01H0X`0800009@<20:80_@2^0:/0200002D30P2^0:X0
[`2S00P0000U0`80[P2Z0</0ZP0800009@<208<0eP2?0<<0200002D30P2?0<<0X@3300P0000U0`80
S`3308l0^`0800009@<206<0eP1`0<@0200002D30P1`0<<0PP3300P0000U0`80L0330700^`080000
9@<204H0eP1B0<@0200002D30P1B0<<0H`3300P0000U0`80DP330580^`0800009@<202P0eP0c0<@0
200002D30P0c0<<0AP3300P0000U0`80=03303@0^`0800009@<200X0eP0F0<<0200002D30P0F0<<0
:03300P0000U0`805P3301H0^`0800009@<20:80e`2^0<D0200002D30P2^0<<0[`2l00P0000U0`80
[P340</0a00800009@<208/0i02?0=d0200002D30P2?0=d0X@3M00P0000U0`80S`3M08l0eP080000
9@<206X0i@1`0=d0200002D30P1`0=d0PP3M00P0000U0`80L03M0700eP0800009@<204d0i@1B0=d0
200002D30P1B0=d0H`3M00P0000U0`80DP3M0580eP0800009@<202l0i@0c0=d0200002D30P0c0=d0
AP3M00P0000U0`80=03M03@0eP0800009@<20180i00F0=d0200002D30P0F0=d0:03M00P0000U0`80
5P3M01H0eP0800009@<20:T0iP2]0=h0200002D30P2]0=d0[@3F00P0000U0`80[P3N0<T0gP080000
9@<20?@0:03n02P0200002D30P3Z03T0m00i00P0000U0`80g`180>X0B00800009@<20=@0F03O05P0
200002D30P3906P0e01X00P0000U0`80m0120?h0@P0800009@<20>X0D@3d0540200002D30P3O0680
jP1R00P0000U0`80e01a0=l0L@0800009@<20<T0PP3D0880200002D30P3d05/0oP1K00P0000U0`80
jP1[0?@0J`0800009@<20=l0NP3Y07X0200002D30P3D08/0g`2;00P0000U0`80b@2K0=@0V`080000
9@<20?@0M03n07@0200002D30P3Z08@0m02400P0000U0`80g`2D0>T0U00800009@<20=@0Y03O0:@0
200002D30P390;@0d`2d00P0000U0`80m02>0?h0SP0800009@<20>X0WP3d09h0200002D30P3O0:d0
j@2]00P0000U0`80e02m0=l0_@0800009@<20<T0c@3C0<d0100002d10`040000l04000P0003j0P00
100402HV9P840000;@4000P0000U0`803P2:0;l0RP0800009@<200h0X`2o0:<0200002D30P0>0;d0
_`2m00P0000U0`803P3D0;l0e00800009@<200l0LP300780100002d10`040000l04000P0003j0P00
0@01000000840000;@4000P0000U0`80A@3W04D0k`0800009@<204D0n@150?l0200002D30P190>L0
B@3_00P0000U0`80B@3i04T0o`0500002@800002100002h100040000;@4500@0003`0@8070000?/2
j?l00000002@0@000000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0
000Q1@40M?o`04h0200002D30P230>H0P`3^00P0000U0`80P`3h08<0oP0800009@<20:40iP2Q0>h0
200002D30P2Q0?P0X@3n00D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;Xo`00
0000090100000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`000245
0@1Qond0Z@040000;@4300@0003`0@0020000?X200020080FEUI0P@0000]0@00200002D30P0/06L0
I`0=00P0000U0`80BP1W08H03@0800009@<206P0I`2T00d0200002D30P2606L0`P0=00P0000U0`80
Y01W0>003@040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00100002d110040000
l04100L0003l0P0000000000100002d10@0>000090<504@0l@0i0?D0?@3a03T0k@140?40100002d1
0`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0A03a03T0m@0m0?40>@3]04@0
l@0800009@<203@0l00m0?40100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000h0
000T0`D0P@3_07H0l`1j0>l0MP3[0840k`040000;@4300@0003`0@0020000?X20001004000000P@0
000]0@003P0002D31@210>l0MP3c07X0k`1f0>/0P@3_00P0000U0`80K`3_07X0k`040000;@4300@0
003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@1:0?00E@3]0540l01E0?@0BP3`00@0
000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<504X0l01E0>d0D@3`05D0
m01:0?00200002D30P1A0?00FP3a00@0000]0@<010000?0100080000nP850000003oool2100002d1
000>000090<50:40k`2/0>`0Z03_0:`0l`2Q0>l0100002d10`040000l04000P0003j0P000@010000
00840000;@4000h0000U0`D0X@3_0:`0k02X0>l0[03c0:40k`0800009@<20:P0k`2b0?00100002L1
ool40000l04000@0003`0@4010000?010P040000l04300@0003`0@@010000?011@030000000A0000
300000P0000;0000400006T1001h0@002@000100001Y0@00N04000X0000@0000ooooooooool90000
400000l1000K0@004P0000`0000100008@0000P0000D0000300000L0000D0000300000d0000V0000
70000040000000000P000080000000029@0000`0000100009@0000`000000020E`0002@0000M0@00
E`0002d1001^00000P000=H0D@3P0440E`0002@0000[0@00B`0002d1001F00000P000>00?`3P03P0
E`0002@0000M0@00G`0001l1001[00000P000=H0C`3F04L0E`0002@0000M0@00C00002d1001Q0000
0P000=H0A`3P03T09P0001`000020000000000400001000000000RD0000<00000P0002P0000<0000
0@0002H0000L00000@000000000100000@000000008U000030000040001G0000900002X1000m0000
:P4004T000020000g`0f0=l0;@0U000030000080000X000030000040000V00007000004000000000
0P000080000000029@0000`000010000E`0002@0000M0@00D`0001l1001N00000P000=H0A@3F03h0
E`0002@0000M0@00@00002d1001E00000P000=H0?P3P03009@0000`000020000:00000`000010000
9P0001`000010000000000400001000000000RD0000<00000@0005L0000T0000:P400340000Z0@00
?0000080003O02`0g`0T02D0000<00000P0002P0000<00000@0002H0000L00000@00000000020000
0P000000008U000030000040001G0000900001d1001800007`40058000020000eP0l0=H0=P1G0000
900001d1000d0000;@4004T000020000eP0e0>009`0U000030000080000X000030000040000V0000
70000040000000000@000040000000029@0000`000010000E`0002@0000Z0@009@0002X1000a0000
0P000=l0903O01/09@0000`000020000:00000`0000100009P0001`0000100000000008000020000
00000RD0000<00000@0005L0000T00007@4003d0000O0@00A`000080003F03@0eP0^05L0000T0000
7@4002L0000]0@00?P000080003F02d0h00M02D0000<00000P0002P0000<00000@0002H0000L0000
0@000000000100000@000000008U000030000040001G0000900002X1000I0000:P4002D000020000
g`0K0=l04P0U000030000080000X000030000040000V000070000040000000000P00008000000002
9@0000`000010000E`0002@0000M0@00<@0001l1000m00000P000=H0;03F02D0E`0002@0000[0@00
700005D1000N00000P000>005@3n01D0E`0002@0000M0@00700002d1000b00000P000=H0903P01D0
E`0002@0000@0@00K00001l1002200000P000<`0H03F0540E`0002@0000M0@00G`0001l1001]0000
0P000=H0D03F04L0E`0002@0000@0@00M0000181001o00000P000<`0GP3<05L0E`0002@0000@0@00
H00001l1001f00000P000<`0E`3F04P09@0000`000020000:00000`0000100009P0001`000010000
000000400001000000000RD0000<00000@0005L0000T00007P400580000N0@00G@000080003F04D0
eP0m02D0000<00000P0002P0000<00000@0002H0000L00000@000000000200000P000000008U0000
30000040001G000090000101001Y00004P4007<000020000c01E0<`0C`1G000090000101001D0000
7`4006X000020000c01>0=H0?`0U000030000080000X000030000040000V00007000004000000000
0@000040000000029@0000`000010000E`0002@0000N0@00AP0001h1001A00000P000=H0?03F03@0
9@0000`000020000:00000`0000100009P0001`000010000000000800002000000000RD0000<0000
0@0005L0000T0000404005`0000B0@00J@000080003<04d0c01505L0000T0000404004P0000O0@00
GP000080003<04D0eP0f02D0000<00000P0002P0000<00000@0002H0000L00000@00000000010000
0@000000008U000030000040001G0000900001`1000j0000704004D000020000e00c0=@0:`0U0000
30000080000X000030000040000V000070000040000000000P000080000000029@0000`000010000
E`0002@0000@0@00D0000181001K00000P000<`0@`3<03`0E`0002@0000@0@00?@0001l1001B0000
0P000<`0?03F02h09@0000`000020000:00000`0000100009P0001`0000100000000004000010000
00000RD0000<00000@0005L0000T000070400300000L0@00>@000080003D02X0e00S02D0000<0000
0P0002P0000<00000@0002H0000L00000@000000000200000P000000008U000030000040001G0000
900000l1001400004@40054000020000b`0k0</0<`1G0000900001d1000a0000A`4003<000020000
eP0U0?@09@1G0000900000l1000a00007`4004H000020000b`0c0=H09@1G0000900000<100200000
4P4009H000020000`P1_0<`0H01G000090000101001d00004P40084000020000c01O0<`0E`1G0000
900000<1002800001@4009<000020000`P1]0<80IP1G0000900000<1001d00004P4008X000020000
`P1V0<`0E`0U000030000080000X000030000040000V000070000040000000000@00004000000002
9@0000`000010000E`0002@0000>0@00J00000h1001a00000P000<X0E03:04d09@0000`000020000
:00000`0000100009P0001`000010000000000800002000000000RD0000<00000@0005L0000T0000
0`4007d000050@00R@000080003206D0`P1N05L0000T00000`4006T0000B0@00OP000080003205d0
c01?02D0000<00000P0002P0000<00000@0002H0000L00000@000000000100000@000000008U0000
30000040001G0000900000h1001J00003P4006H000020000bP1<0<X0@`0U000030000080000X0000
30000040000V000070000040000000000P000080000000029@0000`000010000E`0002@000030@00
L@0000D1001m00000P000<80G03205D0E`0002@000030@00G0000181001b00000P000<80E03<04D0
9@0000`000020000:00000`0000100009P0001`000010000000000400001000000000RD0000<0000
0@0005L0000T00003P4004h0000>0@00FP000080003:04<0bP0j02D0000<00000P0002P0000<0000
0@0002H0000L00000@000000000200000P000000008U000030000040001G0000900000<1001W0000
1@40074000020000`P1C0<80C@1G0000900000<1001@00004@4006L000020000`P1<0</0?00U0000
30000080000X000030000040000V000070000040000000000@000040000000029@0000`000010000
E`0002@0000>0@00A00000h1001=00000P000<X0>@3:03809@0000`000020000:00000`000010000
9P0001`000010000000000800002000000000RD0000<00000@0005L0000T00000`4005T000050@00
I@000080003204X0`P1305L0000T00003`4004D0000j0@00A`000080003;03@0jP0d05L0000T0000
0`4004D0000A0@00F`000080003204<0b`0d02D0000<00000P0002P0000<00000@0002H0000L0000
0@000000000100000@000000008U000030000040001G000090000081002800000P40098000020000
`@1]0<40I@1G000090000041001l00000@4008H000020000`01T0<00G00U000030000080000X0000
30000040000V000070000040000000000P000080000000029@0000`000010000E`0002@0003e0000
O@0000D1002C00000P000;P0K@3205h09@0000`000020000:00000`0000100009P0001`000010000
000000400001000000000RD0000<00000@0005L0000T00000@40070000010@00NP000080003005/0
`01C02D0000<00000P0002P0000<00000@0002H0000L00000@000000000200000P000000008U0000
30000040001G000090000?@000270000mP00090000020000]`1[0;L0I@1G000090000?@0001a0000
1@4008T000020000]`1U0<80E@0U000030000080000X000030000040000V00007000004000000000
0@000040000000029@0000`000010000E`0002@000010@00I@000041001^00000P000<00DP3004/0
9@0000`000020000:00000`0000100009P0001`000010000000000800002000000000RD0000<0000
0@0005L0000T0000m00007T0003f0000QP000080002g06<0]`1K05L0000T0000m00006L000050@00
N`000080002g05/0`P1=02D0000<00000P0002P0000<00000@0002H0000L00000@00000000010000
0@000000008U000030000040001G000090000041001H00000@40068000020000`0190<00@@0U0000
30000080000X000030000040000V000070000040000000000P000080000000029@0000`000010000
E`0002@0003d0000K@000?H0001i00000P000;L0F@2g0580E`0002@000030@00F@0002d1001K0000
0P000<80@`3P04<0E`0002@0003d0000F@0000D1001_00000P000;L0DP3204<09@0000`000020000
:00000`0000100009P0001`000010000000000400001000000000RD0000<00000@0005L0000T0000
m@0008D0003e0000S`000080002g06/0]`1S05L0000T0000m00007T0003d0000Q0000080002f0680
]P1J02D0000<00000P0002P0000<00000@0002H0000L00000@000000000200000P000000008U0000
30000040001G000090000>P0001k0000mP00090000020000[P1[0;L0G00U000030000080000X0000
30000040000V000070000040000000000@000040000000029@0000`000010000E`0002@0003d0000
K@000?@0001h00000P000;H0F@2f05409@0000`000020000:00000`0000100009P0001`000010000
000000800002000000000RD0000<00000@0005L0000T0000i`0008@0003Y0000SP000080002]06T0
[@1S05L0000T0000m00006l0000O0@00L@000080002g05<0eP1C05L0000T0000i`0006l0003f0000
Q@000080002]0680]`1C05L0000T00007P00090000180000TP000080000F06`0=01/05L0000T0000
A`000900001^0000TP000080000e06`0D@1/05L0000T0000KP000900002F0000TP000080001B06`0
K`1/05L0000T0000U`000900002o0000TP000080001a06`0SP1/05L0000T0000_`000900003V0000
TP000080002?06`0Z`1/02D0000<00000P0002P0000<00000@0002H0000L00000@00000000010000
0@000000008U000030000040001G0000900001`000240000700008d000020000501Y01@0HP1G0000
900004@000240000A00008d000020000<P1Y0380HP0U000030000080000X000030000040000V0000
70000040000000000P000080000000029@0000`000010000E`0002@0000N0000Q@0004P000270000
0P0001H0I00d06@09@0000`000020000:00000`0000100009P0001`0000100000000004000010000
00000RD0000<00000@0005L0000T0000K00008@0001/0000S@000080001@06T0D01R02D0000<0000
0P0002P0000<00000@0002H0000L00000@000000000200000P000000008U000030000040001G0000
900004L000250000KP0008L000020000=@1T0540I00U000030000080000X000030000040000V0000
70000040000000000@000040000000029@0000`000010000E`0002@0002E0000Q00009D0002=0000
0P0006l0J@1_06809@0000`000020000:00000`0000100009P0001`0000100000000008000020000
00000RD0000<00000@0005L0000T0000K00008D0002F0000Q`000080001A06@0K`1T02D0000<0000
0P0002P0000<00000@0002H0000L00000@000000000100000@000000008U000030000040001G0000
900009D000240000U@0008d000020000K`1Y06l0HP1G000090000;d000240000_@0008d000020000
S@1Y08d0HP0U000030000080000X000030000040000V000070000040000000000P00008000000002
9@0000`000010000E`0002@0002G0000Q@000;l0002700000P000740I02>06@09@0000`000020000
:00000`0000100009P0001`000010000000000400001000000000RD0000<00000@0005L0000T0000
_@000880002m0000S@000080002=06T0S@1Q05L0000T0000i@0008@0003U0000S@000080002[06T0
Z`1R02D0000<00000P0002P0000<00000@0002H0000L00000@000000000200000P000000008U0000
30000040001G000090000;l000250000iP0008L000020000S`1T0:/0I01G000090000>L000250000
3`4008L000020000[@1T0<X0I00U000030000080000X000030000040000V00007000004000050000
00000000003oool29@0000`000010000EP000300001D00006@0008/0000_00001@0004P04P0n0280
G00R06L04P1801809@0000`000020000:00000`0000100009P0001`0000100000000004000010000
00000RD0000<00000@0005L0000`0000E00001T0002;0000;`0000D000180180?P0R05`08P1W0180
B00B05L0000T0000H`000100001S00006@00008000190180B@0;05L0000T0000R`000100002;0000
6@000080001W0180I`0;02D0000<00000P0002P0000<00000@0002H0000L00000@0000D000000000
00000?ooo`8U000030000040001F0000<00007`0000I0000/`0002l000050000I`0B05`08P1k0280
Q@0B06L04P0U000030000080000X000030000040000V000070000040000000000@00004000000002
9@0000`000010000E`000300001l00006@000;<0000_00001@0006L04P1L0280N`0R08D04P1W0180
E`0002@0002;00003`0008/0000I00000P0006L04P1W00X0E`0002@0002c000040000;<0000I0000
0P0008D04P2500/09@0000`000020000:00000`0000100009P0001`0000100001@00000000000000
oooo0RD0000<00000@0005H0000`0000Y@0001T0003J0000;`0000D000250180N`0R09T08P2S0180
Q@0B02D0000<00000P0002P0000<00000@0002H0000L00000@000000000100000@000000008U0000
30000040001G0000<0000:D0000I0000fP0002l000050000Q@0B07/08P2I0280X`0B08D04P1G0000
90000;<0000?0000/`0001T000020000Q@0B08D02P1G000090000=X0000?0000fP0001T000020000
X`0B0:<02P0U000030000080000X000030000040000V0000700000400005000000000000003oool2
9@0000`000010000EP000300003=00006@000081000_00001@000:<04P2I0280]`0R0<404P2S0180
9@0000`000020000:00000`0000100009P0001`000010000000000400001000000000RD0000<0000
0@0005L0000`0000c@0001T000020@00;`0000D0002S0180V@0R0;L08P310180X`0B05L0000T0000
fP0000l0003J00006@000080002S0180X`0:05L0000T00000P4000l000020@006@00008000310180
`@0:02D0000<00000P0002P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U0000
30000040001F0000<0000?D0000H0000;04002d000050000`@0A0;L08@3F0240h00A0<404@0U0000
30000080000X000030000040000V000070000040000000000@000040000000029@0000`000010000
E`000300003e0000600002`1000]00001@000<404@2g0240eP0Q0>004@310140E`0002@000020@00
3`000081000H00000P000<404@3100X0E`0002@0000/0@003`0002`1000I00000P000>004P3P00X0
9@0000`000020000:00000`0000100009P0001`0000100001@00000000000000oooo0RD0000<0000
0@0005H0000`00007P4001P0001D0@00;@0000D0003P0140eP0Q0?@08@3n0140h00A02D0000<0000
0P0002P0000<00000@0002H0000L00000@000000000100000@000000008U000030000040001G0000
<00001h1000H0000E04002d000050000h00A0=H08@3d0240oP0A0>004@1G0000900002`1000?0000
;04001P000020000h00A0>002P0U000030000080000X000030000040000V00007000004000050000
00000000003oool29@0000`000010000EP00030000150000;@0007`0001200001@0003h08@0c0340
D@0a05`08@0n02409@0000`000020000:00000`0000100009P0001`0000100000000004000010000
00000RD0000<00000@0005L0000`0000A@0002d0001l0000@P0000D0000n0240<`0a0540<@1L0240
?P0Q05L0000T0000E00002<0001D0000;`000080000n0280?P0I05L0000T0000O@0002@0001m0000
;`000080001M0280G@0J02D0000<00000P0002P0000<00000@0002H0000L00000@0000D000000000
00000?ooo`8U000030000040001F0000<00006d0000]0000Y@00048000050000G00Q0540<@1a0340
N`0Q05`08@0U000030000080000X000030000040000V000070000040000000000@00004000000002
9@0000`000010000E`000300001]0000;@000:D0001200001@0005`08@1A0340L@0a07/08@1L0240
E`0002@0001m00008`0007d0000_00000P0005d08P1M01T0E`0002@0002U00008`000:D0000_0000
0P0007/08P1k01T09@0000`000020000:00000`0000100009P0001`0000100001@00000000000000
oooo0RD0000<00000@0005H0000`0000V00002d0003=0000@P0000D0001k0240L@0a08l0<@2I0240
N`0Q02D0000<00000P0002P0000<00000@0002H0000L00000@000000000100000@000000008U0000
30000040001G0000<00009P0000]0000c@00048000050000N`0Q0740<@2?0340V@0Q07/08@1G0000
90000:D0000S0000Y@0002l000020000N`0R07/06@1G000090000<d0000S0000c@0002l000020000
V@0R09T06@0U000030000080000X000030000040000V0000700000400005000000000000003oool2
9@0000`000010000EP00030000300000;@000?D0001100001@0009T08@2?0300[@0`0;L08@2I0240
9@0000`000020000:00000`0000100009P0001`000010000000000400001000000000RD0000<0000
0@0005L0000`0000`00002d0003e0000@@0000D0002I0240S`0`0:d0<02g0240V@0Q05L0000T0000
m@0002<0003e0000;`000080002g0280]`0I02D0000<00000P0002P0000<00000@0002H0000L0000
0@0000D00000000000000?ooo`8U000030000040001F0000<0000>P0000]00007P40044000050000
]`0Q0:d0<03<0300eP0Q0;L08@0U000030000080000X000030000040000V00007000004000000000
0@000040000000029@0000`000010000E`000300003X0000;@0001h1001100001@000;L08@2]0300
c00`0=H08@2g0240E`0002@0000N0@008`0001h1000_00000P000=H08P3F01T09@0000`000020000
:00000`0000100009P0001`0000100001@00000000000000oooo0RD0000<00000@0005H0000`0000
3P4002d000160@00@@0000D0003F0240bP0`0>X0<03d0240eP0Q02D0000<00000P0002P0000<0000
0@0002H0000L00000@000000000100000@000000008U000030000040001G0000<00000h1000]0000
AP40044000050000eP0Q0<X0<03Z0300m00Q0=H08@1G0000900001h1000S00007P4002l000020000
eP0R0=H06@0U000030000080000X000030000040000V0000700000400005000000000000003oool2
9@0000`000010000EP000300000h0000@@0006d0001H00001@0003<0<00Y0440A`110540<00c0300
9@0000`000020000:00000`0000100009P0001`000010000000000400001000000000RD0000<0000
0@0005L0000`0000>0000440001]0000F00000D0000c0300:@1104L0@@1A0300<`0`05L0000T0000
A@0003P000150000@P000080000c0340<`0Y05L0000T0000K`0003P0001_0000@P000080001B0340
DP0Y02D0000<00000P0002P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U0000
30000040001F0000<000060000110000V00005P000050000D@0`04L0@@1V0440L@0`0540<00U0000
30000080000X000030000040000V000070000040000000000@000040000000029@0000`000010000
E`000300001P0000@@0009P0001H00001@000540<0170440IP110740<01A0300E`0002@0001_0000
>00006l0001200000P000580<@1B02T0E`0002@0002H0000>00009P0001200000P000740<@1a02T0
9@0000`000020000:00000`0000100009P0001`0000100001@00000000000000oooo0RD0000<0000
0@0005H0000`0000R@00044000300000F00000D0001a0300IP1108@0@@2?0300L@0`02D0000<0000
0P0002P0000<00000@0002H0000L00000@000000000100000@000000008U000030000040001G0000
<00008T000110000`00005P000050000L@0`06H0@@240440S`0`0740<01G000090000<00000h0000
`000048000020000S`0a08l0:@0U000030000080000X000030000040000V00007000004000050000
00000000003oool29@0000`000010000EP000300002a0000@@000>P0001H00001@0008l0<0240440
X`110:d0<02?03009@0000`000020000:00000`0000100009P0001`0000100000000004000010000
00000RD0000<00000@0005L0000`0000/@000440003X0000F00000D0002?0300Q0110:<0@@2]0300
S`0`05L0000T0000iP0003P0003V0000@P000080002/0340[00Y02D0000<00000P0002P0000<0000
0@0002H0000L00000@0000D00000000000000?ooo`8U000030000040001F0000<0000=T000110000
3P4005P000050000[00`0:80@@300440bP0`0:`0<00U000030000080000X000030000040000V0000
70000040000000000@000040000000029@0000`000010000E`000300003I0000@@0000h1001H0000
1@000:`0<02R0440`0110<X0<02/0300E`0002@0003V0000>0000>H0001200000P000:`0<@2/02T0
E`0002@0000>0@00>00000h1001200000P000<X0<@3:02T09@0000`000020000:00000`000010000
9P0001`0000100001@00000000000000oooo0RD0000<00000@0005H0000`00000@400440000i0@00
F00000D0003:0300`0110=l0@@3Z0300bP0`02D0000<00000P0002P0000<00000@0002H0000L0000
0@000000000100000@000000008U000030000040001G0000<000004100110000>@4005P000050000
bP0`0<00@@3O0440jP0`0<X0<00U000030000080000X000030000040000V00007000004000050000
00000000003oool29@0000`000010000EP000300000[0000F0000600001]00001@0002T0@@0O0540
?@1A04L0@@0Y04409@0000`000020000:00000`0000100009P0001`0000100000000004000010000
00000RD0000<00000@0005L0000`0000:`0005P0001P0000K@0000D0000Y04407`1A03d0D@170440
:@1105L0000T0000>00004d0000h0000F0000080000Y0440:@0i05L0000T0000H00004d0001P0000
F000008000170440A`0i05L0000T0000:`000680000[0000JP000080000O04l07`1902D0000<0000
0P0002P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U000030000040001F0000
<00005<0001F0000R@0006`000050000A`1003d0D01K0500IP1004L0@00U000030000080000X0000
30000040000V000070000040000000000@000040000000029@0000`000010000E`000300001C0000
EP0008T0001/00001@0004L0@00m0500F`1@06H0@0170400E`0002@000290000C@0008T0001H0000
0P0006H0@@1V03T09@0000`000020000:00000`0000100009P0001`0000100001@00000000000000
oooo0RD0000<00000@0005H0000`0000N`0005H0002a0000K00000D0001V0400F`1@07X0D0240400
IP1002D0000<00000P0002P0000<00000@0002H0000L00000@000000000100000@000000008U0000
30000040001G0000<00007/0001F0000/@0006`000050000IP1005/0D01j0500Q01006H0@01G0000
900008T0001=0000R@0005H000020000IP1006H0>@1G000090000;40001=0000/@0005H000020000
Q01008@0>@0U000030000080000X000030000040000V0000700000400005000000000000003oool2
9@0000`000010000EP000300002T0000EP000=T0001/00001@0008@0@01j0500V01@0:80@0240400
9@0000`000020000:00000`0000100009P0001`000010000000000400001000000000RD0000<0000
0@0005L0000`0000Y00005H0003I0000K00000D000240400NP1@09P0D02R0400Q01005L0000T0000
/@0004d0002a0000EP00008000240400Q00i05L0000T0000f@0004d0003I0000EP000080002R0400
XP0i02D0000<00000P0002P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U0000
30000040001F0000<0000<`0001F00000@4006`000050000XP1009P0D02f0500`0100:80@00U0000
30000080000X000030000040000V000070000040000000000@000040000000029@0000`000010000
E`000300003<0000EP000041001/00001@000:80@02H0500]P1@0<00@02R0400E`0002@000010@00
C@000041001F00000P000<00@03003T09@0000`000020000:00000`0000100009P0001`000010000
1@00000000000000oooo0RD0000<00000@0005H0000`0000m00005H0000Z0@00K00000D000300400
]P1@0=@0D03O0400`01002D0000<00000P0002P0000<00000@0002H0000L00000@00000000010000
0@000000008U000030000040001G0000<0000?@0001F0000:P4006`000050000`0100;H0D03D0500
g`100<00@01G000090000041001=00000@4005H000020000`0100<00>@0U000030000080000X0000
30000040000V0000700000400005000000000000003oool29@0000`000010000EP000300000M0000
K00005<0002200001@0001l0D00E0640<`1Q03d0D00O05009@0000`000020000:00000`000010000
9P0001`000010000000000400001000000000RD0000<00000@0005L0000`00007@0006`0001C0000
PP0000D0000O05005@1Q03<0H@0m05007`1@05L0000T0000D`000640001C0000K0000080000m0500
?@1802D0000<00000P0002P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U0000
30000040001F0000<00004D0001/0000N`00088000050000?@1@03<0H@1A0640F`1@03d0D00U0000
30000080000X000030000040000V000070000040000000000@000040000000029@0000`000010000
E`00030000150000K00007/0002200001@0003d0D00c0640D@1Q05/0D00m0500E`0002@0001C0000
H@0005<0001/00000P0003d0D00m04P0E`0002@0001l0000H@0007`0001/00000P0005`0D01L04P0
9@0000`000020000:00000`0000100009P0001`0000100001@00000000000000oooo0RD0000<0000
0@0005H0000`0000K00006`0002T0000PP0000D0001K0500D01Q0700H@1j0500F`1@02D0000<0000
0P0002P0000<00000@0002H0000L00000@000000000100000@000000008U000030000040001G0000
<00006`0001/0000Y000088000050000F`1@0500H@1`0640NP1@05/0D01G000090000:@0001Q0000
Y00006`000020000NP1@07X0B00U000030000080000X000030000040000V00007000004000050000
00000000003oool29@0000`000010000EP000300002G0000K0000<`0002200001@0007X0D01`0640
SP1Q09P0D01j05009@0000`000020000:00000`0000100009P0001`0000100000000004000010000
00000RD0000<00000@0005L0000`0000U`0006`0003<0000PP0000D0001j0500L01Q08h0H@2H0500
NP1@05L0000T0000Y0000640002T0000K0000080001j0500NP1805L0000T0000c0000640003<0000
K0000080002H0500V01802D0000<00000P0002P0000<00000@0002H0000L00000@0000D000000000
00000?ooo`8U000030000040001F0000<0000;h0001/0000m000088000050000V01@08h0H@2/0640
]P1@09P0D00U000030000080000X000030000040000V000070000040000000000@00004000000002
9@0000`000010000E`000300002n0000K0000?@0002200001@0009P0D02>0640[01Q0;H0D02H0500
E`0002@0003<0000H@000<`0001/00000P0009P0D02H04P0E`0002@0003d0000H@000?@0001/0000
0P000;H0D02f04P09@0000`000020000:00000`0000100009P0001`0000100001@00000000000000
oooo0RD0000<00000@0005H0000`0000iP0006`0000L0@00PP0000D0002f0500[01Q0<X0H@3D0500
]P1@02D0000<00000P0002P0000<00000@0002H0000L00000@000000000100000@000000008U0000
30000040001G0000<0000>H0001/00007040088000050000]P1@0:`0H@3:0640e01@0;H0D01G0000
90000?@0001Q0000m00006`000020000]P1@0;H0B00U000030000080000X000030000040000V0000
700000400005000000000000003oool29@0000`000010000EP000300000?0000P@0004D0002F0000
1@0001D0H00:0700:@1`03<0H00E06009@0000`000020000:00000`0000100009P0001`000010000
000000400001000000000RD0000<00000@0005L0000`00003`00084000150000UP0000D0000E0600
2P1`02T0L00c06005@1P05L0000T00007@0007H0000M0000P@000080000E06005@1H05L0000T0000
A00007H000140000P@000080000b0600<P1H02D0000<00000P0002P0000<00000@0002H0000L0000
0@0000D00000000000000?ooo`8U000030000040001F0000<00003L000210000K00009H000050000
<P1P02P0L0160700D01P0380H00U000030000080000X000030000040000V00007000004000000000
0@000040000000029@0000`000010000E`000300000g0000P@0006`0002F00001@000380H00X0700
AP1`0500H00b0600E`0002@0001/0000MP0006`0002100000P000500H01@05P09@0000`000020000
:00000`0000100009P0001`0000100001@00000000000000oooo0RD0000<00000@0005H0000`0000
G`000840002G0000UP0000D0001@0600AP1`06D0L01`0600D01P02D0000<00000P0002P0000<0000
0@0002H0000L00000@000000000100000@000000008U000030000040001G0000<00005l000210000
U`0009H000050000D01P04H0L01U0700L01P0500H01G0000900009L0001f0000U`00084000020000
L01P0700F00U000030000080000X000030000040000V0000700000400005000000000000003oool2
9@0000`000010000EP00030000280000P@000;h0002F00001@000700H01U0700P`1`08h0H01`0600
9@0000`000020000:00000`0000100009P0001`000010000000000400001000000000RD0000<0000
0@0005L0000`0000R0000840002n0000UP0000D0001`0600I@1`08<0L02>0600L01P05L0000T0000
U`0007D0002G0000P@000080001`0600L01G05L0000T0000_P0007D0002n0000P@000080002>0600
SP1G02D0000<00000P0002P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U0000
30000040001F0000<0000;0000210000iP0009H000050000SP1P08<0L02R0700[01P08h0H00U0000
30000080000X000030000040000V000070000040000000000@000040000000029@0000`000010000
E`000300002`0000P@000>H0002F00001@0008h0H0230700XP1`0:`0H02>0600E`0002@0002n0000
M@000;h0002100000P0008h0H02>05L0E`0002@0003V0000M@000>H0002100000P000:`0H02/05L0
9@0000`000020000:00000`0000100009P0001`0000100001@00000000000000oooo0RD0000<0000
0@0005H0000`0000f@000840000>0@00U@0000D0002/0600XP1_0<00K`3:0600[01P02D0000<0000
0P0002P0000<00000@0002H0000L00000@000000000100000@000000008U000030000040001G0000
<0000=T0002100003P4009D000050000[01P0:80K`3006l0bP1P0:`0H00U000030000080000X0000
30000040000V00007000004000000000100000@0001IFET29@0000`000010000E`0002@0000B0000
S00001H0000b0@000P0000h0i00>06X0E`0002@0000j0000S00003h0000b0@000P0002`0i00/06X0
E`0002@0001Q0000S00006D0000b0@000P0004T0i01906X0E`0002@000290000S00008d0000d0@00
0P0006L0i@1W06X0E`0002@0002b0000S0000;H0000d0@000P0008H0i@2606X0E`0002@0003J0000
S0000=h0000d0@000P000:@0i@2T06X09@0000`000020000:00000`0000100009P0001`000010000
000000@00004000000000RD0000<00000@0005L0000T0000H`000180002>00005P000080001;00h0
J00>05L0000T0000R`000180002e00005P000080001Y00h0Q@0>05L0000T0000/P000180003N0000
5P000080002600h0Y00>05L0000T0000fP00018000060@005P000080002T00h0`P0>05L0000T0000
0P400180000/0@005P000080003200h0g`0>05L0000T0000:P400180001D0@005P000080003P00h0
o@0>05L0000T0000EP0002D0001o0000:@000080001101`0G@0L05L0000T0000OP0002D0002Y0000
:@000080001O01`0O00L05L0000T0000YP0002D0003?0000:@000080001m01`0V@0L05L0000T0000
cP0002D0003g0000:@000080002K01`0]`0L05L0000T0000m00002D0000O0@00:@000080002h01`0
e@0L05L0000T0000704002D000170@00:@000080003F01`0l`0L05L0000T0000A`0003P0001c0000
?0000080000f02/0E00[05L0000T0000K`0003P0002K0000?0000080001D02/0LP0[05L0000T0000
V@0003P000320000?0000080001c02/0S`0[05L0000T0000_`0003P0003Z0000?0000080002@02/0
[@0[05L0000T0000iP0003P0000B0@00?0000080002]02/0b`0[05L0000T00003P4003P0000j0@00
?0000080003;02/0j@0[05L0000T0000>P0004h0001V0000DP000080000/03/0BP0k05L0000T0000
HP0004h0002;0000DP000080001:03/0IP0k05L0000T0000RP0004h0002c0000DP000080001X03/0
Q00k05L0000T0000/@0004h0003L0000DP000080002503/0X`0k05L0000T0000f00004h000040@00
DP000080002S03/0`@0k05L0000T0000004004h0000/0@00DP000080003103/0g`0k05L0000T0000
;@000600001G0000I0000080000R04T0?`1905L0000T0000E@000600001n0000I0000080001004T0
G01905L0000T0000N`000600002W0000I0000080001M04T0N`1905L0000T0000Y@000600003>0000
I0000080001l04T0V01905L0000T0000b`0005l0003f0000H`000080002I04P0]P1805L0000T0000
l`0005l0000O0@00H`000080002g04P0e@1805L0000T00007`0007@0001:0000N0000080000H05P0
=@1H05L0000T0000AP0007@0001b0000N0000080000e05P0D`1H05L0000T0000KP0007@0002I0000
N0000080001C05P0L01H05L0000T0000U`0007@000300000N0000080001b05P0SP1H05L0000T0000
_P0007@0003X0000N0000080002?05P0[01H05L0000T0000iP0007@0000@0@00N0000080002]05P0
bP1H02D0000<00000P0002P0000<00000@0002H0000L00000@000000000200000P0005UIF@8U0000
30000040001G0000900005<1000@0000EP400<0000020000oP0<0?l0S`1G0000900004D1000T0000
B@400=@000020000m00K0?D0WP1G0000900003P1000k0000>`400>X000020000jP0/0>/0[P1G0000
900002/1001?0000;@400?d000020000h00k0>00_@1G0000900001d1001S00007`4001<100020000
eP1:0=H0c@1G0000900000l1001g00004@4002T100020000b`3N0</0F@1G000090000180000B0000
I00008/0000200003@1W04T03@0U000030000080000X000030000040000V00007000004000000000
0P000080001VIVH29@0000`000010000E`0002@000030@006P0005<1002H00000P000<80L@3m01<0
E`0002@000030@00>00005H1002h00000P000<80R@3o02X0E`0002@000030@00F`0005D1003K0000
0P000<80X`3n04@0E`0002@000040@00O00005D1003l00000P000<<0_03n05d0E`0002@000040@00
X00005<1000L0@000P000<<0e03m07P09@0000`000020000:00000`0000100009P0001`000010000
000000400001000000000RD0000<00000@0005L0000T0000/0000:4000300000]`000080002308T0
S`1h05L0000T0000`0000:40003H0000X@000080002?07P0X@1h05L0000T0000`00009D000300000
X@000080002?07P0S`1_05L0000T0000Q@000:40002G0000]`000080001S08T0L01h05L0000T0000
U`000:40002_0000X@000080001`07P0PP1h05L0000T0000V00009D0002H0000X@000080001a07P0
L@1_05L0000T0000G`000:40001_0000]`000080001608T0DP1h05L0000T0000K`000:4000250000
X@000080001B07P0H`1h05L0000T0000L00009D0001`0000X@000080001C07P0D`1_05L0000T0000
=`000:4000170000]`000080000X08T0=01h05L0000T0000A`000:40001O0000X@000080000d07P0
AP1h05L0000T0000A`0009D000170000X@000080000d07P0=01_05L0000T000040000:40000O0000
]`000080000;08T05P1h05L0000T00007`000:40000g0000X@000080000F07P0:01h05L0000T0000
7`0009D0000O0000X@000080000F07P05P1_05L0000T0000f@000:80003Y0000^@000080002R08X0
[P1i05L0000T0000j@0009H0003Z0000X@000080002^07P0[`1`05L0000T0000j@000:80000@0@00
XP000080002^07T0b`1i05L0000T0000/0000<4000300000f@00008000230:80S`2@05L0000T0000
`0000<40003H0000`@000080002?0900X@2@05L0000T0000`0000;H000300000`@000080002?0900
S`2805L0000T0000Q@000<40002G0000f@000080001S0:80L02@05L0000T0000U`000<40002_0000
`@000080001`0900PP2@05L0000T0000V0000;L0002H0000`@000080001a0900L@2905L0000T0000
G`000<40001_0000f@00008000160:80DP2@05L0000T0000K`000<4000250000`@000080001B0900
H`2@05L0000T0000L0000;L0001`0000`@000080001C0900D`2905L0000T0000=`000<4000150000
f@000080000X0:80<`2@05L0000T0000A@000<40001O0000`@000080000c0900AP2@05L0000T0000
A`000;H000170000`@000080000d0900=02805L0000T000040000<40000O0000f@000080000;0:80
5P2@05L0000T00007`000<40000g0000`@000080000F0900:02@05L0000T00007`000;H0000O0000
`@000080000F09005P2805L0000T0000f@000<80003Y0000fP000080002R0:<0[P2A05L0000T0000
j@000;L0003Z0000`@000080002^0900[`2905L0000T0000j@000<80000@0@00`P000080002^0940
b`2A05L0000T0000/0000><000300000n`00008000230;`0S`2Z05L0000T0000`0000>80003H0000
hP000080002?0:T0X@2Y05L0000T0000`0000=X000300000hP000080002?0:T0S`2S05L0000T0000
Q@000><0002G0000n`000080001S0;`0L02Z05L0000T0000U`000><0002_0000h`000080001`0:X0
PP2Z05L0000T0000V0000=X0002H0000h`000080001a0:X0L@2S05L0000T0000G`000><0001_0000
n`00008000160;`0DP2Z05L0000T0000K`000><000250000h`000080001B0:X0H`2Z05L0000T0000
K`000=X0001_0000h`000080001B0:X0DP2S05L0000T0000=`000><000150000n`000080000X0;`0
<`2Z05L0000T0000A@000>80001O0000hP000080000c0:T0AP2Y05L0000T0000A`000=X000170000
hP000080000d0:T0=02S05L0000T000040000><0000O0000n`000080000;0;`05P2Z05L0000T0000
7`000>80000g0000hP000080000F0:T0:02Y05L0000T00007`000=X0000O0000hP000080000F0:T0
5P2S05L0000T0000f@000>D0003Y0000o0000080002R0;d0[P2[05L0000T0000j@000=X0003Z0000
h`000080002^0:X0[`2S05L0000T0000j@000><0000@0@00h`000080002^0:X0b`2Z05L0000T0000
/00000@1003000007P40008000230=H0S`3305L0000T0000`00000@1003H000010400080002?0<<0
X@3305L0000T0000`0000?X00030000010400080002?0<<0S`2k05L0000T0000Q@0000H1002G0000
7P400080001S0=H0L03405L0000T0000U`0000@1002_000010400080001`0<<0PP3305L0000T0000
U`000?X0002G000010400080001`0<<0L02k05L0000T0000G`0000H1001_00007P40008000160=H0
DP3405L0000T0000K`0000@10025000010400080001B0<<0H`3305L0000T0000K`000?X0001_0000
10400080001B0<<0DP2k05L0000T0000=`0000H1001500007P400080000X0=H0<`3405L0000T0000
A@0000@1001O000010400080000c0<<0AP3305L0000T0000A`000?X00017000010400080000d0<<0
=02k05L0000T00003`0000@1000O00007P400080000:0=H05P3305L0000T00007`0000@1000g0000
10400080000F0<<0:03305L0000T00007`000?X0000O000010400080000F0<<05P2k05L0000T0000
f@0000L1003Y00007`400080002R0=L0[P3505L0000T0000j@000?/0003Z000010400080002^0<<0
[`2l05L0000T0000j@0000H1000@0@001P400080002^0<@0b`3405L0000T0000^P0002L100300000
<0400080002;0>@0S`3M05L0000T0000`00002L1003H00009`400080002?0=d0X@3M05L0000T0000
`00001h1003000009`400080002?0=d0S`3F05L0000T0000S`0002L1002G0000<P400080001Z0>D0
L03M05L0000T0000U`0002L1002_00009`400080001`0=d0PP3M05L0000T0000U`0001h1002G0000
9`400080001`0=d0L03F05L0000T0000J00002L1001_0000<P400080001=0>D0DP3M05L0000T0000
K`0002L1002500009`400080001B0=d0H`3M05L0000T0000K`0001h1001_00009`400080001B0=d0
DP3F05L0000T0000@00002L100150000<P400080000_0>D0<`3M05L0000T0000A@0002L1001O0000
9`400080000c0=d0AP3M05L0000T0000A`0001h1001700009`400080000d0=d0=03F05L0000T0000
6@0002L1000O0000<0400080000B0>@05P3M05L0000T00007`0002L1000g00009`400080000F0=d0
:03M05L0000T00007`0001h1000O00009`400080000F0=d05P3F05L0000T0000hP0002P1003X0000
<`400080002Y0>H0[@3N05L0000T0000j00001h1003X00009`400080002]0=d0[@3F05L0000T0000
j@0002P1000=0@00:0400080002^0=h0b@3N05L0000T0000AP4003H0001D0@00=P000080003d02P0
oP0X05L0000T0000>@4004d000160@00C@000080003Z03T0m00i05L0000T0000:P400640000i0@00
H@000080003O04P0jP1805L0000T0000704007H0000Z0@00MP000080003D05P0g`1H05L0000T0000
3@4008`0000L0@00S0000080003906P0e01X05L0000T0000AP4005T0001D0@00F@000080003d0480
oP1205L0000T0000>@4006d000160@00K@000080003Z0540m01A05L0000T0000:P4008@0000i0@00
Q0000080003O0680jP1R05L0000T0000704009L0000Z0@00U`000080003D0740g`1a05L0000T0000
3@400:h0000L0@00[P00008000390880e02205L0000T0000AP4007X0001D0@00NP000080003d05/0
oP1K05L0000T0000>@4008l000160@00S`000080003Z06/0m01[05L0000T0000:P400:<0000h0@00
X`000080003O07X0j@1j05L0000T000070400;X0000Z0@00^P000080003D08/0g`2;05L0000T0000
3@400<l0000L0@00c`000080003909/0e02K05L0000T0000AP4009/0001D0@00V`000080003d07@0
oP1d05L0000T0000>@400;4000160@00/@000080003Z08@0m02405L0000T0000:P400<H0000h0@00
aP000080003O09@0j@2D05L0000T000070400=/0000Z0@00f`000080003D0:@0g`2T05L0000T0000
3@400?00000J0@00l000008000390;@0d`2d05L0000T0000AP400;h0001D0@00_P000080003d08h0
oP2>05L0000T0000>@400=<000160@00d`000080003Z09h0m02N05L0000T0000:P400>L0000h0@00
i`000080003O0:d0j@2]05L0000T000070400?`0000Z0@00o0000080003D0;d0g`2m05L0000T0000
3@400181000J0@004P40008000390<d0d`3=02D0000<00000P0002P0000<00000@0002H0000L0000
0@00000000040000100002HV9P8U000030000040001G000090000180002g00000P400;/000020000
3P2:0;l0RP1G000090000180003H00000P400=`0000200003P2S0;l0X`1G000090000180003j0000
0P400?h0000200003P2m0;l0_@1G000090000180000I0@000P4001d1000200003P3D0;l0e01G0000
900001<0002G00000`4009/0000200003`1b0<00LP0U000030000080000X000030000040000V0000
70000040000000000@000040000000029@0000`000010000E`0002@0001M0000=04005d0000o0@00
0P0004D0i`150>l0E`0002@0001M0000C04005d0001D0@000P0004D0n@150?l0E`0002@0001S0000
=04006<0000o0@000P0004T0i`190>l0E`0002@0001S0000C04006<0001D0@000P0004T0n@190?l0
600000`000000002DP0004`100030000j?ooo`000000000000000901000000000000<U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010@410@410@41000U0000300000<0001D0000
E00006T000100@00L@0006<100010000bWh<@Uii349>0000l0000040001<00000000000000000000
00000000001@0000M00000L0001G000090000;00000c0@00/00003h100020000P`3V08<0kP1G0000
90000;00001;0@00/00005<100020000P`3h08<0oP1G000090000=P0000c0@00f00003h100020000
X@3V0:40kP1G000090000=P0001;0@00f00005<100020000X@3h0:40oP1B0000C04000@000000000
0000000000000000GP4000000000004P000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000410@410@410@4002D0000<0000100002P0000<00000`000580001<0@000`000>Soool00000
00000000002@0@0000000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000100000002X0>H0
20000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000400@0001D000000000000000000000000000000000
0@410@410@410@009@0000`000030000E00005@0003R0000?0400>l0001O0@000@000<Yn349NN@a2
Z@000>d000010000C0000000000000000000000000000000D0000640000;00009@0000`000020000
:00000`0000100009P0001`0000100000000008000020000FEUI0RD0000<00000@0005L0000T0000
>`000180002<0000R`000080000/06L0I`0=05L0000T0000H`000180002e0000R`000080001:06L0
QP0=05L0000T0000R`000180003M0000R`000080001X06L0Y00=05L0000T0000/`00018000050@00
R`000080002606L0`P0=05L0000T0000f`000180000]0@00R`000080002T06L0h00=02D0000<0000
0P0002P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U000030000040000U0000
300000@0081F0000<00004d0000l0@00G00004L100050000A03a03T0m@0m0?40>@3]04@0l@0U0000
30000080000X000030000040000V000070000040000000000@000040000000029@0000`000010000
E`000300001=0000?04005`000170@001@0004@0l@0i0?D0?@3a03T0k@140?40E`0002@000170000
@04005<000120@000P0003@0l00m0?409@0000`000020000:00000`0000100009P0001`000010000
1@00000000000000oooo0RD0000<00000@0005H0000`0000W`0003X1002]0000A04000D000210>l0
MP3c07X0k`1f0>/0P@3_02D0000<00000P0002P0000<00000@0002H0000L00000@00000000010000
0@000000008U000030000040001G0000<00009l0000j0@00[@0004@100050000P@3_07H0l`1j0>l0
MP3[0840k`1G0000900009D0000o0@00Y00003l100020000K`3_07X0k`0U000030000080000X0000
30000040000V0000700000400005000000000000003oool29@0000`000010000EP000300001T0000
?04007<000160@001@0004X0l01E0>d0D@3`05D0m01:0?009@0000`000020000:00000`000010000
9P0001`000010000000000400001000000000RD0000<00000@0005L0000`0000I00003`1001c0000
AP4000D0001:0?00E@3]0540l01E0?@0BP3`05L0000T0000K@000401001i0000@P400080001A0?00
FP3a02D0000<00000P0002P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U0000
30000040001F0000<0000=P0000k0@00iP0004@100050000X@3_0:`0k02X0>l0[03c0:40k`0U0000
30000080000X000030000040000V000070000040000000000@000040000000029@0000`000010000
E`000300003H0000>`400>H000140@001@000:40k`2/0>`0Z03_0:`0l`2Q0>l0E`0002@0003Q0000
?`400>h000100@000P000:P0k`2b0?008P0000`0003ooooo:00000`000010000:00000`000030000
:00000`000020000:00000`000040000B`000100000000001@0000h0000D000000000100000D0000

\>"], "Graphics",
  Editable->False,
  ImageSize->{251, 260.938},
  ImageMargins->{{289, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
From Hooke's law in two dimensions, obtained from the above relations,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Hooke2D = {\[Sigma]d[
            x] -> \[Lambda] \((\[ScriptCapitalE]d[x] + \[ScriptCapitalE]d[
                    y])\) + 
            2  \[Mu]\ \[ScriptCapitalE]d[x], \[IndentingNewLine]\[Sigma]d[
            y] -> \[Lambda] \((\[ScriptCapitalE]d[x] + \[ScriptCapitalE]d[
                    y])\) + 
            2  \[Mu]\ \[ScriptCapitalE]d[y], \[IndentingNewLine]\[Tau]dd[x, 
            y] -> 2  \[Mu]\ \[ScriptCapitalE]dd[x, y]}\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox["x",
                        SequenceForm[ x],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox["x",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ x], 
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                RowBox[{
                  RowBox[{"2", " ", "\[Mu]", " ", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[ScriptCapitalE]", 
                          InterpretationBox["x",
                            SequenceForm[ x],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox["x",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[ScriptCapitalE], 
                          SequenceForm[ x], 
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], "+", 
                  RowBox[{"\[Lambda]", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[ScriptCapitalE]", 
                              InterpretationBox["x",
                                SequenceForm[ x],
                                Editable->False], 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["x",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ x, ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[ScriptCapitalE], 
                              SequenceForm[ x], 
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"], "+", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[ScriptCapitalE]", 
                              InterpretationBox["y",
                                SequenceForm[ y],
                                Editable->False], 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["y",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ y, ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[ScriptCapitalE], 
                              SequenceForm[ y], 
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"]}], ")"}]}]}]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox["y",
                        SequenceForm[ y],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox["y",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ y], 
                      SequenceForm[ 
                        StyleForm[ y, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                RowBox[{
                  RowBox[{"2", " ", "\[Mu]", " ", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[ScriptCapitalE]", 
                          InterpretationBox["y",
                            SequenceForm[ y],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox["y",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[ScriptCapitalE], 
                          SequenceForm[ y], 
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], "+", 
                  RowBox[{"\[Lambda]", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[ScriptCapitalE]", 
                              InterpretationBox["x",
                                SequenceForm[ x],
                                Editable->False], 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["x",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ x, ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[ScriptCapitalE], 
                              SequenceForm[ x], 
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"], "+", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[ScriptCapitalE]", 
                              InterpretationBox["y",
                                SequenceForm[ y],
                                Editable->False], 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["y",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ y, ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[ScriptCapitalE], 
                              SequenceForm[ y], 
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"]}], ")"}]}]}]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Tau]", 
                      InterpretationBox[\(x\[InvisibleSpace]y\),
                        SequenceForm[ x, y],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["x",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False], 
                          StyleForm[ y, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Tau], 
                      SequenceForm[ x, y], 
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False], 
                        StyleForm[ y, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                RowBox[{"2", " ", "\[Mu]", " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[\(x\[InvisibleSpace]y\),
                          SequenceForm[ x, y],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["x",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["y",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False], 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ x, y], 
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False], 
                          StyleForm[ y, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}]}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Relation between Lame coefficients and Poisson-Young modulus :
From above we define,\
\>", "Text"],

Cell[BoxData[
    \(\(\[Vee]\(\(=\)\(-\(\[ScriptCapitalE]d[y]\/\[ScriptCapitalE]d[
                x]\)\)\)\); \[CapitalEpsilon] = \[Sigma]d[x]\/\
\[ScriptCapitalE]d[x]\)], "Input",
  Evaluatable->False],

Cell["and we have the Poisson-Young relation in d=2 :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LPY2Drule = \(Solve[{\[Nu] == \[Lambda]/\((\[Lambda] + 
                    2  \[Mu])\), \[CapitalEpsilon] == 
              2  \[Mu] \((2  \[Mu] + 
                      2  \[Lambda])\)/\((2  \[Mu] + \[Lambda])\)}, \
{\[Lambda], \[Mu]}]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\({\[Lambda] \[Rule] \(-\(\(\[CapitalEpsilon]\ \
\[Nu]\)\/\(\((\[Nu] - 1)\)\ \((\[Nu] + 
                          1)\)\)\)\), \[Mu] \[Rule] \[CapitalEpsilon]\/\(2\ \
\((\[Nu] + 1)\)\)}\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(HookePY2D = \(\(Hooke2D /. 
          LPY2Drule\)\(//\)\(Simplify\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\( (*\ \ Fl\
\[UDoubleDot]gge\ p  .54, \ equ . \ 4 - 20\ \ *) \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox["x",
                        SequenceForm[ x],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox["x",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ x], 
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                RowBox[{"-", 
                  FractionBox[
                    RowBox[{"\[CapitalEpsilon]", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["\[ScriptCapitalE]", 
                                InterpretationBox["x",
                                  SequenceForm[ x],
                                  Editable->False], 
                                InterpretationBox[
                                  TagBox[
                                    StyleBox["x",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)],
                                  SequenceForm[ 
                                    StyleForm[ x, ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ \[ScriptCapitalE], 
                                SequenceForm[ x], 
                                SequenceForm[ 
                                  StyleForm[ x, ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"], "+", 
                          RowBox[{"\[Nu]", " ", 
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["\[ScriptCapitalE]", 
                                  InterpretationBox["y",
                                    SequenceForm[ y],
                                    Editable->False], 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["y",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ y, ShowContents -> False]],
                                    Editable->False]],
                                Subsuperscript[ \[ScriptCapitalE], 
                                  SequenceForm[ y], 
                                  SequenceForm[ 
                                    StyleForm[ y, ShowContents -> False]]],
                                Editable->False],
                              "TraditionalForm"]}]}], ")"}]}], \(\[Nu]\^2 - 
                      1\)]}]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox["y",
                        SequenceForm[ y],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox["y",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ y], 
                      SequenceForm[ 
                        StyleForm[ y, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                RowBox[{"-", 
                  FractionBox[
                    RowBox[{"\[CapitalEpsilon]", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"\[Nu]", " ", 
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["\[ScriptCapitalE]", 
                                  InterpretationBox["x",
                                    SequenceForm[ x],
                                    Editable->False], 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["x",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ x, ShowContents -> False]],
                                    Editable->False]],
                                Subsuperscript[ \[ScriptCapitalE], 
                                  SequenceForm[ x], 
                                  SequenceForm[ 
                                    StyleForm[ x, ShowContents -> False]]],
                                Editable->False],
                              "TraditionalForm"]}], "+", 
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["\[ScriptCapitalE]", 
                                InterpretationBox["y",
                                  SequenceForm[ y],
                                  Editable->False], 
                                InterpretationBox[
                                  TagBox[
                                    StyleBox["y",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)],
                                  SequenceForm[ 
                                    StyleForm[ y, ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ \[ScriptCapitalE], 
                                SequenceForm[ y], 
                                SequenceForm[ 
                                  StyleForm[ y, ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"]}], ")"}]}], \(\[Nu]\^2 - 
                      1\)]}]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Tau]", 
                      InterpretationBox[\(x\[InvisibleSpace]y\),
                        SequenceForm[ x, y],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["x",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False], 
                          StyleForm[ y, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Tau], 
                      SequenceForm[ x, y], 
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False], 
                        StyleForm[ y, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                FractionBox[
                  RowBox[{"\[CapitalEpsilon]", " ", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[ScriptCapitalE]", 
                          InterpretationBox[\(x\[InvisibleSpace]y\),
                            SequenceForm[ x, y],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["x",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False], 
                              StyleForm[ y, ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[ScriptCapitalE], 
                          SequenceForm[ x, y], 
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False], 
                            StyleForm[ y, ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], \(\[Nu] + 1\)]}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The first strain we impose to the porous material, is a simple stretching \
",
  Cell[BoxData[
      FormBox[
        TagBox[
          RowBox[{
            StyleBox[
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox["x",
                      SequenceForm[ x],
                      Editable->False], 
                    InterpretationBox[
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ x], 
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"],
              FontFamily->"Courier",
              FontSize->16], 
            StyleBox["=",
              FontFamily->"Courier",
              FontSize->16,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox[" ",
              FontFamily->"Courier",
              FontSize->16], 
            StyleBox[
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox[\(1\[InvisibleSpace]1\),
                      SequenceForm[ 1, 1],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ 1, 1], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"],
              FontFamily->"Courier",
              FontSize->16]}],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " in the x direction, with  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          TagBox[
            RowBox[{
              StyleBox[
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox["y",
                        SequenceForm[ y],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox["y",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ y], 
                      SequenceForm[ 
                        StyleForm[ y, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"],
                FontFamily->"Courier",
                FontSize->16], 
              StyleBox[" ",
                FontFamily->"Courier",
                FontSize->16], 
              StyleBox["=",
                FontFamily->"Courier",
                FontSize->16,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], 
              StyleBox[" ",
                FontFamily->"Courier",
                FontSize->16], 
              StyleBox[
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox["z",
                        SequenceForm[ z],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox["z",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ z], 
                      SequenceForm[ 
                        StyleForm[ z, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"],
                FontFamily->"Courier",
                FontSize->16]}],
            (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], " ", 
          "=", " ", "0"}], TraditionalForm]]],
  " and no shear strain. On the faces x = const this requires stresses in the \
vertical and in the horizontal walls. They add up to the force"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ruleFxx = \(Fdd[x, x]\  -> 2 \((n\ a)\) \((\ n\ t)\)\ \[Sigma]d[x] /. 
          HookePY2D\) /. {\[ScriptCapitalE]d[x] -> \[ScriptCapitalE]dd[1, 
              1], \[ScriptCapitalE]d[y] -> 0}\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["F", 
                  InterpretationBox[\(x\[InvisibleSpace]x\),
                    SequenceForm[ x, x],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False], 
                      StyleForm[ x, ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ F, 
                  SequenceForm[ x, x], 
                  SequenceForm[ 
                    StyleForm[ x, ShowContents -> False], 
                    StyleForm[ x, ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "\[Rule]", 
            RowBox[{"-", 
              FractionBox[
                RowBox[{
                "2", " ", "a", " ", \(n\^2\), " ", "t", " ", 
                  "\[CapitalEpsilon]", " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[\(1\[InvisibleSpace]1\),
                          SequenceForm[ 1, 1],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["1",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["1",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 1, 1], 
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], \(\[Nu]\^2 - 1\)]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
The vertical walls normal to the x axis have no strain and no stress, and on \
the faces y = const (and idem z = const), we have only a contribution from \
the horizontal walls\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ruleFyy = \(Fdd[y, y]\  -> \((n\ a)\) \((\ n\ t)\)\ \[Sigma]d[y] /. 
          HookePY2D\) /. {\[ScriptCapitalE]d[x] -> \[ScriptCapitalE]dd[1, 
              1], \[ScriptCapitalE]d[y] -> 0}\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["F", 
                  InterpretationBox[\(y\[InvisibleSpace]y\),
                    SequenceForm[ y, y],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["y",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["y",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ y, ShowContents -> False], 
                      StyleForm[ y, ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ F, 
                  SequenceForm[ y, y], 
                  SequenceForm[ 
                    StyleForm[ y, ShowContents -> False], 
                    StyleForm[ y, ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "\[Rule]", 
            RowBox[{"-", 
              FractionBox[
                RowBox[{
                "a", " ", \(n\^2\), " ", "t", " ", "\[CapitalEpsilon]", " ", 
                  "\[Nu]", " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[\(1\[InvisibleSpace]1\),
                          SequenceForm[ 1, 1],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["1",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["1",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 1, 1], 
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], \(\[Nu]\^2 - 1\)]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ruleFzz = \(Fdd[z, z]\  -> \((n\ a)\) \((\ n\ t)\)\ \[Sigma]d[y] /. 
          HookePY2D\) /. {\[ScriptCapitalE]d[x] -> \[ScriptCapitalE]dd[1, 
              1], \[ScriptCapitalE]d[y] -> 0}\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["F", 
                  InterpretationBox[\(z\[InvisibleSpace]z\),
                    SequenceForm[ z, z],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["z",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["z",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ z, ShowContents -> False], 
                      StyleForm[ z, ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ F, 
                  SequenceForm[ z, z], 
                  SequenceForm[ 
                    StyleForm[ z, ShowContents -> False], 
                    StyleForm[ z, ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "\[Rule]", 
            RowBox[{"-", 
              FractionBox[
                RowBox[{
                "a", " ", \(n\^2\), " ", "t", " ", "\[CapitalEpsilon]", " ", 
                  "\[Nu]", " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[\(1\[InvisibleSpace]1\),
                          SequenceForm[ 1, 1],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["1",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["1",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 1, 1], 
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], \(\[Nu]\^2 - 1\)]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The gross stress for the porous material is obtained by dividing each \
force by the gross area ",
  Cell[BoxData[
      \(\((na)\)\^2\)]],
  ". Using for them the notation ",
  Cell[BoxData[
      \(\[Sigma]\^11\)]],
  ", ",
  Cell[BoxData[
      \(\[Sigma]\^22\)]],
  ", ",
  Cell[BoxData[
      \(\[Sigma]\^33\)]],
  ", we have :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Stress2D = \[IndentingNewLine]{\[Sigma]uu[1, 1] -> 
              Fdd[x, x]/\((n\ a)\)\^2 /. ruleFxx // 
          Factor, \[IndentingNewLine]\[Sigma]uu[2, 2] -> 
              Fdd[y, y]/\((n\ a)\)\^2 /. ruleFyy // 
          Factor, \[IndentingNewLine]\[Sigma]uu[3, 3] -> 
              Fdd[z, z]/\((n\ a)\)\^2 /. ruleFzz // Factor}\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 1, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[\(1\[InvisibleSpace]1\),
                        SequenceForm[ 1, 1],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False]], 
                      SequenceForm[ 1, 1]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                RowBox[{"-", 
                  FractionBox[
                    RowBox[{"2", " ", "t", " ", "\[CapitalEpsilon]", " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[ScriptCapitalE]", 
                            InterpretationBox[\(1\[InvisibleSpace]1\),
                              SequenceForm[ 1, 1],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox["1",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox["1",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                StyleForm[ 1, ShowContents -> False], 
                                StyleForm[ 1, ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[ScriptCapitalE], 
                            SequenceForm[ 1, 1], 
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"]}], \(a\ \((\[Nu]\^2 - 1)\)\)]}]}], 
              ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 2, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[\(2\[InvisibleSpace]2\),
                        SequenceForm[ 2, 2],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 2, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]], 
                      SequenceForm[ 2, 2]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                RowBox[{"-", 
                  FractionBox[
                    RowBox[{
                    "t", " ", "\[CapitalEpsilon]", " ", "\[Nu]", " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[ScriptCapitalE]", 
                            InterpretationBox[\(1\[InvisibleSpace]1\),
                              SequenceForm[ 1, 1],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox["1",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox["1",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                StyleForm[ 1, ShowContents -> False], 
                                StyleForm[ 1, ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[ScriptCapitalE], 
                            SequenceForm[ 1, 1], 
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"]}], \(a\ \((\[Nu]\^2 - 1)\)\)]}]}], 
              ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Sigma]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["3",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 3, ShowContents -> False], 
                          StyleForm[ 3, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[\(3\[InvisibleSpace]3\),
                        SequenceForm[ 3, 3],
                        Editable->False]],
                    Subsuperscript[ \[Sigma], 
                      SequenceForm[ 
                        StyleForm[ 3, ShowContents -> False], 
                        StyleForm[ 3, ShowContents -> False]], 
                      SequenceForm[ 3, 3]],
                    Editable->False],
                  "TraditionalForm"], "\[Rule]", 
                RowBox[{"-", 
                  FractionBox[
                    RowBox[{
                    "t", " ", "\[CapitalEpsilon]", " ", "\[Nu]", " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[ScriptCapitalE]", 
                            InterpretationBox[\(1\[InvisibleSpace]1\),
                              SequenceForm[ 1, 1],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox["1",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox["1",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                StyleForm[ 1, ShowContents -> False], 
                                StyleForm[ 1, ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[ScriptCapitalE], 
                            SequenceForm[ 1, 1], 
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False]]],
                          Editable->False],
                        
                        "TraditionalForm"]}], \(a\ \((\[Nu]\^2 - 
                          1)\)\)]}]}]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "When the porous medium is submitted to a strain ",
  Cell[BoxData[
      RowBox[{\(\[ScriptCapitalE]\_y\), " ", "=", " ", 
        SubscriptBox[
          FormBox["\[ScriptCapitalE]",
            "TraditionalForm"], "22"]}]]],
  " or ",
  Cell[BoxData[
      RowBox[{\(\[ScriptCapitalE]\_z\), " ", "=", " ", 
        SubscriptBox[
          FormBox["\[ScriptCapitalE]",
            "TraditionalForm"], "33"]}]]],
  ", similar formulas hold, and for a combined stretching in all three \
directions we find"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[Sigma]", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox["1",
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox["1",
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ 1, ShowContents -> False], 
                  StyleForm[ 1, ShowContents -> False]],
                Editable->False], 
              InterpretationBox[\(1\[InvisibleSpace]1\),
                SequenceForm[ 1, 1],
                Editable->False]],
            Subsuperscript[ \[Sigma], 
              SequenceForm[ 
                StyleForm[ 1, ShowContents -> False], 
                StyleForm[ 1, ShowContents -> False]], 
              SequenceForm[ 1, 1]],
            Editable->False],
          "TraditionalForm"],
        FontFamily->"Courier",
        FontSize->16], 
      StyleBox["\[Rule]",
        FontFamily->"Courier",
        FontSize->16], 
      RowBox[{
        StyleBox[
          RowBox[{"-", 
            
            FractionBox[\(\(\ \)\(\(t\)\(\ \)\(\[CapitalEpsilon]\)\(\ \)\)\), 
              
              RowBox[{"a", " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        SuperscriptBox[
                          FormBox["\[Nu]",
                            "TraditionalForm"], "2"],
                        DisplayForm],
                      "TraditionalForm"], "-", "1"}], ")"}]}]]}],
          FontFamily->"Courier",
          FontSize->16], 
        RowBox[{
          StyleBox["(",
            FontFamily->"Courier",
            FontSize->16], 
          RowBox[{
            RowBox[{
              StyleBox["2",
                FontFamily->"Courier",
                FontSize->16], 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox[\(1\[InvisibleSpace]1\),
                      SequenceForm[ 1, 1],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 1, ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ 1, 1], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}], "+", \(\[Nu]\[ScriptCapitalE]\_22\), 
            "+", \(\[Nu]\[ScriptCapitalE]\_33\)}], ")"}]}]}]], "Input",
  Evaluatable->False,
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  "and two similar equations. Now let us submit the medium to a shear strain \
",
  Cell[BoxData[
      FormBox[
        TagBox[
          RowBox[{
            StyleBox[
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox[\(1\[InvisibleSpace]2\),
                      SequenceForm[ 1, 2],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["1",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["2",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ 1, 2], 
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"],
              FontFamily->"Courier",
              FontSize->16], 
            StyleBox[" ",
              FontFamily->"Courier",
              FontSize->16], 
            StyleBox["=",
              FontFamily->"Courier",
              FontSize->16,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox[" ",
              FontFamily->"Courier",
              FontSize->16,
              FontWeight->"Plain",
              FontVariations->{"CompatibilityType"->0}], 
            StyleBox[
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox[\(x\[InvisibleSpace]y\),
                      SequenceForm[ x, y],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["x",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["y",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False], 
                        StyleForm[ y, ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ x, y], 
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False], 
                      StyleForm[ y, ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"],
              FontFamily->"Courier",
              FontSize->16,
              FontWeight->"Plain",
              FontVariations->{"CompatibilityType"->0}]}],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "in the x,y plane. Then only the horizontal walls are stressed,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Stressxy = \[Tau]dd[x, 
            y] -> \((\[Tau]dd[x, y] /. HookePY2D)\) /. \[ScriptCapitalE]dd[x, 
            y] -> \[ScriptCapitalE]dd[1, 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Tau]", 
                  InterpretationBox[\(x\[InvisibleSpace]y\),
                    SequenceForm[ x, y],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["y",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False], 
                      StyleForm[ y, ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Tau], 
                  SequenceForm[ x, y], 
                  SequenceForm[ 
                    StyleForm[ x, ShowContents -> False], 
                    StyleForm[ y, ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "\[Rule]", 
            FractionBox[
              RowBox[{"\[CapitalEpsilon]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[\(1\[InvisibleSpace]2\),
                        SequenceForm[ 1, 2],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 1, 2], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], \(\[Nu] + 1\)]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
On the faces x = const and y = const the stresses add up to forces\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Fdd[x, y] \[Equal] 
      Fdd[y, x] \[Equal] \((Fxy = \(n\^2\) a\ t\ \[Tau]dd[x, y] /. 
            Stressxy)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["F", 
                  InterpretationBox[\(x\[InvisibleSpace]y\),
                    SequenceForm[ x, y],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["y",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False], 
                      StyleForm[ y, ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ F, 
                  SequenceForm[ x, y], 
                  SequenceForm[ 
                    StyleForm[ x, ShowContents -> False], 
                    StyleForm[ y, ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["F", 
                  InterpretationBox[\(y\[InvisibleSpace]x\),
                    SequenceForm[ y, x],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["y",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ y, ShowContents -> False], 
                      StyleForm[ x, ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ F, 
                  SequenceForm[ y, x], 
                  SequenceForm[ 
                    StyleForm[ y, ShowContents -> False], 
                    StyleForm[ x, ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            FractionBox[
              RowBox[{
              "a", " ", \(n\^2\), " ", "t", " ", "\[CapitalEpsilon]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[\(1\[InvisibleSpace]2\),
                        SequenceForm[ 1, 2],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 1, 2], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], \(\[Nu] + 1\)]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["from which we derive the gross stress", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Sigma]uu[1, 2] == \[Sigma]uu[2, 1] == 
      Fxy/\((n\ a)\)\^2 == \((Fxy/\((n\ a)\)\^2 /. {\[ScriptCapitalE]dd[1, 
                2] -> \((\[ScriptCapitalE]dd[1, 2] + \[ScriptCapitalE]dd[2, 
                      1])\)/2})\)\), "\[IndentingNewLine]", 
    \(\(Shear2D = \[Sigma]uu[1, 
            2] -> \((Fxy/\((n\ a)\)\^2 /. {\[ScriptCapitalE]dd[1, 
                    2] -> \((\[ScriptCapitalE]dd[1, 2] + \[ScriptCapitalE]dd[
                          2, 1])\)/2})\);\)\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[\(1\[InvisibleSpace]2\),
                    SequenceForm[ 1, 2],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False]], 
                  SequenceForm[ 1, 2]],
                Editable->False],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[\(2\[InvisibleSpace]1\),
                    SequenceForm[ 2, 1],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 1, ShowContents -> False]], 
                  SequenceForm[ 2, 1]],
                Editable->False],
              "TraditionalForm"], "==", 
            FractionBox[
              RowBox[{"t", " ", "\[CapitalEpsilon]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[\(1\[InvisibleSpace]2\),
                        SequenceForm[ 1, 2],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["1",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["2",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 1, ShowContents -> False], 
                          StyleForm[ 2, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 1, 2], 
                      SequenceForm[ 
                        StyleForm[ 1, ShowContents -> False], 
                        StyleForm[ 2, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], \(a\ \((\[Nu] + 1)\)\)], "==", 
            FractionBox[
              RowBox[{"t", " ", "\[CapitalEpsilon]", " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[ScriptCapitalE]", 
                          InterpretationBox[\(1\[InvisibleSpace]2\),
                            SequenceForm[ 1, 2],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False], 
                              StyleForm[ 2, ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[ScriptCapitalE], 
                          SequenceForm[ 1, 2], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False], 
                            StyleForm[ 2, ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "+", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[ScriptCapitalE]", 
                          InterpretationBox[\(2\[InvisibleSpace]1\),
                            SequenceForm[ 2, 1],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox["2",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox["1",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 2, ShowContents -> False], 
                              StyleForm[ 1, ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[ScriptCapitalE], 
                          SequenceForm[ 2, 1], 
                          SequenceForm[ 
                            StyleForm[ 2, ShowContents -> False], 
                            StyleForm[ 1, ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], 
                  ")"}]}], \(2\ a\ \((\[Nu] + 1)\)\)]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["This gives the elastic constants:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[DoubleStruckCapitalE]uuuu[1, 1, 1, 1] == \[DoubleStruckCapitalE]uuuu[
          2, 2, 2, 2] == \[DoubleStruckCapitalE]uuuu[3, 3, 3, 
          3] == \[Sigma]uu[1, 1]/\[ScriptCapitalE]dd[1, 1] /. 
      Stress2D\), "\[IndentingNewLine]", 
    \(\[DoubleStruckCapitalE]uuuu[1, 1, 2, 2] == \[DoubleStruckCapitalE]uuuu[
          1, 1, 3, 3] == \[DoubleStruckCapitalE]uuuu[2, 2, 3, 
          3] == \[Sigma]uu[2, 2]/\[ScriptCapitalE]dd[1, 1] /. 
      Stress2D\), "\[IndentingNewLine]", 
    \(\[DoubleStruckCapitalE]uuuu[1, 2, 1, 2] == \[DoubleStruckCapitalE]uuuu[
        2, 3, 2, 3] == \[DoubleStruckCapitalE]uuuu[3, 1, 3, 1] == 
      D[\[Sigma]uu[1, 2] /. Shear2D, \[ScriptCapitalE]dd[1, 2]]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False]],
                    Editable->False], 
                  
                  InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]1\
\[InvisibleSpace]1\),
                    SequenceForm[ 1, 1, 1, 1],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 1, ShowContents -> False]], 
                  SequenceForm[ 1, 1, 1, 1]],
                Editable->False],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]],
                    Editable->False], 
                  
                  InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]2\
\[InvisibleSpace]2\),
                    SequenceForm[ 2, 2, 2, 2],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False]], 
                  SequenceForm[ 2, 2, 2, 2]],
                Editable->False],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]],
                    Editable->False], 
                  
                  InterpretationBox[\(3\[InvisibleSpace]3\[InvisibleSpace]3\
\[InvisibleSpace]3\),
                    SequenceForm[ 3, 3, 3, 3],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 3, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False]], 
                  SequenceForm[ 3, 3, 3, 3]],
                Editable->False],
              "TraditionalForm"], 
            "==", \(-\(\(2\ t\ \[CapitalEpsilon]\)\/\(a\ \((\[Nu]\^2 - 
                        1)\)\)\)\)}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]],
                    Editable->False], 
                  
                  InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]2\
\[InvisibleSpace]2\),
                    SequenceForm[ 1, 1, 2, 2],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False]], 
                  SequenceForm[ 1, 1, 2, 2]],
                Editable->False],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]],
                    Editable->False], 
                  
                  InterpretationBox[\(1\[InvisibleSpace]1\[InvisibleSpace]3\
\[InvisibleSpace]3\),
                    SequenceForm[ 1, 1, 3, 3],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False]], 
                  SequenceForm[ 1, 1, 3, 3]],
                Editable->False],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]],
                    Editable->False], 
                  
                  InterpretationBox[\(2\[InvisibleSpace]2\[InvisibleSpace]3\
\[InvisibleSpace]3\),
                    SequenceForm[ 2, 2, 3, 3],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False]], 
                  SequenceForm[ 2, 2, 3, 3]],
                Editable->False],
              "TraditionalForm"], 
            "==", \(-\(\(t\ \[CapitalEpsilon]\ \[Nu]\)\/\(a\ \((\[Nu]\^2 - 
                        1)\)\)\)\)}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False]],
                    Editable->False], 
                  
                  InterpretationBox[\(1\[InvisibleSpace]2\[InvisibleSpace]1\
\[InvisibleSpace]2\),
                    SequenceForm[ 1, 2, 1, 2],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False]], 
                  SequenceForm[ 1, 2, 1, 2]],
                Editable->False],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["2",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 2, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False]],
                    Editable->False], 
                  
                  InterpretationBox[\(2\[InvisibleSpace]3\[InvisibleSpace]2\
\[InvisibleSpace]3\),
                    SequenceForm[ 2, 3, 2, 3],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False], 
                    StyleForm[ 2, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False]], 
                  SequenceForm[ 2, 3, 2, 3]],
                Editable->False],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["3",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["1",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False], 
                      StyleForm[ 3, ShowContents -> False], 
                      StyleForm[ 1, ShowContents -> False]],
                    Editable->False], 
                  
                  InterpretationBox[\(3\[InvisibleSpace]1\[InvisibleSpace]3\
\[InvisibleSpace]1\),
                    SequenceForm[ 3, 1, 3, 1],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 3, ShowContents -> False], 
                    StyleForm[ 1, ShowContents -> False], 
                    StyleForm[ 3, ShowContents -> False], 
                    StyleForm[ 1, ShowContents -> False]], 
                  SequenceForm[ 3, 1, 3, 1]],
                Editable->False],
              "TraditionalForm"], 
            "==", \(\(t\ \[CapitalEpsilon]\)\/\(2\ a\ \((\[Nu] + 1)\)\)\)}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["The elastic coefficients are here very different from \
those of the isotropic solid.",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "In spite of the fact that the material shows the same elastic behavior in \
the three axis directions, it is not isotopic. This could be verified by a \
change in the axis. Fl\[UDoubleDot]gge describes the example where the new \
orthonormal frame, let's call it green frame, has the axis ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckE]", 
                    FormBox[
                      TagBox[
                        StyleBox["3",
                          FontColor->RGBColor[0.133303, 0.545113, 0.133303]],
                        (
                        StyleForm[ #, FontColor -> 
                          RGBColor[ .13330500000000001, .54510599999999998, \
.13330500000000001]]&)],
                      "TraditionalForm"], 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["3",
                              FontColor->RGBColor[0.133303, 0.545113, 
                              0.133303]],
                            (
                            StyleForm[ #, FontColor -> 
                              RGBColor[ .13330500000000001, \
.54510599999999998, .13330500000000001]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]],
                  Subsuperscript[ \[DoubleStruckE], 
                    green[ 3], 
                    StyleForm[ 
                      green[ 3], ShowContents -> False]],
                  Editable->False],
                FontFamily->"Courier",
                FontSize->18],
              (StyleForm[ #, FontSize -> 18, FontFamily -> "Courier"]&)],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " in the direction {1,1,1} in the black frame, and ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckE]", 
                    FormBox[
                      TagBox[
                        StyleBox["2",
                          FontColor->RGBColor[0.133303, 0.545113, 0.133303]],
                        (
                        StyleForm[ #, FontColor -> 
                          RGBColor[ .13330500000000001, .54510599999999998, \
.13330500000000001]]&)],
                      "TraditionalForm"], 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["2",
                              FontColor->RGBColor[0.133303, 0.545113, 
                              0.133303]],
                            (
                            StyleForm[ #, FontColor -> 
                              RGBColor[ .13330500000000001, \
.54510599999999998, .13330500000000001]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]],
                  Subsuperscript[ \[DoubleStruckE], 
                    green[ 2], 
                    StyleForm[ 
                      green[ 2], ShowContents -> False]],
                  Editable->False],
                FontFamily->"Courier",
                FontSize->18],
              (StyleForm[ #, FontSize -> 18, FontFamily -> "Courier"]&)],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "obtained by a rotation of  45\[Degree] of the initial axis ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckE]", "2", 
                    TagBox[
                      StyleBox["2",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]],
                  Subsuperscript[ \[DoubleStruckE], 2, 
                    StyleForm[ 2, ShowContents -> False]],
                  Editable->False],
                FontFamily->"Courier",
                FontSize->18],
              (StyleForm[ #, FontSize -> 18, FontFamily -> "Courier"]&)],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  ". I will not detailed this example here."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simpler form for the elastic law of isotropic bodies", "Subsection"],

Cell["We start from the constitutive equations,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(gdd[red@j, red@p] \((LameForm[\([3]\)])\) \[ScriptCapitalE]dd[
          red@l, red@m]\), "//", 
      StyleBox["Expand",
        FontColor->RGBColor[0, 0, 
        1]]}], "\[IndentingNewLine]", \(\((\(% // MetricSimplify[g]\) // 
          FullSimplify)\);\), "\[IndentingNewLine]", \(HookesLaw2 = % // 
          SymmetricStandardOrder[\[ScriptCapitalE]];\), \
"\[IndentingNewLine]", \(ResultFrame[\[IndentingNewLine]\[Sigma]ud[red@i, 
          red@p] \[Equal] \((\[Sigma]\[Section]\[Section]ud[red@i_, red@p_] = 
            HookesLaw2 // Simplify)\)]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FractionBox[
              RowBox[{"\[CapitalEpsilon]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ j], 
                          red[ p]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            red[ p], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        red[ j], 
                        red[ p]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          red[ p], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ i], 
                          red[ m]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ i], 
                        red[ m]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            red[ l], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ j], 
                          red[ l]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          red[ l], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ j], 
                        red[ l]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], \(2\ \((\[Nu] + 1)\)\)], "+", 
            FractionBox[
              RowBox[{"\[CapitalEpsilon]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ j], 
                          red[ p]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            red[ p], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        red[ j], 
                        red[ p]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          red[ p], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ l], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ i], 
                          red[ l]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ l], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ i], 
                        red[ l]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ j], 
                          red[ m]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ j], 
                        red[ m]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], \(2\ \((\[Nu] + 1)\)\)], "+", 
            FractionBox[
              RowBox[{"\[CapitalEpsilon]", " ", "\[Nu]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ j], 
                          red[ p]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            red[ p], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        red[ j], 
                        red[ p]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          red[ p], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ i], 
                          red[ j]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ i], 
                        red[ j]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ l], 
                          red[ m]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["l",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ l], ShowContents -> False], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 
                        red[ l], 
                        red[ m]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ l], ShowContents -> False], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]]],
                    Editable->False],
                  
                  "TraditionalForm"]}], \(\((1 - 2\ \[Nu])\)\ \((\[Nu] + 
                    1)\)\)]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Sigma]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              red[ p]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              red[ i], 
                              StyleForm[ 
                                red[ p], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[Sigma], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            red[ p]], 
                          SequenceForm[ 
                            red[ i], 
                            StyleForm[ 
                              red[ p], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "==", 
                    FractionBox[
                      RowBox[{"\[CapitalEpsilon]", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["\[ScriptCapitalE]", 
                                  InterpretationBox[
                                    RowBox[{
                                      TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                      FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                    SequenceForm[ 
                                      StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                      red[ p]],
                                    Editable->False], 
                                  InterpretationBox[
                                    RowBox[{
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                      "\[InvisibleSpace]", 
                                      TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                    SequenceForm[ 
                                      red[ i], 
                                      StyleForm[ 
                                        red[ p], ShowContents -> False]],
                                    Editable->False]],
                                Subsuperscript[ \[ScriptCapitalE], 
                                  SequenceForm[ 
                                    StyleForm[ 
                                      red[ i], ShowContents -> False], 
                                    red[ p]], 
                                  SequenceForm[ 
                                    red[ i], 
                                    StyleForm[ 
                                      red[ p], ShowContents -> False]]],
                                Editable->False],
                              "TraditionalForm"], "+", 
                            FractionBox[
                              RowBox[{"\[Nu]", " ", 
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["g", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        red[ p]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        red[ i], 
                                        StyleForm[ 
                                        red[ p], ShowContents -> False]],
                                        Editable->False]],
                                    Subsuperscript[ g, 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ i], ShowContents -> False], 
                                        red[ p]], 
                                      SequenceForm[ 
                                        red[ i], 
                                        StyleForm[ 
                                        red[ p], ShowContents -> False]]],
                                    Editable->False],
                                  "TraditionalForm"], " ", 
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["\[ScriptCapitalE]", 
                                      InterpretationBox[
                                        RowBox[{
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)], "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False], 
                                        red[ m]],
                                        Editable->False], 
                                      InterpretationBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"], 
                                        "\[InvisibleSpace]", 
                                        TagBox[
                                        StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                        SequenceForm[ 
                                        red[ m], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]],
                                        Editable->False]],
                                    Subsuperscript[ \[ScriptCapitalE], 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False], 
                                        red[ m]], 
                                      SequenceForm[ 
                                        red[ m], 
                                        StyleForm[ 
                                        red[ m], ShowContents -> False]]],
                                    Editable->False],
                                  "TraditionalForm"]}], \(1 - 2\ \[Nu]\)]}], 
                          ")"}]}], \(\[Nu] + 1\)]}], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "11", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  Equal[ 
                    Tensor[ \[Sigma], {
                      red[ i], Void}, {Void, 
                      red[ p]}], 
                    Times[ \[CapitalEpsilon], 
                      Power[ 
                        Plus[ 1, \[Nu]], -1], 
                      Plus[ 
                        Tensor[ \[ScriptCapitalE], {
                          red[ i], Void}, {Void, 
                          red[ p]}], 
                        Times[ 
                          Power[ 
                            Plus[ 1, 
                              Times[ -2, \[Nu]]], -1], \[Nu], 
                          Tensor[ g, {
                            red[ i], Void}, {Void, 
                            red[ p]}], 
                          Tensor[ \[ScriptCapitalE], {
                            red[ m], Void}, {Void, 
                            red[ m]}]]]]], "      (4.", 11, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["which gives using Lame coefficients :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]%[\([{2}]\)] /. LameRule // 
        Simplify]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Sigma]", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["p",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ p]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ p], ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[Sigma], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              red[ p]], 
                            SequenceForm[ 
                              red[ i], 
                              StyleForm[ 
                                red[ p], ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"], "==", 
                      RowBox[{
                        RowBox[{"2", " ", "\[Mu]", " ", 
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["\[ScriptCapitalE]", 
                                InterpretationBox[
                                  RowBox[{
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                     "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ 
                                    StyleForm[ 
                                      red[ i], ShowContents -> False], 
                                    red[ p]],
                                  Editable->False], 
                                InterpretationBox[
                                  RowBox[{
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"], "\[InvisibleSpace]",
                                     
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                  SequenceForm[ 
                                    red[ i], 
                                    StyleForm[ 
                                      red[ p], ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ \[ScriptCapitalE], 
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ p]], 
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ p], ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"]}], "+", 
                        RowBox[{"\[Lambda]", " ", 
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["g", 
                                InterpretationBox[
                                  RowBox[{
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                     "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ 
                                    StyleForm[ 
                                      red[ i], ShowContents -> False], 
                                    red[ p]],
                                  Editable->False], 
                                InterpretationBox[
                                  RowBox[{
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"], "\[InvisibleSpace]",
                                     
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                  SequenceForm[ 
                                    red[ i], 
                                    StyleForm[ 
                                      red[ p], ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ g, 
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ p]], 
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ p], ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"], " ", 
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["\[ScriptCapitalE]", 
                                InterpretationBox[
                                  RowBox[{
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                     "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ 
                                    StyleForm[ 
                                      red[ m], ShowContents -> False], 
                                    red[ m]],
                                  Editable->False], 
                                InterpretationBox[
                                  RowBox[{
                                    FormBox[
                                      TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"], "\[InvisibleSpace]",
                                     
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                  SequenceForm[ 
                                    red[ m], 
                                    StyleForm[ 
                                      red[ m], ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ \[ScriptCapitalE], 
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False], 
                                  red[ m]], 
                                SequenceForm[ 
                                  red[ m], 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"]}]}]}],
                    SequenceForm[ 
                      Equal[ 
                        Tensor[ \[Sigma], {
                          red[ i], Void}, {Void, 
                          red[ p]}], 
                        Plus[ 
                          Times[ 2, \[Mu], 
                            Tensor[ \[ScriptCapitalE], {
                              red[ i], Void}, {Void, 
                              red[ p]}]], 
                          Times[ \[Lambda], 
                            Tensor[ g, {
                              red[ i], Void}, {Void, 
                              red[ p]}], 
                            Tensor[ \[ScriptCapitalE], {
                              red[ m], Void}, {Void, 
                              red[ m]}]]]]],
                    Editable->False], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "12", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  SequenceForm[ 
                    Equal[ 
                      Tensor[ \[Sigma], {
                        red[ i], Void}, {Void, 
                        red[ p]}], 
                      Plus[ 
                        Times[ 2, \[Mu], 
                          Tensor[ \[ScriptCapitalE], {
                            red[ i], Void}, {Void, 
                            red[ p]}]], 
                        Times[ \[Lambda], 
                          Tensor[ g, {
                            red[ i], Void}, {Void, 
                            red[ p]}], 
                          Tensor[ \[ScriptCapitalE], {
                            red[ m], Void}, {Void, 
                            red[ m]}]]]]], "      (4.", 12, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inversion of the above relations", "Subsection"],

Cell[TextData[{
  "We first calculate ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ m], ShowContents -> False], 
              red[ m]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ m], 
              StyleForm[ 
                red[ m], ShowContents -> False]],
            Editable->False]], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\(\(HookesLaw2 /. p -> i // ContractKroneckers[g]\) // 
        DummySimplify\) // FullSimplify\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(dilation = \(Solve[% == \[Sigma]ud[red@i, red@i], 
            Tensor[\[ScriptCapitalE], List[red[i], Void], 
              List[Void, red[i]]]]\)[\([1]\)] /. i -> m\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FractionBox[
            RowBox[{"\[CapitalEpsilon]", " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ i]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ i], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ i]], 
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ i], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}], \(1 - 2\ \[Nu]\)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["m",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ m], ShowContents -> False], 
                        red[ m]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["m",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ m], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ m], ShowContents -> False], 
                      red[ m]], 
                    SequenceForm[ 
                      red[ m], 
                      StyleForm[ 
                        red[ m], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], "\[Rule]", 
              FractionBox[
                RowBox[{\((1 - 2\ \[Nu])\), " ", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Sigma]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ m], ShowContents -> False], 
                            red[ m]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["m",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["m",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            red[ m], 
                            StyleForm[ 
                              red[ m], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Sigma], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          red[ m]], 
                        SequenceForm[ 
                          red[ m], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], "\[CapitalEpsilon]"]}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "then determine ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                TagBox[
                  StyleBox["p",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              red[ p]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["p",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ i], 
              StyleForm[ 
                red[ p], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\[CapitalEpsilon]\ \[ScriptCapitalE]ud[
              red@i, red@
                p] == \((\[CapitalEpsilon]\ \[ScriptCapitalE]ud[red@i, 
                    red@p] /. \[IndentingNewLine]\[IndentingNewLine]\(Solve[\
\[Sigma]ud[red@i, red@p] \[Equal] HookesLaw2 /. dilation, 
                    Tensor[\[ScriptCapitalE], List[red[i], Void], 
                      List[Void, red[p]]]]\)[\([1]\)] // FullSimplify)\)] /. 
      p -> j\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  RowBox[{
                    RowBox[{"\[CapitalEpsilon]", " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[ScriptCapitalE]", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ j]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[ScriptCapitalE], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              red[ j]], 
                            SequenceForm[ 
                              red[ i], 
                              StyleForm[ 
                                red[ j], ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"]}], "==", 
                    RowBox[{
                      RowBox[{\((\[Nu] + 1)\), " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Sigma]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ j]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[Sigma], 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ j]], 
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"]}], "-", 
                      RowBox[{"\[Nu]", " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["g", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ j]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ g, 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ j]], 
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"], " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Sigma]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False], 
                                  red[ m]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ m], 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[Sigma], 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ m], ShowContents -> False], 
                                red[ m]], 
                              SequenceForm[ 
                                red[ m], 
                                StyleForm[ 
                                  red[ m], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"]}]}]}], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "13", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  Equal[ 
                    Times[ \[CapitalEpsilon], 
                      Tensor[ \[ScriptCapitalE], {
                        red[ i], Void}, {Void, 
                        red[ j]}]], 
                    Plus[ 
                      Times[ 
                        Plus[ 1, \[Nu]], 
                        Tensor[ \[Sigma], {
                          red[ i], Void}, {Void, 
                          red[ j]}]], 
                      Times[ -1, \[Nu], 
                        Tensor[ g, {
                          red[ i], Void}, {Void, 
                          red[ j]}], 
                        Tensor[ \[Sigma], {
                          red[ m], Void}, {Void, 
                          red[ m]}]]]], "      (4.", 13, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ m], ShowContents -> False], 
              red[ m]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ m], 
              StyleForm[ 
                red[ m], ShowContents -> False]],
            Editable->False]], "represents", " ", "the", " ", 
        StyleBox["cubic",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["dilation",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[",",
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox[" ",
        FontColor->RGBColor[0, 0, 1]], 
      RowBox[{"while", "  ", 
        RowBox[{
          SubsuperscriptBox["\[Sigma]", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["m",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                FormBox[
                  TagBox[
                    StyleBox["m",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"]}],
              SequenceForm[ 
                StyleForm[ 
                  red[ m], ShowContents -> False], 
                red[ m]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["m",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"], "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["m",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                red[ m], 
                StyleForm[ 
                  red[ m], ShowContents -> False]],
              Editable->False]], "/", "3"}], " ", "is", " ", "the", " ", 
        "average", " ", "of", " ", "the", " ", "normal", " ", "stresses", " ",
         "and", " ", "is", " ", "called", " ", "the", " ", 
        StyleBox["hydrostatic",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox["stress",
            FontColor->RGBColor[0, 0, 1]], ".", "\[IndentingNewLine]", 
          "The"}], " ", "relation", " ", "between", " ", 
        StyleBox[
          RowBox[{"th", 
            StyleBox["e",
              FontColor->GrayLevel[0]]}]], 
        StyleBox[" ",
          FontColor->GrayLevel[0]], "hydrostatic", " ", "stress", " ", "and", 
        
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox["the",
          FontColor->GrayLevel[0]], 
        StyleBox[" ",
          FontColor->GrayLevel[0]], "cubic", " ", "dilation", " ", "is"}], 
      ","}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\[Sigma]ud[red@i, red@i]/
          3 == \((\(\(HookesLaw2 /. p -> i // ContractKroneckers[g]\) // 
                DummySimplify\) // Simplify)\)/3 == 
        K\ \[ScriptCapitalE]ud[red@i, red@i]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  RowBox[{
                    RowBox[{\(1\/3\), " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Sigma]", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ i]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ i], ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[Sigma], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              red[ i]], 
                            SequenceForm[ 
                              red[ i], 
                              StyleForm[ 
                                red[ i], ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"]}], "==", 
                    FractionBox[
                      RowBox[{"\[CapitalEpsilon]", " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[ScriptCapitalE]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ i]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[ScriptCapitalE], 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ i]], 
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ i], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"]}], \(3\ \((1 - 2\ \[Nu])\)\)], "==",
                     
                    RowBox[{"K", " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[ScriptCapitalE]", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ i]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ i], ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ \[ScriptCapitalE], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              red[ i]], 
                            SequenceForm[ 
                              red[ i], 
                              StyleForm[ 
                                red[ i], ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"]}]}], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "14", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  Equal[ 
                    Times[ 
                      Rational[ 1, 3], 
                      Tensor[ \[Sigma], {
                        red[ i], Void}, {Void, 
                        red[ i]}]], 
                    Times[ 
                      Rational[ 1, 3], \[CapitalEpsilon], 
                      Power[ 
                        Plus[ 1, 
                          Times[ -2, \[Nu]]], -1], 
                      Tensor[ \[ScriptCapitalE], {
                        red[ i], Void}, {Void, 
                        red[ i]}]], 
                    Times[ K, 
                      Tensor[ \[ScriptCapitalE], {
                        red[ i], Void}, {Void, 
                        red[ i]}]]], "      (4.", 14, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["K",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"CompatibilityType"->0}],
  " is the bulk modulus of the material.\n",
  StyleBox["Hydrostatic stress ",
    FontVariations->{"Underline"->True}],
  StyleBox["s",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox[" and cubic dilation ",
    FontVariations->{"Underline"->True}],
  StyleBox["e",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox[" of are defined by the rule",
    FontVariations->{"Underline"->True}],
  " :"
}], "Text"],

Cell[BoxData[
    \(\(HyddilDEF = \ {\[Sigma]ud[i_, i_] -> 
            3  s, \[ScriptCapitalE]ud[i_, i_] -> 3  e};\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Hyddil = \((\((\(\(\((1 - 2  \[Nu])\) HookesLaw2 /. p -> i // 
                      ContractKroneckers[g]\) // DummySimplify\) // 
                  Simplify)\)/
              3\[IndentingNewLine] -> \((1 - 2  \[Nu])\) \[Sigma]ud[red@i, 
                  red@i]/3)\) /. HyddilDEF\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\(e\ \[CapitalEpsilon] \[Rule] s\ \((1 - 2\ \[Nu])\)\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strain and stress deviations ", "Subsection"],

Cell[TextData[{
  "We introduce the ",
  StyleBox["strain deviation",
    FontColor->RGBColor[0, 0, 1]],
  " and the ",
  StyleBox["stress deviation",
    FontColor->RGBColor[0, 0, 1]],
  " by,"
}], "Text"],

Cell[BoxData[{
    \(Tensor[\ 
        e\[Section], {i_, Void}, {Void, j_}] := \[ScriptCapitalE]ud[i, j] - 
        e\ Tensor[\[Delta], {i, Void}, {Void, j}]\), "\[IndentingNewLine]", 
    \(Tensor[\ s\[Section], {i_, Void}, {Void, j_}] := \[Sigma]ud[i, j] - 
        s\ Tensor[\[Delta], {i, Void}, {Void, j}]\)}], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Tensor[\ e, {red@i, Void}, {Void, red@j}] == 
      Tensor[\ e\[Section], {red@i, Void}, {Void, 
          red@j}]\), "\[IndentingNewLine]", 
    \(Tensor[\ s, {red@i, Void}, {Void, red@j}] == 
      Tensor[\ s\[Section], {red@i, Void}, {Void, red@j}]\)}], "Input",
  CellOpen->False],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["e", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ e, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    red[ j]], 
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptCapitalE]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ j]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptCapitalE], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ j]], 
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], "-", 
              RowBox[{"e", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Delta]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          red[ j]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ i], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Delta], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ j]], 
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["s", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ s, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    red[ j]], 
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Sigma]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ j]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[Sigma], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ j]], 
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], "-", 
              RowBox[{"s", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Delta]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          red[ j]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ i], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Delta], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ j]], 
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["The following relation is verified :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]esrel = \((\[CapitalEpsilon]\ Tensor[\ 
                e, {red@i, Void}, {Void, red@j}] == \((1 + \[Nu])\) 
              Tensor[\ s, {red@i, Void}, {Void, red@j}])\)]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  RowBox[{
                    RowBox[{"\[CapitalEpsilon]", " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["e", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ j]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ e, 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              red[ j]], 
                            SequenceForm[ 
                              red[ i], 
                              StyleForm[ 
                                red[ j], ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"]}], "==", 
                    RowBox[{\((\[Nu] + 1)\), " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["s", 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ j]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ s, 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              red[ j]], 
                            SequenceForm[ 
                              red[ i], 
                              StyleForm[ 
                                red[ j], ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"]}]}], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "15", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", 
                  Equal[ 
                    Times[ \[CapitalEpsilon], 
                      Tensor[ e, {
                        red[ i], Void}, {Void, 
                        red[ j]}]], 
                    Times[ 
                      Plus[ 1, \[Nu]], 
                      Tensor[ s, {
                        red[ i], Void}, {Void, 
                        red[ j]}]]], "      (4.", 15, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((esrel /. {e -> e\[Section], s -> s\[Section]} // Simplify)\) /. 
        Hyddil // Simplify\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{
              RowBox[{"\[CapitalEpsilon]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          red[ j]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ i], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ j]], 
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], "+", 
              RowBox[{"3", " ", "s", " ", "\[Nu]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Delta]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          red[ j]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ i], 
                          StyleForm[ 
                            red[ j], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[Delta], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ j]], 
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}]}], "==", 
            RowBox[{\((\[Nu] + 1)\), " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Sigma]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ j]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[Sigma], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ j]], 
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "which is the relation obtained above (",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["g", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ i], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "\[Congruent] ",
  Cell[BoxData[
      FormBox[
        InterpretationBox[
          SubsuperscriptBox["\[Delta]", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                FormBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"]}],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False], 
                red[ j]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"], "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                red[ i], 
                StyleForm[ 
                  red[ j], ShowContents -> False]],
              Editable->False]],
          Subsuperscript[ \[Delta], 
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              red[ j]], 
            SequenceForm[ 
              red[ i], 
              StyleForm[ 
                red[ j], ShowContents -> False]]],
          Editable->False], TraditionalForm]]],
  "). We can also write with the ",
  "Lame",
  " moduli,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[{\((\(\(\[Lambda] + \[Mu]\)\/\[Mu]\) 
                    Hyddil[\([2]\)] -> \(\(\[Lambda] + \[Mu]\)\/\[Mu]\) 
                    Hyddil[\([1]\)] /. LameRule)\) // 
            FullSimplify\ , \ \ \ \ "\<  and\>"\ , \
\[IndentingNewLine]\(Solve[\((esrel /. \[IndentingNewLine]LameRule)\) // 
                Simplify, Tensor[\ s, {red@i, Void}, {Void, red@j}]]\)[\([1, 
              1]\)]} /. Rule -> Equal]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  RowBox[{"{", 
                    
                    RowBox[{\(s == e\ \((3\ \[Lambda] + 2\ \[Mu])\)\), 
                      ",", "\<\"  and\"\>", ",", 
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["s", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ j]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ s, 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ j]], 
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"], "==", 
                        RowBox[{"2", " ", "\[Mu]", " ", 
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["e", 
                                InterpretationBox[
                                  RowBox[{
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                     "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ 
                                    StyleForm[ 
                                      red[ i], ShowContents -> False], 
                                    red[ j]],
                                  Editable->False], 
                                InterpretationBox[
                                  RowBox[{
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"], "\[InvisibleSpace]",
                                     
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                  SequenceForm[ 
                                    red[ i], 
                                    StyleForm[ 
                                      red[ j], ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ e, 
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ j]], 
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"]}]}]}], "}"}], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "16", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", {
                  Equal[ s, 
                    Times[ e, 
                      Plus[ 
                        Times[ 3, \[Lambda]], 
                        Times[ 2, \[Mu]]]]], "  and", 
                  Equal[ 
                    Tensor[ s, {
                      red[ i], Void}, {Void, 
                      red[ j]}], 
                    Times[ 2, \[Mu], 
                      Tensor[ e, {
                        red[ i], Void}, {Void, 
                        red[ j]}]]]}, "      (4.", 16, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Viscous fluids", "Subsection"],

Cell["\<\
In the case of isotropic viscous fluids, the stresses depend on the time \
derivatives of the strains (the strain rates).  So we may use the above \
equations, simply replacing the strains by the strain rates :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]%[\([2]\)] /. 
        e -> e\& . \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            StyleBox[
              InterpretationBox[
                RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
                  RowBox[{"{", 
                    
                    RowBox[{\(s == \((3\ \[Lambda] + 
                              2\ \[Mu])\)\ \(e\& . \)\), ",", "\<\"  and\"\>",
                       ",", 
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["s", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ j]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ s, 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ j]], 
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ j], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"], "==", 
                        RowBox[{"2", " ", "\[Mu]", " ", 
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox[\(e\& . \), 
                                InterpretationBox[
                                  RowBox[{
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                     "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ 
                                    StyleForm[ 
                                      red[ i], ShowContents -> False], 
                                    red[ j]],
                                  Editable->False], 
                                InterpretationBox[
                                  RowBox[{
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"], "\[InvisibleSpace]",
                                     
                                    TagBox[
                                      StyleBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> 
                                        False]&)]}],
                                  SequenceForm[ 
                                    red[ i], 
                                    StyleForm[ 
                                      red[ j], ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ 
                                OverDot[ e, 1], 
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ j]], 
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ j], ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"]}]}]}], "}"}], 
                  "\[InvisibleSpace]", "\<\"      (4.\"\>", 
                  "\[InvisibleSpace]", "17", 
                  "\[InvisibleSpace]", "\<\")\"\>"}],
                SequenceForm[ "      ", {
                  Equal[ s, 
                    Times[ 
                      Plus[ 
                        Times[ 3, \[Lambda]], 
                        Times[ 2, \[Mu]]], 
                      OverDot[ e, 1]]], "  and", 
                  Equal[ 
                    Tensor[ s, {
                      red[ i], Void}, {Void, 
                      red[ j]}], 
                    Times[ 2, \[Mu], 
                      Tensor[ 
                        OverDot[ e, 1], {
                        red[ i], Void}, {Void, 
                        red[ j]}]]]}, "      (4.", 17, ")"],
                Editable->False],
              Background->RGBColor[0, 1, 0],
              Magnification->1.2],
            (
            StyleForm[ #, Background -> RGBColor[ 0, 1, 0], Magnification -> 
              1.2]&)],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plasticity", "Section",
  CellTags->"Plasticity"],

Cell[TextData[{
  "In the uni-axial tension test, a material is called ",
  StyleBox["ideally plastic",
    FontColor->RGBColor[0, 0, 1]],
  " if stress and strain are related according to the following rules :\ni) \
they obey the Hooke's law  \[Sigma] = E \[Epsilon] for stresses \[Sigma] < ",
  Cell[BoxData[
      StyleBox[
        SubscriptBox[
          StyleBox["\[Sigma]",
            FontSize->16], "Y"],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Masked"->False,
        "CompatibilityType"->0,
        "RotationAngle"->0}]]],
  "\nii) At the yield stress ",
  Cell[BoxData[
      StyleBox[
        SubscriptBox[
          StyleBox["\[Sigma]",
            FontSize->16], "Y"],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Masked"->False,
        "CompatibilityType"->0,
        "RotationAngle"->0}]]],
  "the strain can increase indefinitely without any restriction on the strain \
rate  d\[Epsilon] / dt except d\[Epsilon] / dt > 0.\niii) the stress cannot \
be increased beyond ",
  Cell[BoxData[
      StyleBox[
        SubscriptBox[
          StyleBox["\[Sigma]",
            FontSize->16], "Y"],
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False,
        "StrikeThrough"->False,
        "Masked"->False,
        "CompatibilityType"->0,
        "RotationAngle"->0}]]],
  "."
}], "Text"],

Cell["We shall detail this subject in a future version.", "Text"],

Cell[BoxData[
    \(\(ClearTensorShortcuts[{{\[DoubleStruckE], da, db, dc, 
            u, \[ScriptCapitalE], \[Sigma]}, 
          1}, {{g, \[Sigma], \[ScriptCapitalE], \[ScriptCapitalE]\[Section], 
            d\[ScriptCapitalE], \[Gamma], \[Tau], F}, 2}, {{e}, 
          3}, {{\[DoubleStruckCapitalE]}, 4}];\)\)], "Input"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1013, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"], None, Cell[ 
      "J.-F. Gouyet", "Header"]}, {
    Cell[ "Continuum Mechanics", "Header"], None, Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{True, True},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->True,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
ShowCellLabel->False,
CellLabelAutoDelete->True,
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Stress tensor"->{
    Cell[4714, 138, 72, 1, 41, "Section",
      CellTags->"Stress tensor"]},
  "Constitutive equations"->{
    Cell[739585, 14519, 79, 1, 41, "Section",
      CellTags->"Constitutive equations"]},
  "Plasticity"->{
    Cell[1790441, 35920, 55, 1, 41, "Section",
      CellTags->"Plasticity"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Stress tensor", 1796559, 36094},
  {"Constitutive equations", 1796666, 36097},
  {"Plasticity", 1796774, 36100}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 28, 0, 76, "Title"],

Cell[CellGroupData[{
Cell[1829, 57, 64, 1, 49, "Subsection",
  InitializationCell->True],
Cell[1896, 60, 448, 10, 146, "Input",
  InitializationCell->True],
Cell[2347, 72, 498, 9, 166, "Input",
  InitializationCell->True],
Cell[2848, 83, 375, 6, 46, "Input",
  InitializationCell->True],
Cell[3226, 91, 93, 2, 34, "Text"],
Cell[3322, 95, 1069, 29, 159, "Input",
  InitializationCell->True],
Cell[4394, 126, 69, 1, 34, "Text",
  InitializationCell->True],
Cell[4466, 129, 211, 4, 46, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4714, 138, 72, 1, 41, "Section",
  CellTags->"Stress tensor"],
Cell[4789, 141, 65, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[4879, 145, 44749, 697, 214, "Graphics"],
Cell[49631, 844, 34567, 430, 237, 34449, 426, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],
Cell[84213, 1277, 99, 2, 34, "Text"],
Cell[84315, 1281, 179, 3, 90, "Input"],
Cell[84497, 1286, 475, 13, 35, "Text"],
Cell[84975, 1301, 54, 1, 46, "Input"],

Cell[CellGroupData[{
Cell[85054, 1306, 296, 4, 58, "Input"],
Cell[85353, 1312, 465, 10, 47, "Output"]
}, Open  ]],
Cell[85833, 1325, 280, 10, 35, "Text"],

Cell[CellGroupData[{
Cell[86138, 1339, 504, 8, 86, "Input"],
Cell[86645, 1349, 29771, 628, 47, "Output"],
Cell[116419, 1979, 21155, 469, 47, "Output"]
}, Open  ]],
Cell[137589, 2451, 1147, 34, 35, "Text"],

Cell[CellGroupData[{
Cell[138761, 2489, 97, 2, 46, "Input"],
Cell[138861, 2493, 21155, 469, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160053, 2967, 552, 12, 86, "Input"],
Cell[160608, 2981, 24466, 540, 47, "Output"]
}, Open  ]],
Cell[185089, 3524, 30, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[185144, 3528, 239, 4, 86, "Input"],
Cell[185386, 3534, 7572, 184, 47, "Output"],
Cell[192961, 3720, 3482, 88, 47, "Output"],
Cell[196446, 3810, 3450, 88, 47, "Output"]
}, Open  ]],
Cell[199911, 3901, 99, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[200035, 3907, 313, 6, 79, "Input"],
Cell[200351, 3915, 9205, 224, 47, "Output"]
}, Open  ]],
Cell[209571, 4142, 39, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[209635, 4146, 181, 5, 46, "Input"],
Cell[209819, 4153, 224, 7, 29, "Output"]
}, Open  ]],
Cell[210058, 4163, 915, 33, 78, "Text"],
Cell[210976, 4198, 479, 8, 86, "Input"],

Cell[CellGroupData[{
Cell[211480, 4210, 222, 4, 66, "Input"],
Cell[211705, 4216, 19753, 458, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231495, 4679, 273, 5, 66, "Input"],
Cell[231771, 4686, 8972, 181, 42, "Output"]
}, Open  ]],
Cell[240758, 4870, 30962, 782, 147, "Text"],

Cell[CellGroupData[{
Cell[271745, 5656, 122795, 1891, 199, 122678, 1887, "GraphicsData", "PICT", \
"Graphics"],
Cell[394543, 7549, 32331, 403, 250, 32214, 399, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[426911, 7957, 7366, 159, 47, "Subsubsection"],
Cell[434280, 8118, 56, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[434361, 8122, 684, 14, 106, "Input"],
Cell[435048, 8138, 39388, 867, 32, "Output"]
}, Open  ]],
Cell[474451, 9008, 171, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[474647, 9015, 221, 3, 46, "Input"],
Cell[474871, 9020, 10987, 252, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[485895, 9277, 698, 12, 86, "Input"],
Cell[486596, 9291, 58186, 1275, 32, "Output"]
}, Open  ]],
Cell[544797, 10569, 87, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[544909, 10575, 89, 1, 46, "Input"],
Cell[545001, 10578, 38023, 819, 32, "Output"]
}, Open  ]],
Cell[583039, 11400, 1147, 34, 34, "Text"],

Cell[CellGroupData[{
Cell[584211, 11438, 73, 1, 46, "Input"],
Cell[584287, 11441, 36395, 779, 32, "Output"]
}, Open  ]],
Cell[620697, 12223, 139, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[620861, 12230, 140, 2, 46, "Input"],
Cell[621004, 12234, 32677, 659, 32, "Output"]
}, Open  ]],
Cell[653696, 12896, 38, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[653759, 12900, 258, 4, 66, "Input"],
Cell[654020, 12906, 6721, 148, 32, "Output"]
}, Open  ]],
Cell[660756, 13057, 161, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[660942, 13064, 111, 2, 46, "Input"],
Cell[661056, 13068, 8054, 167, 42, "Output"]
}, Open  ]],
Cell[669125, 13238, 2661, 69, 33, "Text"],

Cell[CellGroupData[{
Cell[671811, 13311, 587, 12, 86, "Input"],
Cell[672401, 13325, 10263, 228, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[682701, 13558, 104, 2, 46, "Input"],
Cell[682808, 13562, 8910, 213, 35, "Output"]
}, Open  ]],
Cell[691733, 13778, 4222, 118, 52, "Text"],
Cell[695958, 13898, 156, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[696139, 13905, 20997, 325, 136, 20880, 321, "GraphicsData", "PICT", \
"Graphics"],
Cell[717139, 14232, 22385, 280, 215, 22263, 276, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[739585, 14519, 79, 1, 41, "Section",
  CellTags->"Constitutive equations"],
Cell[739667, 14522, 199, 5, 34, "Text"],
Cell[739869, 14529, 1410, 28, 206, "Input"],

Cell[CellGroupData[{
Cell[741304, 14561, 633, 12, 106, "Input"],
Cell[741940, 14575, 17274, 333, 42, "Output"]
}, Open  ]],
Cell[759229, 14911, 74, 0, 34, "Text"],
Cell[759306, 14913, 144, 2, 46, "Input"],
Cell[759453, 14917, 2591, 74, 35, "Text"],

Cell[CellGroupData[{
Cell[762069, 14995, 76, 1, 46, "Input"],
Cell[762148, 14998, 12902, 268, 47, "Output"]
}, Open  ]],
Cell[775065, 15269, 373, 8, 94, "Text"],

Cell[CellGroupData[{
Cell[775463, 15281, 228, 3, 102, "Input"],
Cell[775694, 15286, 9473, 187, 60, "Output"]
}, Open  ]],
Cell[785182, 15476, 288, 10, 56, "Text"],

Cell[CellGroupData[{
Cell[785495, 15490, 43, 1, 46, "Input"],
Cell[785541, 15493, 6118, 146, 47, "Output"]
}, Open  ]],
Cell[791674, 15642, 56, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[791755, 15646, 187, 3, 46, "Input"],
Cell[791945, 15651, 40676, 844, 47, "Output"]
}, Open  ]],
Cell[832636, 16498, 171, 6, 35, "Text"],

Cell[CellGroupData[{
Cell[832832, 16508, 777, 11, 106, "Input"],
Cell[833612, 16521, 14456, 304, 47, "Output"]
}, Open  ]],
Cell[848083, 16828, 20698, 473, 58, "Text"],
Cell[868784, 17303, 277, 10, 35, "Text"],
Cell[869064, 17315, 7556, 160, 48, "Input"],
Cell[876623, 17477, 258, 11, 35, "Text"],

Cell[CellGroupData[{
Cell[876906, 17492, 657, 18, 62, "Input"],
Cell[877566, 17512, 6118, 146, 47, "Output"]
}, Open  ]],
Cell[883699, 17661, 161, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[883885, 17668, 237, 7, 46, "Input"],
Cell[884125, 17677, 6105, 146, 35, "Output"]
}, Open  ]],
Cell[890245, 17826, 470, 11, 75, "Text"],
Cell[890718, 17839, 47, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[890790, 17843, 565, 12, 66, "Input"],
Cell[891358, 17857, 32157, 680, 47, "Output"],
Cell[923518, 18539, 39664, 796, 47, "Output"]
}, Open  ]],
Cell[963197, 19338, 182, 4, 34, "Text"],

Cell[CellGroupData[{
Cell[963404, 19346, 391, 9, 106, "Input"],
Cell[963798, 19357, 15953, 341, 47, "Output"]
}, Open  ]],
Cell[979766, 19701, 20, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[979811, 19705, 655, 19, 46, "Input"],
Cell[980469, 19726, 15953, 341, 47, "Output"]
}, Open  ]],
Cell[996437, 20070, 21961, 508, 55, "Text"],
Cell[1018401, 20580, 259, 4, 46, "Input"],

Cell[CellGroupData[{
Cell[1018685, 20588, 166, 3, 66, "Input"],
Cell[1018854, 20593, 5345, 130, 35, "Output"],
Cell[1024202, 20725, 5345, 130, 35, "Output"]
}, Open  ]],
Cell[1029562, 20858, 345, 11, 35, "Text"],

Cell[CellGroupData[{
Cell[1029932, 20873, 328, 7, 86, "Input"],
Cell[1030263, 20882, 44431, 933, 53, "Output"],
Cell[1074697, 21817, 225, 7, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1074959, 21829, 37, 0, 49, "Subsection"],
Cell[1074999, 21831, 434, 14, 55, "Text"],

Cell[CellGroupData[{
Cell[1075458, 21849, 660, 11, 117, "Input"],
Cell[1076121, 21862, 9463, 184, 68, "Output"],
Cell[1085587, 22048, 6128, 119, 68, "Output"]
}, Open  ]],
Cell[1091730, 22170, 16112, 351, 36, "Text"],

Cell[CellGroupData[{
Cell[1107867, 22525, 926, 15, 126, "Input"],
Cell[1108796, 22542, 13924, 285, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1122757, 22832, 926, 15, 126, "Input"],
Cell[1123686, 22849, 13701, 280, 46, "Output"]
}, Open  ]],
Cell[1137402, 23132, 187, 4, 34, "Text"],

Cell[CellGroupData[{
Cell[1137614, 23140, 1009, 16, 126, "Input"],
Cell[1138626, 23158, 13924, 285, 47, "Output"],
Cell[1152553, 23445, 13924, 285, 47, "Output"],
Cell[1166480, 23732, 13701, 280, 46, "Output"],
Cell[1180184, 24014, 13701, 280, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1193922, 24299, 171, 2, 46, "Input"],
Cell[1194096, 24303, 917, 18, 86, "Output"]
}, Open  ]],
Cell[1195028, 24324, 91, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[1195144, 24330, 329, 5, 82, "Input"],
Cell[1195476, 24337, 1229, 29, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1196742, 24371, 1002, 27, 86, "Input"],
Cell[1197747, 24400, 1283, 31, 63, "Output"]
}, Open  ]],
Cell[1199045, 24434, 41, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[1199111, 24438, 160, 3, 46, "Input"],
Cell[1199274, 24443, 54695, 1070, 511, "Output"]
}, Open  ]],
Cell[1253984, 25516, 119, 3, 34, "Text"],
Cell[1254106, 25521, 435, 7, 86, "Input"],

Cell[CellGroupData[{
Cell[1254566, 25532, 191, 3, 46, "Input"],
Cell[1254760, 25537, 12793, 254, 35, "Output"]
}, Open  ]],
Cell[1267568, 25794, 192, 6, 34, "Text"],
Cell[1267763, 25802, 212, 4, 46, "Input"],

Cell[CellGroupData[{
Cell[1268000, 25810, 244, 3, 86, "Input"],
Cell[1268247, 25815, 35027, 653, 42, "Output"]
}, Open  ]],
Cell[1303289, 26471, 445, 15, 35, "Text"],

Cell[CellGroupData[{
Cell[1303759, 26490, 452, 7, 104, "Input"],
Cell[1304214, 26499, 35999, 665, 86, "Output"]
}, Open  ]],
Cell[1340228, 27167, 67, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[1340320, 27171, 555, 11, 96, "Input"],
Cell[1340878, 27184, 357, 8, 49, "Output"],
Cell[1341238, 27194, 284, 8, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1341559, 27207, 98, 1, 43, "Subsubsection"],
Cell[1341660, 27210, 207, 6, 35, "Text"],

Cell[CellGroupData[{
Cell[1341892, 27220, 104184, 1605, 263, 104034, 1600, "GraphicsData", "PICT", \
"Graphics"],
Cell[1446079, 28827, 53954, 670, 269, 53837, 666, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],
Cell[1500048, 29500, 94, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[1500167, 29506, 469, 8, 86, "Input"],
Cell[1500639, 29516, 11600, 239, 32, "Output"]
}, Open  ]],
Cell[1512254, 29758, 108, 3, 54, "Text"],
Cell[1512365, 29763, 203, 4, 60, "Input",
  Evaluatable->False],
Cell[1512571, 29769, 63, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[1512659, 29773, 281, 5, 46, "Input"],
Cell[1512943, 29780, 408, 10, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1513388, 29795, 268, 4, 46, "Input"],
Cell[1513659, 29801, 10297, 208, 50, "Output"]
}, Open  ]],
Cell[1523971, 30012, 6224, 154, 55, "Text"],

Cell[CellGroupData[{
Cell[1530220, 30170, 224, 3, 46, "Input"],
Cell[1530447, 30175, 3069, 69, 50, "Output"]
}, Open  ]],
Cell[1533531, 30247, 200, 4, 54, "Text"],

Cell[CellGroupData[{
Cell[1533756, 30255, 222, 3, 46, "Input"],
Cell[1533981, 30260, 3073, 69, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1537091, 30334, 222, 3, 46, "Input"],
Cell[1537316, 30339, 3073, 69, 50, "Output"]
}, Open  ]],
Cell[1540404, 30411, 364, 15, 34, "Text"],

Cell[CellGroupData[{
Cell[1540793, 30430, 366, 6, 106, "Input"],
Cell[1541162, 30438, 9571, 195, 53, "Output"]
}, Open  ]],
Cell[1550748, 30636, 536, 15, 34, "Text"],
Cell[1551287, 30653, 3601, 93, 66, "Input",
  Evaluatable->False],
Cell[1554891, 30748, 3927, 95, 35, "Text"],

Cell[CellGroupData[{
Cell[1558843, 30847, 179, 3, 46, "Input"],
Cell[1559025, 30852, 2907, 66, 50, "Output"]
}, Open  ]],
Cell[1561947, 30921, 90, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[1562062, 30927, 144, 3, 46, "Input"],
Cell[1562209, 30932, 4153, 95, 50, "Output"]
}, Open  ]],
Cell[1566377, 31030, 53, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[1566455, 31034, 511, 8, 66, "Input"],
Cell[1566969, 31044, 7282, 155, 53, "Output"]
}, Open  ]],
Cell[1574266, 31202, 49, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[1574340, 31206, 729, 11, 86, "Input"],
Cell[1575072, 31219, 6397, 142, 50, "Output"],
Cell[1581472, 31363, 6401, 142, 50, "Output"],
Cell[1587876, 31507, 6364, 141, 50, "Output"]
}, Open  ]],
Cell[1594255, 31651, 153, 2, 34, "Text"],
Cell[1594411, 31655, 4827, 116, 74, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1599287, 31777, 74, 0, 49, "Subsection"],
Cell[1599364, 31779, 57, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[1599446, 31783, 598, 10, 126, "Input"],
Cell[1600047, 31795, 38949, 844, 56, "Output"],
Cell[1638999, 32641, 17978, 338, 82, "Output"]
}, Open  ]],
Cell[1656992, 32982, 53, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[1657070, 32986, 110, 2, 66, "Input"],
Cell[1657183, 32990, 18089, 348, 42, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1675321, 33344, 54, 0, 49, "Subsection"],
Cell[1675378, 33346, 2025, 56, 34, "Text"],

Cell[CellGroupData[{
Cell[1677428, 33406, 348, 6, 86, "Input"],
Cell[1677779, 33414, 3386, 78, 50, "Output"],
Cell[1681168, 33494, 6795, 149, 48, "Output"]
}, Open  ]],
Cell[1687978, 33646, 2029, 57, 35, "Text"],

Cell[CellGroupData[{
Cell[1690032, 33707, 496, 8, 126, "Input"],
Cell[1690531, 33717, 16763, 326, 42, "Output"]
}, Open  ]],
Cell[1707309, 34046, 5356, 142, 54, "Text"],

Cell[CellGroupData[{
Cell[1712690, 34192, 281, 4, 106, "Input"],
Cell[1712974, 34198, 12837, 254, 68, "Output"]
}, Open  ]],
Cell[1725826, 34455, 597, 18, 54, "Text"],
Cell[1726426, 34475, 163, 3, 46, "Input"],

Cell[CellGroupData[{
Cell[1726614, 34482, 314, 5, 66, "Input"],
Cell[1726931, 34489, 275, 7, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1727255, 34502, 51, 0, 49, "Subsection"],
Cell[1727309, 34504, 206, 8, 34, "Text"],
Cell[1727518, 34514, 356, 6, 66, "Input"],

Cell[CellGroupData[{
Cell[1727899, 34524, 305, 6, 19, "Input",
  CellOpen->False],
Cell[1728207, 34532, 9487, 217, 35, "Output"],
Cell[1737697, 34751, 9469, 217, 35, "Output"]
}, Open  ]],
Cell[1747181, 34971, 52, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[1747258, 34975, 232, 3, 66, "Input"],
Cell[1747493, 34980, 8513, 172, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1756043, 35157, 127, 2, 46, "Input"],
Cell[1756173, 35161, 9897, 219, 35, "Output"]
}, Open  ]],
Cell[1766085, 35383, 4532, 125, 35, "Text"],

Cell[CellGroupData[{
Cell[1770642, 35512, 454, 7, 102, "Input"],
Cell[1771099, 35521, 9323, 184, 42, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1780471, 35711, 36, 0, 49, "Subsection"],
Cell[1780510, 35713, 234, 4, 54, "Text"],

Cell[CellGroupData[{
Cell[1780769, 35721, 118, 2, 86, "Input"],
Cell[1780890, 35725, 9490, 188, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1790441, 35920, 55, 1, 41, "Section",
  CellTags->"Plasticity"],
Cell[1790499, 35923, 1794, 56, 94, "Text"],
Cell[1792296, 35981, 65, 0, 34, "Text"],
Cell[1792364, 35983, 326, 5, 46, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

