(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    209436,       4834]*)
(*NotebookOutlinePosition[    213687,       4953]*)
(*  CellTagsIndexPosition[    213541,       4946]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Derivatives and Integrals", "Title"],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  InitializationCell->True],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(\(\(Needs["\<TContinuumMechanics1`TContinuumMechanics`\>"]\)\(\n\)
    \)\), "\n", 
    \(\(numequ = 1;\)\), "\[IndentingNewLine]", 
    \(ResultFrame[i_] := 
      StyleForm[
        SequenceForm["\<      \>", 
          i, "\<      (5.\>", \(numequ++\), "\<)\>"], 
        Background -> RGBColor[0, 1, 0], Magnification -> 1.2]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}, {green, ForestGreen}, {star, 
        SuperStar}, {blue, Blue}, {hat, OverHat}, {tilde, Overtilde}, {bar, 
        OverBar}]\), "\[IndentingNewLine]", 
    \(\(black = Identity;\)\), "\[IndentingNewLine]", 
    \(\(DeclareBaseIndices[{1, 2, 3}];\)\), "\n", 
    \(\({NDim, BaseIndices};\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DefineTensorShortcuts[{{\[DoubleStruckE], u, v, w, x, y, dA, dr, ds, 
            dt}, 1}, {{\[Sigma]}, 2}, {{\[Epsilon], e}, 3}, {{R}, 
          4}, {{\[Epsilon]}, 6}];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
The following values are taken as an example of a (red) basis frame :\
\>", "Text"],

Cell[BoxData[{\(SetMetricValues[g, 
      IdentityMatrix[3]]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"RedBasisVectors", "=", 
        RowBox[{"(", GridBox[{
              {"1", "1", "0"},
              {"0", "1", "2"},
              {"1", "0", "1"}
              }], ")"}]}], ";", 
      RowBox[{"RedMetric", "=", 
        StyleBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "1", "1"},
                {"1", "5", "2"},
                {"1", "2", "2"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
          FontFamily->"Courier",
          FontSize->12]}], 
      StyleBox[";",
        FontFamily->"Courier",
        FontSize->
          12]}], "\[IndentingNewLine]", \
\(SetTensorValueRules[\[DoubleStruckE]d[red@i], 
      RedBasisVectors]\), "\[IndentingNewLine]", \(SetTensorValueRules[\
\[DoubleStruckE]u[red@i], 
      Inverse[RedBasisVectors // 
          Transpose]]\), "\[IndentingNewLine]", \(SetMetricValueRules[g, 
      RedMetric, red]\)}], "Input",
  InitializationCell->True],

Cell["and from equation (2.5) :", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(Tensor[\[ScriptCapitalE]\[Section], {Void, Void}, {i_, 
          j_}] := \((PartialD[ud[red@i], red@j] + 
            PartialD[ud[red@j], red@i])\)/2\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Christoffel symbols", "Section",
  CellTags->"Christoffel symbols"],

Cell[BoxData[
    RowBox[{
      FormBox[
        InterpretationBox[
          SubsuperscriptBox["\[DoubleStruckE]", 
            InterpretationBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"], "\[InvisibleSpace]", 
                FormBox[
                  InterpretationBox[
                    RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ ",", 
                      red[ j]],
                    Editable->False],
                  "TraditionalForm"]}],
              SequenceForm[ 
                red[ i], 
                Dif[ 
                  red[ j]]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    FormBox[
                      InterpretationBox[
                        RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ ",", 
                          red[ j]],
                        Editable->False],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False], 
                StyleForm[ 
                  Dif[ 
                    red[ j]], ShowContents -> False]],
              Editable->False]],
          Subsuperscript[ \[DoubleStruckE], 
            SequenceForm[ 
              red[ i], 
              Dif[ 
                red[ j]]], 
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                Dif[ 
                  red[ j]], ShowContents -> False]]],
          Editable->False],
        "TraditionalForm"], "  ", 
      StyleBox["is",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["related",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["to",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["the",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["base",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["via",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["a",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox["Christoffel",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox[
        RowBox[{"symbol", " ", ".", "\[IndentingNewLine]", 
          RowBox[{"(", 
            RowBox[{
            "while", " ", "the", " ", "covariant", " ", "derivative", " ", 
              "of", " ", 
              SubsuperscriptBox["\[DoubleStruckE]", 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False]], "  ", "is", " ", "zero"}], ")"}], "."}],
        FontFamily->"Times"]}]], "Text"],

Cell["\<\
When we want to differentiate a vector, we must differentiate the sum of the \
products of the components with the base vectors :\
\>", "Text"],

Cell[BoxData[{
    \(\[DoubleStruckV] = 
      vu[red@i] \[DoubleStruckE]d[red@i]\), "\[IndentingNewLine]", 
    \(\[DoubleStruckV]$ = vd[red@i] \[DoubleStruckE]u[red@i]\)}], "Input"],

Cell[CellGroupData[{

Cell["Introduction of the Christoffel symbols", "Subsubsection"],

Cell["Examples :", "Text"],

Cell[BoxData[{
    \(PartialD[\[DoubleStruckE]d[red@i], red@j]\), "\[IndentingNewLine]", 
    \(% // ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], 
        k]\), "\[IndentingNewLine]", 
    \(%% // 
      ChristoffeldSymbol[\[DoubleStruckE], \[CapitalGamma], 
        k]\), "\[IndentingNewLine]", 
    \(PartialD[\[DoubleStruckE]u[red@i], red@j]\), "\[IndentingNewLine]", 
    \(% // ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], 
        k]\)}], "Input"],

Cell[TextData[{
  "The Christoffel symbol are ",
  StyleBox["symmetrical",
    FontVariations->{"Underline"->True}],
  " with respect to the last two indices. \nThey can be put into a standard \
order using ",
  "SymmetricStandardOrder",
  "[\[CapitalGamma],{2}]."
}], "Text"],

Cell[BoxData[{
    \(Tensor[\[CapitalGamma], {Void, Void, Void}, 
        red /@ {k, j, 
            i}]\ \  \[Equal] \ \((Tensor[\[CapitalGamma], {Void, Void, Void}, 
            red /@ {k, j, i}] // 
          SymmetricStandardOrder[\[CapitalGamma], {2, 
              3}])\)\), "\[IndentingNewLine]", 
    \(Tensor[\[CapitalGamma], {red@k, Void, Void}, {Void, red@j, 
          red@i}]\  == \[IndentingNewLine]\((Tensor[\[CapitalGamma], {red@k, 
              Void, Void}, {Void, red@j, red@i}] // 
          SymmetricStandardOrder[\[CapitalGamma], {2, 3}])\)\)}], "Input"],

Cell[TextData[{
  "I will be necessary in the following to make the equivalence between \
partial derivatives with respect to the basis coordinates ",
  StyleBox["xu[i]",
    FontWeight->"Bold"],
  " and the partial derivatives with respect to the indices :"
}], "Text"],

Cell["Examples :", "Text"],

Cell["1)", "Text"],

Cell[BoxData[{\((\((drv = \(PartialD[labels]\)[
              Tensor[T, {i, j}, {Void, Void}], {xu[k], 
                xu[h]}])\) == \[IndentingNewLine]\((drv // 
            PartialDToDif)\))\), "\[IndentingNewLine]", 
    RowBox[{"(", " ", 
      RowBox[{
        RowBox[{"\"\<If y is the coordinate \>\"", 
          RowBox[{"(", 
            RowBox[{"drv", "=", 
              RowBox[{
                RowBox[{"PartialD", "[", 
                  TagBox[
                    StyleBox[\({y, \[Delta], g, \[CapitalGamma]}\),
                      FontFamily->"Courier",
                      FontSize->12],
                    (
                    StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)],
                   "]"}], 
                "[", \(Tensor[T, {i, j}, {Void, Void}], {yu[k], yu[h]}\), 
                "]"}]}], ")"}]}], "==", "\[IndentingNewLine]", 
        RowBox[{"(", 
          RowBox[{"drv", "//", 
            StyleBox["PartialDToDif",
              FontColor->RGBColor[0, 0, 1]]}], ")"}]}], ")"}]}], "Input"],

Cell["2)", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"labels", "=", 
        StyleBox[\({x, \[Delta], g, \[CapitalGamma]}\),
          FontFamily->"Courier",
          FontSize->16]}], 
      StyleBox[";",
        FontFamily->"Courier",
        FontSize->16]}], "\n", 
    RowBox[{\((PartialD[Tensor[T, {i, j}, {Void, Void}], {k, h}])\), 
      "\[Equal]", " ", 
      RowBox[{"(", 
        RowBox[{\(PartialD[Tensor[T, {i, j}, {Void, Void}], {k, h}]\), "//", 
          StyleBox[\(DifToPartialD[labels]\),
            FontColor->RGBColor[0, 0, 1]]}], ")"}]}]}], "Input"],

Cell[TextData[StyleBox["Derivation of a vector \[DoubleStruckV]",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[BoxData[{
    \(PartialD[\[DoubleStruckV], red@j]\ \), "\[IndentingNewLine]", 
    \(\ "\< == \>" % // 
      ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], 
        k]\), "\[IndentingNewLine]", 
    \(\ "\< == \>" %% // 
      ChristoffeldSymbol[\[DoubleStruckE], \[CapitalGamma], k]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{\(PartialD[\[DoubleStruckV]$, red@j]\), "\[IndentingNewLine]", 
    RowBox[{" ", "\"\< == \>\""}], "\[IndentingNewLine]", \(%% // 
      ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], 
        k]\), "\[IndentingNewLine]", 
    RowBox[{"Print", "[", "\"\<\!\(\*
StyleBox[\"but\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"the\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"following\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"result\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"cannot\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"exist\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"!\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[0, 0, 1]]\)\>\"", 
      "]"}], "\[IndentingNewLine]", \(%% . \[DoubleStruckE]u[red@h] // 
      EvaluateDotProducts[\[DoubleStruckE], g]\), "\[IndentingNewLine]", 
    RowBox[{"Print", "[", "\"\<as only the \!\(\*
StyleBox[\"first\",\nFontColor->RGBColor[0, 0, 1]]\) \!\(\*
StyleBox[\"index\",\nFontColor->RGBColor[0, 0, 1]]\) can be raised and \
lowered\>\"", "]"}]}], "Input"],

Cell[BoxData[
    FormBox["\"\<as only the \!\(\*
StyleBox[\\\"first\\\",\\nFontColor->RGBColor[0, 0, 1]]\) \!\(\*
StyleBox[\\\"index\\\",\\nFontColor->RGBColor[0, 0, 1]]\) can be raised and \
lowered\>\"", TraditionalForm]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
The symmetry of the two first indices comes from the commutation of the \
second derivatives, and we have,\
\>", "Text"],

Cell[BoxData[{
    \(PartialD[\[DoubleStruckE]d[red@i], red@j] == 
      PartialD[\[DoubleStruckE]d[red@j], red@i]\), "\[IndentingNewLine]", 
    \(% // ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], 
        k]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Explicit expression of the Christoffel symbols", "Subsubsection"],

Cell[BoxData[{
    \(PartialD[\[DoubleStruckE]d[red@j] . \[DoubleStruckE]d[red@k], 
          red@i] + \[IndentingNewLine]PartialD[\[DoubleStruckE]d[
              red@k] . \[DoubleStruckE]d[red@i], 
          red@j] - \[IndentingNewLine]PartialD[\[DoubleStruckE]d[
              red@i] . \[DoubleStruckE]d[red@j], red@k] // 
      ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], 
        h]\), "\[IndentingNewLine]", 
    \(% // EvaluateDotProducts[\[DoubleStruckE], g]\)}], "Input"],

Cell[BoxData[
    \(ResultFrame[% == \ \[IndentingNewLine]PartialD[\[DoubleStruckE]d[
                  red@j] . \[DoubleStruckE]d[red@k] // 
              EvaluateDotProducts[\[DoubleStruckE], g], 
            red@i] + \[IndentingNewLine]PartialD[\[DoubleStruckE]d[
                  red@k] . \[DoubleStruckE]d[red@i] // 
              EvaluateDotProducts[\[DoubleStruckE], g], 
            red@j] - \[IndentingNewLine]PartialD[\[DoubleStruckE]d[
                  red@i] . \[DoubleStruckE]d[red@j] // 
              EvaluateDotProducts[\[DoubleStruckE], g], 
            red@k]\[IndentingNewLine]]\)], "Input"],

Cell["\<\
We see that with the notation \"upper index in the third position\", the \
above proof is immediate.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Covariant Derivative (this subsection is only an exercise)", \
"Subsection"],

Cell[TextData[{
  StyleBox["Important remarks :",
    FontVariations->{"Underline"->True}],
  "\nCovariantD is applied only over objects in the simple tensor shape \
without partial derivatives involved.\nMathematically the covariant \
derivative is only defined over strict tensors and a partial derivative is \
not a strict tensor.\n \n Mathematically we are allowed to take covariant \
derivatives of other objects such as the first order total derivative or the \
non-expanded TotalDerivative or LieDerivative but they are not implemented \
because it could be too complicated for the general case. (It is preferable \
to have Tensorial sharp limitations rather than fuzzy ones) \n \n What we can \
do instead is to take the Covariant derivative  of a simple tensor object, \
expand it and replace the values in the expanded expression. The calculation \
of the acceleration components is an example of this where we do not take the \
Absolute derivative of the Total derivative of the position directly.\n \nThe \
partial derivative can be taken over anything as well as the Total derivative \
but the Absolute derivative is like the Covariant derivative."
}], "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(labels := {x, \[Delta], g, \[CapitalGamma]}\)], "Input"],

Cell[BoxData[
    \(PartialD[\[DoubleStruckV], red@j] // 
      ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], k]\)], "Input"],

Cell[BoxData[
    \(%[\([1]\)] + \((%[\([2]\)] // IndexChange[{{i, k}, {k, i}}])\) // 
      Factor\)], "Input"],

Cell["so that the quantity,", "Text"],

Cell[BoxData[
    \(%[\([2]\)]\)], "Input"],

Cell[TextData[{
  "is the ",
  StyleBox["i",
    FontColor->RGBColor[1, 0, 0]],
  "-component of the ",
  StyleBox["j",
    FontColor->RGBColor[1, 0, 0]],
  "-derivative of ",
  StyleBox["\[DoubleStruckV]",
    FontWeight->"Bold"],
  ". It is the ",
  StyleBox["covariant derivative",
    FontColor->RGBColor[0, 0, 1]],
  " of ",
  StyleBox["\[DoubleStruckV]",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(CovariantD[vu[red@i], red@j] == %\)], "Input"],

Cell[TextData[{
  StyleBox["This result is of course directly given by the operation ",
    FontVariations->{"Underline"->True}],
  StyleBox["ExpandCovariantD",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  " :"
}], "Text"],

Cell[BoxData[{
    \(CovariantD[vu[red@i], red@j] // 
      ExpandCovariantD[labels, red@k]\), "\[IndentingNewLine]", 
    \(% // PartialDToDif\)}], "Input"],

Cell[TextData[{
  "similarly, the covariant derivative of the covariant component ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["v", 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " is given by,"
}], "Text"],

Cell[BoxData[
    \(PartialD[\[DoubleStruckV]$, red@j] // 
      ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], k]\)], "Input"],

Cell[BoxData[
    \(%[\([1]\)] + \((%[\([2]\)] // IndexChange[{{i, k}, {k, i}}])\) // 
      Factor\)], "Input"],

Cell["or also,", "Text"],

Cell[BoxData[{
    \(CovariantD[vd[red@i], red@j] // 
      ExpandCovariantD[labels, red@k]\), "\[IndentingNewLine]", 
    \(% // PartialDToDif\)}], "Input"],

Cell[BoxData[{
    \(A =. \), "\n", 
    \(\[Phi] = 
      Tensor[A, {Void, Void}, {red@i, red@j}] uu[red@i] vu[red@j]\), "\n", 
    \(D\[Phi] = \(\(PartialD[\[Phi], 
          red@k]\)\(//\)\(Expand\)\(\ \ \ \ \ \ \ \)\)\)}], "Input"],

Cell["\<\
As \[Phi] is a scalar, D\[Phi] is also a covariant derivative Dcov\[Phi] :\
\>", "Text"],

Cell[BoxData[
    \(Dcov\[Phi] = CovariantD[\[Phi], red@k] // Expand\)], "Input"],

Cell[BoxData[
    \(res1 = \(\(Dcov\[Phi] // ExpandCovariantD[labels, red@h]\) // Expand\) // 
        PartialDToDif\)], "Input"],

Cell[BoxData[
    \(res2 = \(Dcov\[Phi][\([1]\)] + \((Dcov\[Phi] - Dcov\[Phi][\([1]\)] // 
                ExpandCovariantD[labels, red@h])\) // Expand\) // 
        PartialDToDif\)], "Input"],

Cell[BoxData[
    \(Coefficient[\((res1 - res2)\) // Factor, uu[red@i] vu[red@j]] == 
      0\)], "Input"],

Cell[TextData[{
  "The term   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["A", 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      InterpretationBox[
                        RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ ",", 
                          red[ k]],
                        Editable->False],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j], 
                    Dif[ 
                      red[ k]]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["k",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ",", 
                              red[ k]],
                            Editable->False],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    StyleForm[ 
                      Dif[ 
                        red[ k]], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ A, 
                SequenceForm[ 
                  red[ i], 
                  red[ j], 
                  Dif[ 
                    red[ k]]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False], 
                  StyleForm[ 
                    Dif[ 
                      red[ k]], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], "-", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["A", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["h",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ h], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["h",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ h], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ A, 
                  SequenceForm[ 
                    red[ h], 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ h], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[CapitalGamma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["h",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["k",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ h], ShowContents -> False], 
                      red[ k], 
                      red[ i]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["h",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ h], 
                      StyleForm[ 
                        red[ k], ShowContents -> False], 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[CapitalGamma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ h], ShowContents -> False], 
                    red[ k], 
                    red[ i]], 
                  SequenceForm[ 
                    red[ h], 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    StyleForm[ 
                      red[ i], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}], "-", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["A", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["h",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ h]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["h",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ h], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ A, 
                  SequenceForm[ 
                    red[ i], 
                    red[ h]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ h], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[CapitalGamma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["h",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["k",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ h], ShowContents -> False], 
                      red[ k], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["h",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ h], 
                      StyleForm[ 
                        red[ k], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[CapitalGamma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ h], ShowContents -> False], 
                    red[ k], 
                    red[ j]], 
                  SequenceForm[ 
                    red[ h], 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}]}], TraditionalForm]]],
  "   gives the covariant derivative of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["A", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox["j",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
            SequenceForm[ 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ". \nOf course, we can verify that this directly obtained using ",
  StyleBox["ExpandCovariantD",
    FontWeight->"Bold"],
  " :"
}], "Text"],

Cell[BoxData[
    \(CovariantD[Tensor[A, {Void, Void}, {red@i, red@j}], 
        red@k] == \((\(CovariantD[Tensor[A, {Void, Void}, {red@i, red@j}], 
              red@k] // ExpandCovariantD[labels, red@h]\) // 
          PartialDToDif)\)\)], "Input"],

Cell["and the three other equivalent expressions,", "Text"],

Cell[BoxData[
    \(CovariantD[Tensor[A, {red@i, Void}, {Void, red@j}], 
        red@k] == \((\(CovariantD[Tensor[A, {red@i, Void}, {Void, red@j}], 
              red@k] // ExpandCovariantD[labels, red@h]\) // 
          PartialDToDif)\)\)], "Input"],

Cell[BoxData[
    \(CovariantD[Tensor[A, {Void, red@j}, {red@i, Void}], 
        red@k] == \((\(CovariantD[Tensor[A, {Void, red@j}, {red@i, Void}], 
              red@k] // ExpandCovariantD[labels, red@h]\) // 
          PartialDToDif)\)\)], "Input"],

Cell[BoxData[
    \(CovariantD[Tensor[A, {red@i, red@j}, {Void, Void}], 
        red@k] == \((\(CovariantD[Tensor[A, {red@i, red@j}, {Void, Void}], 
              red@k] // ExpandCovariantD[labels, red@h]\) // 
          PartialDToDif)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Application : Derivative of a force", "Subsection"],

Cell[BoxData[
    \(d\[DoubleStruckCapitalF] = \[Sigma]uu[red@i, red@j] 
        dAd[red@i] \[DoubleStruckE]d[red@j]\)], "Input"],

Cell[BoxData[
    \(CovariantD[d\[DoubleStruckCapitalF], red@k] // Expand\)], "Input"],

Cell[TextData[{
  StyleBox["The covariant derivative",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " (in the above expression ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[DoubleStruckE]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ k]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ j], 
              Cov[ 
                red[ k]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ k]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ j], ShowContents -> False], 
              StyleForm[ 
                Cov[ 
                  red[ k]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ")  ",
  StyleBox["of the basis vectors are zero",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  "."
}], "Text"],

Cell[BoxData[{
    \(CovariantD[\[DoubleStruckE]d[red@i], red@k]\), "\[IndentingNewLine]", 
    \(CovDerivRule = 
      CovariantD[\[DoubleStruckE]d[red@i_], 
          red@k_] \[Rule] \((\(\(\(% // ExpandCovariantD[labels, red@h]\) // 
                PartialDToDif\) // 
              ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], h]\) // 
            SymmetricStandardOrder[\[CapitalGamma], {2, 3}])\)\)}], "Input"],

Cell[TextData[{
  " ",
  StyleBox["Also the covariant derivative of the tensor g is zero",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " :"
}], "Text"],

Cell[BoxData[
    \(\[DoubleStruckE]d[red@i] . \[DoubleStruckE]d[
          red@j] \[Equal] \((\[DoubleStruckE]d[red@i] . \[DoubleStruckE]d[
              red@j] // EvaluateDotProducts[\[DoubleStruckE], 
            g])\)\)], "Input"],

Cell["which derivative is explicitely :", "Text"],

Cell[BoxData[{
    RowBox[{\(MapAt[CovariantD[#, red@k] &, #, 1] + 
          MapAt[CovariantD[#, red@k] &, #, 2] &\), " ", "[", "  ", 
      StyleBox[\(\[DoubleStruckE]d[red@i] . \[DoubleStruckE]d[red@j]\),
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox["   ",
        FontColor->RGBColor[0, 0, 1]], 
      "]"}], "\[IndentingNewLine]", \(CovariantD[\[DoubleStruckE]d[
              red@i_] . \[DoubleStruckE]d[red@j_] // 
          EvaluateDotProducts[\[DoubleStruckE], g], 
        red@k_] \[Rule] \((% /. CovDerivRule // 
          EvaluateDotProducts[\[DoubleStruckE], g])\)\)}], "Input"],

Cell[TextData[{
  "See Fluegge p.72 for an intuitive explanation of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[DoubleStruckE]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ k]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ j], 
              Cov[ 
                red[ k]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ k]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ j], ShowContents -> False], 
              StyleForm[ 
                Cov[ 
                  red[ k]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "\[Congruent] 0."
}], "Text"],

Cell[TextData[{
  "All this is summarized in the operator ",
  StyleBox["CovariantDSimplify[",
    FontWeight->"Bold"],
  StyleBox["\[DoubleStruckE],g",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " .  Coming back to the covariant derivative of ",
  "d\[DoubleStruckCapitalF] we have :"
}], "Text"],

Cell[BoxData[
    \(CovariantD[d\[DoubleStruckCapitalF], red@k] // 
      CovariantDSimplify[\[DoubleStruckE], g]\)], "Input"],

Cell[TextData[{
  "Now let us choose at ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["x", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["k",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ k], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["k",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ k]],
            Editable->False]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["x", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["k",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ k], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["k",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ k]],
            Editable->False]], TraditionalForm]]],
  "+ ",
  StyleBox["d",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["x", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["k",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ k], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["k",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ k]],
            Editable->False]], TraditionalForm]]],
  "two area elements ",
  StyleBox["d",
    FontSlant->"Italic"],
  StyleBox["A",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " equal in size and orientation. Then ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            SubsuperscriptBox[
              StyleBox[
                RowBox[{
                  StyleBox["d",
                    FontWeight->"Plain",
                    FontSlant->"Italic"], 
                  StyleBox["A",
                    FontSlant->"Italic"]}]], 
              InterpretationBox[
                RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                  FormBox[
                    TagBox[
                      StyleBox["k",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"]}],
                SequenceForm[ ",", 
                  red[ k]],
                Editable->False], 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ k], ShowContents -> False]],
                Editable->False]],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "= 0  and hence ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox["dA",
            FontSlant->"Italic"], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ k]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              Cov[ 
                red[ k]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ k]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                Cov[ 
                  red[ k]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "= 0 and the derivative of the force ",
  StyleBox["d",
    FontSlant->"Italic"],
  StyleBox["F",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " is, "
}], "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["dA", 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ dA, 
                SequenceForm[ 
                  red[ i]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[DoubleStruckE]", 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ j]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ \[DoubleStruckE], 
                SequenceForm[ 
                  red[ j]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ j], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    FormBox[
                      InterpretationBox[
                        RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ ";", 
                          red[ k]],
                        Editable->False],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    Cov[ 
                      red[ k]]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["k",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ";", 
                              red[ k]],
                            Editable->False],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j], 
                    StyleForm[ 
                      Cov[ 
                        red[ k]], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ \[Sigma], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False], 
                  Cov[ 
                    red[ k]]], 
                SequenceForm[ 
                  red[ i], 
                  red[ j], 
                  StyleForm[ 
                    Cov[ 
                      red[ k]], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"]}],
        FontSize->16,
        FontWeight->"Bold"], TraditionalForm]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "This vanishes, for any choice of the components ",
  Cell[BoxData[
      FormBox[
        InterpretationBox[
          SubsuperscriptBox["dA", 
            InterpretationBox[
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"],
              SequenceForm[ 
                red[ i]],
              Editable->False], 
            InterpretationBox[
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]],
              Editable->False]],
          Subsuperscript[ dA, 
            SequenceForm[ 
              red[ i]], 
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]]],
          Editable->False], TraditionalForm]]],
  " of the two section elemnts, if and only if ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Sigma]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ k]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False], 
              Cov[ 
                red[ k]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ k]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ i], 
              red[ j], 
              StyleForm[ 
                Cov[ 
                  red[ k]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "= 0. Each of the 27 quantities ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Sigma]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ k]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False], 
              Cov[ 
                red[ k]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ k]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ i], 
              red[ j], 
              StyleForm[ 
                Cov[ 
                  red[ k]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " expresses one aspect of the rate of change of the stress tensor, namely \
the ",
  StyleBox["j",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  "-component of the change of the force as far as it depends on the  ",
  StyleBox["i",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  "-component of ",
  StyleBox["d",
    FontSlant->"Italic"],
  StyleBox["A",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ". Vanishing of all the components of the covariant derivative means that \
between adjacent points the physical stress does not change."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Case for the Levi-Civita tensors", "Subsubsection"]], \
"Subsubsection"],

Cell["\<\
As the covariant derivatives of the metric tensor are zero, it is also the \
case for the Levi-Civita tensor which only depends on the determinant of the \
metric tensor. As a consequence :\
\>", "Text"],

Cell[BoxData[{
    \(CovariantD[Tensor[e, {Void, Void, Void}, {1, 2, 3}], 
      l]\), "\[IndentingNewLine]", 
    \(\((\(\(\(\(% // ExpandCovariantD[labels, h]\) // SumExpansion[h]\) // 
              FullSimplify\) // ToFlavor[red]\) // LeviCivitaSimplify[e])\) == 
      0\)}], "Input"],

Cell["\<\
ResultFrame[
%[[1,2]]==-%[[1,1]]==(Tensor[e,{Void,Void,Void},{1,2,3}]Tensor[\[CapitalGamma]\
,{m,Void,Void},{Void,l,m}]//ToFlavor[red])
]//PartialDToDif\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The Riemann-Christoffel tensor ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["R", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["m",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox["j",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox["k",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox["m",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["k",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ m, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]],
            Editable->False]], TraditionalForm]]]
}], "Subsubsection"],

Cell["By definition :", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\((res = \((CovariantD[
                  vd[red@i], {red@j, red@k}] - 
                CovariantD[vd[red@i], {red@k, red@j}])\))\) == 
        vd[red@m] \((Ruddd[m, i, j, k] // ToFlavor[red])\)]\)], "Input"],

Cell["Explicit expression of the Riemann-Christoffel tensor :", "Text",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[{
    \(res\), "\[IndentingNewLine]", 
    \(\(% // ExpandCovariantD[labels, {red@m, red@l}]\) // 
      Expand\), "\[IndentingNewLine]", 
    \(% // SymmetrizeSlots[\[CapitalGamma], 
        3, {{1, {2, 3}}}]\), "\[IndentingNewLine]", 
    \(MapAt[# /. \ l \[RuleDelayed] \ m &, %, {{3}, {4}}] // 
      PartialDToDif\)}], "Input"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\((Ruddd[m, i, j, k] // 
            ToFlavor[red])\) == 
        Coefficient[%, {vd[red@m]}]\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  StyleBox["Note :",
    FontWeight->"Bold"],
  " ",
  StyleBox["The second derivatives with respect to indices do not include the \
symmetry between the considered indices :",
    FontWeight->"Bold"]
}], "Text",
  FontColor->RGBColor[1, 0, 1],
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(PartialD[vu[red@i], {red@j, red@k}] - 
      PartialD[vu[red@i], {red@k, red@j}]\)], "Input",
  Background->GrayLevel[0.900008]],

Cell[TextData[StyleBox["while this is the case for the expanded notation \
(with labels),",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(PartialD[labels]\)[
        vu[red@i], {xu[red@j], xu[red@k]}] - \(PartialD[labels]\)[
        vu[red@i], {xu[red@k], xu[red@j]}]\)], "Input",
  Background->GrayLevel[0.900008]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Partial\ and\ covariant\ derivatives\ \ of\ vectors\ \
\((Fl\[UDoubleDot]gge\ pages\ 68\ and\ 74)\)\)], "Subsubsection"],

Cell[TextData[{
  StyleBox["Basis",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Derivation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" assign to zero covariant derivatives of basis vectors, and \
express their partial derivatives using Christoffel symbols. ",
    FontColor->RGBColor[0, 0, 1]],
  "It is used here to prove the relation   ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckV]", 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ",", 
                              red[ j]],
                            Editable->False],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["k",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ",", 
                              red[ k]],
                            Editable->False],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        Dif[ 
                          red[ j]], 
                        Dif[ 
                          red[ k]]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              InterpretationBox[
                                RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ ",", 
                                  red[ j]],
                                Editable->False],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              InterpretationBox[
                                RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["k",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ ",", 
                                  red[ k]],
                                Editable->False],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          Dif[ 
                            red[ j]], ShowContents -> False], 
                        StyleForm[ 
                          Dif[ 
                            red[ k]], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckV], 
                    SequenceForm[ 
                      Dif[ 
                        red[ j]], 
                      Dif[ 
                        red[ k]]], 
                    SequenceForm[ 
                      StyleForm[ 
                        Dif[ 
                          red[ j]], ShowContents -> False], 
                      StyleForm[ 
                        Dif[ 
                          red[ k]], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], "==", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ i]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        red[ i]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["v", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ j]],
                                  Editable->False],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["k",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ k]],
                                  Editable->False],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ i], 
                              Cov[ 
                                red[ j]], 
                              Cov[ 
                                red[ k]]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    InterpretationBox[
                                      
                                      RowBox[{"\<\";\"\>", 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                      SequenceForm[ ";", 
                                        red[ j]],
                                      Editable->False],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    InterpretationBox[
                                      RowBox[{"\<\";\"\>", 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["k",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                      SequenceForm[ ";", 
                                        red[ k]],
                                      Editable->False],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              StyleForm[ 
                                Cov[ 
                                  red[ j]], ShowContents -> False], 
                              StyleForm[ 
                                Cov[ 
                                  red[ k]], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ v, 
                          SequenceForm[ 
                            red[ i], 
                            Cov[ 
                              red[ j]], 
                            Cov[ 
                              red[ k]]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              Cov[ 
                                red[ j]], ShowContents -> False], 
                            StyleForm[ 
                              Cov[ 
                                red[ k]], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "+", 
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["v", 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  InterpretationBox[
                                    
                                    RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                      
                                      FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                    SequenceForm[ ";", 
                                      red[ l]],
                                    Editable->False],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                red[ i], 
                                Cov[ 
                                  red[ l]]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      InterpretationBox[
                                        
                                        RowBox[{"\<\";\"\>", 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                        SequenceForm[ ";", 
                                        red[ l]],
                                        Editable->False],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                StyleForm[ 
                                  Cov[ 
                                    red[ l]], ShowContents -> False]],
                              Editable->False]],
                          Subsuperscript[ v, 
                            SequenceForm[ 
                              red[ i], 
                              Cov[ 
                                red[ l]]], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              StyleForm[ 
                                Cov[ 
                                  red[ l]], ShowContents -> False]]],
                          Editable->False],
                        "TraditionalForm"], " ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[CapitalGamma]", 
                            InterpretationBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["k",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"], "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["l",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)]}],
                              SequenceForm[ 
                                red[ j], 
                                red[ k], 
                                StyleForm[ 
                                  red[ l], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox[
                              RowBox[{
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                TagBox[
                                  StyleBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox["k",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"],
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)], 
                                "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["l",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ j], ShowContents -> False], 
                                StyleForm[ 
                                  red[ k], ShowContents -> False], 
                                red[ l]],
                              Editable->False]],
                          Subsuperscript[ \[CapitalGamma], 
                            SequenceForm[ 
                              red[ j], 
                              red[ k], 
                              StyleForm[ 
                                red[ l], ShowContents -> False]], 
                            SequenceForm[ 
                              StyleForm[ 
                                red[ j], ShowContents -> False], 
                              StyleForm[ 
                                red[ k], ShowContents -> False], 
                              red[ l]]],
                          Editable->False],
                        "TraditionalForm"]}]}], ")"}]}]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["Examples", "Text"],

Cell[BoxData[{
    \(PartialD[\[DoubleStruckE]d[red@i], 
        red@j] == \((PartialD[\[DoubleStruckE]d[red@i], 
            red@j] // \(BasisDerivation[\[CapitalGamma], 
              red@m]\)[{\[DoubleStruckE], red@i}, 
            red@j])\)\), "\[IndentingNewLine]", 
    \(PartialD[\[DoubleStruckE]u[red@i], 
        red@j] == \((PartialD[\[DoubleStruckE]u[red@i], 
            red@j] // \(BasisDerivation[\[CapitalGamma], 
              red@m]\)[{\[DoubleStruckE], red@i}, red@j])\)\)}], "Input"],

Cell[BoxData[{
    \(PartialD[\[DoubleStruckE]d[red@i], {red@j, 
          red@k}] == \((PartialD[\[DoubleStruckE]d[red@i], {red@j, 
              red@k}] // \(BasisDerivation[\[CapitalGamma], red@h, 
              red@m]\)[{\[DoubleStruckE], red@i}, {red@j, 
              red@k}])\)\), "\[IndentingNewLine]", 
    \(PartialD[\[DoubleStruckE]u[red@i], {red@j, 
          red@k}] == \((PartialD[\[DoubleStruckE]u[red@i], {red@j, 
              red@k}] // \(BasisDerivation[\[CapitalGamma], red@h, 
              red@m]\)[{\[DoubleStruckE], red@i}, {red@j, 
              red@k}])\)\)}], "Input"],

Cell[BoxData[{
    \(PartialD[ud[red@i], 
        red@j] == \((PartialD[ud[red@i], 
            red@j] // \(DifToCov[\[CapitalGamma], red@m]\)[{u, red@i}, 
            red@j])\)\), "\[IndentingNewLine]", 
    \(PartialD[uu[red@i], 
        red@j] == \((PartialD[uu[red@i], 
            red@j] // \(DifToCov[\[CapitalGamma], red@m]\)[{u, red@i}, 
            red@j])\)\)}], "Input"],

Cell[BoxData[{
    \(PartialD[
        uu[red@i], {red@j, 
          red@k}] == \((PartialD[
            uu[red@i], {red@j, red@k}] // \(DifToCov[\[CapitalGamma], red@p, 
              red@q]\)[{u, red@i}, {red@j, 
              red@k}])\)\), "\[IndentingNewLine]", 
    \(PartialD[
        ud[red@i], {red@j, 
          red@k}] == \((PartialD[
            ud[red@i], {red@j, red@k}] // \(DifToCov[\[CapitalGamma], red@p, 
              red@q]\)[{u, red@i}, {red@j, red@k}])\)\)}], "Input"],

Cell["\<\
The first partial derivative of a vector is identical to its covariant \
derivative :\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[{
    \(\[DoubleStruckU] =. ; 
    T\[DoubleStruckU] = 
      Tensor[\[DoubleStruckU], {Void}, {Dif[red@j]}];\), "\n", 
    \(\(\[DoubleStruckU] = \[DoubleStruckE]d[red@i] uu[red@i];\)\), "\n", 
    \(\(PartialD[\[DoubleStruckU], {red@j}];\)\), "\n", 
    \(\(% // \(BasisDerivation[\[CapitalGamma], red@m]\)[{\[DoubleStruckE], 
            red@i}, red@j];\)\), "\[IndentingNewLine]", 
    \(\(\((\(%[\([1]\)] + \((%[\([2]\)] // IndexChange[{{m, i}, {i, m}}])\) // 
              ExpandCovariantD[labels, red@m]\) // PartialDToDif)\) // 
        SymmetricStandardOrder[\[CapitalGamma], \ {2, 3}]\) // 
      Factor; \[DoubleStruckU] =. ; % // \(DifToCov[\[CapitalGamma], 
          red@k]\)[{u, red@i}, red@j];\), "\[IndentingNewLine]", 
    \(ResultFrame[
      T\[DoubleStruckU] == \((\(\((%[\([1]\)] + \((%[\([2]\)] // 
                      IndexChange[{{m, i}, {i, k}}])\))\) // 
              SymmetricStandardOrder[\[CapitalGamma], \ {2, 3}]\) // 
            Expand)\)\[IndentingNewLine]]\)}], "Input"],

Cell["\<\
The second partial derivative of a vector contains a correction to its second \
covariant derivative, involving a Christoffel symbol :\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[{
    \(\[DoubleStruckU] =. ; 
    T\[DoubleStruckU] = 
      Tensor[\[DoubleStruckU], {Void, Void}, {Dif[red@j], 
          Dif[red@k]}];\), "\n", 
    \(\(\[DoubleStruckU] = \[DoubleStruckE]d[red@i] uu[red@i];\)\), "\n", 
    \(\(PartialD[\[DoubleStruckU], {red@j, 
          red@k}];\)\), "\[IndentingNewLine]", 
    \(\(\(\(% // \(BasisDerivation[\[CapitalGamma], 
                red@m]\)[{\[DoubleStruckE], red@i}, 
              red@j]\) // \(BasisDerivation[\[CapitalGamma], 
              red@m]\)[{\[DoubleStruckE], red@i}, 
            red@k]\) // \(BasisDerivation[\[CapitalGamma], red@m, 
            red@h]\)[{\[DoubleStruckE], red@i}, {red@j, 
            red@k}];\)\), "\[IndentingNewLine]", 
    \(\(\(\(\(\(% // \(DifToCov[\[CapitalGamma], red@h]\)[{u, red@i}, 
                red@k]\) // \(DifToCov[\[CapitalGamma], red@h]\)[{u, red@i}, 
              red@j]\) // \(DifToCov[\[CapitalGamma], red@m, red@h]\)[{u, 
              red@i}, {red@j, red@k}]\) // Expand;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Collect[%, {\[DoubleStruckE]d[red@i], \[DoubleStruckE]d[
            red@m]}];\)\), "\[IndentingNewLine]", 
    \(\(%[\([1]\)] + \((%[\([2]\)] // IndexChange[{{i, m}, {m, i}}])\) // 
        Factor;\)\), "\[IndentingNewLine]", 
    \(\(resa = 
        Coefficient[%, \[DoubleStruckE]d[red@i]] /. {uu[red@m] -> 0, 
            uu[red@h] -> 0};\)\), "\[IndentingNewLine]", 
    \(\(Coefficient[resa, uu[red@m]] uu[red@m];\)\), "\[IndentingNewLine]", 
    \(\(Coefficient[resa, uu[red@h]] uu[red@h] // 
        IndexChange[{{h, m}, {m, h}}];\)\), "\[IndentingNewLine]", 
    \(\(% + %% + %%% // SymmetricStandardOrder[\[CapitalGamma], \ {2, 3}]\) // 
      Expand; \[DoubleStruckU] =. ;\), "\[IndentingNewLine]", 
    \(ResultFrame[
      T\[DoubleStruckU] == \((\[DoubleStruckE]d[
              red@i] \((%[\([1]\)] + %[\([2]\)] + %[\([3]\)] + \((%[\([4]\)] // 
                      IndexChange[{{m, h}}])\) // 
                SymmetricStandardOrder[\[CapitalGamma], \ {2, 
                    3}])\))\)\[IndentingNewLine]]\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gradient, Divergence and Curl", "Subsection"],

Cell[TextData[{
  "Relation between the standard definitions included in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and the present tensorial definition."
}], "Text"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \ \)\(\(<< 
      Calculus`VectorAnalysis`\)\(\ \ \ \)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell["Gradient", "Subsubsection"],

Cell[BoxData[
    \(Grad[f[x, y, z], Cartesian[x, y, z]]\)], "Input"],

Cell["\<\
In tensorial notations, the gradient (we use the notation TGrad) is defined \
as,\
\>", "Text"],

Cell[BoxData[{
    \(\(Tf = Tensor[f, {}, {}];\)\), "\n", 
    \(\(TGrad[\[DoubleStruckE], red@k]\)[Tf]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Divergence", "Subsubsection"],

Cell[BoxData[
    \(Div[{fx[x, y, z], fy[x, y, z], fz[x, y, z]}, 
      Cartesian[x, y, z]]\)], "Input"],

Cell["\<\
In tensorial notations, the divergence (we use the notation TDiv) applied to  \
\[DoubleStruckU] or  \[DoubleStruckV]  gives,\
\>", "Text"],

Cell[BoxData[{
    \({\[DoubleStruckU] = 
        ud[red@j] \[DoubleStruckE]u[
            red@j], \[DoubleStruckV]}\), "\[IndentingNewLine]", 
    \(TDiv[\[DoubleStruckE], g, 
        red@k] /@ {\[DoubleStruckU], \[DoubleStruckV]}\)}], "Input"],

Cell[BoxData[
    \(\(TDiv[\[DoubleStruckE], g, blue@j]\)[\[DoubleStruckV]] /. 
      g \[Rule] \[Beta]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Curl :", "Subsubsection"],

Cell[BoxData[
    \(Curl[{f[r, \[Theta], \[CurlyPhi]], g[r, \[Theta], \[CurlyPhi]], 
        h[r, \[Theta], \[CurlyPhi]]}, 
      Cylindrical[r, \[Theta], \[CurlyPhi]]]\)], "Input"],

Cell["\<\
In tensorial notations, the curl (we use the notation TCurl) is defined as,\
\>", "Text"],

Cell[BoxData[
    \(\(TCurl[\[DoubleStruckE], g, red /@ {i, j, k}, 
        e]\)[\[DoubleStruckU]]\)], "Input"],

Cell["\<\
Curl of a vector expressed in the red basis and calculated in the blue one \
:\
\>", "Text"],

Cell[BoxData[
    \(\(TCurl[\[DoubleStruckE], g, blue /@ {p, q, r}, e]\)[\[DoubleStruckU]] /. 
      g \[Rule] \[Beta]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laplacian", "Subsubsection"],

Cell[BoxData[
    \(\(TLaplacian[\[DoubleStruckE], g, red@i, red@j]\)[Tf]\)], "Input"],

Cell[TextData[{
  "We can also check that ",
  StyleBox["a gradient field has no curl",
    FontColor->RGBColor[0, 0, 1]],
  " : the second covariant derivative is symmetrical with respect to i and j \
while the LeviCivita symbol is antisymmetrical."
}], "Text"],

Cell[BoxData[
    \(\(TGrad[\[DoubleStruckE], red@h]\)[Tf]\)], "Input"],

Cell[BoxData[
    \(\(TCurl[\[DoubleStruckE], g, red /@ {p, q, r}, 
        e]\)[\(TGrad[\[DoubleStruckE], red@h]\)[Tf]]\)], "Input"],

Cell[BoxData[
    \(\(\(% // SumExpansion[red@p, red@q]\) // LeviCivitaSimplify[e]\) // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(% // SymmetricStandardOrder[f]\)], "Input"],

Cell[TextData[{
  "and that that ",
  StyleBox["a curl field has no divergence",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[BoxData[{
    \(\(TDiv[\[DoubleStruckE], g, 
        red@r]\)[\(TCurl[\[DoubleStruckE], g, red /@ {p, q, i}, 
          e]\)[\[DoubleStruckU]]]\ \), "\[IndentingNewLine]", 
    \(\(% // SumExpansion[red /@ {p, q, r}]\) // 
      LeviCivitaSimplify[e]\), "\[IndentingNewLine]", 
    \(% // SymmetricStandardOrder[u, {2, 3}]\)}], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Integral theorems of Stokes and Gauss", "Section",
  CellTags->"Integral theorems of Stokes and Gauss"],

Cell[CellGroupData[{

Cell["Gauss theorem in two dimensions :", "Outline1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
  "Consider an element ",
  StyleBox["d",
    FontSlant->"Italic"],
  StyleBox["s",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " of a close curve ",
  StyleBox["C",
    FontSlant->"Italic"],
  " on a surface ",
  StyleBox["S",
    FontSlant->"Italic"],
  "; ",
  StyleBox["C",
    FontSlant->"Italic"],
  " is the contour of a domain ",
  StyleBox["A",
    FontSlant->"Italic"],
  " :"
}], "Text"],

Cell[BoxData[
    \(d\[DoubleStruckS] := dsu[red@j] \[DoubleStruckE]d[red@j]\)], "Input"],

Cell[TextData[{
  "Suppose that ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubsuperscriptBox["\[DoubleStruckE]", 
            InterpretationBox[
              FormBox[
                TagBox[
                  StyleBox["3",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"],
              SequenceForm[ 
                red[ 3]],
              Editable->False], 
            InterpretationBox[
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["3",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)],
              SequenceForm[ 
                StyleForm[ 
                  red[ 3], ShowContents -> False]],
              Editable->False]],
          FontFamily->"Courier",
          FontSize->16], TraditionalForm]]],
  " is the vector normal to ",
  StyleBox["S ",
    FontSlant->"Italic"],
  "at the considered point of ",
  StyleBox["C",
    FontSlant->"Italic"],
  ". ",
  StyleBox["d\[DoubleStruckN]",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " is the vector tangent to ",
  StyleBox["S",
    FontSlant->"Italic"],
  " and normal to ",
  StyleBox["C",
    FontSlant->"Italic"],
  ".\nIntegration of a vector field ",
  StyleBox["\[DoubleStruckV]",
    FontWeight->"Bold"],
  " in ",
  StyleBox["S",
    FontSlant->"Italic"],
  ". First integrate along the contour ABCD of the figure :"
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PICT", "\<\
42kooooo09X0ZP0A0_l<0?ooooooo`00ool0002Z0000VP000000002Q0<03NBE@
Kg=dDf=bJG1d84QQHf/PHWTPCFU[IB12LVmbLb0a<Rlg;cT`3Bm4JG=QHVaUCVEh
M5=UM597@T=_K6mb3@Uk3@UeLfEbI6USM21RIFMYKPd9;g=UM79WHV=_K6mb80d9
2G/=2@U`Kg0=2@U`Kg0=2@U`Kg0=2@UeLfEbI6USM21RIFMYKPd92BmcIGAbIf9S
Kfa_LR1cNG=dIFeTJF=d82mcIGAbIf9SKfa_LR1WIG@PI6EV3@T9IFiT3@T9OB1T
IFH=2FE^I0em869YKV@PI6EV3BmRHf5bLV5i87MXIG9U87/=2G1_L0d9HV=QLW9Q
NB0b87/=2@T_I64P=21`Lb1TJGHPI6EV3@T9I6HPLfEdIVm^M21WLf5fIB1SLb1g
J@d92C4PJFiTIGPP<21^IG]UN6=X86AQ865TI21UN6=XOFUV86MbIG=dKg9U87=U
M6=XHG9gJFAdJ0d92F=c830P<21cKF<PI64P<21cKF<PI64PI64PLfeS830PI64P
LfeS86<=2@UWLV5i3@T9Nb1WK7d=2@Uk<B1cIGAWLV5iOFUVIFacI@d92FAQ838^
86AYMR1TMG0PKFmfIGA_87=XKgL=2GeRJFiT871eM0em86UV3BD=9B1ELfET87A_
87=^HG0PM6lPI6EfJF=U871YN6E/Lb`P<BldM6PPKfHPM6QU871YN6E/86U^;Pd_
LgA`87/P82DPN21i821`K20PN21i820P820P820P820P820P82DPDfiQL21DKb1@
JGQUK2`PL6UhIF`P82QQMGA_87=dLVm[IB1QI6YeLg@Y3@UdLV5^LfI_LVd=2C0^
<SDPLgER879_MFiT830^<SDPHFAT86EhHfP=2C0^<SDPLgER879_MFiT830^<SDP
HFAT86EhHfP=2FUdLV5^LfI_LVd=OB1RJFiT86AUIPd=;g=^HG1]KgIUM6lPNb0U
87PPNB0PKB0P;B0P820P820P820P820U86e_MVEdKb`PHGEdKb1cM79_JfDPHFAZ
MG=d3@UcM70P86e_MVEdK`em869YKV@PI6EV3@d_LfiQL6aYKVEdKb1k82DPN21i
821/820]820P820P820P820P82DPK6U^IGA_;21QMGA_87=dLVm[IB1QI6YeLg@=
2G=dL21/JFiUM6l=OB1RJFiT86AUIPd00:00S00N00402_ooool0VP2Z00L00000
00P02P0S00008`000:40]P0400400@2P0:00X@2T0041000100X0000000000007
00400@0800P08P2400d0000SK`008`0002<NS`0S00008h<F02<0000Sl5/08`00
0:00X`2P0;h00@0:ooooo`2J0:X01`0000008`000:40]P0400400@0R08<03000
0:40]P0400400@0700400@1`01h04P0<08<0V@2300`0P`1k0180V@0X01`0P`0<
0:00_`2P0:40X02<00comOn400402_n3oo@07P2O00L00000028000000000X02P
0:40Y0010P000@0:0000000000008P080740000Sj`L08`0002<7n@0S00008oWi
02<0000S5@L08`0000402_n3oo@07P2O08@02P00000000000:00X`2P0;h0L@0N
0000F`0>07001`1`00h0F`070680001K00L0L00R000000000:00_`2P0:408`00
0:40]P0400400@2P0:00X@2T0041000100X000000000000700400@0R00P0L@00
02?[1`0S00008`Oi02<0000SnOT08`0002<E1`0S0000X02S0:00_P0100[oPood
01h0W`070000000S0000X@2f00@00@0102801`1`0000X@2f00@00@0100L00@01
07007P0005/03P1`00L0L00>05/01`1R0000F`070700X02o0:00X@070000000S
0000X@2f00@00`0300L00`0302801P00HP00X02=0:00S00<0000D`0100[oe_od
0740W`070000000R000000000:00X02Q0:@00@8000402P000000000002800@0C
00008`<F02<0000Sn_P08`0002?h1@0S00008`_]02<0000100[oe_od0740W`24
00X000000000002P0:<0X02n07407P0000L05P0E00004P0F01D03P0?01<01`00
01808P000000002P0;l0X02Q02<0002Q0;H010010040X02P0:40Y0010@000@0:
0000000000001`0100408P0101<0000S0aH08`0002?jn00S00008oP502<0000S
2nd08`000:00X`2P0;h00@0:omKom01a09l01`0000008`000:40]P0400400@0R
00004P000:40]P0400400@0700400@1`01h0000701H05@0001805P0E00h03`0C
00L0000B0:00_`2P0:401`0000008`000:40]P0400<00`0700<00`0R05T000jc
0:00S@2P08`03?oDojl00@0:ohGob00P07<01`0000008P000000002P0:00X@2T
0042000100X000000000000R00D06P0002?h100S00008`?l02<0000SoO`08`00
02<8100S00000@0:ohGob00P07<0Q00:000000000000X02S0:00_P1a01h0000A
00P06@0401T0200A00@050000140100I028000000000X02o0:00X@0S0000X@2f
00@00@010:00X02Q0:@00@4000402P000000000000L00@0102801@0J00008oP4
02<0000S0o`08`0002?mo00S00008`P402<0002P0:<0X02n00402_n5olP0801c
00L0000002<0002Q0;H0100100408P0401T0002Q0;H0100100401`010040L00N
00004@0801T0100I00P04@0401@0000A00@06@2P0;l0X02Q00L0000002<0002Q
0;H0100100401`0100408P04000D002P08d0X02<00co]`0b00402_ngogl0DP0Z
00L00000028000000000X02P0:40Y0010P000@0:0000000000008P0100L0000S
0PT08`0002?mo00S00008o/202<0000S1_T08`0000402_ngogl0DP0Z08@02P00
000000000:00X`2P0;h0L@0N0000000900P0000600T0200500D01`0000001P0R
000000000:00_`2P0:408`000:40]P0400400@2P0:00X@2T0041000100X00000
0000000700400@0R00401`0002<22@0S00008ogl02<0000Sn`808`0002<6n@0S
0000X02S0:00_P0100[o]omo0580:P070000000S0000X@2f00@00@0102800006
0000X@2f00@00@0100L00@0107007P0000002@0800001P0900P01@0500L00000
00H0X02o0:00X@070000000S0000X@2f00@00@0100L00@0102805`011>h0X02=
0:00S00<03D0:00100[ogond07X0G`070000000R000000000:00X02Q0:@00@80
00402P000000000002801P0100008`Ok02<0000SoP@08`0002<40`0S00008oOn
02<0000100[ogond07X0G`2400X000000000002P0:<0X02n07407P0000001`09
00D0000000L0100500L02@0500008P000000002P0;l0X02Q02<0002Q0;H01001
0040X02P0:40Y0010@000@0:0000000000001`0100408P060040000S1o/08`00
02?n100S00008`@302<0000Smoh08`000:00X`2P0;h00@0:omoo]01j05l01`00
00008`000:40]P0400400@0R00D000000:40]P0400400@0700400@1`01h00000
00L02@050000000700@01@0700T01@000:00_`2P0:401`0000008`000:40]P04
00400@0700400@0R00@01A;l0:00S@2P08`0300foll00@0:ojkojP1909D01`00
00008P000000002P0:00X@2T0042000100X000000000000R01H00`0002?nm`0S
00008`<402<0000S1Oh08`0002?j1`0S00000@0:ojkojP1909D0Q00:00000000
0000X02S0:00_P1a01h0300001D0200E0080300001000`0>00P05@0202800000
0000X02o0:00X@0S0000X@2f00@00@010:00X02Q0:@00@4000402P0000000000
00L00@0102805P0300008okg02<0000S0`@08`0002<5oP0S00008oX702<0002P
0:<0X02n00402_n^onX0B@2E00L0000002<0002Q0;H0100100408P0E0080002Q
0;H0100100401`010040L00N00`0000E00P05@0200`0000@00<03P0801D00P2P
0;l0X02Q00L0000002<0002Q0;H0100100401`0100408P0@00<3l02P08d0X@2F
00`100000P0000000000300E00800@0:0000000E01401`0000008P000000002P
09P0X@2J00Sol5V00008P00/0187fPmDJFeULb1>IGLPDVm]HFh00`OJ00@2000=
0180;P04003o000Z405T00040`00:@T1L`00X02I0:00U`0S0000X@2F00`10000
0P00000000003?o8ol`00@0:0000000E01808`000:00V02Q09X02?o`SH000440
00@2000X0100005T00@3000Y2@5b002P09T0X02G02<0002Q09H0304000020000
0000000<03P00P0100X0000001D03@0S0000X02H0:40VP08oo2;P0001X001080
02P040000D40X02I0:00U`0S0000X@2F00`100000P00000000003?n300000@0:
0000000E00`08`000:00V02Q09X02?o`Rh0008<002T00D800:00V@2P09L08`00
0:40UP0<0@0000800000000000coh02100402P000000:P0;02<0002P09P0X@2J
00Sol1D0002RP00Y0053002P09T0X02G02<0002Q09H03040000200000000000<
08_ojP0100X0000001D03@0S0000X02H0:40VP08oo0PP0006800:@01A000X02I
0:00U`0S0000X02=0?l\>"], "Graphics",
  Editable->False,
  ImageSize->{171, 155},
  ImageMargins->{{252, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0002240@0005P0000M00007@000?d0003V0000
0000000000017`00BA/00215CDH00040Q20008D000050000000000000000000000@00003000>0@00
b`0004H0000L2@0040T004M4BD<1002000<00?2DA6D00000n0P000402@000g`4000601`0000000D0
000;0_ooool5000030;70>80100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@0>00009@<50240UP2A09H0[`0U0380?00Q09H0100002d10`040000
l04000P0003j0PD000000?ooo`840000;@4000@0000]0@@010000?010@070000o0800000000000@0
000]0@403P0002@31@2@09H0N`2M0880UP1k08l0T02F00@0000]0@<010000?0100080000nP800040
0@000002100002d1000>00009@<50900UP1k09d0PP2F07/0S`2@09H0100002d10`040000l04000P0
003j0P000`03000000840000;@4000P0000U0`808@2F08<0UP040000;@4300@0003`0@0020000?X2
1@000000oooo0P@0000]0@003P0002@31@0b03`0=@1B02l0BP0W04l0<P0l00@0000]0@<010000?01
00080000nP8000400@000002100002d1000>00009@<50380?00e0580;`1:02L0C`0b03`0100002d1
0`040000l04000P0003j0P000`03000000840000;@4000P0000U0`808@2F02l0B@040000;@4300@0
003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@1U0940G@2E0600T@1M08d0I@2A00@0
000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<506D0T@1M09D0H02A05d0
S@1U0940200002D30P1<0940H02A00@0000]0@<010000?0100080000nP850000003oool2100002d1
000>000090<509/0F`2M06@0VP1P09D0HP2K05/0100002d10`040000l04000P0003j0P000@010000
00840000;@4000h0000U0`D0V`1K09d0I02J0600U@1R09/0F`0800009@<209H0LP2J0600100002d1
0`040000l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0H00h06L0<`1U03L0J@0j0600
>0040000;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D31@1P03P0I`0c06D0
=`1Y03X0H00h00P0000U0`80I@0g07L0<`040000;@4300@0003`0@0020000?X21@000000oooo0P@0
000]0@003P0002@31@0/07T0:P1`02d0M00b0780;01i00@0000]0@<010000?0100080000nP800040
0@000002100002d1000>00009@<502`0N@0Z0700;@1d0380LP0/07T0200002D30P0]07@0<01T00D0
00090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`00000009010@000000039DJFeU
Lb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`0002450@1Tof805@0500002@800002
100002h100040000;@4500@0003`0@8070000?/2k_l00000002l0P400000000bE6U]IG<PCVEg859_
KF5^0000000000000000000000040000;@4200L0000Q1@40LomR01h01@0000T200000P@0000^0@00
100002d11@040000l04201`0003k0^ko00000000T04100000000<UAYKFEc84iUMb1BKfeQKP000000
0000000000000000100002d10P0700008@D106CoV01=00D000090P0000840000;P4000@0000]0@D0
10000?010P0L0000n`;^o`0000000;`20@000000039DJFeULb1>IGLPDVm]HFh00000000000000000
000000@0000]0@801`0002450@1boiP0EP0500002@800002100002h100040000;@4500@0003`0@80
70000?/2k_l00000002@0@400000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000
;@4200L0000Q1@40@OnF01D01@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko
00000000T04100000000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d10P070000
8@D104;oUP2B00D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000901
0@000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`0002450@13oaD0
/P0500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@400000000b
E6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40A?l[02L0100002L1
ool40000l04000@0003`0@4010000?010P040000l04300@0003`0@@010000?011@030000000A0000
300000P0000;0000400002d100080@002@000100000]0@00204000X0000@0000ooooooooool90000
40000>80003700004P0000`0000100008@0000P0000V000070000040000000000@00004000000002
9@0000`0000100009@0000`000000020E`000300000]0000<P000>X0003800001@000240UP2A09H0
[`0U0380?00Q09H09P0001`0000200001@00000000000000oooo0RD0000<00000P0002D0000<0000
1000P5H0000`0000Y@000;l000310000dP0000D0002@09H0N`2M0880UP1k08l0T02F02D0000<0000
0@0002P0000<00000P0002H0000L00000P000000000100000@000000008U000030000080001G0000
<0000:D0002o0000`@000=8000050000T02F07/0W@2209H0N`2?0900UP0U000030000040000X0000
30000080000V000070000080000000000`0000<0000000029@0000`000020000E`0002@0000[0000
aP000;80003:00000P000240UP2309H09@0000`000010000:00000`0000200009P0001`000020000
1@00000000000000oooo0RD0000<00000P0005H0000`0000=@00054000180000KP0000D0000b03`0
=@1B02l0BP0W04l0<P0l02D0000<00000@0002P0000<00000P0002H0000L00000P00000000010000
0@000000008U000030000080001G0000<00003D0001A0000B00006h000050000<P0l03D0DP0_04X0
9`1?0380?00U000030000040000X000030000080000V000070000080000000000`0000<000000002
9@0000`000020000E`0002@0000[0000H0000480003:00000P000240UP0_04T09@0000`000010000
:00000`0000200009P0001`0000200001@00000000000000oooo0RD0000<00000P0005H0000`0000
O@000;`000280000a`0000D0001U0940G@2E0600T@1M08d0I@2A02D0000<00000@0002P0000<0000
0P0002H0000L00000P000000000100000@000000008U000030000080001G0000<00007d0002l0000
R0000<L000050000I@2A05d0U@1P0940G@2=06D0T@1G0000900006L000320000P@000<8000020000
C02A0600T@0U000030000040000X000030000080000V0000700000800005000000000000003oool2
9@0000`000020000EP00030000380000NP000=80002600001@0009/0F`2M06@0VP1P09D0HP2K05/0
9@0000`000010000:00000`0000200009P0001`000020000000000400001000000000RD0000<0000
0P0005L0000`0000b00007X0003B0000QP0000D0002K05/0W@1T09X0H02E0680V`1K05L0000T0000
b@000840003>0000V@000080002F0780VP1P02D0000<00000@0002P0000<00000P0002H0000L0000
0P0000D00000000000000?ooo`8U000030000080001F0000<000084000150000S@0004h000050000
H00h06L0<`1U03L0J@0j0600>00U000030000040000X000030000080000V00007000008000000000
0@000040000000029@0000`000020000E`00030000210000A@0008d0001>00001@000600>01W03<0
I@0g06T0>P1P03P0E`0002@000280000A@000:00001:00000P0006D0=`1g03<09@0000`000010000
:00000`0000200009P0001`0000200001@00000000000000oooo0RD0000<00000P0005H0000`0000
>@0009H000140000XP0000D0000/07T0:P1`02d0M00b0780;01i02D0000<00000@0002P0000<0000
0P0002H0000L00000P000000000100000@000000008U000030000080001G0000<00003T0002F0000
A0000:8000050000;01i02X0L00]07@0<P1b02`0N@1G0000900003d000260000@@0009/000020000
;@1d0300I00H000030000000009B0000C04000<0003^oooo0000000000000000T04000400000000b
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0002C?ITmYcfc?KdmbSg@?Mhml3ge?Olm33hB?R0n
;ch00000GCiT?VhnNcj1?XlnZ3j]?[Lna3k:?]PnlCkf?P0o3ClC?b4o=3li?d<oD3mF?f@oMcml?hHo
TcnI?jLo`Co6?m0ogCoS?o4o0000@040208000/`430J<2L`;C0k<4h`Dc1M<6X`L31n<94`US2P<:d`
/c31<<d`dc3P<>X`003n<0`a6C4O<BDa<S4k<DHaE35J<FTaN36G<K`aaS7J<NdalS7j<Adb:C9@<V0b
MS9l<Ylb`c;:<^Tb0S<9<`00000000000000000000000000000000410@410@410@4^=2D0000<0000
0`0005@0001D00007@0008<0000X0000W@000040000]N0a2RT<<@QD0001R00000@0004`000000000
000000000000000000000500001T08Tf2@000580001<0@00100000000000000000000000001N0@00
000000000B0002`h<SQd>7dhTSRO>:`h/SSY>?8hnSP8>@di4cTR>BLi<CTn>D@iDSUN>FPiMCUk>HTi
VSVO>JTi]SVl>@00003i>@8j4CXJ>R8j<3Xe>S/jBSY?>UTjISY/>WXjQSZ@>YdjXcZa>[dj`S[M>^8j
mc[l>PTk:C/b>cXkB3]=>e<kHS]W>g4kOS^4>i8kWS^X>kDk^c_9>mXkgc_Y>oHko3/:?1Hl6c`f?3/l
D3aE?68lNCb2?8XlV3bM?:<l/S`00<4lcScD?>8lkSch?0Dm2cdI?BXm;cdi?DHmC3eJ?FLmW3gD?@00
050109P1001Y<g4cNS>8<i8cXS>W<k4c000000000000000000000000000000000@410@410@410Hld
9@0000`000040000:00000`000030000DP0004`100030000k_ooo`000000000000000;`200010000
0000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000CcS_>?Dh0STA>AHi83T]>C<i@CV?>IHi
/cVi>LDi00000><il3Wf>@@j4CY;>U4jH3YW>XHjSCZ/>[<jaS[<>]/jhSX1>`Pk9c/^>d4kG3]]>gPk
OS^=>i8kW3^Y>jlk_C_C>mhki3_c>oPk0S`??1Dl8c`i?4@lBSaI?5hlJ3ae?7/lRCbO?:Xl/3bo?<@l
cScK?>4lkccl?1`m;Sdi?@00CSeC?EdmJSe`?GhmUCfP?JHm]Cfj?L@mdCgG?NDmlSdB?Q`n8Ch`?SLn
E3iK?V@nJCik?XXnTCjl?/<ni3h0000000000000000000000000000000010@410@410@41000U0000
300000<0001D0000E00002T000230000<@0009h000010000;GP<@XY3348N0000HP000040001<0000
000000000000000000000000001@0000L`0J<`L0000U0000300000@0000X0000300000<0001B0000
C04000<0003^oooo0000000000000000T04000400000000bE01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h0000f=T@fD3Ia=WLfQCJC=Z/f/CJk=/PfcSKL=^TfkcH0000063LW=b`g=SM3=dTgEcMj=kXg
ccOb=`hh>SQM>7DhVcRh>20iAcUK>GPiVcW6>M8imcTF>R4j=CY6>UXjISZ0>Y<jaC[<>]@jfS[Y>_0j
0S/@>adk9c/^>cHk?3]8>eXkHc]^>gPkQC^;>iTkYS^/>kHk`c_9>mLki3/9?14l000V?2dlA3a:?5Tl
GSaX?7DlNcb9?9Hl_3c;?=4lh3cW?0Hm3CdR?BLm=Sdm?GDm/cfo?O<mBciT?VXnN3jK?P0000000000
0000000000000000000000410@410@410@7_<BD0000<00000`0005@0001D0000J0000</0001c0000
i@000040000]N0a2RT<<@Td0002H00000@0004`000000000000000000000000000000500001T01dd
2@0002D0000<0000100002P0000<00000`000580001<0@000`000>koool0000000000000002l0P00
0@000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP0004PfECIJ=V@fLCIf=X0fSCJC=Z4f
ZCKA=]LfnSH@=`00001G=mPgi3OX=n`gl3Od=oPgC3QD>5XhJCQ`>98hX3R^>;`hbSSH>>Hh0CT5>@Ti
3CTA>ADi6CTO>Bhi=CU8>GTiPCVC>I/i]CVl>L@idcW_>O/i0CX@>QLj:cXl>TDjDcYH>V8jMcYo>YTj
X3ZX>[4j_S[6>]XjjS[j>Plk93/003<k?C]7>e8kKC]m>hdkWC^]>k<k`c_<>n@km3/:?10l6S`T?2dl
=ca4?4TlDcaT?6TlLcb4?8TlTcbT?:Tl000000000000000000000000000000000@410@410@410FTm
9@0000`000030000E00005@0001d0000b`0007`0003V00000@0002eh34::@`a2EP0009P000010000
C0000000000000000000000000000000D0000780=SH700009@0000`000040000:00000`000030000
DP0004`100030000k_ooo`000000000000000901000100000000<U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^0000@SQA>5/hHcQo>8Thd3SS>40iDcV/>L@id3WL>NLi000001`j9cXb>STjAcYC>U/j
ISYa>WdjXCZU>ZTj[CZa>[Dj^C[9>]PjiC[a>_dj13/C>alk=S]B>e/kMC]n>iPkXC^V>kDkec_M>nhk
3ca>?5@lJcb<?;Pl_3c0?<@lb3c<?=8loC`3?B@mACe=?F0mM3el?HlmUCfX?JhmbcgD?@00k3ge?O/m
3ShD?RLn;Ci1?TTnGCiU?WLnP3j6?YPnXCjW?[`na3kI?^<nlSh1?`Lo3ClC?aTo:Sl`?d4oC3l00000
00000000000000000000000000010@410@410@41000U0000300000<0001D0000E00001d000380000
:P000>8000010000;GP<@XY3348E0000UP000040001<0000000000000000000000000000001@0000
@@25<P/0000U0000300000@0000X0000300000<0001B0000C04000<0003^oooo0000000000000000
T04000400000000bE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00039==<dhCCW=?hd13DG=Ade
8cD_=CHeBSER=FPeKSD00000QcF==IHeW3FV=J`e]CG9=MHej3G^=O/e0CH>=QXf83HZ=S@f?cI5=U4f
FSIR=VLfKCIb=WLfRcJD=Y/fc3KD=^df53LN=dTgI3MZ=h`gVSNY=k0gccOG=n0gm3L1>0Xh<3Po>4/h
LcR2>:XhdCSg>?dh83T]>DHiDSUH>G/i003=>BHj?CYG>V`jNCZC>Z0j[3[4>/TjeS[Z>_<j03/B>blk
K3^U>l@kgS_a>a0l:S`i?4TlNcb[?;Dl_Sc]?000000000000000000000000000000000410@410@41
0@5b?bD0000<00000`0005@0001D0000a0000<P0003B0000hP000040000]N0a2RT<<@Y80002F0000
0@0004`00000000000000000000000000000050000120<dc2`0002D0000<0000100002P0000<0000
0`000580001<0@000`000>koool0000000000000002@0@000@000000039D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP0009@eWSFX=K8e_3G6=M0efSGT=NhenCD2=PXf53HN=P00000l=THfD3IJ=V@f
KcIg=X8fW3Je=/hfgCKT=_4f2SLP=fLgOCO9=mlgnSL@>2`h@SQN>7@h/SS0><XhfSS`>3LiCCVI>Jli
bSWP>O`i4SX^>T@jT3[;>STkTS^Y>l<kf3_U>olk33`H?30l=Ca2?5HlGca/?7hlVccH?0Xm5Cd002/m
=3dl?D@mCceD?EXmGce[?HXmScfE?J<m]SgE?MXmh3g^?Odm3Cho?VlnNCj2?Y`nXSj`?[lnf3kM?^<n
000000000000000000000000000000000@410@410@410B0`9@0000`000030000E00005@0003^0000
7@000?d0000g00000@0002eh34::@`a2/P0001D000010000C0000000000000000000000000000000
D00004<0DSL<00009@0000`000040000:00000`000030000DP0004`100030000k_ooo`0000000000
00000901000100000000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00005cd_?E0mQcfM?K@m
bcgZ?OXm9Shl?U0nECi[?Wln00000:hn/ck9?]dnhckl?P/o6ClX?cHoHCmY?g0oN3n0?hLoScnG?iho
YSn^?kDo_Co7?mLohco_?oho0000`000e08000P`630T<30`?c17<50`F31Q<6T`LS1j<8<`Rc2D<9/`
[C2c<;d``c3f<0`a834U<C/aCc5D<FXaOS63<@00[C6e<L<ad37Q<NTalC7i<A/b8c8Z<S8b>S91<TTb
DC9H<V0bJ39_<WLbOc:8<Y0bVC:Q<ZXb/S:k</<bbC80000000000000000000000000000000010@41
0@410@41cS<U0000300000<0001D0000E00003D0000j0000A@0005@000010000;GP<@XY3348W0000
:`000040001<0000000000000000000000000000001@0000A037=@d0000R000030000?oooolX0000
30000080000X0000300000<0000X000030000040000X0000300000@0001;00004000000000050000
3P0001@000000000400001@0
\>"], "Graphics",
  Editable->False,
  ImageSize->{224, 201},
  ImageMargins->{{375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[BoxData[
    \(\(\(\ \)\(\(d\[DoubleStruckS]\[Cross]\[DoubleStruckE]d[
          red@3];\)\[IndentingNewLine]
    d\[DoubleStruckN] = \(% // \(LinearBreakout[
              Cross]\)[\[DoubleStruckE]d[_]]\) // 
        CrossProductExpansion[\[DoubleStruckE], e, h]\[IndentingNewLine]
    d\[DoubleStruckN]\[Section] = % /. ds -> dr\)\)\)], "Input"],

Cell[BoxData[{
    \(DA = \((\[DoubleStruckV] . d\[DoubleStruckN] // 
            EvaluateDotProducts[\[DoubleStruckE], g])\) // 
        LeviCivitaSimplify[e]\), "\[IndentingNewLine]", 
    \(AB = % /. ds -> dr\)}], "Input"],

Cell[BoxData[
    \(\(CovariantD[\[DoubleStruckV], red@k] dru[red@k] // Expand\) // 
      CovariantDSimplify[\[DoubleStruckE], g]\)], "Input"],

Cell[BoxData[
    \(BC = \((\((\(\[DoubleStruckV] + 
                      CovariantD[\[DoubleStruckV], red@k] dru[red@k] // 
                    CovariantDSimplify[\[DoubleStruckE], g]\) // Factor)\) . 
              d\[DoubleStruckN] // 
            EvaluateDotProducts[\[DoubleStruckE], g])\) // 
        LeviCivitaSimplify[e]\)], "Input"],

Cell[BoxData[
    \(CD = \((\((\(\[DoubleStruckV] + 
                    CovariantD[\[DoubleStruckV], red@k] dsu[red@k] // 
                  CovariantDSimplify[\[DoubleStruckE], g]\) // Factor)\) . 
            d\[DoubleStruckN]\[Section] // 
          EvaluateDotProducts[\[DoubleStruckE], g])\)\)], "Input"],

Cell[BoxData[
    \(ABCD = AB + BC - CD - DA // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\((ABCD // SumExpansion[red@i, red@j, red@k])\) /. 
          CovariantD[vu[red@i_], red@3] \[RuleDelayed] 0 // 
        LeviCivitaSimplify[e]\) // FullSimplify\)], "Input"],

Cell[BoxData[
    \("\<\[DoubleStruckV].d\[DoubleStruckN] ==  \>"\ % /. \((\(\((\(\(-eddd[
                          i, j, 3]\) dru[i] dsu[j] // 
                    SumExpansion[i, j, k]\) // 
                  LeviCivitaSimplify[e])\) :> \(-dAd[red@3]\) // 
            ToFlavor[red]\) // FullSimplify)\)\)], "Input"],

Cell[TextData[{
  "The second term in parenthesis is ",
  Cell[BoxData[
      StyleBox[\(TDiv\ \[DoubleStruckV]\),
        Background->None]], "Text",
    TextAlignment->Center,
    TextJustification->0,
    Background->None],
  " in two dimensions. Now assembling together such quadrilaterals to fill \
the area ",
  StyleBox["A",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ", gives the Gauss theorem in d = 2 :"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{"    ", 
          StyleBox["   ",
            Background->RGBColor[0, 1, 0]]}]], 
      RowBox[{
        StyleBox[
          RowBox[{\(\[Integral]\_A\), 
            RowBox[{"TDiv", " ", "\[DoubleStruckV]", " ", 
              RowBox[{
                StyleBox["\[DifferentialD]",
                  Background->RGBColor[0, 1, 0]], 
                StyleBox["A",
                  FontWeight->"Bold",
                  Background->RGBColor[0, 1, 0]]}]}]}],
          Background->RGBColor[0, 1, 0]], 
        StyleBox[" ",
          Background->RGBColor[0, 1, 0]], 
        StyleBox["=",
          Background->RGBColor[0, 1, 0]], 
        StyleBox[" ",
          Background->RGBColor[0, 1, 0]], 
        RowBox[{
          StyleBox[\(\[ContourIntegral]\_C\),
            Background->RGBColor[0, 1, 0]], 
          StyleBox["  ",
            Background->RGBColor[0, 1, 0]], 
          RowBox[{
            StyleBox["\[DoubleStruckV]",
              Background->RGBColor[0, 1, 0]], 
            StyleBox[" ",
              Background->RGBColor[0, 1, 0]], 
            RowBox[{
              StyleBox["\[DifferentialD]",
                Background->RGBColor[0, 1, 0]], 
              StyleBox["n",
                FontWeight->"Bold",
                Background->RGBColor[0, 1, 0]], 
              StyleBox["  ",
                FontWeight->"Bold",
                Background->RGBColor[0, 1, 0]]}]}]}]}]}]], "Text",
  TextAlignment->Center,
  TextJustification->0,
  Background->RGBColor[0, 1, 0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gauss theorem in three dimensions :", "Outline1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[GraphicsData["PICT", "\<\
3g[ooooo07D0`00A0_l<0?ooooooo`00ool000300000M@000000002Q0<03NBE@
Kg=dDf=bJG1d84QQHf/PHWTPCFU[IB12LVmbLb0a<Rlg;cT`3Bm4JG=QHVaUCVEh
M5=UM597@T=_K6mb3@Uk3@UeLfEbI6USM21RIFMYKPd9;g=UM79WHV=_K6mb80d9
2G/=2@U`Kg0=2@U`Kg0=2@U`Kg0=2@UeLfEbI6USM21RIFMYKPd92BmcIGAbIf9S
Kfa_LR1cNG=dIFeTJF=d82mcIGAbIf9SKfa_LR1WIG@PI6EV3@T9IFiT3@T9OB1T
IFH=2FE^I0em869YKV@PI6EV3BmRHf5bLV5i87MXIG9U87/=2G1_L0d9HV=QLW9Q
NB0b87/=2@T_I64P=21`Lb1TJGHPI6EV3@T9I6HPLfEdIVm^M21WLf5fIB1SLb1g
J@d92C4PJFiTIGPP<21^IG]UN6=X86AQ865TI21UN6=XOFUV86MbIG=dKg9U87=U
M6=XHG9gJFAdJ0d92F=c830P<21cKF<PI64P<21cKF<PI64PI64PLfeS830PI64P
LfeS86<=2@UWLV5i3@T9Nb1WK7d=2@Uk<B1cIGAWLV5iOFUVIFacI@d92FAQ838^
86AYMR1TMG0PKFmfIGA_87=XKgL=2GeRJFiT871eM0em86UV3BD=9B1ELfET87A_
87=^HG0PM6lPI6EfJF=U871YN6E/Lb`P<BldM6PPKfHPM6QU871YN6E/86U^;Pd_
LgA`87/P82DPN21i821`K20PN21i820P820P820P820P820P82DPDfiQL21DKb1@
JGQUK2`PL6UhIF`P82QQMGA_87=dLVm[IB1QI6YeLg@Y3@UdLV5^LfI_LVd=2C0^
<SDPLgER879_MFiT830^<SDPHFAT86EhHfP=2C0^<SDPLgER879_MFiT830^<SDP
HFAT86EhHfP=2FUdLV5^LfI_LVd=OB1RJFiT86AUIPd=;g=^HG1]KgIUM6lPNb0U
87PPNB0PKB0P;B0P820P820P820P820U86e_MVEdKb`PHGEdKb1cM79_JfDPHFAZ
MG=d3@UcM70P86e_MVEdK`em869YKV@PI6EV3@d_LfiQL6aYKVEdKb1k82DPN21i
821/820]820P820P820P820P82DPK6U^IGA_;21QMGA_87=dLVm[IB1QI6YeLg@=
2G=dL21/JFiUM6l=OB1RJFiT86AUIPd00:00S00N00402_ooool0M@3000L00000
00P02P0S0000X02<00`00?oQ00402_oPool0EP3002<0002P08`03?oool<00@0:
oj?ooP0I0;l08`000:00X02Q0:@00@8000402P000000000002801@1c00008oH4
02<0000S1?`08`0002?lo00S00008`X402<0000100[oXoon01T0_`2400X00000
0000002P0:<0X02n00P0201a01h0001X00P0LP040780201X00@0K00006P0101b
028000000000X02o0:00X@0S0000X@2f00@00@010:00X02Q0:@00@4000402P00
0000000000L00@0102801@1c00008oH402<0000S1?`08`0002?lo00S00008`X4
02<0002P0:<0X02n00402_nSooh06@2o00L0000002<0002Q0;H0100100408P04
0780002Q0;H0100100401`010040L00N0000J0080780101b00P0J00406`0001X
00@0LP2P0;l0X02Q00L0000002<0002Q0;H0100100401`0200808P02001[0@2P
08d0X02<00`00@0m00402_oPool0EP3000L00000028000000000X02P0:40Y001
0P000@0:0000000000008P0101h0000S00/08`0002?nn`0S00008oX202<0000S
2?P08`0000402_oPool0EP3008@02P00000000000:00X`2P0;h0L@0N00005@0;
01d0000M00/07@0601/0200E00007@0R000000000:00_`2P0:408`000:40]P04
00400@2P0:00X@2T0041000100X000000000000700400@0R00407P0002<02`0S
00008okk02<0000SnP808`0002<8n00S0000X02S0:00_P0100[oh?oo05H0`007
0000000S0000X@2f00@00@010280000M0000X@2f00@00@0100L00@0107007P00
01D02`0M00007@0;01d01P0K00P05@0001d0X02o0:00X@070000000S0000X@2f
00@00@0100L00P020280@0006/D0X02=0:00S00<003og@0100[o_Ooo03<0`007
0000000R000000000:00X02Q0:@00@8000402P000000000002800@0a00008oX9
02<0000S0OX08`0002?jo`0S00008`_n02<0000100[o_Ooo03<0`02400X00000
0000002P0:<0X02n07407P0002D02@0`0000<00902X00`0[00809@0003008P00
0000002P0;l0X02Q02<0002Q0;H010010040X02P0:40Y0010@000@0:00000000
00001`0100408P010340000SnPT08`0002<1nP0S00008o[o02<0000S2oh08`00
0:00X`2P0;h00@0:okgoo`0c0<001`0000008`000:40]P0400400@0R0000<000
0:40]P0400400@0700400@1`01h0000U00T0<00003002@0Z00<0:`0202D0000`
0:00_`2P0:401`0000008`000:40]P0400400@0S0000X@2f00@00@010:40f004
0020002Q0=H01000P000X03G0:40]00500022@T000L00P0200P05`0R01h00B[U
0:00]@2Q0=H01000P000X03G0:00f@070000000800P08`000:40]P0400400@2Q
0=H01000P000X@3H00@008000:00_P2P0=T0L@0N01P0000O00X07@0001P0200J
00X07`0201d0001a01h03P0?01D06@0C00l03P0G01006@0E01404`0?07407P05
01h0300X00X07P0502H01`0X00`0800:01h0X@3H00@008000:00_`2P0=T0X03G
0:00S@2P08d0X02<00co]@1200402_oook@0M@1e0280000000008`000:40]P04
00400@0700400@0SL@401`0000008`000:40]P0400400@0700400@0R0440EQbo
00L0000002<0002Q0;H0100100401`0100408P0N04<_hP2P08d0301;00000@0:
ooooo`1e0<001`0000008`000:40]P0400400@2P0:00X@2T0041000100X00000
0000000700400@0R0040C@0002?@7`0S00008g4002<0000Si4008`0002<_hP0S
0000X02S0:00_P0100[ooooo07D0`0070000000S0000X@2f00@00@010280@@2P
0000X@2f00@00@0100L00@0107007P0001`0G`2P0000C00O01`07`2=05l0L@11
0:00X02o0:00X@070000000S0000X@2f00@00@0102<0002Q0;H010010040X@3H
00@008000:40eP040020002P0=L0X@2d00D000892@001`010040200G0280@00^
7L00X02e0:40eP040020002P0=L0X03I00L0000000P0200S0000X@2f00@00@01
0:40eP040020002Q0=P01000P000X02n0:00f@0700400@0R0400;PCh0280<00e
1?L08P0O03d4n00R00l0A0Ch0:40f0040020002P0;l0X03I0:00e`2P08`03?oA
ol<00@0:ol;od00h09401`0000008P000000002P0:00X@2T0042000100X00000
0000000R00D0M00002?h100S00008`?l02<0000SoO`08`0002<8100S00000@0:
ol;od00h0940Q00:000000000000X02S0:00_P1a01h0001[00P0L`0407<0201[
00@0KP0006/0101c028000000000X02o0:00X@0S0000X@2f00@00@010:00X02Q
0:@00@4000402P000000000000L00@0102801@1d00008oP402<0000S0o`08`00
02?mo00S00008`P402<0002P0:<0X02n00402_o2om00>02A00L0000002<0002Q
0;H0100100408P0407<0002Q0;H0100100401`010040L00N0000J`0807<0101c
00P0J`0406h0001[00@0L`2P0;l0X02Q00L0000002<0002Q0;H0100100408`00
0:40]P0400400@2Q0=P01000P000X@3F00@008000:00e`2Q0;@01@000PT90007
00400@0801L08P03001]002P0;D0X@3F00@008000:00e`2P0=T01`0000002008
02<0002Q0;H010010040X@3F00@008000:40f0040020002P0;h0X03I00L00@01
02800`0020008P030188000R00<090P002800`0f20008P0304P8000R00<0FPP0
02800`1/0000X@3H00@008000:00_`2P0=T0X03G0:00S@2Q09H0304000020000
0000000<om;og`0100X0000001D04`070000000R000000000:00V02Q09X02?o`
J80006J002`04POJ3eAYKFEc84iUMb1BKfeQKP031mX0108000d04P0^00@00?l0
02X@0F@000@3000Y2@5b002P09T0X02G02<0002Q09H03040000200000000000<
02h0800100X0000001D04P0S0000X02H0:40VP08oo18P000>000108002P04000
0F@010<002T90G<00:00V@2P09L08`000:40UP0<0@0000800000000000`0;@0[
00402P0000005@0A02<0002P09P0X@2J00Sol1f0000:P0040P00:00@0001I004
0`00:@T1M000X02I0:00U`0S0000X02=0?l\>"], "Graphics",
  Editable->False,
  ImageSize->{193, 118},
  ImageMargins->{{264, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001^80@0005P0000100000`000?`0002L0000
00000000001e6P00[1000215CDH00040R1/0070000050000000000000000000000@00003000>0@00
b`0004H0003X1`00g0L004M4BD<1002000<000:K@k@00000a0L000402@000n83000601`0000000D0
000;0_koo_l50000309j0<80100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00
100002d110040000l04100L0003l0P0000000000100002d10@0>000090<50780G`1X06<0J`1O06P0
F`1b05l0100002d10`040000l04000P0003j0P000@01000000840000;@4000h0000U0`D0LP1O06P0
H`1[05l0J01K0780G`040000;@4300@0003`0@0020000?X20002008000000P@0000]0@00200002D3
0P0105l0J`1O00@0000]0@<010000?0100080000nP850000003oool2100002d1000>000090<501`0
7`0L02X06@0U01@09`0L01l0100002d10`040000l04000P0003j0P000@01000000840000;@4000h0
000U0`D0700O01`0:P0I02D0500W01`07`040000;@4300@0003`0@0020000?X20002008000000P@0
000]0@00200002D30P0005l06@0U00@0000]0@<010000?0100080000nP850000003oool2100002d1
000>000090<502l0@@0Y04X0:@1502@0@`0_0440100002d10`040000l04000P0003j0P000@010000
00840000;@4000h0000U0`D0;`1102T0BP0Y04D0901302l0@@040000;@4300@0003`0@0020000?X2
1@000000oooo0P@0000]0@003P0002@31@3ooel01`1J00T0F`010600oomO00h0000T0`D03P1E01H0
D@0H0580401F00h0E@0>000090<501d0C00U04L09`1801l0C@0M04`0100002d10`040000l04000P0
003j0P000@01000000840000;@4000P0000U0`80BP000;/0000800009@<20:00@02l0000200002D3
0P2=01h0_00000h0000U0`D0B`0001/07`2<01l0L01O09l0@@0800009@<204/0001700P0200002D3
0P140100@00I00P0000U0`80?00Q03P0:@0800009@<203D0<@0a03T0200002D30P0_0440=`1100P0
000U0`80@@1104T0@@0800009@<205<0@@1K0440200002D30P1U0440K@1100P0000U0`80M`1107l0
@@0800009@<208T0@@2A0440200002D30P2K0440X01100D000090P0000840000;P4000@0000]0@D0
10000?010P0L0000n`;^o`00000009010@000000039DJFeULb1>IGLPDVm]HFh00000000000000000
000000@0000]0@801`0002450@1Tof00G00500002@800002100002h100040000;@4500@0003`0@80
70000?/2k_l00000002l0P400000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000
;@4200L0000Q1@40L_mP06D01@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko
00000000T04100000000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d10P070000
8@D106Co@00^00D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000;`2
0@000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`0002450@1cod00
=`0500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@400000000b
E6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40I?lE00401@0000T2
00000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000_08100000000<UAYKFEc84iU
Mb1BKfeQKP0000000000000000000000100002d10P0700008@D107Co5@0:00@0000W0Ooo10000?01
00040000l04100@0003`0@8010000?010`040000l04400@0003`0@D00`0000004@0000`000080000
2`00010000010@00X@0000T0000@00000@400:40000:000040000?koooonoooo2@00010000320000
NP000180000<00000@000240000800009P0001`0000100001@00000000000000oooo0RD0000<0000
0@0002D0000<00001000P5H0000`0000S00007/0002J0000Q@0000D0001b05l0J01S06/0G`1X05/0
LP1O02H0000L00000P000000000100000@000000008U000030000080000X000030000040000V0000
70000040000000000@000040000000029@0000`000010000E`000300002<0000N`0009X000250000
1@000780G`1X06<0J`1O06P0F`1b05l09@0000`000020000:00000`0000100009P0001`000010000
000000800002000000000RD0000<00000@0005L0000T00000`0007l0002A0000P@000080000105l0
J`1O02D0000<00000P0002P0000<00000@0002H0000L00000@0000D00000000000000?ooo`8U0000
30000040001F0000<00001d0000/0000:00003X000050000700O01`0:P0I02D0500W01`07`0U0000
30000080000X000030000040000V000070000040000000000@000040000000029@0000`000010000
E`000300000M0000;00002P0000j00001@0001`07`0L02X06@0U01@09`0L01l09@0000`000020000
:00000`0000100009P0001`000010000000000800002000000000RD0000<00000@0005L0000T0000
0P000380000U0000P@000080000005l06@0U02D0000<00000P0002P0000<00000@0002H0000L0000
0@0000D00000000000000?ooo`8U000030000040001F0000<0000380001H0000@@0006@000050000
;`1102T0BP0Y04D0901302l0@@0U000030000080000X000030000040000V00007000004000000000
0@000040000000029@0000`000010000E`000300000b0000F0000440001T00001@0002l0@@0Y04X0
:@1502@0@`0_04409@0000`000020000:00000`0000100009P0001`0000100001@00000000000000
oooo0RD0000<00000@0005H0000`00000@0007T0000?0000P@0000D0003ooel01`1J00T0F`010600
oomO05H0000`00005@0006h0000R0000M00000D0000>05D05P1A01P0DP0@05H03P1E05H0000`0000
:@000600000f0000J00000D0000M04`09@1702L0B00O04d07@1<02D0000<00000P0002P0000<0000
0@0002H0000L00000@000000000100000@000000008U000030000040001G0000900006D000030000
nP0000<000020000BP000;/0001G000090000=L000030000o00005L000020000X0100;`0001G0000
90000;d000030000o00002X000020000S@0N0;`0001G0000<00002H000030000e@00080000050000
B`0001/07`2<01l0L01O09l0@@1G00009000064000030000IP0000d000020000B`0004L0201G0000
900005L0000H0000G@0002@000020000A00@04006@1G0000900004d0000^0000DP0003T000020000
?00Q03P0:@1G0000900004@000130000B@0004h000020000=@0a0340>@1G000090000440001H0000
C00005P000020000;`1103L0@@1G0000900005T0001H0000H`0005P000020000@@1104T0@@1G0000
90000740001H0000N`0005P000020000D`1105/0@@1G0000900008P0001H0000T`0005P000020000
I@1106d0@@1G000090000:00001H0000Z`0005P000020000M`1107l0@@1G000090000;P0001H0000
``0005P000020000R@110940@@1G000090000=00001H0000e`0005P000020000V`110:00@@0H0000
30000000009B0000C04000<0003^oooo0000000000000000T04000400000000bE01Y06d0I@1c0200
CP1U07L0801B06l0K@1Q06h0002m?<Lle3cJ?>Plnc`0?@Xm5cdM?B/m=ceP?GlmQCd000003chG?RDn
:Sh`?SlnA3i>?U/nHCi_?W/nQCjB?YPnYSk<?]4nfckX?^hno3h??a@o7Sl[?c4o?cmB?eLoHCm^?g@o
PSnE?iXoY3na?kLoaCoA?oXo0000`080]04001T`830o<4D`QC2?<9d`/c31<24a<S50<EhaK37<<Mda
000e<SlbCC9S<W4bdC;R<_0b3S<L<g`cSC>K<k0cdS?P<o4c0C@;=1Ld7c@[=5TdKCAd=:Hd_CC3=>Td
lS@T=@00000000000000000000000000000000410@410@410@7B=RD0000<00000`0005@0001D0000
O@00084000280000V`000040000;^0]288L;@U`0001P00000@0004`0000000000000000000000000
00000500001T05/i2@000580001<0@00100000000000000000000000001N0@00000000000B000;lj
aC[:>]@jhC[W>_Dj4S/`>d4kAS]@>edkHc]a>gdkQc^D>iXkZ3^j>lPk3c`U?2/lFCb[?;8l^Sc8?000
003L?>8llCcf?00m3CdC?B4m;Cdg?D@mBSeH?FDmJce`?GXmQcf=?I/m^3gF?NLmk3gf?@<n2ChG?R<n
;Chj?T0nCSiP?XHnU3jQ?[Tnc3kB?^4nich<?kXob3o^?o`o0=0207@10001<10`5C0T<60`YS2[<<l`
fc3W<00a7S4004haLc5h<GhaRC6?<IXaX36[<K4a_371<NXal37f<O`a9S9B<W0bV39/<g/cRS>/<lhc
fc<4=0Xd43@A=[df000000000000000000000000000000000@410@410@410A/h9@0000`000040000
:00000`000030000DP0004`100030000k_ooo`000000000000000;`2000100000000<U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^0000dC_d>`@l8c`c?4hlJSb5?9dlYCbc?<0lcScD?>0l0000028m
@CeA?F`mR3fS?K/m`cgW?OHm53hN?R/n<Ci=?U`nI3iZ?WLnPCj>?Y<nWCj^?[<n_Ck>?]<ngCk^?_@n
0cl9?aPo7Sl]?c<o@Sm9?dhoECmJ?f4oIcm^?g@oNcn3?h`oTSnR?jhoh3oe?`000>0200010003<14`
730Z<000A31<<5@`HC1W<7T`QC2D<:D`]c3B<=P`lS08<@ha534c<D8aCc5N<F@aICkl?PPo33l@?a@o
63lL?cdoCcl0000000000000000000000000000000010@410@410@41000U0000300000<0001D0000
E00008P000210000T00009`0000100002kP;@R272d9U0000H0000040001<00000000000000000000
00000000001@0000LP3o<PL0000U0000300000@0000X0000300000<0001B0000C04000<0003^oooo
0000000000000000T04000400000000bE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00029=Hhe
UcFM=J8eYcFb=K`eaCG;=M0eeCGP=ALf8cH00000@CI>=U<fGcI/=W4fOCJ:=XlfXSJW=[Xf_cKB=]Lf
jSK_=_Tf2SL?=aTg9SL[=cDgASM;=eDgISM/=gXgR3NZ=l@gfcO`=`DhGCQW>7@hNSR8>9Dha3Sf>?`h
4cU1>DliGCUR>G0iMSV4>I0iVSVW>Jdi^cW7>L`ifCWS>O0i0004>Q0j5CXU>S`jC3YL>W<jRC[[>_4j
ocX@>bXk?C];>fLkW3^U>k`kbS_Z>`hl=3a3?4PlECaR?6PlMSbF?000000000000000000000000000
000000410@410@410@6m?BD0000<00000`0005@0001D0000@00005L0001;0000L@000040000;^0]2
88L;@Rh0001000000@0004`000000000000000000000000000000500001T0>Ha2@0002D0000<0000
100002P0000<00000`000580001<0@000`000>koool0000000000000002l0P000@000000039D06T0
K@1U07<0801>06D0M`0P0580K`1]0640KP0009`jcc^d?>Lmc3ko?`2`0@0l0000i30^<E4aEC5I<@00
001a<HPa1S8P<T8bM3;]<_<bcC?C<d`eDSEY>VljTcfI?HPoXSoW?`300@3`00000C1L<74`OS2<<=D`
h309<B4a<S5E<F8a@S9?<]dcjC?]<o4cmC?i<odc0C@5=0Td3C@A=1Dd6C@M=24d9C@Y=2dd<C@B=CLe
b3G?=O4en3D0050fTcJJ=Zdf/cK2=/TfgCHR=bTgO3N2=j8g1CPZ>80hQSSZ>00i3CTK>B4i;STk>E0i
J3VF>IhiaSTh>Udj000000000000000000000000000000000@410@410@410@hm9@0000`000030000
E00005@0001<0000E`0005@0001b00000@0000^h2d8PQ`]2=`00040000010000C000000000000000
0000000000000000D00007<0fc8700009@0000`000040000:00000`000030000DP0004`100030000
k_ooo`000000000000000901000100000000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
MCQk>8XhgCP3>@Xi<3Tl>D8iDCUH>F`iZSVa>N`i000001`j@SY>>U@jHcZF>Ydj`c[?>]Dji3[[>_lj
?C]4>jdkdS^2?8Pl/ScG?0Pm3cd_?FLmZSfa?LhmeCgb?OTm5ShM?S0n=Si5?T`nK3j0?XLnYcjk?/8n
eCkK?^XnlCh5?d<oBSn5?h`oWcnU?k@o0>0103010007<2d`=317<000G31S<8<`Uc2N<;h`dS3I<>``
lS01<@Pa735J<F4aW36S<LDac37O<NDam34W<Rhb@C97<UHbGC9m<Y4bV38000000000000000000000
0000000000010@410@410@41P3@U0000300000<0001D0000E00000@0000N00003`0003P000010000
2kP;@R272d8100005@000040001<0000000000000000000000000000001@0000I01O>`T0000U0000
300000@0000X0000300000<0001B0000C04000<0003^oooo0000000000000000_08000400000000b
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0002d0000931D<8<`[S3`<?L`5c5?<I8aVC6k<L8a
mC400000@c9o<ZXb/C;A<PTcC3=C<gDcO3>I<j0chC=A=94dV3CC==Xd3cDF=CleFCE]=G@eYSFm=L<e
jCGb=B@f>cI1=UTfKCId=ZHf_CK3=QlgN3M1>60hn3S0>LLi9cYG>UhjP3Z7>ZTj/3[?>]HjmSZ4>hXk
Wc]K?>hlmS`=?A@m002E?I/mZSfa?N4mj3g_?P000P1`0@00d30:<A4a<S4i<EPaGc5n<HDadc73</lb
dc;G<]/bgc;S<RXcJ3=d<`00000000000000000000000000000000410@410@410@5j=2D0000<0000
0`0005@0001D0000400001h0000F0000>@000040000;^0]288L;@PX0000E00000@0004`000000000
000000000000000000000500001d00dh1@000280000<0000ooooobP0000<00000@0002P0000<0000
0`0002P0000<00000P0002P0000<0000100004/0000@0000000000D0000>000050000000000@0000
5000
\>"], "Graphics",
  Editable->False,
  ImageSize->{251, 153},
  ImageMargins->{{292, 0}, {0, 5}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[BoxData[
    \(\(\(\ \)\(\[DoubleStruckV]\[IndentingNewLine]
    d\[DoubleStruckR] := 
      dru[red@j]\ \[DoubleStruckE]d[red@j]\[IndentingNewLine]
    d\[DoubleStruckT] := 
      dtu[red@k]\ \[DoubleStruckE]d[red@k]\[IndentingNewLine]
    {d\[DoubleStruckR], d\[DoubleStruckS], d\[DoubleStruckT]}\)\)\)], "Input"],

Cell[TextData[{
  "We calculate for the volume element defined by {d\[DoubleStruckR], d\
\[DoubleStruckS], d\[DoubleStruckT]} the surface integral ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Integral]", 
          RowBox[{
            FormBox["\[DoubleStruckV]",
              "InputForm"], \(\[DifferentialD]A\)}]}], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Integral]", 
          RowBox[{
            TagBox[
              StyleBox[
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["v", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ i]],
                        Editable->False]],
                    Subsuperscript[ v, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ i]]],
                    Editable->False],
                  "TraditionalForm"],
                FontFamily->"Courier",
                FontSize->16],
              (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
            RowBox[{"\[DifferentialD]", 
              SubsuperscriptBox["A", 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["h",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ h]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["h",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ h], ShowContents -> False]],
                  Editable->False]]}]}]}], TraditionalForm]]],
  "\n\nThe surface delimited by the vector {d\[DoubleStruckS], d\
\[DoubleStruckT]} is associated to the vector"
}], "Text"],

Cell[BoxData[{
    \(d\[DoubleStruckCapitalA] = \(d\[DoubleStruckS]\[Cross]
            d\[DoubleStruckT] // \(LinearBreakout[
              Cross]\)[\[DoubleStruckE]d[_], \[DoubleStruckE]u[_]]\) // 
        CrossProductExpansion[\[DoubleStruckE], e, 
          h]\), "\[IndentingNewLine]", 
    \(d\[ScriptCapitalA]d[l_] := 
      d\[DoubleStruckCapitalA] . \[DoubleStruckE]d[l] // 
        EvaluateDotProducts[\[DoubleStruckE], g]\)}], "Input"],

Cell["\<\
so, for the two opposite faces defined by {d\[DoubleStruckS], d\
\[DoubleStruckT]} (Note the subtility between Tensor... and its ShortCut )\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(vu[red@i] \((\(-dAd[red@i]\))\)\), "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"vu", "[", 
                RowBox[{
                  StyleBox[
                    RowBox[{"re", 
                      StyleBox["d",
                        FontSize->12]}]], "@", "i"}], "]"}], 
              "+", \(CovariantD[vu[red@i], red@h] dru[red@h]\)}], 
            ")"}], \(dAd[red@i]\)}]}], "//", 
      "Simplify"}], "\[IndentingNewLine]", \(% /. {dA -> 
          d\[ScriptCapitalA]}\), "\[IndentingNewLine]", \(%% /. 
        dAd[red@i] -> d\[ScriptCapitalA]d[red@i] // 
      LeviCivitaSimplify[e]\), "\[IndentingNewLine]", \(drst = 
      Coefficient[%, dru[red@h] dsu[red@j] dtu[red@k]]\)}], "Input"],

Cell[TextData[{
  "The contribution of the other two pairs of faces of the volume element are \
obtained by cyclic permutation of the free indices {",
  StyleBox["i j k",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "} :"
}], "Text"],

Cell[BoxData[
    \(drst + \((drst /. {h -> j, j \[Rule] k, 
            k \[Rule] h})\) + \((\(drst /. {h -> j, j \[Rule] k, 
              k \[Rule] h}\) /. {h -> j, j \[Rule] k, 
            k \[Rule] h})\)\)], "Input"],

Cell[TextData[{
  "which can then be compared to result  ( ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["dr", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ i]],
                      Editable->False]],
                  Subsuperscript[ dr, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ i]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["ds", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ j]],
                      Editable->False]],
                  Subsuperscript[ ds, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ j]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["dt", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ k], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["k",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ k]],
                      Editable->False]],
                  Subsuperscript[ dt, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ k], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ k]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["e", 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ i], 
                        red[ j], 
                        red[ k]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          red[ k], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ e, 
                    SequenceForm[ 
                      red[ i], 
                      red[ j], 
                      red[ k]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      StyleForm[ 
                        red[ k], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["v", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["h",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["h",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ";", 
                              red[ h]],
                            Editable->False],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ h], ShowContents -> False], 
                        Cov[ 
                          red[ h]]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["h",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              InterpretationBox[
                                RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["h",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ ";", 
                                  red[ h]],
                                Editable->False],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ h], 
                        StyleForm[ 
                          Cov[ 
                            red[ h]], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ v, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ h], ShowContents -> False], 
                      Cov[ 
                        red[ h]]], 
                    SequenceForm[ 
                      red[ h], 
                      StyleForm[ 
                        Cov[ 
                          red[ h]], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " ) :"
}], "Text"],

Cell[BoxData[
    \(\((\(\(%  dru[red@h] dsu[red@j] dtu[red@k] // 
              SumExpansion[red@i, red@j, red@k, red@h]\) // 
            LeviCivitaSimplify[e]\) // 
          Simplify)\) \[Equal] \((\(\(\((result = 
                  dru[red@i] dsu[red@j] dtu[red@k] eddd[red@i, red@j, red@k] 
                    CovariantD[vu[red@h], red@h])\) // 
              SumExpansion[red@i, red@j, red@k, red@h]\) // 
            LeviCivitaSimplify[e]\) // Simplify)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["This constitute the three dimensional form of the divergence \
theorem of Gauss",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " :"
}], "Outline1"],

Cell[BoxData[{\(Off[Integrate::"\<ilim\>"];\), "\[IndentingNewLine]", 
    RowBox[{"ResultFrame", "[", 
      RowBox[{
        RowBox[{"\[Integral]", 
          RowBox[{
            TagBox[
              StyleBox[
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["v", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ i]],
                        Editable->False]],
                    Subsuperscript[ v, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ i]]],
                    Editable->False],
                  "TraditionalForm"],
                FontFamily->"Courier",
                FontSize->16],
              (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
            RowBox[{"\[DifferentialD]", 
              SubsuperscriptBox["A", 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["h",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ h]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["h",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ h], ShowContents -> False]],
                  Editable->False]]}]}]}], " ", "==", "result", "==", 
        "\"\<\!\(\[Integral]\_V\)TDiv \[DoubleStruckV]  \[DifferentialD]V == \
\!\(\[Integral]\_S\) \[DoubleStruckV].\[DifferentialD]A\>\""}], 
      "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", \(On[
      Integrate::"\<ilim\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stokes theorem in two dimensions :", "Outline1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[GraphicsData["PICT", "\<\
3T3ooooo08@0RP0A0_l<0?ooooooo`00ool0002:0000Q0000000002Q0<03NBE@
Kg=dDf=bJG1d84QQHf/PHWTPCFU[IB12LVmbLb0a<Rlg;cT`3Bm4JG=QHVaUCVEh
M5=UM597@T=_K6mb3@Uk3@UeLfEbI6USM21RIFMYKPd9;g=UM79WHV=_K6mb80d9
2G/=2@U`Kg0=2@U`Kg0=2@U`Kg0=2@UeLfEbI6USM21RIFMYKPd92BmcIGAbIf9S
Kfa_LR1cNG=dIFeTJF=d82mcIGAbIf9SKfa_LR1WIG@PI6EV3@T9IFiT3@T9OB1T
IFH=2FE^I0em869YKV@PI6EV3BmRHf5bLV5i87MXIG9U87/=2G1_L0d9HV=QLW9Q
NB0b87/=2@T_I64P=21`Lb1TJGHPI6EV3@T9I6HPLfEdIVm^M21WLf5fIB1SLb1g
J@d92C4PJFiTIGPP<21^IG]UN6=X86AQ865TI21UN6=XOFUV86MbIG=dKg9U87=U
M6=XHG9gJFAdJ0d92F=c830P<21cKF<PI64P<21cKF<PI64PI64PLfeS830PI64P
LfeS86<=2@UWLV5i3@T9Nb1WK7d=2@Uk<B1cIGAWLV5iOFUVIFacI@d92FAQ838^
86AYMR1TMG0PKFmfIGA_87=XKgL=2GeRJFiT871eM0em86UV3BD=9B1ELfET87A_
87=^HG0PM6lPI6EfJF=U871YN6E/Lb`P<BldM6PPKfHPM6QU871YN6E/86U^;Pd_
LgA`87/P82DPN21i821`K20PN21i820P820P820P820P820P82DPDfiQL21DKb1@
JGQUK2`PL6UhIF`P82QQMGA_87=dLVm[IB1QI6YeLg@Y3@UdLV5^LfI_LVd=2C0^
<SDPLgER879_MFiT830^<SDPHFAT86EhHfP=2C0^<SDPLgER879_MFiT830^<SDP
HFAT86EhHfP=2FUdLV5^LfI_LVd=OB1RJFiT86AUIPd=;g=^HG1]KgIUM6lPNb0U
87PPNB0PKB0P;B0P820P820P820P820U86e_MVEdKb`PHGEdKb1cM79_JfDPHFAZ
MG=d3@UcM70P86e_MVEdK`em869YKV@PI6EV3@d_LfiQL6aYKVEdKb1k82DPN21i
821/820]820P820P820P820P82DPK6U^IGA_;21QMGA_87=dLVm[IB1QI6YeLg@=
2G=dL21/JFiUM6l=OB1RJFiT86AUIPd00:00S00N00402_ooool0Q02:00L00000
00P02P0S00008`000:40]P0400400@2P0:00X@2T0041000100X0000000000007
00400@0800P08P1^00d0000SK`008`0002>QYP0S00008o1J02<0002P0:<0X02n
00402_ooool0Q02:00L0000002<0002Q0;H0100100408P1]00`0002Q0;H01001
00401`010040L00J01<0301]07/0K@0<06d0N`0C01`0K@0<0:00_`2P0:40X02<
00comOnJ00402_nIoo@07P1o00L00000028000000000X02P0:40Y0010P000@0:
0000000000008P080700000Sj`L08`0002<7n@0S00008oWi02<0000S5@L08`00
00402_nIoo@07P1o08@02P00000000000:00X`2P0;h0L@0N0000FP0>06l01`1_
00h0FP070640001J00L0K`0R000000000:00_`2P0:408`000:40]P0400400@2P
0:00X@2T0041000100X000000000000700400@0R00P0L00002?[1`0S00008`Oi
02<0000SnOT08`0002<E1`0S0000X02S0:00_P0100[oVOod01h0O`070000000S
0000X@2f00@00@0102801`1_0000X@2f00@00@0100L00@0107007P0005X03P1_
00L0K`0>05X01`1Q0000FP0706l0X02o0:00X@070000000S0000X@2f00@00`03
00L00`0302801`00HOl0X02=0:00S00<0000D`0100[ok?od0740O`070000000R
000000000:00X02Q0:@00@8000402P000000000002800@0C00008`<F02<0000S
n_P08`0002?h1@0S00008`_]02<0000100[ok?od0740O`2400X000000000002P
0:<0X02n07407P0000L05P0E00004P0F01D03P0?01<01`0001808P000000002P
0;l0X02Q02<0002Q0;H010010040X02P0:40Y0010@000@0:0000000000001`01
00408P0101<0000S0aH08`0002?jn00S00008oP502<0000S2nd08`000:00X`2P
0;h00@0:oncom01a07l01`0000008`000:40]P0400400@0R00004P000:40]P04
00400@0700400@1`01h0000701H05@0001805P0E00h03`0C00L0000B0:00_`2P
0:401`0000008`000:40]P0400<00`0700<00`0R05X000jb0:00S@2P08`03?oE
ojl00@0:oi_ob@0P05@01`0000008P000000002P0:00X@2T0042000100X00000
0000000R00D06`0002?h100S00008`?l02<0000SoO`08`0002<8100S00000@0:
oi_ob@0P05@0Q00:000000000000X02S0:00_P1a01h0000B00P06P0401X0200B
00@05@000180100J028000000000X02o0:00X@0S0000X@2f00@00@010:00X02Q
0:@00@4000402P000000000000L00@0102801@0K00008oP402<0000S0o`08`00
02?mo00S00008`P402<0002P0:<0X02n00402_nKolT0801D00L0000002<0002Q
0;H0100100408P0401X0002Q0;H0100100401`010040L00N00004P0801X0100J
00P04P0401D0000B00@06P2P0;l0X02Q00L0000002<0002Q0;H0100100401`01
00408P04000E002P08d0X02<00con`0/00402_o7ol@0C01?00L0000002800000
0000X02P0:40Y0010P000@0:0000000000008P010040000S20<08`0002?l0@0S
00008ol502<0000SoOL08`0000402_o7ol@0C01?08@02P00000000000:00X`2P
0;h0L@0N0000000900P0000000<0200400@02@030000000R000000000:00_`2P
0:408`000:40]P0400400@2P0:00X@2T0041000100X000000000000700400@0R
00400@0002<80`0S00008o`102<0000So`D08`0002?mm`0S0000X02S0:00_P01
00[oaoo404`0C`070000000S0000X@2f00@00@01028000000000X@2f00@00@01
00L00@0107007P0000002@080000000300P0100400T00`000000X02o0:00X@07
0000000S0000X@2f00@00@0100L00@01028010042`/0X02=0:00S00<02Koo@01
00[oa?oZ04T0M@070000000R000000000:00X02Q0:@00@8000402P0000000000
02805P0300008okg02<0000S0`@08`0002<5oP0S00008oX702<0000100[oa?oZ
04T0M@2400X000000000002P0:<0X02n07407P0<00005@0801D00P0<00004003
00h0200E00808P000000002P0;l0X02Q02<0002Q0;H010010040X02P0:40Y001
0@000@0:0000000000001`0100408P0F00<0000So_L08`0002<3100S00008`Gn
02<0000SnPL08`000:00X`2P0;h00@0:olCojP1907D01`0000008`000:40]P04
00400@0R01D00P000:40]P0400400@0700400@1`01h0300001D0200E00803000
01000`0>00P05@020:00_`2P0:401`0000008`000:40]P0400400@0700400@0R
01000`?`0:00S@2Q09H03040000200000000000<01D0100100X0000001D04@07
0000000R000000000:00V02Q09X02?o`@H0000R002`04POJ3eAYKFEc84iUMb1B
KfeQKP031mX0108000d04P0^00@00?l002X@0F@000@3000Y2@5d002P09T0X02G
02<0002Q09H03040000200000000000<olWobP0100X0000001D04`0S0000X02H
0:40VP08oo1gP000@800108002P040000F@010<002T90G800:00V@2P09L08`00
0:40UP0<0@0000800000000000`0=`0200402P0000005@0=02<0002P09P0X@2J
00Sol7F00006P0040P00:00@0001@@2P09T0X02G02<0002Q09H0304000020000
0000000<oh@0000100X0000001D0300S0000X02H0:40VP08oo1eP000PP00:@01
@P00X02I0:00U`0S0000X@2F00`100000P0000000000301Z06/00@0:0000000Z
00/08`000:00V02Q09X02?o`5@0001N002T00D<00:00V@2P09L08`000:00S@3o\>"], "Graphics",
  Editable->False,
  ImageSize->{139, 133},
  ImageMargins->{{288, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001cD0@0005P0000M00007@000=8000390000
00000000001B6P00I1P00215CDH00040e1`007L000050000000000000000000000@00003000>0@00
b`0004H0000P200050P004M4BD<1002000<0097T8l`00000o0L000402@000oh3000601`0000000D0
000;0_ooool5000030:b0<00100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@040000104700@000040@d0300002D3100Q0840T@2103809P0Q0840
100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000@0000]0@@010000?010@070000
o0800000000000@0000]0@403P0002@31@2@0840N`280880P@1k07X0T02100@0000]0@<010000?01
00080000nP8000400@000002100002d1000>00009@<50900P@1k08P0PP2107/0NP2@0840100002d1
0`040000l04000P0003j0P000`03000000840000;@4000P0000U0`808@2108<0P@040000;@4300@0
003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@0b02H0=@0l02l0=00W03T0<P0V00@0
000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<503809P0e03`0;`0d02L0
>@0b02H0100002d10`040000l04000P0003j0P000`03000000840000;@4000P0000U0`808@2102l0
<`040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@1U07/0G@1o0600
N`1M07L0I@1k00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<506D0
N`1M07l0H01k05d0M`1U07/0200002D30P1<07/0H01k00@0000]0@<010000?0100080000nP850000
003oool2100002d1000>000090<50500B`1H04h0E01?05<0E01@04/0100002d10`040000l04000P0
003j0P000@01000000840000;@4000h0000U0`D0D01;05P0CP1D04l0D`1D0500B`0800009@<205@0
C`1O05X0100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000h0000T0`D0;01S02X0
FP0]05h0<P1L02`0H`040000;@4300@0003`0@0020000?X20001004000000P@0000]0@003P0002D3
1@0/06<0:P1J02d0GP0b05`0;01S00P0000U0`80;@1N0300CP0500002@800002100002h100040000
;@4500@0003`0@8070000?/2k_l00000002@0@400000000bE6U]IG<PCVEg859_KF5^000000000000
0000000000040000;@4200L0000Q1@40I?m=01D01@0000T200000P@0000^0@00100002d11@040000
l04201`0003k0^ko00000000_08100000000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000
100002d10P0700008@D107CoC@0N00D000090P0000840000;P4000@0000]0@D010000?010P0L0000
n`;^o`00000009010@000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0000]0@80
1`0002450@1Toh80C@0500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000
002l0P400000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40
L_n205H01@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000T0410000
0000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d10P0700008@D1047oP@0E00D0
00090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`00000009010@000000039DJFeU
Lb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`0002450@12oh40TP0500002@800002
100002h100040000;@4500@0003`0@8070000?/2k_l00000002@0@400000000bE6U]IG<PCVEg859_
KF5^0000000000000000000000040000;@4200L0000Q1@40@olE02L0100002L1ool40000l04000@0
003`0@4010000?010P040000l04300@0003`0@@010000?011@030000000A0000300000P0000;0000
40000001003/00002@00010000000@00k00000X0000@0000ooooooooool9000040000<00002b0000
4P0000`0000100008@0000P0000D0000300000L0000D0000300000d0000V00007000004000000000
0@000040000000029@0000`0000100009@0000`000000020E`0002`0000]0000=0000<<0002/0000
10000240P@2A0840<P0V0240P@0V0000700000800005000000000000003oool29@0000`000020000
9@0000`000040020EP000300002U0000X`000<40002f00001@000900P@1k08P0PP2107/0NP2@0840
9@0000`000010000:00000`0000200009P0001`000020000000000400001000000000RD0000<0000
0P0005L0000`0000Y@000:<000310000]P0000D0002@0840N`280880P@1k07X0T02102D0000<0000
0@0002P0000<00000P0002H0000L00000P000000000300000`000000008U000030000080001G0000
900002/0002Z0000/P000:h0000200008@2108<0P@0U000030000040000X000030000080000V0000
700000800005000000000000003oool29@0000`000020000EP000300000e0000=00004P0001A0000
1@0003809P0e03`0;`0d02L0>@0b02H09@0000`000010000:00000`0000200009P0001`000020000
000000400001000000000RD0000<00000P0005L0000`0000=@0003@000180000D@0000D0000b02H0
=@0l02l0=00W03T0<P0V02D0000<00000@0002P0000<00000P0002H0000L00000P00000000030000
0`000000008U000030000080001G0000900002/000130000@P000:h0000200008@2102l0<`0U0000
30000040000X000030000080000V0000700000800005000000000000003oool29@0000`000020000
EP000300001m0000W`0008P0002Z00001@0006D0N`1M07l0H01k05d0M`1U07/09@0000`000010000
:00000`0000200009P0001`000020000000000400001000000000RD0000<00000P0005L0000`0000
O@0009l000280000ZP0000D0001U07/0G@1o0600N`1M07L0I@1k05L0000T0000I`000:@000210000
Y0000080001<07/0H01k02D0000<00000@0002P0000<00000P0002H0000L00000P0000D000000000
00000?ooo`8U000030000080001F0000<00006`0001U0000M`00074000050000D01;05P0CP1D04l0
D`1D0500B`0U000030000040000X000030000080000V000070000080000000000@00004000000002
9@0000`000020000E`000300001/0000I@0007L0001a00001@000500B`1H04h0E01?05<0E01@04/0
E`0002@0001a0000JP000800001i00000P0005@0C`1O05X09@0000`000010000:00000`000020000
9P0001`0000200001@00000000000000oooo0RD0000<00000P0005H0000`0000>@0007T000140000
Q@0000D0000/06<0:P1J02d0GP0b05`0;01S02D0000<00000@0002P0000<00000P0002H0000L0000
0P000000000100000@000000008U000030000080001G0000<00003T0001i0000A00008D000050000
;01S02X0FP0]05h0<P1L02`0H`1G0000900003d0001Y0000@@0007h000020000;@1N0300CP0H0000
30000000009B0000C04000<0003^oooo0000000000000000T04000400000000bE01Y06d0I@1c0200
CP1U07L0801B06l0K@1Q06h0002O?Zhn_3k>?]Xnh3kY?QTo8ClX?c0o>3lo?dLoCcl00000ISm]?gDo
OCn6?hhoUcnO?jPo/3ni?l4oaco@?n4ojSl0003@003T0P00830Z<3/`@31:<5L`G31V<7L`O326<9L`
WC2d<<L`c33O<>@`mc3l<0la5S4U<C<a@S5@<G/aP365<HdaU36L<J@aZc6c<K/a`S7:<M8afC7Q<NTa
003j<@<b2c8D<Q`b9C8_<SHbAS9?<UPbGc9a<WLbPC:7<[0b^S;;<]0bfS;W<^`bmS87<``c5S<W<bdc
A3=G<`00000000000000000000000000000000410@410@410@4Q=2D0000<00000`0005@0001D0000
7@0006L0000X0000P@0000400000X0a292h<@QD0001=00000@0004`0000000000000000000000000
00000500001T00lf2@000580001<0@00100000000000000000000000001N0@00000000000B00018g
6SLR=bTg<CLi=d8gBSMC=e/gI3M/=gDgOcN6=iHgWcNU=jhg_cO8=mLggcOW=nlg8SPa>3lhCSQL>000
0021>9<hVCRS>:Th/SRj><8hbSSa>?Th03T8>A0i5cTO>BLi;STf>ChiACU=>EDiGSUV>FliMcV0>HPi
TCVK>J8i/SVk>L@ibcWM>N<ikCWc>O`i0SX9>QHj73XS>S0j>CXo>TLjLSZ1>XljWSZ/>[hjbS[@>]Tj
2C/A>aPk83/002lk=c/o>dHkCS]F>edkIC]]>gHkOS^7>hlkV3^P>jTk/c^j>lXkdc_I>n8klc_l>c8l
@Ca??5hlK3an?8Xl000000000000000000000000000000000@410@410@410Chm9@0000`000040000
:00000`000030000DP0004`100030000k_ooo`000000000000000;`2000100000000<U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^0000RcnB?iXoXSnY?k4o^co;?mLohcob?o`o0>000;`2000001P`
930c<3/`A31<<5D`GC1V<6h`Mc1o<8P`Sc2Q<:L`/C2g<>0`jS3k<00a2S4G<A`a9S4g<C`aAS5G<Eda
M367<H`aWc6T<KLa_37?<MLaiC4@<QDb6S8R<RTb<C8i<T0bB39@<ULbGc9W<VhbMS9n<XLbSc:H<Z0b
ZC:a<P00`S;8<]4bhS;[<R0c:S<k<d0cBS=G<e`cIS=g<g`cQS>G<idc]3?7<l`cgc?T<oLco3<?=1Hd
9C@c=48dD3@0000000000000000000000000000000010@410@410@41nS@U0000300000<0001D0000
E00002T0001W0000;`000880000100000:0<@R@^348N0000C@000040001<00000000000000000000
00000000001@0000M03Y=PD0000U0000300000@0000X0000300000<0001B0000C04000<0003^oooo
0000000000000000T04000400000000bE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00011>Dli
GSU/>GhiRSV@>ITibCWA>MPih3WX>NlimcT000003SXF>Qdj9CX]>SHj?SY7>TljF3YP>VTjLCYg>X0j
TCZJ>]Hjk3X0>`Dk6c/_>c@kBS]N>f<kNC^=>i8kW3^Y>jhk^3_5>l/khc_b>oPk1c`>?1dl:c`j?4Pl
Lcak?88lRSbB?9TlXCbY?;0l^3c0?<LlcccG?>0lj3ca??Tl000:?A<m6cdR?C@m>Se4?DXmDceL?Fhm
Mcf9?HlmYcf]?LDmeCg^?OTm03hR?Rln?3i6?U@nGCiZ?W@nPSjf?P00000000000000000000000000
000000410@410@410@6[?bD0000<00000`0005@0001D0000J0000:h0001c0000b00000400000X0a2
92h<@Td0002200000@0004`000000000000000000000000000000500001T08@a2@0002D0000<0000
100002P0000<00000`000580001<0@000`000>koool0000000000000002l0P000@000000039D06T0
K@1U07<0801>06D0M`0P0580K`1]0640KP000?lc1c@@=1Pd8C@Y=38d>SA3=58dEcAP=6ldM3Aj=000
002J=:ld]3C4=<dddcCQ=>`dlc@3=@Te6CDV=C<e?CE;=E@eHCE[=GTeX3FZ=KLe_3G6=M<efCGa=@0f
1SHE=Q`f:cHi=TPfESJ1=XTfT3JH=Z0fYcJ_=[Lf_SK6=/hfeCKM=^DfkSKf=_lf1cL@=aPg8CLY=blg
>3M9=`040P0004X0000@0P00CP0M0?HI003F0`000000000000000000000004eQM6QUKF5dJF=Q<P00
0000000000000000000000000000000000000000000000000@410@410@410@009@0000`000030000
E00005@0001d0000[P0007`0003900000@00002P348T;Pa2EP00088000010000C000000000000000
0000000000000000D0000780000700009@0000`000040000:00000`000030000DP0004`100030000
k_ooo`000000000000000901000100000000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000010@410@410@412`0U0000300000<0001D0000E00001d0002/0000:P000<H000010000
0:0<@R@^348E0000P@000040001<0000000000000000000000000000001@0000@@0400/0000U0000
300000@0000X0000300000<0001B0000C04000<0003^oooo0000000000000000T04000400000000b
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0000600800P0200X0100500L02@0400D01`0900D0
2@0000001@0:00X02P0300<00`0300<00`0300<0200?00P0200800l03`0?00D01@0500D01@0500D0
1@0;01H02`0;00/0600H01L01@0500D01@0300D00P0400<00`0200<00`0500P02`0400H01@0500L0
1@0200D01P0500X0000:00X01`0700P02`0@01L0400G00l0600?01P02@0>00T03P0800P0100300<0
100800`0400400H010060000000000000000000000000000000000410@410@410@4002D0000<0000
0`0005@0001D0000a0000:`0003B0000aP0000400000X0a292h<@Y80002100000@0004`000000000
000000000000000000000500001200002`0002D0000<0000100002P0000<00000`000580001<0@00
0`000>koool0000000000000002@0@000@000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000@410@410@410@009@0000`000030000E00005@0000e00007@0004@0000g0000
0@00002P348T;Pa29`0001D000010000C0000000000000000000000000000000D00004<0000<0000
8P0000`0003ooooo:00000`000020000:00000`000030000:00000`000010000:00000`000040000
B`000100000000001@0000h0000D000000000100000D0000
\>"], "Graphics",
  Editable->False,
  ImageSize->{181, 172},
  ImageMargins->{{324, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
The triangle represented in the figure has an area represented by the vector,\
\
\>", "Text"],

Cell[BoxData[
    \(d\[DoubleStruckCapitalA] = \(\(1\/2\) 
            d\[DoubleStruckR]\[Cross]d\[DoubleStruckT] // \(LinearBreakout[
              Cross]\)[\[DoubleStruckE]d[_], \[DoubleStruckE]u[_]]\) // 
        CrossProductExpansion[\[DoubleStruckE], e, h]\)], "Input"],

Cell[TextData[{
  "We calculate now the integral along the counterclockwise contour ABCA. On \
each three sides (",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["dr", 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False]],
              Subsuperscript[ dr, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i]]],
              Editable->False],
            "TraditionalForm"], " "}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["dt", 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False]],
              Subsuperscript[ dt, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i]]],
              Editable->False],
            "TraditionalForm"], "-", " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["dr", 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False]],
              Subsuperscript[ dr, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["dt", 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False]],
              Subsuperscript[ dt, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  " ) we have an average value :."
}], "Text"],

Cell[BoxData[{
    \(\((ud[red@i] + \(1\/2\) CovariantD[ud[red@i], red@j] dru[red@j])\) 
        dru[red@i] + \((ud[red@i] + \(1\/2\) 
              CovariantD[ud[red@i], 
                red@j] \((dru[red@j] + dtu[red@j])\))\) \((dtu[red@i] - 
            dru[red@i])\) + \((ud[red@i] + \(1\/2\) 
              CovariantD[ud[red@i], red@j] dtu[red@j])\) \((\(-dtu[
              red@i]\))\)\), "\[IndentingNewLine]", 
    \(% // Simplify\)}], "Input"],

Cell[BoxData[
    \(\(\(\(\(1\/2\) \[Epsilon]uuuddd[red@j, red@i, red@k, red@p, red@q, 
                red@k]\ dru[red@p] dtu[red@q] // 
            ContractKroneckers[\[Epsilon]]\) // 
          FullKroneckerExpand[\[Epsilon]]\) // Expand\) // 
      KroneckerAbsorb[\[Epsilon]]\)], "Input"],

Cell[TextData[{
  "Including this last result into the",
  StyleBox[" integral along the perimeter of ABCA",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " gives"
}], "Text"],

Cell[BoxData[
    \(\(1\/2\) \[Epsilon]uuuddd[red@j, red@i, red@k, red@p, red@q, 
          red@k]\ dru[red@p] dtu[red@q] 
        CovariantD[ud[red@i], red@j] == \(1\/2\) \[Epsilon]uuu[red@j, red@i, 
          red@k] \[Epsilon]ddd[red@p, red@q, red@k]\ dru[red@p] dtu[red@q] 
        CovariantD[ud[red@i], red@j]\)], "Input"],

Cell[TextData[{
  "which is equal to",
  StyleBox[" TCurl[\[DoubleStruckU]].d\[DoubleStruckCapitalA]",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["TCurl",
              FontColor->RGBColor[0, 0, 1]], "[", \(\[DoubleStruckE], g, 
            red /@ {j, i, k}, e\), "]"}], 
          StyleBox["[",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["\[DoubleStruckU]",
            FontColor->RGBColor[0, 0, 1]], 
          StyleBox["]",
            FontColor->RGBColor[0, 0, 1]]}], 
        StyleBox[".",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{"(", 
          RowBox[{
            StyleBox["d\[DoubleStruckCapitalA]",
              FontColor->RGBColor[0, 0, 1]], 
            "//", \(IndexChange[{{j, p}, {k, q}}]\)}], ")"}]}], 
      "//", \(EvaluateDotProducts[\[DoubleStruckE], 
        g]\)}], "\[IndentingNewLine]", \(% /. \(LeviCivitaRule[
          e, \[Epsilon]]\)[g, red]\)}], "Input"],

Cell["\<\
Covering any area A with contour C with triangles of this kind leads to the \
cancellation of all the terms from adjacent sides of the infinitesimal \
triangles so that only the integration along C remains. \
\>", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\*"\"\<\!\(\[Integral]\_\(\(\\\ \
\)\(C\)\)\) \[DoubleStruckU] \[DifferentialD]s == \!\(\[Integral]\_\(\(\\\ \)\
\(A\)\)\) (TCurl \[DoubleStruckU]).\[DifferentialD]A\>\""\[IndentingNewLine]]\
\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vector field versus scalar and solenoidal fields", "Subsubsection"],

Cell[BoxData[
    \(\[Phi] =. \)], "Input"],

Cell[TextData[{
  "Given a vector field \[DoubleStruckU], find the scalar field \[Phi] of \
which it is the gradient, or a vector field \[DoubleStruckW] of which it is \
the curl;\n",
  StyleBox["\t\tIf ",
    FontSize->18],
  "TCurl",
  StyleBox[" \[DoubleStruckU] = 0\tthen \t\[DoubleStruckU] = ",
    FontSize->18],
  "TGrad",
  StyleBox[" \[Phi]\n\t\tIf  ",
    FontSize->18],
  "TDiv",
  StyleBox[" \[DoubleStruckU] = 0\tthen\t\[DoubleStruckU] = ",
    FontSize->18],
  "TCurl",
  StyleBox[" \[DoubleStruckW]",
    FontSize->18],
  "\nso, every vector field may be split (in more than one way) into a \
gradient field and a solenoidal field, and"
}], "Text"],

Cell[BoxData[
    \(ud[red@i] \[Equal] 
      CovariantD[Tensor[\[Phi], {}, {}], 
          red@i] + \((CovariantD[wu[red@k], red@j] // RaiseIndex[j, j])\) 
          eddd[red@i, red@j, red@k]\)], "Input"],

Cell[TextData[{
  "where  ",
  StyleBox["\[Phi]",
    FontWeight->"Bold"],
  "  is a scalar potential, and ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["w", 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ k]],
                    Editable->False], 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ k], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ w, 
                  SequenceForm[ 
                    red[ k]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ k], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " a vector potential"
}], "Text"],

Cell[BoxData[
    \(\(ClearTensorShortcuts[{{\[DoubleStruckE], u, v, w, x, y, dA, dr, ds, 
            dt}, 1}, {{\[Sigma]}, 2}, {{\[Epsilon], e}, 3}, {{R}, 
          4}, {{\[Epsilon]}, 6}];\)\)], "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{987, 650},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"], None, Cell[ 
      "J.-F. Gouyet", "Header"]}, {
    Cell[ "Continuum Mechanics", "Header"], None, Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{True, True},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->True,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
ShowCellLabel->False,
CellLabelAutoDelete->True,
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Christoffel symbols"->{
    Cell[4591, 136, 73, 1, 41, "Section",
      CellTags->"Christoffel symbols"]},
  "Integral theorems of Stokes and Gauss"->{
    Cell[117894, 3000, 109, 1, 41, "Section",
      CellTags->"Integral theorems of Stokes and Gauss"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Christoffel symbols", 213283, 4936},
  {"Integral theorems of Stokes and Gauss", 213411, 4939}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 45, 0, 76, "Title"],

Cell[CellGroupData[{
Cell[1846, 57, 64, 1, 49, "Subsection",
  InitializationCell->True],
Cell[1913, 60, 448, 10, 146, "Input",
  InitializationCell->True],
Cell[2364, 72, 498, 9, 166, "Input",
  InitializationCell->True],
Cell[2865, 83, 235, 4, 46, "Input",
  InitializationCell->True],
Cell[3103, 89, 93, 2, 34, "Text"],
Cell[3199, 93, 1069, 29, 159, "Input",
  InitializationCell->True],
Cell[4271, 124, 69, 1, 34, "Text",
  InitializationCell->True],
Cell[4343, 127, 211, 4, 46, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4591, 136, 73, 1, 41, "Section",
  CellTags->"Christoffel symbols"],
Cell[4667, 139, 5629, 155, 55, "Text"],
Cell[10299, 296, 153, 3, 34, "Text"],
Cell[10455, 301, 183, 3, 66, "Input"],

Cell[CellGroupData[{
Cell[10663, 308, 64, 0, 43, "Subsubsection"],
Cell[10730, 310, 26, 0, 34, "Text"],
Cell[10759, 312, 471, 9, 126, "Input"],
Cell[11233, 323, 276, 8, 54, "Text"],
Cell[11512, 333, 576, 10, 106, "Input"],
Cell[12091, 345, 270, 6, 55, "Text"],
Cell[12364, 353, 26, 0, 34, "Text"],
Cell[12393, 355, 18, 0, 34, "Text"],
Cell[12414, 357, 1041, 23, 106, "Input"],
Cell[13458, 382, 18, 0, 34, "Text"],
Cell[13479, 384, 560, 14, 86, "Input"],
Cell[14042, 400, 146, 2, 34, "Text"],
Cell[14191, 404, 310, 6, 86, "Input"],

Cell[CellGroupData[{
Cell[14526, 414, 1439, 24, 146, "Input"],
Cell[15968, 440, 286, 6, 25, "Print"]
}, Open  ]],
Cell[16269, 449, 130, 3, 34, "Text"],
Cell[16402, 454, 232, 4, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16671, 463, 71, 0, 43, "Subsubsection"],
Cell[16745, 465, 490, 8, 106, "Input"],
Cell[17238, 475, 612, 10, 126, "Input"],
Cell[17853, 487, 124, 3, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18014, 495, 82, 1, 49, "Subsection"],
Cell[18099, 498, 1208, 18, 270, "Text"],
Cell[19310, 518, 76, 1, 46, "Input"],
Cell[19389, 521, 133, 2, 46, "Input"],
Cell[19525, 525, 112, 2, 46, "Input"],
Cell[19640, 529, 37, 0, 34, "Text"],
Cell[19680, 531, 43, 1, 46, "Input"],
Cell[19726, 534, 403, 17, 35, "Text"],
Cell[20132, 553, 66, 1, 46, "Input"],
Cell[20201, 556, 245, 7, 35, "Text"],
Cell[20449, 565, 157, 3, 66, "Input"],
Cell[20609, 570, 1093, 31, 34, "Text"],
Cell[21705, 603, 134, 2, 46, "Input"],
Cell[21842, 607, 112, 2, 46, "Input"],
Cell[21957, 611, 24, 0, 34, "Text"],
Cell[21984, 613, 157, 3, 66, "Input"],
Cell[22144, 618, 235, 5, 86, "Input"],
Cell[22382, 625, 98, 2, 34, "Text"],
Cell[22483, 629, 81, 1, 46, "Input"],
Cell[22567, 632, 129, 2, 46, "Input"],
Cell[22699, 636, 192, 3, 46, "Input"],
Cell[22894, 641, 106, 2, 46, "Input"],
Cell[23003, 645, 21038, 501, 56, "Text"],
Cell[44044, 1148, 250, 4, 86, "Input"],
Cell[44297, 1154, 59, 0, 34, "Text"],
Cell[44359, 1156, 250, 4, 86, "Input"],
Cell[44612, 1162, 250, 4, 86, "Input"],
Cell[44865, 1168, 250, 4, 86, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45152, 1177, 57, 0, 49, "Subsection"],
Cell[45212, 1179, 129, 2, 46, "Input"],
Cell[45344, 1183, 86, 1, 46, "Input"],
Cell[45433, 1186, 3020, 82, 35, "Text"],
Cell[48456, 1270, 426, 7, 106, "Input"],
Cell[48885, 1279, 185, 6, 34, "Text"],
Cell[49073, 1287, 234, 4, 46, "Input"],
Cell[49310, 1293, 49, 0, 34, "Text"],
Cell[49362, 1295, 601, 11, 86, "Input"],
Cell[49966, 1308, 2813, 75, 35, "Text"],
Cell[52782, 1385, 323, 10, 35, "Text"],
Cell[53108, 1397, 126, 2, 46, "Input"],
Cell[53237, 1401, 7831, 225, 55, "Text"],
Cell[61071, 1628, 8032, 201, 39, "Text"],
Cell[69106, 1831, 9184, 247, 76, "Text"],

Cell[CellGroupData[{
Cell[78315, 2082, 96, 1, 43, "Subsubsection"],
Cell[78414, 2085, 213, 4, 54, "Text"],
Cell[78630, 2091, 289, 5, 86, "Input"],
Cell[78922, 2098, 177, 5, 82, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79136, 2108, 3473, 83, 46, "Subsubsection"],
Cell[82612, 2193, 31, 0, 34, "Text"],
Cell[82646, 2195, 259, 4, 86, "Input"],
Cell[82908, 2201, 125, 2, 35, "Text"],
Cell[83036, 2205, 345, 7, 106, "Input"],
Cell[83384, 2214, 177, 3, 86, "Input"],
Cell[83564, 2219, 295, 9, 51, "Text"],
Cell[83862, 2230, 148, 3, 46, "Input"],
Cell[84013, 2235, 190, 4, 51, "Text"],
Cell[84206, 2241, 199, 4, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84442, 2250, 140, 2, 44, "Subsubsection"],
Cell[84585, 2254, 24340, 492, 56, "Text"],
Cell[108928, 2748, 24, 0, 34, "Text"],
Cell[108955, 2750, 502, 9, 66, "Input"],
Cell[109460, 2761, 595, 10, 106, "Input"],
Cell[110058, 2773, 381, 8, 66, "Input"],
Cell[110442, 2783, 490, 11, 106, "Input"],
Cell[110935, 2796, 141, 4, 34, "Text"],
Cell[111079, 2802, 1023, 17, 206, "Input"],
Cell[112105, 2821, 190, 4, 34, "Text"],
Cell[112298, 2827, 2084, 37, 386, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[114431, 2870, 51, 0, 49, "Subsection"],
Cell[114485, 2872, 182, 5, 34, "Text"],
Cell[114670, 2879, 107, 2, 46, "Input"],

Cell[CellGroupData[{
Cell[114802, 2885, 33, 0, 43, "Subsubsection"],
Cell[114838, 2887, 69, 1, 46, "Input"],
Cell[114910, 2890, 105, 3, 34, "Text"],
Cell[115018, 2895, 117, 2, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115172, 2902, 35, 0, 43, "Subsubsection"],
Cell[115210, 2904, 104, 2, 46, "Input"],
Cell[115317, 2908, 149, 3, 34, "Text"],
Cell[115469, 2913, 245, 5, 66, "Input"],
Cell[115717, 2920, 116, 2, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115870, 2927, 31, 0, 43, "Subsubsection"],
Cell[115904, 2929, 181, 3, 46, "Input"],
Cell[116088, 2934, 99, 2, 34, "Text"],
Cell[116190, 2938, 111, 2, 46, "Input"],
Cell[116304, 2942, 102, 3, 34, "Text"],
Cell[116409, 2947, 131, 2, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116577, 2954, 34, 0, 43, "Subsubsection"],
Cell[116614, 2956, 86, 1, 46, "Input"],
Cell[116703, 2959, 262, 6, 54, "Text"],
Cell[116968, 2967, 71, 1, 46, "Input"],
Cell[117042, 2970, 133, 2, 46, "Input"],
Cell[117178, 2974, 116, 2, 46, "Input"],
Cell[117297, 2978, 63, 1, 46, "Input"],
Cell[117363, 2981, 126, 4, 34, "Text"],
Cell[117492, 2987, 341, 6, 86, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[117894, 3000, 109, 1, 41, "Section",
  CellTags->"Integral theorems of Stokes and Gauss"],

Cell[CellGroupData[{
Cell[118028, 3005, 107, 2, 36, "Outline1"],
Cell[118138, 3009, 422, 20, 35, "Text"],
Cell[118563, 3031, 89, 1, 46, "Input"],
Cell[118655, 3034, 1796, 58, 56, "Text"],

Cell[CellGroupData[{
Cell[120476, 3096, 5770, 91, 163, 5657, 87, "GraphicsData", "PICT", \
"Graphics"],
Cell[126249, 3189, 11449, 145, 209, 11336, 141, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],
Cell[137713, 3337, 352, 6, 86, "Input"],
Cell[138068, 3345, 225, 4, 66, "Input"],
Cell[138296, 3351, 143, 2, 46, "Input"],
Cell[138442, 3355, 342, 6, 86, "Input"],
Cell[138787, 3363, 310, 5, 46, "Input"],
Cell[139100, 3370, 69, 1, 46, "Input"],
Cell[139172, 3373, 195, 3, 66, "Input"],
Cell[139370, 3378, 319, 5, 86, "Input"],
Cell[139692, 3385, 434, 14, 35, "Text"],
Cell[140129, 3401, 1551, 44, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141717, 3450, 109, 2, 36, "Outline1"],

Cell[CellGroupData[{
Cell[141851, 3456, 5526, 87, 126, 5413, 83, "GraphicsData", "PICT", \
"Graphics"],
Cell[147380, 3545, 9728, 124, 166, 9615, 120, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],
Cell[157123, 3672, 320, 6, 106, "Input"],
Cell[157446, 3680, 3754, 92, 74, "Text"],
Cell[161203, 3774, 446, 8, 66, "Input"],
Cell[161652, 3784, 163, 3, 34, "Text"],
Cell[161818, 3789, 788, 18, 106, "Input"],
Cell[162609, 3809, 249, 7, 35, "Text"],
Cell[162861, 3818, 222, 4, 46, "Input"],
Cell[163086, 3824, 13648, 315, 35, "Text"],
Cell[176737, 4141, 477, 8, 106, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[177251, 4154, 208, 6, 36, "Outline1"],
Cell[177462, 4162, 3621, 84, 124, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181120, 4251, 108, 2, 36, "Outline1"],

Cell[CellGroupData[{
Cell[181253, 4257, 5100, 80, 141, 4987, 76, "GraphicsData", "PICT", \
"Graphics"],
Cell[186356, 4339, 10177, 129, 181, 10064, 125, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],
Cell[196548, 4471, 103, 3, 34, "Text"],
Cell[196654, 4476, 274, 4, 58, "Input"],
Cell[196931, 4482, 6454, 175, 34, "Text"],
Cell[203388, 4659, 452, 8, 147, "Input"],
Cell[203843, 4669, 293, 5, 79, "Input"],
Cell[204139, 4676, 207, 6, 34, "Text"],
Cell[204349, 4684, 326, 5, 92, "Input"],
Cell[204678, 4691, 138, 4, 35, "Text"],
Cell[204819, 4697, 877, 23, 66, "Input"],
Cell[205699, 4722, 231, 4, 54, "Text"],
Cell[205933, 4728, 256, 4, 105, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206226, 4737, 73, 0, 43, "Subsubsection"],
Cell[206302, 4739, 43, 1, 46, "Input"],
Cell[206348, 4742, 663, 20, 102, "Text"],
Cell[207014, 4764, 205, 4, 66, "Input"],
Cell[207222, 4770, 1965, 54, 35, "Text"],
Cell[209190, 4826, 206, 3, 46, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

