(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    235512,       4501]*)
(*NotebookOutlinePosition[    239972,       4625]*)
(*  CellTagsIndexPosition[    239773,       4617]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
6. The Fundamental Equations 
of Continuum Mechanics\
\>", "Title"],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  InitializationCell->True],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(\(\(Needs["\<TContinuumMechanics1`TContinuumMechanics`\>"]\)\(\n\)
    \)\), "\n", 
    \(\(numequ = 1;\)\), "\[IndentingNewLine]", 
    \(ResultFrame[i_] := 
      StyleForm[
        SequenceForm["\<      \>", 
          i, "\<      (6.\>", \(numequ++\), "\<)\>"], 
        Background -> RGBColor[0, 1, 0], Magnification -> 1.2]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}, {green, ForestGreen}, {star, 
        SuperStar}, {blue, Blue}, {hat, OverHat}, {tilde, Overtilde}, {bar, 
        OverBar}]\), "\[IndentingNewLine]", 
    \(\(black = Identity;\)\), "\[IndentingNewLine]", 
    \(\(DeclareBaseIndices[{1, 2, 3}];\)\), "\n", 
    \(\({NDim, BaseIndices};\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DefineTensorShortcuts[{{\[DoubleStruckE], \[EHat], u, v, w, x, y, 
            z, \ dx, dy, dz, \ dr, \ ds, \ dt, \ \[Gamma], \ da, \ db, \ 
            dc, \[ScriptCapitalE], \[Sigma], \[Omega], \ dA, X}, 
          1}, {{g, \[Delta], \[Beta], \[Gamma], \[Zeta], \ \[InvisibleSpace]\
\[ScriptCapitalE], \ \[InvisibleSpace]\[ScriptCapitalE]\[Section], 
            a, \[Sigma], \[Sigma]\[Section]\[Section], \[Tau], \[Epsilon], 
            d\[ScriptCapitalE], F, A, u, X}, 2}, {{\[Epsilon], e, u}, 
          3}, {{\[DoubleStruckCapitalE], R, u}, 4}, {{\[Epsilon]}, 
          6}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{\(SetMetricValues[g, 
      IdentityMatrix[3]]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"RedBasisVectors", "=", 
        RowBox[{"(", GridBox[{
              {"1", "1", "0"},
              {"0", "1", "2"},
              {"1", "0", "1"}
              }], ")"}]}], ";", 
      RowBox[{"RedMetric", "=", 
        StyleBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "1", "1"},
                {"1", "5", "2"},
                {"1", "2", "2"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
          FontFamily->"Courier",
          FontSize->12]}], 
      StyleBox[";",
        FontFamily->"Courier",
        FontSize->
          12]}], "\[IndentingNewLine]", \
\(SetTensorValueRules[\[DoubleStruckE]d[red@i], 
      RedBasisVectors]\), "\[IndentingNewLine]", \(SetTensorValueRules[\
\[DoubleStruckE]u[red@i], 
      Inverse[RedBasisVectors // 
          Transpose]]\), "\[IndentingNewLine]", \(SetMetricValueRules[g, 
      RedMetric, red]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(g[Identity] = 1; g[red] = 9;\)], "Input"],

Cell[BoxData[{
    \(d\[DoubleStruckR] := 
      dru[red@i]\ \[DoubleStruckE]d[red@i]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckS] := 
      dsu[red@j] \[DoubleStruckE]d[red@j]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckT] := dtu[red@k]\ \[DoubleStruckE]d[red@k]\)}], "Input"],

Cell["and from equation (2.5) :", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(Tensor[\[ScriptCapitalE]\[Section], {Void, Void}, {i_, 
          j_}] := \((PartialD[ud[red@i], red@j] + 
            PartialD[ud[red@j], red@i])\)/2\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[DoubleStruckU] = uu[red@i] \[DoubleStruckE]d[red@i];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Kinematic Relations", "Section",
  CellTags->"Kinematic Relations"],

Cell[TextData[{
  "The kinematic equation have been presented in the section ",
  StyleBox["Strain Tensor",
    FontWeight->"Bold"],
  " of Chapter 2, in a non tensorial form, involving partial derivatives. \
Using the results of Chapter 5 on the covariant derivatives, and the fact \
that we have tensors, it can be easily shown that we can identify in \
cartesian coordinates the partial derivatives with the covariant derivatives \
and then see that the kinematic equations take the form"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\[ScriptCapitalE]dd[red@i, 
          red@j]\  == \(1\/2\) \((CovariantD[ud[red@i], red@j] + 
              CovariantD[ud[red@j], red@i] + 
              CovariantD[uu[red@k], red@i] 
                CovariantD[ud[red@k], 
                  red@j])\)\[IndentingNewLine]]\)], "Input"],

Cell["\<\
and the linear version of the kinematic equation may be written,\
\>", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\[ScriptCapitalE]dd[red@i, 
          red@j]\  \[Equal] \((\[ScriptCapitalE]\[Section]dd[red@i_, 
              red@j_] = \(1\/2\) \((CovariantD[ud[red@i], red@j] + 
                  CovariantD[ud[red@j], 
                    red@i])\))\)\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  "This equation is now valid in any coordinate system. The above equation is \
symmetrical in its indices, but what is the meaning of the antisymmetric \
expression ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{\(1\/2\), " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["u", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ j]],
                                  Editable->False],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ i], 
                              Cov[ 
                                red[ j]]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    InterpretationBox[
                                      
                                      RowBox[{"\<\";\"\>", 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                      SequenceForm[ ";", 
                                        red[ j]],
                                      Editable->False],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              StyleForm[ 
                                Cov[ 
                                  red[ j]], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ u, 
                          SequenceForm[ 
                            red[ i], 
                            Cov[ 
                              red[ j]]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              Cov[ 
                                red[ j]], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "-", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["u", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ i]],
                                  Editable->False],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ j], 
                              Cov[ 
                                red[ i]]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    InterpretationBox[
                                      
                                      RowBox[{"\<\";\"\>", 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                      SequenceForm[ ";", 
                                        red[ i]],
                                      Editable->False],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ j], ShowContents -> False], 
                              StyleForm[ 
                                Cov[ 
                                  red[ i]], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ u, 
                          SequenceForm[ 
                            red[ j], 
                            Cov[ 
                              red[ i]]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ j], ShowContents -> False], 
                            StyleForm[ 
                              Cov[ 
                                red[ i]], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], ")"}], "."}]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " Consider the tensor "
}], "Text"],

Cell[BoxData[
    \(\[Omega]u[k_] := \(-\(1\/2\)\) CovariantD[ud[i], j] 
        euuu[i, j, k]\)], "Input"],

Cell["and we have the identity :", "Text"],

Cell[BoxData[
    \(\((\[Omega]u[k] // ToFlavor[red])\) \[DoubleStruckE]d[
          red@k] == \(1\/2\) \(TCurl[\[DoubleStruckE], g, red /@ {j, i, k}, 
            e]\)[\[DoubleStruckU]]\)], "Input"],

Cell["that is to say,", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]Tensor[\[Omega], {red@
                i}, {Void}] \[DoubleStruckE]d[red@i] == \(1\/2\) 
          TCurl[\[DoubleStruckU]]\[IndentingNewLine]]\)], "Input"],

Cell["In cartesian coordinates,", "Text"],

Cell[BoxData[
    \(\(\((\(\[Omega]u[3] // SumExpansion[{i, j}]\) // 
              LeviCivitaSimplify[e])\) /. \(LeviCivitaRule[e, \[Epsilon]]\)[
            g, black]\) /. PermutationSymbolRule[\[Epsilon]] // 
      Factor\)], "Input"],

Cell[TextData[{
  "In this expression, ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Omega]", 
                  InterpretationBox[
                    TagBox[
                      StyleBox["3",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 3, ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox["3",
                    SequenceForm[ 3],
                    Editable->False]],
                Subsuperscript[ \[Omega], 
                  SequenceForm[ 
                    StyleForm[ 3, ShowContents -> False]], 
                  SequenceForm[ 3]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "is the average rotation of a deformable volume element in the plane \
{1,2}."
}], "Text"],

Cell[CellGroupData[{

Cell["Compatibility conditions", "Subsection"],

Cell[TextData[{
  "There are three displacements ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["u", 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False], 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ u, 
                  SequenceForm[ 
                    red[ i]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  ", but six different strain components ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ". In fact if we calculate the second derivatives of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ", and there combination"
}], "Text"],

Cell[BoxData[{
    \(CovariantD[\[ScriptCapitalE]dd[red@i, red@j], {red@k, red@l}] 
      euuu[red@i, red@k, red@m] 
      euuu[red@j, red@l, red@n]\), "\[IndentingNewLine]", 
    \(% /. {CovariantD[\[ScriptCapitalE]dd[red@i, red@j], {l1_, l2_}] :> 
          CovariantD[\((\(1\/2\) \((CovariantD[ud[red@i], red@j] + 
                    CovariantD[ud[red@j], red@i])\))\), {l1, 
              l2}]}\), "\[IndentingNewLine]", 
    \(\(\(\((\(\(% // SumExpansion[red@i, red@j, red@k, red@l]\) // 
                  ArrayExpansion[red@m, red@n]\) // 
                LeviCivitaSimplify[e])\) /. \(LeviCivitaRule[e, \[Epsilon]]\)[
              g, red]\) /. PermutationSymbolRule[\[Epsilon]] // 
        SymmetricStandardOrder[u, {2, 4}]\) // Simplify\)}], "Input"],

Cell[TextData[{
  "The above matrix {m,n}is symmetrical and the six equations corresponding \
to {m,n}={1,1},{2,2},{3,3},{1,2},{2,3},{3,1} give ",
  StyleBox["zero",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(CovariantD[\[ScriptCapitalE]dd[red@i, red@j], {red@k, red@l}] 
        euuu[red@i, red@k, red@m] euuu[red@j, red@l, red@n];\)\), "\n", 
    \(\(res = \(\(\(\((\(\(9  % // 
                          SumExpansion[red@i, red@j, red@k, red@l]\) // 
                        ArrayExpansion[red@m, red@n]\) // 
                      LeviCivitaSimplify[e])\) /. \(LeviCivitaRule[
                      e, \[Epsilon]]\)[g, red]\) /. 
                PermutationSymbolRule[\[Epsilon]] // 
              SymmetricStandardOrder[\[ScriptCapitalE], {1, 2}]\) // 
            SymmetricStandardOrder[\[ScriptCapitalE], {3, 4}]\) // 
          Simplify;\)\n\), "\n", 
    \(restable = \[IndentingNewLine]{res[\([1, 1]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([2, 2]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([3, 3]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([1, 2]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([2, 3]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([3, 1]\)] \[Equal] 0} // 
        TableForm\)}], "Input"],

Cell[TextData[{
  StyleBox["In cartesian coordinates the compatibility equations are",
    FontVariations->{"Underline"->True}],
  " (the covariant derivatives being then identical to partial derivatives):"
}], "Text"],

Cell[BoxData[
    \(\(\((\(\(restable /. Cov \[Rule] Dif // ToFlavor[black, red]\) // 
                DifToPartialD[{x, \[Delta], g, \[CapitalGamma]}]\) // 
              UseCoordinates[{x, y, z}])\) /. {\[ScriptCapitalE]dd[1, 
                1] -> \[ScriptCapitalE]d[x], \[ScriptCapitalE]dd[2, 
                2] -> \[ScriptCapitalE]d[y], \[ScriptCapitalE]dd[3, 
                3] -> \[ScriptCapitalE]d[z], \[ScriptCapitalE]dd[1, 
                2] \[Rule] \(1\/2\) \[Gamma]dd[x, y], \[ScriptCapitalE]dd[2, 
                3] \[Rule] \(1\/2\) \[Gamma]dd[y, z], \[ScriptCapitalE]dd[1, 
                3] \[Rule] \(1\/2\) \[Gamma]dd[x, z]} // FullSimplify\) // 
      TableForm\)], "Input"],

Cell["In the covariant form we would have written :", "Text"],

Cell[BoxData[
    \(\(\(\((\(\(restable // ToFlavor[black, red]\) // 
                  TensorNesting[\[ScriptCapitalE]]\) // 
                TensorNesting[\[ScriptCapitalE]])\) /. {\[ScriptCapitalE]dd[
                  1, 1] -> \[ScriptCapitalE]d[x], \[ScriptCapitalE]dd[2, 
                  2] -> \[ScriptCapitalE]d[y], \[ScriptCapitalE]dd[3, 
                  3] -> \[ScriptCapitalE]d[z], \[ScriptCapitalE]dd[1, 
                  2] \[Rule] \(1\/2\) \[Gamma]dd[x, y], \[ScriptCapitalE]dd[
                  2, 3] \[Rule] \(1\/2\) \[Gamma]dd[y, 
                    z], \[ScriptCapitalE]dd[1, 
                  3] \[Rule] \(1\/2\) \[Gamma]dd[x, z], 
              Cov[1] \[Rule] Cov[x], Cov[2] \[Rule] Cov[y], 
              Cov[3] \[Rule] Cov[z]} // TensorUnNesting[\[ScriptCapitalE]]\) // 
        TensorUnNesting[\[Gamma]]\) // FullSimplify\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Condition of Equilibrium and Equation of Motion", "Section",
  CellTags->"Condition of Equilibrium and Equation of Motion"],

Cell[CellGroupData[{

Cell[GraphicsData["PICT", "\<\
3g[ooooo07D0`00A0_l<0?ooooooo`00ool000300000M@000000002Q0<03NBE@
Kg=dDf=bJG1d84QQHf/PHWTPCFU[IB12LVmbLb0a<Rlg;cT`3Bm4JG=QHVaUCVEh
M5=UM597@T=_K6mb3@Uk3@UeLfEbI6USM21RIFMYKPd9;g=UM79WHV=_K6mb80d9
2G/=2@U`Kg0=2@U`Kg0=2@U`Kg0=2@UeLfEbI6USM21RIFMYKPd92BmcIGAbIf9S
Kfa_LR1cNG=dIFeTJF=d82mcIGAbIf9SKfa_LR1WIG@PI6EV3@T9IFiT3@T9OB1T
IFH=2FE^I0em869YKV@PI6EV3BmRHf5bLV5i87MXIG9U87/=2G1_L0d9HV=QLW9Q
NB0b87/=2@T_I64P=21`Lb1TJGHPI6EV3@T9I6HPLfEdIVm^M21WLf5fIB1SLb1g
J@d92C4PJFiTIGPP<21^IG]UN6=X86AQ865TI21UN6=XOFUV86MbIG=dKg9U87=U
M6=XHG9gJFAdJ0d92F=c830P<21cKF<PI64P<21cKF<PI64PI64PLfeS830PI64P
LfeS86<=2@UWLV5i3@T9Nb1WK7d=2@Uk<B1cIGAWLV5iOFUVIFacI@d92FAQ838^
86AYMR1TMG0PKFmfIGA_87=XKgL=2GeRJFiT871eM0em86UV3BD=9B1ELfET87A_
87=^HG0PM6lPI6EfJF=U871YN6E/Lb`P<BldM6PPKfHPM6QU871YN6E/86U^;Pd_
LgA`87/P82DPN21i821`K20PN21i820P820P820P820P820P82DPDfiQL21DKb1@
JGQUK2`PL6UhIF`P82QQMGA_87=dLVm[IB1QI6YeLg@Y3@UdLV5^LfI_LVd=2C0^
<SDPLgER879_MFiT830^<SDPHFAT86EhHfP=2C0^<SDPLgER879_MFiT830^<SDP
HFAT86EhHfP=2FUdLV5^LfI_LVd=OB1RJFiT86AUIPd=;g=^HG1]KgIUM6lPNb0U
87PPNB0PKB0P;B0P820P820P820P820U86e_MVEdKb`PHGEdKb1cM79_JfDPHFAZ
MG=d3@UcM70P86e_MVEdK`em869YKV@PI6EV3@d_LfiQL6aYKVEdKb1k82DPN21i
821/820]820P820P820P820P82DPK6U^IGA_;21QMGA_87=dLVm[IB1QI6YeLg@=
2G=dL21/JFiUM6l=OB1RJFiT86AUIPd00:00S00N00402_ooool0M@3000L00000
00P02P0S0000X02<00`00?oQ00402_oPool0EP3002<0002P08`03?oool<00@0:
oj?ooP0I0;l08`000:00X02Q0:@00@8000402P000000000002801@1c00008oH4
02<0000S1?`08`0002?lo00S00008`X402<0000100[oXoon01T0_`2400X00000
0000002P0:<0X02n00P0201a01h0001X00P0LP040780201X00@0K00006P0101b
028000000000X02o0:00X@0S0000X@2f00@00@010:00X02Q0:@00@4000402P00
0000000000L00@0102801@1c00008oH402<0000S1?`08`0002?lo00S00008`X4
02<0002P0:<0X02n00402_nSooh06@2o00L0000002<0002Q0;H0100100408P04
0780002Q0;H0100100401`010040L00N0000J0080780101b00P0J00406`0001X
00@0LP2P0;l0X02Q00L0000002<0002Q0;H0100100401`0200808P02001[0@2P
08d0X02<00`00@0m00402_oPool0EP3000L00000028000000000X02P0:40Y001
0P000@0:0000000000008P0101h0000S00/08`0002?nn`0S00008oX202<0000S
2?P08`0000402_oPool0EP3008@02P00000000000:00X`2P0;h0L@0N00005@0;
01d0000M00/07@0601/0200E00007@0R000000000:00_`2P0:408`000:40]P04
00400@2P0:00X@2T0041000100X000000000000700400@0R00407P0002<02`0S
00008okk02<0000SnP808`0002<8n00S0000X02S0:00_P0100[oh?oo05H0`007
0000000S0000X@2f00@00@010280000M0000X@2f00@00@0100L00@0107007P00
01D02`0M00007@0;01d01P0K00P05@0001d0X02o0:00X@070000000S0000X@2f
00@00@0100L00P020280@0006/D0X02=0:00S00<003og@0100[o_Ooo03<0`007
0000000R000000000:00X02Q0:@00@8000402P000000000002800@0a00008oX9
02<0000S0OX08`0002?jo`0S00008`_n02<0000100[o_Ooo03<0`02400X00000
0000002P0:<0X02n07407P0002D02@0`0000<00902X00`0[00809@0003008P00
0000002P0;l0X02Q02<0002Q0;H010010040X02P0:40Y0010@000@0:00000000
00001`0100408P010340000SnPT08`0002<1nP0S00008o[o02<0000S2oh08`00
0:00X`2P0;h00@0:okgoo`0c0<001`0000008`000:40]P0400400@0R0000<000
0:40]P0400400@0700400@1`01h0000U00T0<00003002@0Z00<0:`0202D0000`
0:00_`2P0:401`0000008`000:40]P0400400@0S0000X@2f00@00@010:40f004
0020002Q0=H01000P000X03G0:40]00500022@T000L00P0200P05`0R01h00B[U
0:00]@2Q0=H01000P000X03G0:00f@070000000800P08`000:40]P0400400@2Q
0=H01000P000X@3H00@008000:00_P2P0=T0L@0N01P0000O00X07@0001P0200J
00X07`0201d0001a01h03P0?01D06@0C00l03P0G01006@0E01404`0?07407P05
01h0300X00X07P0502H01`0X00`0800:01h0X@3H00@008000:00_`2P0=T0X03G
0:00S@2P08d0X02<00co]@1200402_oook@0M@1e0280000000008`000:40]P04
00400@0700400@0SL@401`0000008`000:40]P0400400@0700400@0R0440EQbo
00L0000002<0002Q0;H0100100401`0100408P0N04<_hP2P08d0301;00000@0:
ooooo`1e0<001`0000008`000:40]P0400400@2P0:00X@2T0041000100X00000
0000000700400@0R0040C@0002?@7`0S00008g4002<0000Si4008`0002<_hP0S
0000X02S0:00_P0100[ooooo07D0`0070000000S0000X@2f00@00@010280@@2P
0000X@2f00@00@0100L00@0107007P0001`0G`2P0000C00O01`07`2=05l0L@11
0:00X02o0:00X@070000000S0000X@2f00@00@0102<0002Q0;H010010040X@3H
00@008000:40eP040020002P0=L0X@2d00D000892@001`010040200G0280@00^
7L00X02e0:40eP040020002P0=L0X03I00L0000000P0200S0000X@2f00@00@01
0:40eP040020002Q0=P01000P000X02n0:00f@0700400@0R0400;PCh0280<00e
1?L08P0O03d4n00R00l0A0Ch0:40f0040020002P0;l0X03I0:00e`2P08`03?oA
ol<00@0:ol;od00h09401`0000008P000000002P0:00X@2T0042000100X00000
0000000R00D0M00002?h100S00008`?l02<0000SoO`08`0002<8100S00000@0:
ol;od00h0940Q00:000000000000X02S0:00_P1a01h0001[00P0L`0407<0201[
00@0KP0006/0101c028000000000X02o0:00X@0S0000X@2f00@00@010:00X02Q
0:@00@4000402P000000000000L00@0102801@1d00008oP402<0000S0o`08`00
02?mo00S00008`P402<0002P0:<0X02n00402_o2om00>02A00L0000002<0002Q
0;H0100100408P0407<0002Q0;H0100100401`010040L00N0000J`0807<0101c
00P0J`0406h0001[00@0L`2P0;l0X02Q00L0000002<0002Q0;H0100100408`00
0:40]P0400400@2Q0=P01000P000X@3F00@008000:00e`2Q0;@01@000PT90007
00400@0801L08P03001]002P0;D0X@3F00@008000:00e`2P0=T01`0000002008
02<0002Q0;H010010040X@3F00@008000:40f0040020002P0;h0X03I00L00@01
02800`0020008P030188000R00<090P002800`0f20008P0304P8000R00<0FPP0
02800`1/0000X@3H00@008000:00_`2P0=T0X03G0:00S@2Q09H0304000020000
0000000<om;og`0100X0000001D04`070000000R000000000:00V02Q09X02?o`
J80006J002`04POJ3eAYKFEc84iUMb1BKfeQKP031mX0108000d04P0^00@00?l0
02X@0F@000@3000Y2@5b002P09T0X02G02<0002Q09H03040000200000000000<
02h0800100X0000001D04P0S0000X02H0:40VP08oo18P000>000108002P04000
0F@010<002T90G<00:00V@2P09L08`000:40UP0<0@0000800000000000`0;@0[
00402P0000005@0A02<0002P09P0X@2J00Sol1f0000:P0040P00:00@0001I004
0`00:@T1M000X02I0:00U`0S0000X02=0?l\>"], "Graphics",
  Editable->False,
  ImageSize->{193, 118},
  ImageMargins->{{264, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000AM00@0005P0000=00003@0005X1002Y0000
00000000001H9@00KQ<00215CDH00040@1L108`0000500000000000000000@0000@00003000>0@00
b`0004H00034PP00]X8004M4BD<1002000<00=PMfZd00000WX8000402@000dm100070>Xj000000D0
000;0_ooool5000030:>0101100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@040000104700<0000N00D2003g0003007oool000100000P0000?l0
0200000P@0008800023o00100000@40004200010o`00H0000610001PP000H?l008000020@000P800
083o002P0000X4000:20002Po`00`0000<100030P000`?l00?l0003o@000oh000?oo0200000P0400
80200200o`0P80008210020PP00P8?l084000210@00P@800843o021P000PH4008620021Po`0PP000
88100220P00PP?l08:00022P@00PX8008:3o0230000P`4008<200230o`0Po`008?m0023oP00Pool0
@0000400@0100800@03o040P00108400@220040Po`10@000@4100410P010@?l0@600041P@010H800
@63o04200010P400@8200420o`10X000@:10042PP010X?l0@<000430@010`800@<3o043o0010od00
@?n0043oo`1P0000H0100600P01P0?l0H200060P@01P8800H23o0610001P@400H4200610o`1PH000
H610061PP01PH?l0H8000620@01PP800H83o062P001PX400H:20062Po`1P`000H<100630P01P`?l0
H?l0063o@01Poh00H?oo080000200400P0200800o`208000P210080PP0208?l0P4000810@020@800
P43o081P0020H400P620081Po`20P000P8100820P020P?l0P:00082P@020X800P:3o08300020`400
P<200830o`20o`00P?m0083oP020ool0X0000:00@02P0800X03o0:0P002P8400X2200:0Po`2P@000
X4100:10P02P@?l0X6000:1P@02PH800X63o0:20002PP400X8200:20o`2PX000X:100:2PP02PX?l0
X<000:30@02P`800X<3o0:3o002Pod00X?n00:3oo`300000`0100<00P0300?l0`2000<0P@0308800
`23o0<100030@400`4200<10o`30H000`6100<1PP030H?l0`8000<20@030P800`83o0<2P0030X400
`:200<2Po`30`000`<100<30P030`?l0`?l00<3o@030oh00`?oo0?l0003o0400o`200?l0o`3o8000
ob100?lPP03o8?l0od000?m0@03o@800od3o0?mP003oH400of200?mPo`3oP000oh100?n0P03oP?l0
oj000?nP@03oX800oj3o0?o0003o`400ol200?o0o`3oo`00oom00?ooP0000000100003@21P030000
=@0400001`430>Xj00133b00c00004l0KP4000004`1502H0_P0X0000KP4004l0000100P00000091a
000000000000000000000000oooo040000200000o`00000P00108000P2000?lP0000@000@4000810
003o@0000600041P0020H000of0000200010P000P8000?n00000X000@:00082P003oX0000<000430
0020`000ol00003o0010o`00P?l00?oo00000200@00P0800803o0200020P040P80208200ob0P0010
8010@200P40P0?m08000H200@60P081P803oH200080P04208020P200oh0P002P8010X200P:0P0?nP
8000`200@<0P0830803o`2000?lP043o8020ob00oolP0000@0100400P0100?l0@0008400@210080P
@03o840004100410@020@400od10001P@010H400P6100?mP@000P400@8100820@03oP4000:10042P
@020X400oj100030@010`400P<100?o0@000od00@?m0083o@03ood00001P0400H0200600o`1P000P
H0108600P21P0?lPH000@600@41P0810H03o@600061P041PH020H600of1P0020H010P600P81P0?n0
H000X600@:1P082PH03oX6000<1P0430H020`600ol1P003oH010of00P?mP0?ooH0000800@0200800
P03o08000220040PP0208800ob200010P010@800P4200?m0P000H800@620081PP03oH80008200420
P020P800oh20002PP010X800P:200?nPP000`800@<200830P03o`8000?n0043oP020oh00oon00000
X0100:00P02P0?l0X0008:00@22P080PX03o8:00042P0410X020@:00od2P001PX010H:00P62P0?mP
X000P:00@82P0820X03oP:000:2P042PX020X:00oj2P0030X010`:00P<2P0?o0X000oj00@?nP083o
X03ooj0000300400`0200<00o`30000P`0108<00P2300?lP`000@<00@4300810`03o@<000630041P
`020H<00of300020`010P<00P8300?n0`000X<00@:30082P`03oX<000<300430`020`<00ol30003o
`010ol00P?o00?oo`0000?l0@03o0800o`3o0?l0023o040Po`208?l0ob3o0010o`10@?l0P43o0?m0
o`00H?l0@63o081Po`3oH?l0083o0420o`20P?l0oh3o002Po`10X?l0P:3o0?nPo`00`?l0@<3o0830
o`3o`?l00?oo043oo`20ool000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3P0000h>3P
h>3Ph>00003Ph>3Ph>3Ph00000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>3Ph>3P
h>3Ph03Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph00000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3P000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003Ph>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3Ph>3Ph000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
h>3Ph>00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003Ph>3Ph000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000>3Ph>3P0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P
00000000h>3Ph>000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3P0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3P0000
0000h>3Ph>000000003Ph>3Ph0000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000h>3Ph>000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
h>3Ph>000000003Ph>3Ph00000000>3Ph>3P00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003Ph>3Ph0000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000>3Ph>3P00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000h>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000h>3Ph>000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003Ph>3Ph0000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P0000
0000h>3Ph>0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000>3Ph>3P00000000000000000000000000000000000000000000
000000000000000000000?ooooooooooool000000000000000000000000000000>3Ph>3P00000000
h>3Ph>3P0000003Ph>3Ph000000000000000000000000000000000000000000000000000oooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooool0000000000000003o
ooooooooooooooooool000000000000000000000h>3Ph>0000000000000000000000000000000000
0000000000000000000000000000ooooooooooooooooooooool0000000000000000000000000h>3P
h>3Ph000003Ph>3Ph>3P00000>3Ph>3P000000000000000000000000000000000000000000000000
oooooooooooooooooooo000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000ooooooooooooooooooooooooool0oooooooooooooooooooooooooooooooooooooooo0000
00000000oooooooooooooooooooooooo0000000000000000003Ph>3Ph00000000000000000000000
000000000000000000000000000000000000ooooooooooooooooooooooooooooo`00000000000000
003Ph>3Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000h>3Ph>3P000000000000000000000000000000000000
00000000ooooooooooooooooooooooooool000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000003ooooooooooooooooooooooooo0000000000000000003Ph>3Ph00000000000
000000000000000000000000000000000000000000000?oooooooooo00000000003ooooooooooooo
000000000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00000000000000000000000000
00000000000000000?ooooooooooooooooooooooooooool000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0000000000?ooooooooooooooooooooooool000000000000000000>3Ph>3P
0000000000000000000000000000000000000000000000000000003ooooooooo0000000000000000
003oooooooooool00000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P0000000000000000
0000000000000000000000000000oooooooooooooooooooooooooooooooo00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000000ooooooooooooooooooooooooo`00000000000000
0000h>3Ph>0000000000000000000000000000000000000000000000000000000?oooooooooo0000
0000000000000000003oooooo`0000000>3Ph>3Ph>3Ph>00h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000000
0000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooo0000
000000000000003Ph>3Ph000000000000000000000000000000000000000000000000000003ooooo
ooooool0000000000000000000000000ool000000000003Ph>3Ph>3Ph000h>3Ph>3Ph000h>3Ph>3P
h>3P00000000000000000000000000000000000000000000ooooooooooooo`0000000000oooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000ooooooooooooool000000000
003oooooooooooooooooooooooooooooooooooooooooooooo`000000000000000?oooooooooooooo
ooooo`0000000000000000000>3Ph>3P000000000000000000000000000000000000000000000000
00000?ooool0ooooo`000000000000000000000000000000000000000000000000000000h>3Ph>00
00000>3Ph>3Ph0000000000000000000000000000000000000000000003oooooooooo`0000000000
0000003oooooooooo`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003oooooooooool0
0000000000000000oooooooooooooooo00000000003oooooooooo`00000000000000000000000000
ooooooooool00000000000000000000000000>3Ph>3P000000000000000000000000000000000000
000000000000003oooooo`3oooooo`00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000?ooooooool0
0000000000000000003oooooooooo`00000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
oooooooo000000000000000000000?ooooooooooool0000000000?oooooooooo0000000000000000
00000000003ooooooooo0000000000000000000000000000h>3Ph>00000000000000000000000000
0000000000000000000000000?oooooo003ooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
oooooooo000000000000000000000000ooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003oooooooooo`00000000000000000000000?ooooooooooo`00000000000?oooooooooo0000
000000000000000000000?ooooooool0000000000000000000000000003Ph>3Ph000000000000000
000000000000000000000000000000000000ooooo`000?ooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooool0000000000000000000000000ooooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?ooooooool00000000000000000000000000?oooooooooo0000000000000?oo
oooooooo000000000000000000000000ooooooooo`000000000000000000000000000>3Ph>3P0000
00000000000000000000000000000000000000000000003ooooo0000ooooool00000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooooooo`00000000000000000000000000oooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000ooooooooo`000000000000000000000000000?oooooooooo0000
00000000ooooooooool000000000000000000000003ooooooooo0000000000000000003Ph>3Ph>3P
h>3Ph>000000000000000000000000000000000000000000000000000?ooool00000ooooo`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000oooooooo0000000000000000000000000000oooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooo00000000000000000000000000000?oo
ooooool0000000000000ooooooooooooooooooooooooooooooooooooooooool00000000000000000
h>3Ph>3Ph>3Ph>3Ph>00000000000000000000000000000000000000000000000000ooooo`00003o
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooool00000000000000000000000000000
oooooooo000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000?ooooooool000000000000000000000
00000000ooooooooo`00000000000000oooooooooooooooooooooooooooooooooooooooo00000000
00000000003Ph>3Ph>3Ph>3Ph>3Ph000000000000000000000000000000000000000000000000000
ooooo`000?oooooo0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003oooooool00000000000000000
00000000003oooooool0000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000ooooooooo`0000000000
0000000000000000003ooooooooo000000000000003ooooooooooooooooooooooooooooooooooooo
ool000000000000000000>3Ph>3Ph>3Ph>3Ph>3P0000000000000000000000000000000000000000
00000000003ooooo00000?ooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?ooooooo`000000
00000000000000000000003oooooool0000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000oooooooo
0000000000000000000000000000003oooooool0000000000000003ooooooooooooooooooooooooo
ooooooooooooo`000000000000000000003Ph>3Ph>3Ph>3Ph>000000000000000000000000000000
000000000000000000000?ooool00000ooooooooooooooooooooooooooooooooool0000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
oooo00000000000000000000000000000?ooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003ooooooooo00000000000000000000000000000?ooooooool00000000000000?oooooooooooooo
oooooooooooooooooooooooo00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooool0003oooooooooooooooooooooooooooooooooool0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000oooooooo0000000000000000000000000000oooooooo0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?ooooooool00000000000000000000000000000ooooooooo`000000000000000?oo
ooooooooooooooooooooooooooooooooool000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000ooooo`00003ooooooooooooooooooooooooo
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003oooooool00000000000000000000000000000oooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooool0000000000000000000000000003ooooooooo00000000
000000000?oooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000oooo00000?ooool000000000
0000000000000000oooo000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooool0000000000000000000000000003oooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000ooooooooool0000000000000000000000000oooooooo
ool00000000000000000ooooooooool00000000000000?ooooooool0000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003ooooo0000oooo
ool000000000000000000000003ooooo000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000?ooooooool00000000000000000000000000?oo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000ooooooooo`0000000000000000000000
003oooooooooool00000000000000000ooooooooool0000000000000ooooooooo`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003o
oooo0000ooooo`00000000000000000000000?ooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?ooooooool00000000000000000
00000000oooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003oooooooooo`0000000000
000000000000ooooooooooooo`000000000000000000ooooooooool000000000003ooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oool0003ooooo000000000000000000000000ooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?ooooooool00000
0000000000000000003oooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
ool00000000000000000003ooooooooooooo0000000000000000003oooooooooo`0000000000oooo
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooool00?oooooo00000000000000000000003ooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000?oo
ooooool0000000000000000000000?ooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003oooooooooool0000000000000003oooooooooooooool00000000000000000003oooooooooo`00
0000003ooooooooo0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooool00?ooool000000000000000000000ooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000ooooooooool00000000000000000003ooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?ooooooooooooooo`000000003oooooooooooooooooool00000000000000000003o
oooooooo000000000?ooooooool00000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooool0ooooo`000000000000000000003o
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000oooooooooooo00000000000000000?ooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooooooooooooooooooooooooooooooooooooooo`0000000000
000000000?oooooooooo00000000ooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003oooooooooo`0000000000
00000000ooooool00000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooooooooooool0000000000?ooooooooooo`0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
000000000000000000000?oooooooooo0000003ooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
0000000000000000oooooooo00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000003ooooooooooooooooooooooooooooo
ooooooooool000000000000000000000ooooooooool00000ooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003oooooooooo`0000000000ooooooooo`0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000?oooooooooooooooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003ooooooooooooooooo
ooooooooooooooooooooo`0000000000000000000000ooooooooool0003ooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000ooooooooooooooooooooooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
ooooooooooooooooooooooooooooooooo`000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P0000003P
h>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3Ph>3Ph00000000000000000000000000000000000oooo
ooooooooooooooooooooo`00ooooooooo`0000000000000000000000ooooooooool00?ooooooool0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000?ooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000oooooooooooooooooooooooooooooooooooooooo00000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph000h>3Ph>3Ph>3Ph>3Ph03Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>00000000000000000000000000
000000000?ooooooooooooooooooo`00003ooooooooo00000000000000000000003oooooooooo`00
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooo0000003Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000000000000000
0000000000000000000000000?oooooooooo000000000?ooooooool000000000000000000000003o
ooooooooo`3ooooooooo000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooooooooooooooooooooooooooooooool000000>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P0000
00000000000000000000000000000000000000000000000000000000ooooooooo`00000000000000
00000000003oooooooooooooooooool0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P0000003Ph>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3P
h>3Ph00000000000000000000000000000000000000000000000000000000000003oooooooooo`00
000000000000000000000?oooooooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000h>3Ph>0000000000000000000000h>3Ph>000000003Ph>3Ph000
00000>3Ph>3P0000000000000000000000000000000000000000000000000000000000000000003o
oooooooo0000000000000?ooooooooooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003Ph>3Ph0000000000000000000003Ph>3Ph0000000
0>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000000000000000000000000000
000000000?ooooooool000000000003oooooooooooooooooooooooooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000>3Ph>3P00000000000000000000003P
h>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000ooooooooo`00000000000?oooooooooooooooooooooooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000>3Ph>3P000000000000
000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000000000000000
00000000000000000000003oooooooooooooooooo`0000000000oooooooooooooooooooooooooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000h>3Ph>00
00000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P000000000000000000000000
00000000000000000000000000000000oooooooooooooooooooo00000000003ooooooooooooooooo
oooooooooooo00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003Ph>3Ph0000000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>00000000000000
0000000000000000000000000000000000000000003oooooooooooooooooool000000000003ooooo
ooooooooooooooooooooool000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3P000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph000
00000000000000000000000000000000000000000000000000000?ooooooooooooooooooo`000000
00000000ooooooooooooooooooooooooo`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000h>3Ph>00000000000000000000000>3Ph>3P00000000h>3Ph>000000
003Ph>3Ph0000000000000000000000000000000000000000000000000000000oooooooooooooooo
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000h>3Ph>0000000000000000000000h>3Ph>000000003P
h>3Ph00000000>3Ph>3P00000000000000000000000000000000000000000000000000000000oooo
oooooooooooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003Ph>3Ph0000000000000000000003Ph>3P
h00000000>3Ph>3P00000000h>3Ph>00000000000000000000000000000000000000000000000000
000000000?ooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000>3Ph>3P0000000000000000
00000>3Ph>3P00000000h>3Ph>3P0000003Ph>3Ph000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>000000
0000000000000000h>3Ph>3Ph000003Ph>3Ph>3P00000>3Ph>3P0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph000000000000000003Ph>3Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000h>3Ph>3P0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003Ph>3Ph000000000000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000>3Ph>3P000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3P0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000h>3Ph>000000000000000>3Ph>3Ph>3Ph>00h>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003Ph>3Ph000000000000000003Ph>3Ph>3Ph000
h>3Ph>3Ph000h>3Ph>3Ph>3P00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>3Ph>3P00000000000000000000
000000000000h>3Ph>0000000>3Ph>3Ph00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000>3Ph>3P00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000h>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003Ph>3Ph0000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000>3Ph>3P00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000h>3Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3P000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000100002L1
ool40000l04600@000040@d0100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000@0
000]0@@010000?010@070000o0800000000000@0000]0@403P0002@31@1l06T0LP1]07D0J@1b06D0
O01Y00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<507`0J@1b06d0
M@1Y0780I@1l06T0100002d10`040000l04000P0003j0P000P02000000840000;@4000P0000U0`80
2P1X07D0J@040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@0V02P0
9P0c02<0;P0N03009P0X00@0000]0@<010000?0100080000nP8000400@000002100002d1000>0000
9@<502H0:00V03<08`0^01h0<00V02P0100002d10`040000l04000P0003j0P000P02000000840000
;@4000P0000U0`802P1Y02<0;P040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00
3P0002@31@0i04/0<`1D03<0C`0^04d0>@1;00@0000]0@<010000?0100080000nP8000400@000002
100002d1000>00009@<503T0B`0c05@0<`1?02h0C@0i04/0100002d10`040000l04000P0003j0PD0
00000?ooo`840000;@4000h0000T0`D02@1Y0140I00C06D02`1Z00T0J@0>000090<501P0G`0P05/0
8P1L01X0H00H05l03P0002@31@0W05H0;`1A0340DP0Y05L09`1F00@0000]0@<010000?0100080000
nP8000400@000002100002d1000800009@<205<02P3500X0200002D30P2Y04X0a@0:00P0000U0`80
UP0X0<D02P0>00009@<505D02@0T02T0U@0X07X0J02Y04X0200002D30P1D00X0D00B00P0000U0`80
C@0J04T08`0800009@<204H0:`1203<0200002D30P0n03/0>`1400P0000U0`80>@1:0440BP080000
9@<204/0BP1C04X0200002D30P1M04X0I@1:00P0000U0`80K`1:07L0BP0800009@<20840BP2904X0
200002D30P2C04X0V`1:00P0000U0`80Y@1:0:T0BP0500002@800002100002h100040000;@4500@0
003`0@8070000?/2k_l00000002@0@400000000bE6U]IG<PCVEg859_KF5^00000000000000000000
00040000;@4200L0000Q1@40I?mZ06H01@0000T200000P@0000^0@00100002d11@040000l04201`0
003k0^ko00000000_08100000000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d1
0P0700008@D107;oJP1_00D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`00
000009010@000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`000245
0@1TodX0>00500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002l0P40
0000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40Lom:0440
1@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000T04100000000<UAY
KFEc84iUMb1BKfeQKP0000000000000000000000100002d10P0700008@D106Co7P0;00D000090P00
00840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000;`20@000000039DJFeULb1>IGLP
DVm]HFh00000000000000000000000@0000]0@801`0002450@1doah050040000;@4300@0003`0@00
20000?X21@000000oooo0P@0000]0@003P0002@31@3@01h0b@0V0<X08@3501l0d00N00@0000]0@<0
10000?0100080000nP8000400@000002100002d1000>00009@<50=007P3902H0bP0Q0<D07`3@01h0
100002d10`040000l04000P0003j0P000P02000000840000;@4000P0000U0`80X`0g0<X08@040000
9`7oo`@0003`0@0010000?010@040000l04200@0003`0@<010000?0110040000l04500<000000=co
4@0000`0000800002`000100001[0@00_00000T0000@0000J`400;`0000:000040000?oooooooooo
2@000100000@0@00SP000180000<00000@00024000080000500000`0000700009P0001`000010000
000000400001000000000RD0000<00000@0002D0000<00000000P580001<0@000P00000000000000
00000000001N0@00000000000B000<M5j000j@@0001VodGX3km5j0noC@`k`@n=C@000:6l0[013km=
j8]E20noC8X2:l431K@2/04?_dgXR`000014RP:Q^0:`0@noCNR;E@P?_`b::l431K02/04?_dgXReD8
IXT4R^VOoooojBh0003Y:@000>TT0000PggH0`n76P0008]5f?lTQEBU[`4VY:l1M:B_0GVT[`75Y:l1
jM82000?_`G20[01RDGDjAX1001VadGX003Y100006H00>P?_dGX3km=33_13he=0000XK`2/04?_dgX
ReD83km<RP8[`@<5]0:`0@noCNR;E@QVRDB:0Z6h0[013km=00000000000000000000000000000000
0@410@410@410@009@0000`0000200008@0000P0000a000040@000<000000`01oooo0000@0000800
003o000P000084000220000Po`00@00004100010P000@?l00600001P@000H800063o00200000P400
08200020o`00X0000:10002PP000X?l00<000030@000`8000<3o003o0000od000?n0003oo`0P0000
80100200P00P0?l08200020P@00P8800823o0210000P@40084200210o`0PH0008610021PP00PH?l0
88000220@00PP800883o022P000PX4008:20022Po`0P`0008<100230P00P`?l08?l0023o@00Poh00
8?oo040000100400@0200400o`108000@210040PP0108?l0@4000410@010@800@43o041P0010H400
@620041Po`10P000@8100420P010P?l0@:00042P@010X800@:3o04300010`400@<200430o`10o`00
@?m0043oP010ool0H0000600@01P0800H03o060P001P8400H220060Po`1P@000H4100610P01P@?l0
H600061P@01PH800H63o0620001PP400H8200620o`1PX000H:10062PP01PX?l0H<000630@01P`800
H<3o063o001Pod00H?n0063oo`200000P0100800P0200?l0P200080P@0208800P23o08100020@400
P4200810o`20H000P610081PP020H?l0P8000820@020P800P83o082P0020X400P:20082Po`20`000
P<100830P020`?l0P?l0083o@020oh00P?oo0:00002P0400X0200:00o`2P8000X2100:0PP02P8?l0
X4000:10@02P@800X43o0:1P002PH400X6200:1Po`2PP000X8100:20P02PP?l0X:000:2P@02PX800
X:3o0:30002P`400X<200:30o`2Po`00X?m00:3oP02Pool0`0000<00@0300800`03o0<0P00308400
`2200<0Po`30@000`4100<10P030@?l0`6000<1P@030H800`63o0<200030P400`8200<20o`30X000
`:100<2PP030X?l0`<000<30@030`800`<3o0<3o0030od00`?n00<3oo`3o0000o`100?l0P03o0?l0
ob000?lP@03o8800ob3o0?m0003o@400od200?m0o`3oH000of100?mPP03oH?l0oh000?n0@03oP800
oh3o0?nP003oX400oj200?nPo`3o`000ol100?o0P03o`?l0ool00?oo@03ooh0000000300000<0000
0`0003@0000800005@0000`000030000D@0000ag003o0000=00005X1001<0000_P0002H000000000
000006h1001?0000D00002`5001l1@00T7400000000P0<`0A@0001<0000X0000KP4004l0000100P0
0000091a000000000000000000000000oooo040000200000o`00000P00108000P2000?lP0000@000
@4000810003o@0000600041P0020H000of0000200010P000P8000?n00000X000@:00082P003oX000
0<0004300020`000ol00003o0010o`00P?l00?oo00000200@00P0800803o0200020P040P80208200
ob0P00108010@200P40P0?m08000H200@60P081P803oH200080P04208020P200oh0P002P8010X200
P:0P0?nP8000`200@<0P0830803o`2000?lP043o8020ob00oolP0000@0100400P0100?l0@0008400
@210080P@03o840004100410@020@400od10001P@010H400P6100?mP@000P400@8100820@03oP400
0:10042P@020X400oj100030@010`400P<100?o0@000od00@?m0083o@03ood00001P0400H0200600
o`1P000PH0108600P21P0?lPH000@600@41P0810H03o@600061P041PH020H600of1P0020H010P600
P81P0?n0H000X600@:1P082PH03oX6000<1P0430H020`600ol1P003oH010of00P?mP0?ooH0000800
@0200800P03o08000220040PP0208800ob200010P010@800P4200?m0P000H800@620081PP03oH800
08200420P020P800oh20002PP010X800P:200?nPP000`800@<200830P03o`8000?n0043oP020oh00
oon00000X0100:00P02P0?l0X0008:00@22P080PX03o8:00042P0410X020@:00od2P001PX010H:00
P62P0?mPX000P:00@82P0820X03oP:000:2P042PX020X:00oj2P0030X010`:00P<2P0?o0X000oj00
@?nP083oX03ooj0000300400`0200<00o`30000P`0108<00P2300?lP`000@<00@4300810`03o@<00
0630041P`020H<00of300020`010P<00P8300?n0`000X<00@:30082P`03oX<000<300430`020`<00
ol30003o`010ol00P?o00?oo`0000?l0@03o0800o`3o0?l0023o040Po`208?l0ob3o0010o`10@?l0
P43o0?m0o`00H?l0@63o081Po`3oH?l0083o0420o`20P?l0oh3o002Po`10X?l0P:3o0?nPo`00`?l0
@<3o0830o`3o`?l00?oo043oo`20ool0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3Ph>3Ph>00003Ph>3Ph>3Ph0000>3Ph>3Ph>3P000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3P00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003Ph>3Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>00h>3Ph>3Ph>3Ph00000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000h>3Ph>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P003P
h>3Ph>3Ph>0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>00003Ph>3P
h>3Ph0000>3Ph>3Ph>3P000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003Ph>3Ph000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003Ph>3Ph000
00000>3Ph>3P00000000h>3Ph>000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3P0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0>3Ph>3P00000000h>3Ph>000000003Ph>3Ph0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph>000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph0000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000>3Ph>3P0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3P
h0000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000h>3Ph>000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph>000000003Ph>3Ph000
00000>3Ph>3P00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003Ph>3Ph0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>000000
003Ph>3Ph00000000>3Ph>3P00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003Ph>3Ph0000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>3Ph>3P00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000ooooooooooooo`00000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000h>3Ph>0000000000
00000000000000000000000000000000000000000000000000000000ooooooooooooo`0000000000
00000000000000000000h>3Ph>000000003Ph>3Ph>0000000>3Ph>3P000000000000000000000000
000000000000000000000000003ooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003ooooooooooooooooooooo0000oooooooooooooooooooo
ooooooooooooooooo`000000000000000?ooooooooooooooooooo`000000000000000000003Ph>3P
h00000000000000000000000000000000000000000000000000000000000003ooooooooooooooooo
ooooo`0000000000000000000000003Ph>3Ph>3P00000>3Ph>3Ph>000000h>3Ph>00000000000000
00000000000000000000000000000000003oooooooooooooooooool0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooooooooooooooooooooooo`3ooooooooo
ooooooooooooooooooooooooooooool000000000003oooooooooooooooooooooool0000000000000
00000>3Ph>3P00000000000000000000000000000000000000000000000000000000003ooooooooo
oooooooooooooooooooo00000000000000000>3Ph>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3Ph>00
0000000000000000000000000000000000000000003oooooooooooooooooooooooooo`0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0000000000?ooooooooooooooooooooooool0
00000000000000000>3Ph>3P00000000000000000000000000000000000000000000000000000000
ooooooooool0000000000?ooooooooooool000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph0000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
o`000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000oooooooooooooooo
ooooooooo`000000000000000000h>3Ph>0000000000000000000000000000000000000000000000
000000000?ooooooool000000000000000000?ooooooooooo`0000000>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>000000000000000000000000000000000000000000003ooooooooooooooooo
ooooooooooooool00000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000003ooooo
oooooooooooooooooooo0000000000000000003Ph>3Ph00000000000000000000000000000000000
00000000000000000000ooooooooool0000000000000000000000?oooooo00000000h>3Ph>3Ph>3P
h03Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph0000000000000000000000000000000000000000000oooooooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
0000003oooooooooooooooooooooool000000000000000000>3Ph>3P000000000000000000000000
00000000000000000000000000000?ooooooooooo`0000000000000000000000003oo`0000000000
0>3Ph>3Ph>3P003Ph>3Ph>3P003Ph>3Ph>3Ph>000000000000000000000000000000000000000000
003ooooooooooooo00000000003ooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooooooo
oooo0000000000000000oooooooooooooooooooo00000000000000000000h>3Ph>00000000000000
0000000000000000000000000000000000000000ooooo`3ooooo0000000000000000000000000000
000000000000000000000000003Ph>3Ph0000000h>3Ph>3P00000000000000000000000000000000
0000000000000?oooooooooo00000000000000000?oooooooooo0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooooooooooo`00000000000000003oooooooooooooool0000000000?oo
oooooooo000000000000000000000000003oooooooooo`00000000000000000000000000h>3Ph>00
0000000000000000000000000000000000000000000000000?oooooo0?oooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000ooooooooo`0000000000000000000?oooooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooooooool000000000000000000000ooooooooooooo`00
00000000ooooooooool00000000000000000000000000?ooooooool0000000000000000000000000
003Ph>3Ph000000000000000000000000000000000000000000000000000ooooool00?ooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003oooooool000000000000000000000003ooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000?oooooooooo000000000000000000000000oooo
oooooooo000000000000ooooooooool0000000000000000000000000ooooooooo`00000000000000
0000000000000>3Ph>3P000000000000000000000000000000000000000000000000003ooooo0000
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooooooo`0000000000000000000000003o
oooooooo000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000ooooooooo`000000000000000000
00000000ooooooooool0000000000000ooooooooool000000000000000000000003ooooooooo0000
000000000000000000000000h>3Ph>00000000000000000000000000000000000000000000000000
0?ooool0003oooooo`00000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000oooooooo0000000000000000
00000000003oooooool0000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003ooooooooo00000000
00000000000000000000ooooooooool000000000003oooooooooo`00000000000000000000000?oo
ooooool000000000000000000>3Ph>3Ph>3Ph>3Ph000000000000000000000000000000000000000
000000000000ooooo`00003ooooo0000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003oooooool00000
00000000000000000000003oooooool0000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ool00000000000000000000000000000ooooooooo`0000000000003ooooooooooooooooooooooooo
ooooooooooooooooo`00000000000000003Ph>3Ph>3Ph>3Ph>3Ph000000000000000000000000000
00000000000000000000003ooooo00000?ooool00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000?oo
ooooo`00000000000000000000000000003oooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000ooooooooo`00000000000000000000000000003ooooooooo000000000000003ooooooooooooo
ooooooooooooooooooooooooool000000000000000000>3Ph>3Ph>3Ph>3Ph>3P0000000000000000
00000000000000000000000000000000003ooooo0000ooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000?ooooooo`000000000000000000000000000?ooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000003ooooooooo00000000000000000000000000000?ooooooool00000000000000?oo
ooooooooooooooooooooooooooooooooooooo`000000000000000000h>3Ph>3Ph>3Ph>3Ph>000000
000000000000000000000000000000000000000000000?ooool00000ooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000oooooooo00000000000000000000000000000?ooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003oooooool000000000000000000000000000000?ooooooo`000000
000000000?oooooooooooooooooooooooooooooooooooooo000000000000000000000>3Ph>3Ph>3P
h>3Ph000000000000000000000000000000000000000000000000000ooooo`00003ooooooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooool00000000000000000000000000000oooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?ooooooool00000000000000000000000000000oooo
ooooo`00000000000000ooooooooooooooooooooooooooooooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000ooooo`000?oo
ooooooooooooooooooooooooooooooooo`0000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooool0000000000000000000000000003o
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000ooooooooo`0000000000000000000000
0000003ooooooooo0000000000000000ooooooooooooooooooooooooooooooooooooo`0000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003o
oooo00000?oooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?ooooooo`000000000000000000
00000000003oooooool0000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000ooooooooo`0000000000
00000000000000000?ooooooool00000000000000000ooooooooooooooooooooooooooooooooool0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oool00000ooooo`0000000000000000000000003oool0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?ooooooo`000000
000000000000000000000?ooooooo`00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
o`0000000000000000000000003oooooooooo`00000000000000003oooooooooo`00000000000000
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooool0003oooooo`00000000000000000000000?ooool0000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
ooooo`00000000000000000000000000oooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003ooooooooo0000000000000000000000000?ooooooooooo`00000000000000003oooooooooo`00
00000000003ooooooooo000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooool0003ooooo000000000000000000000000ooooo`00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000ooooooooo`0000000000000000000000003oooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?oooooooooo00000000000000000000003ooooooooooooo0000000000000000003o
ooooooooo`00000000000?ooooooool0000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooo`000?ooool000000000000000000000
003ooooo000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000ooooooooo`00000000000000000000000?ooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooooooo`0000000000000000000?ooooooooooool000000000
000000000?oooooooooo00000000003oooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000ooooo`00ooooool000000000
0000000000000?ooool0000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000ooooooooo`0000000000000000000000oooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?ooooooooooo`000000000000000?oooooooooooooo
o`0000000000000000000?oooooooooo000000000?ooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000ooooo`00oooo
o`000000000000000000003oooooo`00000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooooooo`0000000000000000000?oooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000oooooooooooooooo000000000?oooooo
ooooooooooooo`0000000000000000000?ooooooool000000000ooooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooo`3ooooo000000000000000000000?ooool00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003oooooooooool0000000000000
0000ooooooooo`000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooo00000000000000000000ooooooooool00000003ooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?oooooooooo0000000000000000003oooooo`000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000oooooooooooo
o`0000000000oooooooooooo00000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ooooooooooooooooooooooooooooooooool000000000000000000000ooooooooool000000?oooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooool0000000000000003oooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooooooooooooooooooooooooooooooooooo`0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000?ooooooooooooooooooooooooooooooooooooooo`000000000000000000003oooooooooo`00
003oooooooooo`000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?oooooooooo00000000003ooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000oooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooo00000000000000000000003o
ooooooooo`000?ooooooool000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000003oooooooooooooooooooooooooo`00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo000000000>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>0000000>3Ph>3Ph>3Ph>00003Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000
0000000000000000000000000000003ooooooooooooooooooooooooo003ooooooooo000000000000
00000000003oooooooooo`00ooooooooo`0000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000oooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003oooooooooooooooooooooooooooooooooooooool0
0000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>00h>3P
h>3Ph>3Ph00000000000000000000000000000000000oooooooooooooooooooo00000?ooooooool0
000000000000000000000?oooooooooo003ooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooo`000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
ooooooooool000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3P
h>3Ph000h>3Ph>3Ph>3P0000000000000000000000000000000000000000ooooooooool000000000
ooooooooo`00000000000000000000000?oooooooooo0?ooooooool0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000oooooooooooo
ooooooooooooooooooooo`000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph000h>3Ph>3Ph>3Ph>3P
h000h>3Ph>3Ph>3P003Ph>3Ph>3Ph>00000000000000000000000000000000000000000000000000
00000000003ooooooooo0000000000000000000000000?ooooooooooooooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>0000000>3P
h>3Ph>3Ph>00003Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000000000000000000000000000000000000000
000000000000000000000?oooooooooo000000000000000000000000ooooooooooooooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003Ph>3Ph00000000000
00000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000
000000000000000000000000000000000?ooooooool0000000000000oooooooooooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3P
000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000ooooooooo`00000000000?oooooooooooooo
oooooooooooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000h>3Ph>00000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000
0000000000000000000000000000000000000000000000000000003ooooooooo000000000000oooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000h>3Ph>0000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P
000000000000000000000000000000000000000000000000000000000?oooooooooooooooooo0000
0000003oooooooooooooooooooooooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003Ph>3Ph0000000000000000000003Ph>3Ph00000000>3Ph>3P0000
0000h>3Ph>000000000000000000000000000000000000000000000000000000003ooooooooooooo
ooooool0000000000?ooooooooooooooooooooooooooool000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000>3Ph>3P000000000000000000000>3Ph>3P00000000
h>3Ph>000000003Ph>3Ph00000000000000000000000000000000000000000000000000000000?oo
ooooooooooooooooo`00000000000?ooooooooooooooooooooooooooo`0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000h>3Ph>0000000000000000000000h>3P
h>000000003Ph>3Ph00000000>3Ph>3P000000000000000000000000000000000000000000000000
00000000oooooooooooooooooooo000000000000003ooooooooooooooooooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph000000000000000
00000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P000000000000000000000000000000000000
0000000000000000003oooooooooooooooooool00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003Ph>3Ph000
0000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>00000000000000000000000000
0000000000000000000000000000003oooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0>3Ph>3P000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph000000000000000
00000000000000000000000000000000000000000000ooooooooooooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000h>3Ph>0000000000000000000000h>3Ph>000000003Ph>3Ph>0000000>3Ph>3P0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003Ph>3Ph0000000000000000000003Ph>3Ph>3P00000>3Ph>3Ph>000000
h>3Ph>00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3P00000000000000000>3Ph>3Ph>3Ph>3P0000h>3P
h>3Ph>00003Ph>3Ph>00000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3P000000000000003Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph>000000000000000>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003Ph>3Ph0000000
00000000h>3Ph>3Ph>3Ph03Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph0000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000>3P
h>3P00000000000000000>3Ph>3Ph>3P003Ph>3Ph>3P003Ph>3Ph>3Ph>0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000h>3Ph>000000000000000000000000000000003Ph>3Ph0000000h>3Ph>3P000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000h>3Ph>000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003Ph>3Ph0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000>3Ph>3P00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000h>3Ph>0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph00000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3P
h0000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3P
h>3Ph>3Ph>3P00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000h>3Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000>3Ph>3Ph>3Ph>3Ph00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000R000030000?oooolX0000300000<0000D0000300000d0000V0000
700000<00005000000000000003oool29@0000`0000300009@0000`000040020EP000300002I0000
Q`000:L0002B00001@0007`0J@1b06d0M@1Y0780I@1l06T09@0000`000010000:00000`000030000
9P0001`000030000000000400001000000000RD0000<00000`0005L0000`0000V@0008L0002W0000
TP0000D0001l06T0LP1]07D0J@1b06D0O01Y02D0000<00000@0002P0000<00000`0002H0000L0000
0`000000000200000P000000008U0000300000<0001G0000900000h0002:0000WP0008d000020000
2P1X07D0J@0U000030000040000X0000300000<0000V0000700000<00005000000000000003oool2
9@0000`000030000EP000300000Y0000=P0003@0001500001@0002H0:00V03<08`0^01h0<00V02P0
9@0000`000010000:00000`0000300009P0001`000030000000000400001000000000RD0000<0000
0`0005L0000`0000:@0003H0000d0000A@0000D0000V02P09P0c02<0;P0N03009P0X02D0000<0000
0@0002P0000<00000`0002H0000L00000`000000000200000P000000008U0000300000<0001G0000
900000h0000m0000<@0008d0000200002P1Y02<0;P0U000030000040000X0000300000<0000V0000
700000<00005000000000000003oool29@0000`000030000EP000300000o0000I@0004d0001a0000
1@0003T0B`0c05@0<`1?02h0C@0i04/09@0000`000010000:00000`0000300009P0001`000030000
000000400001000000000RD0000<00000`0005L0000`0000?`0006D0001=0000L@0000D0000i04/0
<`1D03<0C`0^04d0>@1;02D0000<00000@0002P0000<00000`0002H0000L00000`0000D000000000
00000?ooo`8U0000300000<0001F0000<00000d0002600006`0008h0000500002@1Y0140I00C06D0
2`1Z00T0J@1F0000<0000240001j0000;`00080000050000601O0200F`0R05`06P1P01P0G`1F0000
<00003D0001]0000@`0007D0000500009`1F02l0D@0a0580:@1G02L0EP0U000030000040000X0000
300000<0000V0000700000<0000000000@000040000000029@0000`000030000E`0002@0001`0000
3`0000P1000?00000P0005<02P3500X0E`0002@0003S00003`0000P1001S00000P000:T0BP3500X0
E`0002@0003:00003`0000P1000f00000P0009H0:03500X0E`000300000a00003@000><0002;0000
1@0005D02@0T02T0U@0X07X0J02Y04X0E`0002@0001/00003`000740000I00000P0005@02P1@0180
E`0002@0001S0000900006P0000`00000P0004d06P1902<0E`0002@0001I0000>P0005l000150000
0P0004H0:`1203<0E`0002@0001@0000C`0005@0001K00000P0003h0>`0k04@0E`0002@0001=0000
H`0005P0001S00000P0003T0BP1104X0E`0002@0001U0000H`000700001S00000P0004/0BP1C04X0
E`0002@0001m0000H`0008P0001S00000P0005d0BP1U04X0E`0002@0002E0000H`000:00001S0000
0P0006l0BP1g04X0E`0002@0002]0000H`000;P0001S00000P000840BP2904X0E`0002@000360000
H`000=00001S00000P0009<0BP2K04X0E`0002@0003N0000H`000><0001S00000P000:D0BP2Y04X0
600000`000000002DP0004`100040000k_ooo`000000000000000901000100000000<U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^0000k@000000003^000000000>l000000000l000000000000000
00000?8000000000l`000000003d000000000?D000000000mP000000003g000000000?P000000000
n@000000003j000000000?/000000000o0000000003m000000000?h000000000o`00000000000@00
00000000000000000P40000000030@00000000@1000000001@40000000060@00000000L100000000
204000000000000000000000000000000000000000010@410@410@41000U0000300000@0001D0000
E00008T0002>0000U0000:P0000100005l4<@[kj2d9V0000JP000040001<00000000000000000000
00000000001@0000I00000T0000U000030000080000X0000300000@0001B0000C04000@0003^oooo
0000000000000000_08000400000000bE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
9P400000000W0@00000002P100000000:@400000000Z0@00000002/100000000;0400000000]0@00
000002h100000000;`400000000`0@000000034100000000<P400000000c0@00000003@100000000
=@400000000f0@00000003L100000000>0400000000i0@00000003X100000000>`400000000l0@00
000003d100000000?P400000000o0@000000040100000000@@400000000000000000000000000000
000000410@410@410@4002D0000<0000100005@0001D0000U@0008h0002M0000Z@000040000G`@a2
__X;@Vl0001Z00000@0004`000000000000000000000000000000500001b00001`0002D0000<0000
0P0002P0000<000010000580001<0@0010000>koool0000000000000002@0@000@000000039D06T0
K@1U07<0801>06D0M`0P0580K`1]0640KP0005h100000000G`400000001P0@000000064100000000
00000000001S0@00000006@100000000I@400000001V0@00000006L100000000J0400000001Y0@00
000006X100000000J`400000001/0@00000006d100000000KP400000001_0@000000070100000000
L@40000000000000000007<100000000M0400000001e0@00000007H100000000M`400000001h0@00
000007T100000000000000000000000000000000000000000@410@410@410@009@0000`000040000
E00005@0001<0000H`0005L0001m00000@0001O134:nnP]2>00004X000010000C000000000000000
0000000000000000D00006@0000900009@0000`000020000:00000`000040000DP0004`100040000
k_ooo`000000000000000;`2000100000000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
000009L100000000V0400000002I0@00000009X100000000V`400000002L0@00000009d100000000
WP400000002O0@0000000:0100000000X@400000002R0@0000000:<100000000Y0400000002U0@00
00000:H100000000Y`400000002X0@0000000:T100000000ZP400000002[0@0000000:`100000000
[@400000002^0@0000000:l100000000/0400000002a0@0000000;81000000000000000000000000
0000000000010@410@410@41000U0000300000@0001D0000E00005P0001S0000H00007h000010000
5l4<@[kj2d910000BP000040001<0000000000000000000000000000001@0000L`0000L0000U0000
30000080000X0000300000@0001B0000C04000@0003^oooo0000000000000000T04000400000000b
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0003?0@0000000=0100000000d@400000003B0@00
0000000000000000e0400000003E0@0000000=H100000000e`400000003H0@0000000=T100000000
fP400000003K0@0000000=`100000000g@400000003N0@0000000=l100000000h0400000003Q0@00
00000>810000000000000000003T0@00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000410@410@410@4002D0000<0000
100005@0001D0000400002T0000K0000@`000040000G`@a2__X;@P/0000N00000@0004`000000000
000000000000000000000500001T00002@0002D0000<00000P0002P0000<000010000580001<0@00
10000>koool0000000000000002l0P000@000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000@410@410@410@009@0000`000040000E00005@0000L0000:@00028000140000
0@0001O134:nnP]2500001h000010000C0000000000000000000000000000000D00007@000050000
9@0000`000010000:00000`0000300009P0001`0000300001@00000000000000oooo0RD0000<0000
0`0005H0000`0000204002T0000G0@00=00000D0003@01h0b@0V0<X08@3501l0d00N02D0000<0000
0@0002P0000<00000`0002H0000L00000`000000000100000@000000008U0000300000<0001G0000
<00000P1000Y00005`4003@000050000d00N0<T09P3:0240a@0O0=007P0U000030000040000X0000
300000<0000V0000700000<0000000000P000080000000029@0000`000030000E`0002@0003J0000
;0000101001;00000P000:<0=`3:02408P0000`0003ooooo:00000`000030000:00000`000040000
:00000`000010000:00000`000020000B`000100000000001@0000h0000D100000400100003oool0
00100000P0000?l00200000P@0008800023o00100000@40004200010o`00H0000610001PP000H?l0
08000020@000P800083o002P0000X4000:20002Po`00`0000<100030P000`?l00?l0003o@000oh00
0?oo0200000P040080200200o`0P80008210020PP00P8?l084000210@00P@800843o021P000PH400
8620021Po`0PP00088100220P00PP?l08:00022P@00PX8008:3o0230000P`4008<200230o`0Po`00
8?m0023oP00Pool0@0000400@0100800@03o040P00108400@220040Po`10@000@4100410P010@?l0
@600041P@010H800@63o04200010P400@8200420o`10X000@:10042PP010X?l0@<000430@010`800
@<3o043o0010od00@?n0043oo`1P0000H0100600P01P0?l0H200060P@01P8800H23o0610001P@400
H4200610o`1PH000H610061PP01PH?l0H8000620@01PP800H83o062P001PX400H:20062Po`1P`000
H<100630P01P`?l0H?l0063o@01Poh00H?oo080000200400P0200800o`208000P210080PP0208?l0
P4000810@020@800P43o081P0020H400P620081Po`20P000P8100820P020P?l0P:00082P@020X800
P:3o08300020`400P<200830o`20o`00P?m0083oP020ool0X0000:00@02P0800X03o0:0P002P8400
X2200:0Po`2P@000X4100:10P02P@?l0X6000:1P@02PH800X63o0:20002PP400X8200:20o`2PX000
X:100:2PP02PX?l0X<000:30@02P`800X<3o0:3o002Pod00X?n00:3oo`300000`0100<00P0300?l0
`2000<0P@0308800`23o0<100030@400`4200<10o`30H000`6100<1PP030H?l0`8000<20@030P800
`83o0<2P0030X400`:200<2Po`30`000`<100<30P030`?l0`?l00<3o@030oh00`?oo0?l0003o0400
o`200?l0o`3o8000ob100?lPP03o8?l0od000?m0@03o@800od3o0?mP003oH400of200?mPo`3oP000
oh100?n0P03oP?l0oj000?nP@03oX800oj3o0?o0003o`400ol200?o0o`3oo`00oom00?ooP0000000
50@0
\>"], "Graphics",
  Editable->False,
  ImageSize->{328, 153.625},
  ImageMargins->{{290, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
The edges of the infinitesimal block of material (figure), are the vectors,\
\>", "Text"],

Cell[BoxData[
    \({d\[DoubleStruckR], d\[DoubleStruckS], d\[DoubleStruckT]}\)], "Input"],

Cell[TextData[{
  "The face on the right hand side is ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["dA", 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["l",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ l]],
                Editable->False], 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["l",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ l], ShowContents -> False]],
                Editable->False]],
            Subsuperscript[ dA, 
              SequenceForm[ 
                red[ l]], 
              SequenceForm[ 
                StyleForm[ 
                  red[ l], ShowContents -> False]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]], "Output"],
  " equal to,"
}], "Text"],

Cell[BoxData[{\(\((\(d\[DoubleStruckS]\[Cross]
                d\[DoubleStruckT] // \(LinearBreakout[
                  Cross]\)[\[DoubleStruckE]d[_], \[DoubleStruckE]u[_]]\) // 
            CrossProductExpansion[\[DoubleStruckE], e, 
              h])\) . \[DoubleStruckE]d[red@l];\), "\[IndentingNewLine]", 
    RowBox[{\(d\[ScriptCapitalA]d[red@l_]\), "=", 
      RowBox[{"%", "//", 
        RowBox[{"EvaluateDotProducts", "[", 
          RowBox[{
            FormBox["\[DoubleStruckE]",
              "TraditionalForm"], ",", "g"}], "]"}]}]}]}], "Input"],

Cell["\<\
The difference between the forces applied on opposite faces are then given \
by,\
\>", "Text"],

Cell[BoxData[{
    \(CovariantD[
            dAd[red@l] \[Sigma]uu[red@l, red@m] \[DoubleStruckE]d[red@m], 
            red@i] dru[red@i] /. CovariantD[dAd[red@l], red@i] \[Rule] 0 // 
      CovariantDSimplify[\[DoubleStruckE], g]\), "\[IndentingNewLine]", 
    \(force1 = 
      Coefficient[% /. dAd[red@l] \[Rule] d\[ScriptCapitalA]d[red@l], 
        dru[red@i] dsu[red@j] dtu[red@k]]\)}], "Input"],

Cell["\<\
Similar expression are obtained for the two others opposite faces, and \
globally we have\
\>", "Text"],

Cell[BoxData[{
    \(force2 = 
      force1 // IndexChange[{{i, j}, {j, k}, {k, 
              i}}]\), "\[IndentingNewLine]", 
    \(force3 = force2 // IndexChange[{{i, j}, {j, k}, {k, i}}]\)}], "Input"],

Cell[BoxData[
    \(res1 = \((force1 + force2 + force3)\) dru[red@i] dsu[red@j] dtu[red@k] // 
        Factor\)], "Input"],

Cell["\<\
This expression is identical to (see also the section treating the Gauss \
theorem in three dimensions, for a similar result)\
\>", "Text"],

Cell[BoxData[
    \(res2 = 
      dru[red@i] dsu[red@j] dtu[red@k] 
        CovariantD[\[Sigma]uu[red@l, red@m], red@l] 
        eddd[red@i, red@j, red@k] \[DoubleStruckE]d[red@m]\)], "Input"],

Cell[BoxData[
    \(\((\(\(res1 // SumExpansion[red@i, red@j, red@k, red@l]\) // 
            LeviCivitaSimplify[e]\) // 
          Simplify)\) \[Equal] \((\(\(res2 // 
              SumExpansion[red@i, red@j, red@k, red@l]\) // 
            LeviCivitaSimplify[e]\) // Simplify)\)\)], "Input"],

Cell[TextData[{
  "In addition, we see that ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["dr", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ i]],
                      Editable->False]],
                  Subsuperscript[ dr, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ i]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["ds", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ j]],
                      Editable->False]],
                  Subsuperscript[ ds, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ j]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["dt", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ k], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["k",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ k]],
                      Editable->False]],
                  Subsuperscript[ dt, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ k], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ k]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["e", 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ i], 
                        red[ j], 
                        red[ k]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          red[ k], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ e, 
                    SequenceForm[ 
                      red[ i], 
                      red[ j], 
                      red[ k]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      StyleForm[ 
                        red[ k], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]], "Output"],
  " is the volume  ",
  Cell[BoxData[
      \(TraditionalForm\`d\[ScriptCapitalV]\)], "Output"],
  " of the block, so that the resultant of all the stresses is"
}], "Text"],

Cell[BoxData[
    \(TotalStress = \((res2 /. 
            dru[red@i] dsu[red@j] dtu[red@k] 
                eddd[red@i, red@j, red@k] \[Rule] d\[ScriptCapitalV])\) // 
        IndexChange[{{m, i}, {l, j}}]\)], "Input"],

Cell["Superposed to the stress we can have an external force ", "Text"],

Cell[BoxData[
    \(ExternalForce = Xu[red@i] \[DoubleStruckE]d[red@i]\)], "Input"],

Cell["The system is in equilibrium if", "Text"],

Cell[BoxData[
    \(TotalStress + ExternalForce \[Equal] 0\ \ \  // FullSimplify\)], "Input"],

Cell[TextData[StyleBox["Condition of Equilibrium :",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\((TotalForce = %[\([1, 
                2]\)])\) \[Equal] 0\[IndentingNewLine]]\)], "Input"],

Cell["\<\
The equilibrium of the moments is itself satisfied by the symmetry of the \
stress tensor (as shown in the above section on the stress tensor).\
\>", "Text"],

Cell[CellGroupData[{

Cell["Dynamic equation ", "Subsection"],

Cell[TextData[{
  "In the limit of ",
  StyleBox["small ",
    FontSlant->"Italic"],
  "motion the Lagrangian or particle formulation and the Eulerian or field \
formulation coincide. We can associate a certain time dependent velocity to \
each particle, but since the particle always stay close to the position it \
has at rest, the same velocity is also associated with that point in space."
}], "Text"],

Cell[BoxData[
    \(\[DoubleStruckU]\& .  = 
      PartialD[\[DoubleStruckU], 
          t] /. \(\(PartialD[\[DoubleStruckE]d[_], 
            t]\)\(\[Rule]\)\(0\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\)\( (*\ \ t\ is\ the\ time\ parameter\ \ \ *) \)\)\)], "Input"],

Cell[BoxData[
    \(Tensor[OverDot[u, 2], {red@i}, {Void}] \[DoubleStruckE]d[red@i] == 
        PartialD[\[DoubleStruckU]\& . , t] /. 
      PartialD[\[DoubleStruckE]d[_], t] \[Rule] 0\)], "Input"],

Cell["\<\
If  \[Rho]  is the mass density, we have the dynamic equation,\
\>", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]TotalForce[\([2, 
            2]\)] \[Equal] \((totalforce = \[Rho]\ Tensor[
                  OverDot[u, 2], {red@i}, {Void}] - 
              TotalForce[\([1]\)])\)\[IndentingNewLine]]\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fundamental Equations of the theory of Elasticity", "Section",
  CellTags->"Fundamental Equations"],

Cell[TextData[{
  "We have the basic equations describing the equilibrium and the small \
motions of an elastic solid :\n\n",
  StyleBox["(1) the kinematic relation\t\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[ScriptCapitalE]", 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ \[ScriptCapitalE], 
                SequenceForm[ 
                  red[ i], 
                  red[ j]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], "==", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["u", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ";", 
                                red[ j]],
                              Editable->False],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ i], 
                          Cov[ 
                            red[ j]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ j]],
                                  Editable->False],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            Cov[ 
                              red[ j]], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ u, 
                      SequenceForm[ 
                        red[ i], 
                        Cov[ 
                          red[ j]]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          Cov[ 
                            red[ j]], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "+", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["u", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ";", 
                                red[ i]],
                              Editable->False],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ j], 
                          Cov[ 
                            red[ i]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ i]],
                                  Editable->False],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            Cov[ 
                              red[ i]], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ u, 
                      SequenceForm[ 
                        red[ j], 
                        Cov[ 
                          red[ i]]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          Cov[ 
                            red[ i]], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], ")"}]}]}], TraditionalForm]],
    FontSize->16],
  StyleBox["\n",
    FontSize->16],
  StyleBox["\n(2) the equilibrium condition\t\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["X", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ X, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"], "+", 
            RowBox[{"d\[ScriptCapitalV]", " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Sigma]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ";", 
                              red[ j]],
                            Editable->False],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        Cov[ 
                          red[ j]]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              InterpretationBox[
                                RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ ";", 
                                  red[ j]],
                                Editable->False],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ j], 
                        red[ i], 
                        StyleForm[ 
                          Cov[ 
                            red[ j]], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[Sigma], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      Cov[ 
                        red[ j]]], 
                    SequenceForm[ 
                      red[ j], 
                      red[ i], 
                      StyleForm[ 
                        Cov[ 
                          red[ j]], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}]}], "==", "0", "\[InvisibleSpace]"}], 
        TraditionalForm]],
    FontSize->16],
  StyleBox["\t\tor the dynamic equation\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    FormBox[
                      InterpretationBox[
                        RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ ";", 
                          red[ j]],
                        Editable->False],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    Cov[ 
                      red[ j]]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ";", 
                              red[ j]],
                            Editable->False],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    red[ j], 
                    red[ i], 
                    StyleForm[ 
                      Cov[ 
                        red[ j]], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ \[Sigma], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ j], ShowContents -> False], 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  Cov[ 
                    red[ j]]], 
                SequenceForm[ 
                  red[ j], 
                  red[ i], 
                  StyleForm[ 
                    Cov[ 
                      red[ j]], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], "==", 
          RowBox[{
            RowBox[{"\[Rho]", " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox[\(u\&\[DoubleDot]\), 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ i]],
                      Editable->False]],
                  Subsuperscript[ 
                    OverDot[ u, 2], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ i]]],
                  Editable->False],
                "TraditionalForm"]}], "-", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["X", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ X, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"], "\[InvisibleSpace]"}]}], TraditionalForm]],
    FontSize->16],
  StyleBox["\n\t\t",
    FontSize->16],
  StyleBox["\n(3) the Hooke's laws\t\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j]],
                  Editable->False]],
              Subsuperscript[ \[Sigma], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i], 
                  red[ j]]],
              Editable->False],
            "TraditionalForm"], "\[InvisibleSpace]", "\<\" = \"\>", 
          "\[InvisibleSpace]", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ l], 
                      red[ m]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ l], ShowContents -> False], 
                      StyleForm[ 
                        red[ m], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ l], 
                    red[ m]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ l], ShowContents -> False], 
                    StyleForm[ 
                      red[ m], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      StyleForm[ 
                        red[ l], ShowContents -> False], 
                      StyleForm[ 
                        red[ m], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j], 
                      red[ l], 
                      red[ m]],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    StyleForm[ 
                      red[ l], ShowContents -> False], 
                    StyleForm[ 
                      red[ m], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j], 
                    red[ l], 
                    red[ m]]],
                Editable->False],
              "TraditionalForm"]}]}], TraditionalForm]],
    FontSize->16],
  StyleBox["\n",
    FontSize->16],
  StyleBox["\n\tand\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["p",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ p]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ p], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    red[ p]], 
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      red[ p], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            FractionBox[
              RowBox[{"\[CapitalEpsilon]", " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[ScriptCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              red[ p]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              red[ i], 
                              StyleForm[ 
                                red[ p], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[ScriptCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            red[ p]], 
                          SequenceForm[ 
                            red[ i], 
                            StyleForm[ 
                              red[ p], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "+", 
                    FractionBox[
                      RowBox[{"\[Nu]", " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["g", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ p]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ p], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ g, 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ p]], 
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ p], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"], " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[ScriptCapitalE]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False], 
                                  red[ m]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ m], 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[ScriptCapitalE], 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ m], ShowContents -> False], 
                                red[ m]], 
                              SequenceForm[ 
                                red[ m], 
                                StyleForm[ 
                                  red[ m], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"]}], \(1 - 2\ \[Nu]\)]}], 
                  ")"}]}], \(\[Nu] + 1\)]}]}], TraditionalForm]],
    FontSize->16],
  StyleBox["\tor\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["p",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ p]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ p], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    red[ p]], 
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      red[ p], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            RowBox[{
              RowBox[{"2", " ", "\[Mu]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          red[ p]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ i], 
                          StyleForm[ 
                            red[ p], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ p]], 
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ p], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], "+", 
              RowBox[{"\[Lambda]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          red[ p]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ i], 
                          StyleForm[ 
                            red[ p], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ p]], 
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ p], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          red[ m]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ m], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ m], ShowContents -> False], 
                        red[ m]], 
                      SequenceForm[ 
                        red[ m], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[InvisibleSpace]"}]}]}]}], 
        TraditionalForm]],
    FontSize->16],
  "\n\t\nThey form 6+3+6 = 15 component equations, which contain 15 unknowns \
(6 ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]],
    FontSize->16],
  ", 6 ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[Sigma]", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"], "\[InvisibleSpace]", 
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"]}],
                SequenceForm[ 
                  red[ i], 
                  red[ j]],
                Editable->False]],
            Subsuperscript[ \[Sigma], 
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False], 
                StyleForm[ 
                  red[ j], ShowContents -> False]], 
              SequenceForm[ 
                red[ i], 
                red[ j]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]],
    FontSize->16],
  ", and 3 ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["u", 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ") . \nWe recall first here the Hooke's laws :"
}], "Text"],

Cell[BoxData[
    \(\[Sigma]\[Section]uu[i_, j_] := 
      Tensor[\[ScriptCapitalE], {Void, Void}, {l, 
            m}]\ Tensor[\[DoubleStruckCapitalE], {i, j, l, m}, {Void, Void, 
            Void, Void}]\)], "Input",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\[Sigma]\[Section]\[Section]ud[i_, 
        j_] := \((\[CapitalEpsilon]*\((Tensor[\[ScriptCapitalE], {i, 
                    Void}, {Void, 
                    j}] + \((\[Nu]*Tensor[g, {i, Void}, {Void, j}]*
                      Tensor[\[ScriptCapitalE], {m, Void}, {Void, 
                          m}])\)/\((1 - 
                      2*\[Nu])\))\))\)/\((1 + \[Nu])\)\)], "Input",
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  StyleBox["If the material is anisotropic",
    FontColor->RGBColor[0, 0, 1]],
  ", we have from (2) and (3)"
}], "Text"],

Cell[BoxData[
    \(CovariantD[\((\[Sigma]\[Section]uu[i, j] // 
              ToFlavor[red])\) /. \[ScriptCapitalE]dd[red@i_, 
              red@j_] -> \[ScriptCapitalE]\[Section]dd[red@i, red@j], 
        red@j] \[Equal] totalforce\)], "Input"],

Cell[TextData[{
  StyleBox["If the material is anisotropic but homogeneous",
    FontColor->RGBColor[0, 0, 1]],
  ", the covariant derivative of the elastic modulus vanishes,"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]% /. 
        CovariantD[\[DoubleStruckCapitalE]uuuu[i_, j_, k_, l_], m_] \[Rule] 
          0\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  StyleBox["If the material is isotropic",
    FontColor->RGBColor[0, 0, 1]],
  ", we have (we first calculate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j]],
                  Editable->False]],
              Subsuperscript[ \[Sigma], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i], 
                  red[ j]]],
              Editable->False],
            "TraditionalForm"], "\[InvisibleSpace]"}], TraditionalForm]],
    FontSize->16],
  " as a function of the displacements),"
}], "Text"],

Cell[BoxData[
    \(\(\((\(\(\[Sigma]\[Section]\[Section]ud[i, p] guu[p, j] // 
                  ToFlavor[red]\) // Expand\) // 
              MetricSimplify[g])\) /. {\[ScriptCapitalE]uu[red@i_, 
                red@j_] -> \[ScriptCapitalE]\[Section]dd[red@p, red@q] 
                guu[red@p, red@i] guu[red@q, red@j], \[ScriptCapitalE]ud[
                red@i_, 
                red@i_] -> \[ScriptCapitalE]\[Section]dd[red@p, red@i] 
                guu[red@p, red@i]} // Expand\) // 
      MetricSimplify[g]\)], "Input"],

Cell[BoxData[
    \(\[Sigma]uu[red@i, red@j] == % /. 
        Tensor[u, {Void, Cov@\(red@p\)}, {red@p, Void}] -> 
          CovariantD[uu[red@p], red@p] // FullSimplify\)], "Input"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\((\(\(\(\(CovariantD[%[\([2]\)], 
                      red@j] // CovariantDSimplify[\[DoubleStruckE], g]\) // 
                  MetricSimplify[g]\) // IndexChange[{{p, j}}]\) // 
              SymmetricStandardOrder[u, {2, 3}]\) // Simplify)\) \[Equal] 
        totalforce]\)], "Input"],

Cell["\<\
This fundamental equation can also be expressed using Lame moduli,\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(LameRule := {\[CapitalEpsilon] \[Rule] \(\[Mu]\ \((3\ \
\[Lambda] + 2\ \[Mu])\)\)\/\(\[Lambda] + \[Mu]\), \[Nu] \[Rule] \
\[Lambda]\/\(2\ \((\[Lambda] + \[Mu])\)\)}\)\)\)], "Input",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\((kin = %%[\([2]\)] /. LameRule // 
            Simplify)\)\[IndentingNewLine]]\)], "Input"],

Cell["Taking the divergence of the above equation,", "Text"],

Cell[BoxData[{
    \(\(\((\(kin[\([1]\)]\ \[DoubleStruckE]d[red@i] // Expand\) // 
            TDiv[\[DoubleStruckE], g, 
              red@i])\) \[Equal] \((\(kin[\([2]\)]\ \[DoubleStruckE]d[red@i] // 
              Expand\) // TDiv[\[DoubleStruckE], g, red@i])\);\)\), "\n", 
    \(divkin = \((\(\((%[\([1, 1]\)] // 
                    IndexChange[{{i, j}, {j, i}}])\) + %[\([1, {2, 3, 4}]\)] // 
              SymmetricStandardOrder[u, {2, 4}]\) // 
            Simplify)\) \[Equal] %[\([2]\)]\)}], "Input"],

Cell["\<\
We can then introduce the Laplace operator and write using the preceding \
identification,\
\>", "Text"],

Cell[BoxData[
    RowBox[{\((\(TLaplacian[\[DoubleStruckE], g, red@i, red@h]\)[
            uud[red@j, Cov[red@j]]] // SymmetricStandardOrder[u, {2, 4}])\), 
      "->", \(\[CapitalDelta][uud[red@i, Cov[red@i]]]\), "  ", 
      RowBox[{"(*", " ", 
        RowBox[{
        "we", " ", "have", " ", "changed", " ", "the", " ", "index", " ", 
          StyleBox["j",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["  ",
            FontColor->RGBColor[1, 0, 0]], "into", 
          StyleBox[" ",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["i",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0]]}], 
        StyleBox["  ",
          FontColor->RGBColor[1, 0, 0]], "*)"}]}]], "Input"],

Cell["\<\
so that the preceding equation is simply in absence of external force,\
\>", "Text"],

Cell[BoxData[{
    \(\((divkin /. 
        Xud[red@i, Cov[red@i]] \[Rule] 0)\)\), "\[IndentingNewLine]", 
    \(ResultFrame[%[\([1]\)]/\((\[Lambda] + 
                2\ \[Mu])\) == %[\([2]\)]/\((\[Lambda] + 2\ \[Mu])\) \[Equal] 
          c^2\ %[\([2]\)]/\[Rho] /. %%]\)}], "Input"],

Cell["\<\
where  c has the dimension of a velocity.
A second important equation is obtained when taking the curl of equation \
(6.8) :\
\>", "Text"],

Cell[BoxData[
    \(\(\@g[
                red]\) \((\((\(kin[\([1]\)]\ \[DoubleStruckE]d[red@i] // 
                      Expand\) // 
                    TCurl[\[DoubleStruckE], g, red /@ {k, l, m}, 
                      e])\) /. \(LeviCivitaRule[e, \[Epsilon]]\)[g, red] // 
              Simplify)\) \[Equal] \(\@g[
                red]\) \((\(kin[\([2]\)]\ \[DoubleStruckE]d[red@i] // 
                Expand\) // 
              TCurl[\[DoubleStruckE], g, red /@ {k, l, m}, 
                e])\) /. \(LeviCivitaRule[e, \[Epsilon]]\)[g, red]\)], "Input"],

Cell[TextData[{
  "The second term in the parenthesis gives zero (antisymmetric combination \
of a symmetric tensor with respect to {",
  StyleBox["k",
    FontColor->RGBColor[1, 0, 0]],
  ", ",
  StyleBox["l",
    FontColor->RGBColor[1, 0, 0]],
  "})"
}], "Text"],

Cell[BoxData[
    \(curlkin = 
      Factor[Coefficient[\((%[\([1]\)] /. %[\([1, 1, 2]\)] \[Rule] 
                    0)\) - %[\([2]\)], \[DoubleStruckE]d[red@m]]] \[Equal] 
        0\)], "Input"],

Cell["and introducing the laplacian", "Text"],

Cell[BoxData[
    \(\(\((\(TLaplacian[\[DoubleStruckE], g, red@j, red@i]\)[
            udd[red@l, Cov[red@k]]] // 
          SymmetricStandardOrder[u, {2, 4}])\)\(->\)\(\[CapitalDelta][
        udd[red@l, Cov[red@k]]]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(ResultFrame[\ \((res = %%[\([1]\)] /. %)\) \[Equal] 0]\)], "Input"],

Cell["\<\
An up-down swap of the indices gives an equivalent expression : \
\>", "Text"],

Cell[BoxData[
    \(\(\((UpDownSwap[
                red@k] /@ \(UpDownSwap[
                  red@l] /@ \((curlkin[\([1]\)] // 
                    Expand)\)\))\) /. \[Epsilon]ddu[i_, j_, 
              k_] \[Rule] \[Epsilon]ddd[i, j, k] // 
        SymmetricStandardOrder[u, {2, 4}]\) // Factor\)], "Input"],

Cell[BoxData[
    \(\(\((\(TLaplacian[\[DoubleStruckE], g, red@j, red@i]\)[
            uuu[red@l, Cov[red@k]]] // 
          SymmetricStandardOrder[u, {2, 4}])\)\(->\)\(\[CapitalDelta][
        uuu[red@l, Cov[red@k]]]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(ResultFrame[\ \((res = %% /. %)\) \[Equal] 0]\)], "Input"],

Cell["When there is no force in equ. (6.10) ", "Text"],

Cell[BoxData[
    \(ResultFrame[\((\(\(-res\)/\[Mu] /. 
                res[\([2, 1]\)] \[Rule] 0\) /. \[Rho] \[Rule] \[Mu]\ c\^2 // 
            Simplify)\) \[Equal] 0]\)], "Input"],

Cell["with  ", "Text"],

Cell[BoxData[
    \(\(c == \@\(\[Rho]\/\[Mu]\);\)\)], "Input"],

Cell[TextData[{
  "Any solution of equ. (6.8) without external force, must satisfy equ. (6.9) \
and (6.10). \n\tEquation (5.10) has a trivial solution ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["u", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["l",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ k]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ l], 
              Cov[ 
                red[ k]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["l",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ k]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ l], ShowContents -> False], 
              StyleForm[ 
                Cov[ 
                  red[ k]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Epsilon]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["k",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["l",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ k], ShowContents -> False], 
              StyleForm[ 
                red[ l], ShowContents -> False], 
              StyleForm[ 
                red[ m], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["k",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["l",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ k], 
              red[ l], 
              red[ m]],
            Editable->False]], TraditionalForm]]],
  "= 0, or  Curl [\[DoubleStruckU]] = 0.\nA vector field which satisfies this \
condition derives from a potential ",
  StyleBox["\[Phi]",
    FontWeight->"Bold"],
  ", the displacement potential."
}], "Text"],

Cell[BoxData[{
    \(\(T\[Phi] = Tensor[\[Phi], {}, {}];\)\), "\[IndentingNewLine]", 
    \(\[DoubleStruckU] := \(TGrad[\[DoubleStruckE], red@i]\)[
        T\[Phi]]\), "\[IndentingNewLine]", 
    \(uu[red@j_] := \[DoubleStruckU] . \[DoubleStruckE]u[red@j] // 
        EvaluateDotProducts[\[DoubleStruckE], g]\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox["to be continued ...",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Section",
  TextAlignment->Center,
  TextJustification->0,
  Background->RGBColor[1, 0.658824, 1]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"], None, Cell[ 
      "J.-F. Gouyet", "Header"]}, {
    Cell[ "Continuum Mechanics", "Header"], None, Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{True, True},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->True,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
ShowCellLabel->False,
CellLabelAutoDelete->True,
ShowCellTags->True,
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Kinematic Relations"->{
    Cell[5415, 155, 73, 1, 55, "Section",
      CellTags->"Kinematic Relations"]},
  "Condition of Equilibrium and Equation of Motion"->{
    Cell[28446, 693, 129, 1, 55, "Section",
      CellTags->"Condition of Equilibrium and Equation of Motion"]},
  "Fundamental Equations"->{
    Cell[146910, 2401, 105, 1, 55, "Section",
      CellTags->"Fundamental Equations"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Kinematic Relations", 239379, 4604},
  {"Condition of Equilibrium and Equation of Motion", 239517, 4607},
  {"Fundamental Equations", 239659, 4610}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 77, 3, 131, "Title"],

Cell[CellGroupData[{
Cell[1878, 60, 64, 1, 49, "Subsection",
  InitializationCell->True],
Cell[1945, 63, 448, 10, 146, "Input",
  InitializationCell->True],
Cell[2396, 75, 498, 9, 166, "Input",
  InitializationCell->True],
Cell[2897, 86, 647, 10, 66, "Input",
  InitializationCell->True],
Cell[3547, 98, 1069, 29, 159, "Input",
  InitializationCell->True],
Cell[4619, 129, 61, 1, 46, "Input"],
Cell[4683, 132, 287, 5, 86, "Input"],
Cell[4973, 139, 69, 1, 34, "Text",
  InitializationCell->True],
Cell[5045, 142, 211, 4, 46, "Input",
  InitializationCell->True],
Cell[5259, 148, 119, 2, 46, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5415, 155, 73, 1, 55, "Section",
  CellTags->"Kinematic Relations"],
Cell[5491, 158, 503, 9, 75, "Text"],
Cell[5997, 169, 334, 6, 142, "Input"],
Cell[6334, 177, 88, 2, 34, "Text"],
Cell[6425, 181, 323, 5, 102, "Input"],
Cell[6751, 188, 9652, 195, 56, "Text"],
Cell[16406, 385, 107, 2, 58, "Input"],
Cell[16516, 389, 42, 0, 34, "Text"],
Cell[16561, 391, 199, 3, 58, "Input"],
Cell[16763, 396, 31, 0, 34, "Text"],
Cell[16797, 398, 206, 3, 102, "Input"],
Cell[17006, 403, 41, 0, 34, "Text"],
Cell[17050, 405, 237, 4, 66, "Input"],
Cell[17290, 411, 1168, 32, 34, "Text"],

Cell[CellGroupData[{
Cell[18483, 447, 46, 0, 49, "Subsection"],
Cell[18532, 449, 5961, 161, 35, "Text"],
Cell[24496, 612, 762, 12, 181, "Input"],
Cell[25261, 626, 208, 6, 35, "Text"],
Cell[25472, 634, 1074, 18, 286, "Input"],
Cell[26549, 654, 218, 4, 34, "Text"],
Cell[26770, 660, 696, 10, 113, "Input"],
Cell[27469, 672, 61, 0, 34, "Text"],
Cell[27533, 674, 864, 13, 134, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[28446, 693, 129, 1, 55, "Section",
  CellTags->"Condition of Equilibrium and Equation of Motion"],

Cell[CellGroupData[{
Cell[28600, 698, 5526, 87, 126, 5413, 83, "GraphicsData", "PICT", \
"Graphics"],
Cell[34129, 787, 96726, 1198, 162, 96609, 1194, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],
Cell[130870, 1988, 99, 2, 34, "Text"],
Cell[130972, 1992, 90, 1, 46, "Input"],
Cell[131065, 1995, 1534, 43, 34, "Text"],
Cell[132602, 2040, 558, 10, 66, "Input"],
Cell[133163, 2052, 104, 3, 34, "Text"],
Cell[133270, 2057, 400, 7, 86, "Input"],
Cell[133673, 2066, 113, 3, 34, "Text"],
Cell[133789, 2071, 203, 4, 66, "Input"],
Cell[133995, 2077, 122, 2, 46, "Input"],
Cell[134120, 2081, 149, 3, 34, "Text"],
Cell[134272, 2086, 192, 4, 46, "Input"],
Cell[134467, 2092, 293, 5, 66, "Input"],
Cell[134763, 2099, 9828, 231, 35, "Text"],
Cell[144594, 2332, 218, 4, 66, "Input"],
Cell[144815, 2338, 71, 0, 34, "Text"],
Cell[144889, 2340, 83, 1, 46, "Input"],
Cell[144975, 2343, 47, 0, 34, "Text"],
Cell[145025, 2345, 93, 1, 46, "Input"],
Cell[145121, 2348, 133, 2, 34, "Text"],
Cell[145257, 2352, 144, 2, 86, "Input"],
Cell[145404, 2356, 167, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[145596, 2363, 39, 0, 49, "Subsection"],
Cell[145638, 2365, 405, 8, 54, "Text"],
Cell[146046, 2375, 273, 5, 46, "Input"],
Cell[146322, 2382, 197, 3, 46, "Input"],
Cell[146522, 2387, 86, 2, 34, "Text"],
Cell[146611, 2391, 250, 4, 86, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[146910, 2401, 105, 1, 55, "Section",
  CellTags->"Fundamental Equations"],
Cell[147018, 2404, 71503, 1637, 318, "Text"],
Cell[218524, 4043, 253, 5, 46, "Input"],
Cell[218780, 4050, 439, 8, 86, "Input"],
Cell[219222, 4060, 138, 4, 34, "Text"],
Cell[219363, 4066, 246, 4, 66, "Input"],
Cell[219612, 4072, 187, 4, 34, "Text"],
Cell[219802, 4078, 178, 3, 86, "Input"],
Cell[219983, 4083, 3073, 78, 37, "Text"],
Cell[223059, 4163, 528, 9, 86, "Input"],
Cell[223590, 4174, 181, 3, 66, "Input"],
Cell[223774, 4179, 340, 5, 86, "Input"],
Cell[224117, 4186, 90, 2, 34, "Text"],
Cell[224210, 4190, 246, 4, 60, "Input"],
Cell[224459, 4196, 144, 2, 86, "Input"],
Cell[224606, 4200, 60, 0, 34, "Text"],
Cell[224669, 4202, 511, 8, 106, "Input"],
Cell[225183, 4212, 114, 3, 34, "Text"],
Cell[225300, 4217, 772, 18, 66, "Input"],
Cell[226075, 4237, 94, 2, 34, "Text"],
Cell[226172, 4241, 283, 5, 66, "Input"],
Cell[226458, 4248, 148, 4, 54, "Text"],
Cell[226609, 4254, 560, 10, 90, "Input"],
Cell[227172, 4266, 264, 9, 34, "Text"],
Cell[227439, 4277, 197, 4, 46, "Input"],
Cell[227639, 4283, 45, 0, 34, "Text"],
Cell[227687, 4285, 241, 4, 66, "Input"],
Cell[227931, 4291, 87, 1, 46, "Input"],
Cell[228021, 4294, 88, 2, 34, "Text"],
Cell[228112, 4298, 309, 6, 66, "Input"],
Cell[228424, 4306, 241, 4, 66, "Input"],
Cell[228668, 4312, 78, 1, 46, "Input"],
Cell[228749, 4315, 54, 0, 34, "Text"],
Cell[228806, 4317, 182, 3, 46, "Input"],
Cell[228991, 4322, 22, 0, 34, "Text"],
Cell[229016, 4324, 62, 1, 69, "Input"],
Cell[229081, 4327, 5883, 156, 76, "Text"],
Cell[234967, 4485, 322, 5, 86, "Input"]
}, Closed]],
Cell[235304, 4493, 192, 5, 57, "Section"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

