(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4341,        133]*)
(*NotebookOutlinePosition[      5335,        167]*)
(*  CellTagsIndexPosition[      5261,        161]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["TensorNesting", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData["\<\"TensorNesting[\\!\\(\\* StyleBox[\\\"T\\\",\\nFontSlant->\
\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"[\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"expr\\\",\\nFontSlant->\\\"Italic\\\"]\\)]\"\>"]],
  "reexpresses in expr covariant (or partial) derivatives of a tensor T, \
Tensor[T,{...,Void},{...,Cov[_]}] into a nested form \
Tensor[Tensor[T,{...},{...}],{Void},{Cov[_]}], which allows aesy replacements \
of parts of the derivatives of T. This operation also works in the case of \
contravariant derivatives."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "See also: ",
  ButtonBox["TensorUnNesting",
    ButtonData:>{"TensorUnNesting"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(Needs["\<TContinuumMechanics1`TContinuumMechanics`\>"]\)}], "Input",
  CellLabel->"In[1]:="],

Cell["Save old settings and declare a flavor...", "Text"],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "The replacement  T",
  Cell[BoxData[
      \(TraditionalForm\` -> \)]],
  "U does not work directly on the partial derivative of T,"
}], "Text"],

Cell[BoxData[
    \(PartialD[Tensor[T, {i, j}, {Void, Void}], k] /. 
      Tensor[T, {i, j}, {Void, Void}] -> \(1\/2\) 
          Tensor[U, {i, j}, {Void, Void}]\)], "Input",
  CellLabel->"In[6]:="],

Cell["After nesting, the replacement becomes possible", "Text"],

Cell[BoxData[{
    \(% // TensorNesting[T]\), "\[IndentingNewLine]", 
    \(% /. Tensor[T, {i, j}, {Void, Void}] -> \(1\/2\) 
          Tensor[U, {i, j}, {Void, Void}]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[7]:="],

Cell["Unnesting again reestablishes the standard tensorial form.", "Text"],

Cell[BoxData[{
    \(% // TensorUnNesting[U]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[{
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldflavors]\)}], "Input",
  CellLabel->"In[12]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{674, 669},
WindowMargins->{{46, Automatic}, {Automatic, 1}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 60, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1839, 56, 694, 13, 66, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5090, 152}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1839, 56, 694, 13, 66, "Usage",
  CellTags->"Function?"],
Cell[2536, 71, 156, 6, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2717, 81, 36, 0, 40, "ExampleSection"],
Cell[2756, 83, 169, 3, 49, "Input"],
Cell[2928, 88, 57, 0, 25, "Text"],
Cell[2988, 90, 205, 4, 69, "Input"],
Cell[3196, 96, 163, 5, 25, "Text"],
Cell[3362, 103, 198, 4, 62, "Input"],
Cell[3563, 109, 63, 0, 25, "Text"],
Cell[3629, 111, 252, 5, 83, "Input"],
Cell[3884, 118, 74, 0, 25, "Text"],
Cell[3961, 120, 130, 3, 49, "Input"],
Cell[4094, 125, 219, 4, 69, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

